
.. Note this file is autogenerated by scripts/update-plugin-list.py - usually weekly via github action

.. _plugin-list:

Pytest Plugin List
==================

Below is an automated compilation of ``pytest`` plugins available on `PyPI <https://pypi.org>`_.
It includes PyPI projects whose names begin with ``pytest-`` or ``pytest_`` and a handful of manually selected projects.
Packages classified as inactive are excluded.

For detailed insights into how this list is generated,
please refer to `the update script <https://github.com/pytest-dev/pytest/blob/main/scripts/update-plugin-list.py>`_.

.. warning::

   Please be aware that this list is not a curated collection of projects
   and does not undergo a systematic review process.
   It serves purely as an informational resource to aid in the discovery of ``pytest`` plugins.

   Do not presume any endorsement from the ``pytest`` project or its developers,
   and always conduct your own quality assessment before incorporating any of these plugins into your own projects.


.. The following conditional uses a different format for this list when
   creating a PDF, because otherwise the table gets far too wide for the
   page.

This list contains 2004 plugins.

.. only:: not latex

   =======================================================  ======================================================================================================================================================================================================================================================================================================================================================================================  ==============  =====================  ================================================
   name                                                     summary                                                                                                                                                                                                                                                                                                                                                                                 last_release    status                 requires
   =======================================================  ======================================================================================================================================================================================================================================================================================================================================================================================  ==============  =====================  ================================================
   :pypi:`databricks-labs-pytester`                         Python Testing for Databricks                                                                                                                                                                                                                                                                                                                                                           Oct 17, 2025    4 - Beta               pytest>=8.3
   :pypi:`logassert`                                        Simple but powerful assertion and verification of logged lines                                                                                                                                                                                                                                                                                                                          Aug 14, 2025    5 - Production/Stable  pytest; extra == "dev"
   :pypi:`logot`                                            Test whether your code is logging correctly 🪵                                                                                                                                                                                                                                                                                                                                          Mar 31, 2026    5 - Production/Stable  pytest<10,>=7; extra == "pytest"
   :pypi:`nuts`                                             Network Unit Testing System                                                                                                                                                                                                                                                                                                                                                             May 17, 2026    N/A                    pytest>=9.0
   :pypi:`pytest-abort`                                     Pytest plugin + helpers for attributing hard crashes (SIGSEGV/SIGABRT) to the last running test and keeping pytest-html reports mergeable.                                                                                                                                                                                                                                              Feb 11, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-abq`                                       Pytest integration for the ABQ universal test runner.                                                                                                                                                                                                                                                                                                                                   Apr 07, 2023    N/A                    N/A
   :pypi:`pytest-abstracts`                                 A pytest fixture for testing abstract interface implementations                                                                                                                                                                                                                                                                                                                         May 15, 2026    4 - Beta               pytest>=7.4.0
   :pypi:`pytest-accept`                                                                                                                                                                                                                                                                                                                                                                                                                            Mar 01, 2026    N/A                    pytest>=7
   :pypi:`pytest-adaptavist`                                pytest plugin for generating test execution results within Jira Test Management (tm4j)                                                                                                                                                                                                                                                                                                  Oct 13, 2022    N/A                    pytest (>=5.4.0)
   :pypi:`pytest-adaptavist-fixed`                          pytest plugin for generating test execution results within Jira Test Management (tm4j)                                                                                                                                                                                                                                                                                                  Jan 17, 2025    N/A                    pytest>=5.4.0
   :pypi:`pytest-adbc-replay`                               pytest plugin to record and replay ADBC database queries                                                                                                                                                                                                                                                                                                                                Mar 13, 2026    5 - Production/Stable  pytest>=8.0
   :pypi:`pytest-addons-test`                               用于测试pytest的插件                                                                                                                                                                                                                                                                                                                                                                    Aug 02, 2021    N/A                    pytest (>=6.2.4,<7.0.0)
   :pypi:`pytest-adf`                                       Pytest plugin for writing Azure Data Factory integration tests                                                                                                                                                                                                                                                                                                                          May 10, 2021    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-adf-azure-identity`                        Pytest plugin for writing Azure Data Factory integration tests                                                                                                                                                                                                                                                                                                                          Mar 06, 2021    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-adk`                                       Helpers for testing agents with Google's adk-python                                                                                                                                                                                                                                                                                                                                     Jun 06, 2026    1 - Planning           pytest>=8; extra == "dev"
   :pypi:`pytest-ads-testplan`                              Azure DevOps Test Case reporting for pytest tests                                                                                                                                                                                                                                                                                                                                       Sep 15, 2022    N/A                    N/A
   :pypi:`pytest-adversarial`                               Generate adversarial pytest tests using LLM                                                                                                                                                                                                                                                                                                                                             Jan 22, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-affected`                                                                                                                                                                                                                                                                                                                                                                                                                          Nov 06, 2023    N/A                    N/A
   :pypi:`pytest-agent`                                     Service that exposes a REST API that can be used to interract remotely with Pytest. It is shipped with a dashboard that enables running tests in a more convenient way.                                                                                                                                                                                                                 Nov 25, 2021    N/A                    N/A
   :pypi:`pytest-agentcontract`                             Deterministic CI tests for LLM agent trajectories — record once, replay offline, assert contracts                                                                                                                                                                                                                                                                                       Feb 18, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-agent-digest`                              A Pytest plugin to generate a Markdown report for AI Agents                                                                                                                                                                                                                                                                                                                             May 02, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-agent-eval`                                A pytest plugin for LLM evaluation tests with threshold-based pass/fail                                                                                                                                                                                                                                                                                                                 Apr 30, 2026    3 - Alpha              pytest>=7.4
   :pypi:`pytest-agent-evals`                               Pytest plugin for evaluating AI Agents                                                                                                                                                                                                                                                                                                                                                  Mar 13, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-agentharness`                              Open-source test harness for AI agents that take real-world actions.                                                                                                                                                                                                                                                                                                                    Apr 20, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-agent-health`                              Catch silent agent failures in CI. Behavior lint for LLM agents, powered by agent-failure-debugger.                                                                                                                                                                                                                                                                                     Apr 03, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-agentkit`                                  Pytest plugin for testing AI agents — mock LLMs, assert tool calls, track tokens, regression-test prompts.                                                                                                                                                                                                                                                                              May 03, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-agent-observability`                       pytest plugin that uploads LiveKit-agents eval results to agent-observability                                                                                                                                                                                                                                                                                                           Apr 27, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-agentprobe`                                pytest-compatible test harness for AI agents — deterministic record & replay for Anthropic Claude                                                                                                                                                                                                                                                                                       Jun 01, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-agents`                                    Pytest plugin framework with AI agent capabilities for multi-agent testing                                                                                                                                                                                                                                                                                                              Feb 20, 2026    3 - Alpha              pytest>=8.0.0
   :pypi:`pytest-aggreport`                                 pytest plugin for pytest-repeat that generate aggregate report of the same test cases with additional statistics details.                                                                                                                                                                                                                                                               Mar 07, 2021    4 - Beta               pytest (>=6.2.2)
   :pypi:`pytest-ai`                                        A Python package to generate regular, edge-case, and security HTTP tests.                                                                                                                                                                                                                                                                                                               Jan 22, 2025    N/A                    N/A
   :pypi:`pytest-ai1899`                                    pytest plugin for connecting to ai1899 smart system stack                                                                                                                                                                                                                                                                                                                               Mar 13, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-aio`                                       Pytest plugin for testing async python code                                                                                                                                                                                                                                                                                                                                             Feb 12, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-aioboto3`                                  Aioboto3 Pytest with Moto                                                                                                                                                                                                                                                                                                                                                               Jan 17, 2025    N/A                    N/A
   :pypi:`pytest-aiofiles`                                  pytest fixtures for writing aiofiles tests with pyfakefs                                                                                                                                                                                                                                                                                                                                May 14, 2017    5 - Production/Stable  N/A
   :pypi:`pytest-aiogram`                                                                                                                                                                                                                                                                                                                                                                                                                           May 06, 2023    N/A                    N/A
   :pypi:`pytest-aiohttp`                                   Pytest plugin for aiohttp support                                                                                                                                                                                                                                                                                                                                                       Jan 23, 2025    4 - Beta               pytest>=6.1.0
   :pypi:`pytest-aiohttp-client`                            Pytest \`client\` fixture for the Aiohttp                                                                                                                                                                                                                                                                                                                                               Jan 10, 2023    N/A                    pytest (>=7.2.0,<8.0.0)
   :pypi:`pytest-aiohttp-mock`                              Send responses to aiohttp.                                                                                                                                                                                                                                                                                                                                                              Sep 13, 2025    3 - Alpha              pytest>=8
   :pypi:`pytest-aiohutils`                                 Pytest plugin providing fixtures and configuration for aiohutils projects (offline, record, cleanup modes).                                                                                                                                                                                                                                                                             Apr 23, 2026    N/A                    pytest
   :pypi:`pytest-aiomoto`                                   pytest-aiomoto                                                                                                                                                                                                                                                                                                                                                                          Jun 24, 2023    N/A                    pytest (>=7.0,<8.0)
   :pypi:`pytest-aioresponses`                              py.test integration for aioresponses                                                                                                                                                                                                                                                                                                                                                    Jan 02, 2025    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-aioworkers`                                A plugin to test aioworkers project with pytest                                                                                                                                                                                                                                                                                                                                         Dec 26, 2024    5 - Production/Stable  pytest>=8.3.4
   :pypi:`pytest-airflow`                                   pytest support for airflow.                                                                                                                                                                                                                                                                                                                                                             Apr 03, 2019    3 - Alpha              pytest (>=4.4.0)
   :pypi:`pytest-airflow-utils`                                                                                                                                                                                                                                                                                                                                                                                                                     Nov 15, 2021    N/A                    N/A
   :pypi:`pytest-alembic`                                   A pytest plugin for verifying alembic migrations.                                                                                                                                                                                                                                                                                                                                       May 27, 2025    N/A                    pytest>=7.0
   :pypi:`pytest-alerts`                                    A pytest plugin for sending test results to Slack and Telegram                                                                                                                                                                                                                                                                                                                          Feb 21, 2025    4 - Beta               pytest>=7.4.0
   :pypi:`pytest-allclose`                                  Pytest fixture extending Numpy's allclose function                                                                                                                                                                                                                                                                                                                                      Jul 30, 2019    5 - Production/Stable  pytest
   :pypi:`pytest-allure-adaptor`                            Plugin for py.test to generate allure xml reports                                                                                                                                                                                                                                                                                                                                       Jan 10, 2018    N/A                    pytest (>=2.7.3)
   :pypi:`pytest-allure-adaptor2`                           Plugin for py.test to generate allure xml reports                                                                                                                                                                                                                                                                                                                                       Oct 14, 2020    N/A                    pytest (>=2.7.3)
   :pypi:`pytest-allure-collection`                         pytest plugin to collect allure markers without running any tests                                                                                                                                                                                                                                                                                                                       Apr 13, 2023    N/A                    pytest
   :pypi:`pytest-allure-dsl`                                pytest plugin to test case doc string dls instructions                                                                                                                                                                                                                                                                                                                                  Oct 25, 2020    4 - Beta               pytest
   :pypi:`pytest-allure-host`                               Publish Allure static reports to private S3 behind CloudFront with history preservation                                                                                                                                                                                                                                                                                                 Nov 03, 2025    3 - Alpha              N/A
   :pypi:`pytest-allure-id2history`                         Overwrite allure history id with testcase full name and testcase id if testcase has id, exclude parameters.                                                                                                                                                                                                                                                                             May 14, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-allure-intersection`                                                                                                                                                                                                                                                                                                                                                                                                               Oct 27, 2022    N/A                    pytest (<5)
   :pypi:`pytest-allure-spec-coverage`                      The pytest plugin aimed to display test coverage of the specs(requirements) in Allure                                                                                                                                                                                                                                                                                                   Oct 26, 2021    N/A                    pytest
   :pypi:`pytest-allure-step`                               Enhanced logging integration with Allure reports for pytest                                                                                                                                                                                                                                                                                                                             Jul 13, 2025    3 - Alpha              pytest>=6.0.0
   :pypi:`pytest-alphamoon`                                 Static code checks used at Alphamoon                                                                                                                                                                                                                                                                                                                                                    Dec 30, 2021    5 - Production/Stable  pytest (>=3.5.0)
   :pypi:`pytest-amaranth-sim`                              Fixture to automate running Amaranth simulations                                                                                                                                                                                                                                                                                                                                        Feb 18, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-ampel-core`                                A plugin to provide AmpelContext fixtures in pytest                                                                                                                                                                                                                                                                                                                                     Dec 17, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-analyzer`                                  this plugin allows to analyze tests in pytest project, collect test metadata and sync it with testomat.io TCM system                                                                                                                                                                                                                                                                    Feb 21, 2024    N/A                    pytest <8.0.0,>=7.3.1
   :pypi:`pytest-android`                                   This fixture provides a configured "driver" for Android Automated Testing, using uiautomator2.                                                                                                                                                                                                                                                                                          Feb 21, 2019    3 - Alpha              pytest
   :pypi:`pytest-anki`                                      A pytest plugin for testing Anki add-ons                                                                                                                                                                                                                                                                                                                                                Jul 31, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-annotate`                                  pytest-annotate: Generate PyAnnotate annotations from your pytest tests.                                                                                                                                                                                                                                                                                                                Jun 07, 2022    3 - Alpha              pytest (<8.0.0,>=3.2.0)
   :pypi:`pytest-annotated`                                 Pytest plugin to allow use of Annotated in tests to resolve fixtures                                                                                                                                                                                                                                                                                                                    Sep 30, 2024    N/A                    pytest>=8.3.3
   :pypi:`pytest-ansible`                                   Plugin for pytest to simplify calling ansible modules from tests or fixtures                                                                                                                                                                                                                                                                                                            Apr 01, 2026    5 - Production/Stable  pytest>=6
   :pypi:`pytest-ansible-playbook`                          Pytest fixture which runs given ansible playbook file.                                                                                                                                                                                                                                                                                                                                  Mar 08, 2019    4 - Beta               N/A
   :pypi:`pytest-ansible-playbook-runner`                   Pytest fixture which runs given ansible playbook file.                                                                                                                                                                                                                                                                                                                                  Dec 02, 2020    4 - Beta               pytest (>=3.1.0)
   :pypi:`pytest-ansible-units`                             A pytest plugin for running unit tests within an ansible collection                                                                                                                                                                                                                                                                                                                     Apr 14, 2022    N/A                    N/A
   :pypi:`pytest-antilru`                                   Bust functools.lru_cache when running pytest to avoid test pollution                                                                                                                                                                                                                                                                                                                    May 03, 2026    5 - Production/Stable  pytest<9,>=3; python_version == "3.9"
   :pypi:`pytest-anyio`                                     The pytest anyio plugin is built into anyio. You don't need this package.                                                                                                                                                                                                                                                                                                               Jun 29, 2021    N/A                    pytest
   :pypi:`pytest-anything`                                  Pytest fixtures to assert anything and something                                                                                                                                                                                                                                                                                                                                        Jan 18, 2024    N/A                    pytest
   :pypi:`pytest-aoc`                                       Downloads puzzle inputs for Advent of Code and synthesizes PyTest fixtures                                                                                                                                                                                                                                                                                                              Dec 02, 2023    5 - Production/Stable  pytest ; extra == 'test'
   :pypi:`pytest-aoreporter`                                pytest report                                                                                                                                                                                                                                                                                                                                                                           Jun 27, 2022    N/A                    N/A
   :pypi:`pytest-api`                                       An ASGI middleware to populate OpenAPI Specification examples from pytest functions                                                                                                                                                                                                                                                                                                     May 12, 2022    N/A                    pytest (>=7.1.1,<8.0.0)
   :pypi:`pytest-apibean`                                   Pytest plugin providing apibean-based API testing fixtures integrated with apibean-client, designed for testing apibean REST services and datacore backends.                                                                                                                                                                                                                            Dec 30, 2025    N/A                    pytest
   :pypi:`pytest-api-contract`                              pytest plugin for automated API contract testing from OpenAPI specs                                                                                                                                                                                                                                                                                                                     Jun 05, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-api-core`                                  Pytest API automation framework with custom HTML reporting, reusable fixtures, and fluent assertions                                                                                                                                                                                                                                                                                    Jun 01, 2026    5 - Production/Stable  pytest>=7.4
   :pypi:`pytest-api-cov`                                   Pytest Plugin to provide API Coverage statistics for Python Web Frameworks                                                                                                                                                                                                                                                                                                              May 04, 2026    N/A                    pytest>=6.0.0
   :pypi:`pytest-api-coverage`                              Pytest plugin for API test coverage analysis                                                                                                                                                                                                                                                                                                                                            Mar 24, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-api-framework`                             pytest framework                                                                                                                                                                                                                                                                                                                                                                        Jun 22, 2025    N/A                    pytest==7.2.2
   :pypi:`pytest-api-framework-alpha`                                                                                                                                                                                                                                                                                                                                                                                                               Apr 14, 2026    N/A                    pytest==7.2.2
   :pypi:`pytest-api-kit`                                   Pragmatic scaffolding for API smoke / regression tests — zero-dep schema, snapshot drift, HTML reports, AWS ECS deploy.                                                                                                                                                                                                                                                                 Apr 23, 2026    4 - Beta               pytest>=8.0
   :pypi:`pytest-api-soup`                                  Validate multiple endpoints with unit testing using a single source of truth.                                                                                                                                                                                                                                                                                                           Aug 27, 2022    N/A                    N/A
   :pypi:`pytest-apistellar`                                apistellar plugin for pytest.                                                                                                                                                                                                                                                                                                                                                           Jun 18, 2019    N/A                    N/A
   :pypi:`pytest-apiver`                                                                                                                                                                                                                                                                                                                                                                                                                            Jun 21, 2024    N/A                    pytest
   :pypi:`pytest-appengine`                                 AppEngine integration that works well with pytest-django                                                                                                                                                                                                                                                                                                                                Feb 27, 2017    N/A                    N/A
   :pypi:`pytest-appium`                                    Pytest plugin for appium                                                                                                                                                                                                                                                                                                                                                                Dec 05, 2019    N/A                    N/A
   :pypi:`pytest-appium-scheduler`                          Pytest plugin for Appium device scheduling and driver lifecycle management.                                                                                                                                                                                                                                                                                                             Apr 13, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-approval`                                  A simple approval test library utilizing external diff programs such as PyCharm and Visual Studio Code to compare approved and received output.                                                                                                                                                                                                                                         May 05, 2026    N/A                    pytest>=9.0.3
   :pypi:`pytest-approvaltests`                             A plugin to use approvaltests with pytest                                                                                                                                                                                                                                                                                                                                               May 08, 2022    4 - Beta               pytest (>=7.0.1)
   :pypi:`pytest-approvaltests-geo`                         Extension for ApprovalTests.Python specific to geo data verification                                                                                                                                                                                                                                                                                                                    Apr 29, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-archon`                                    Rule your architecture like a real developer                                                                                                                                                                                                                                                                                                                                            Sep 19, 2025    5 - Production/Stable  pytest>=7.2
   :pypi:`pytest-argus`                                     pyest results colection plugin                                                                                                                                                                                                                                                                                                                                                          Jun 24, 2021    5 - Production/Stable  pytest (>=6.2.4)
   :pypi:`pytest-argus-reporter`                            A simple plugin to report results of test into argus                                                                                                                                                                                                                                                                                                                                    May 26, 2026    4 - Beta               pytest~=9.0.0; extra == "dev"
   :pypi:`pytest-argus-server`                              A plugin that provides a running Argus API server for tests                                                                                                                                                                                                                                                                                                                             Mar 05, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-arrakis`                                   Pytest plugin providing Arrakis fixtures for testing                                                                                                                                                                                                                                                                                                                                    Jun 02, 2026    3 - Alpha              pytest
   :pypi:`pytest-arraydiff`                                 pytest plugin to help with comparing array output from tests                                                                                                                                                                                                                                                                                                                            Jun 02, 2026    4 - Beta               pytest>=6.2
   :pypi:`pytest-artifacts`                                 Pytest plugin for managing test artifacts                                                                                                                                                                                                                                                                                                                                               May 14, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-asdf-plugin`                               Pytest plugin for testing ASDF schemas                                                                                                                                                                                                                                                                                                                                                  Jun 04, 2026    5 - Production/Stable  pytest>=7
   :pypi:`pytest-asgi-server`                               Convenient ASGI client/server fixtures for Pytest                                                                                                                                                                                                                                                                                                                                       Dec 12, 2020    N/A                    pytest (>=5.4.1)
   :pypi:`pytest-aspec`                                     A rspec format reporter for pytest                                                                                                                                                                                                                                                                                                                                                      Dec 20, 2023    4 - Beta               N/A
   :pypi:`pytest-asptest`                                   test Answer Set Programming programs                                                                                                                                                                                                                                                                                                                                                    Apr 28, 2018    4 - Beta               N/A
   :pypi:`pytest-assay`                                     Evaluation framework for Pydantic AI agents                                                                                                                                                                                                                                                                                                                                             Mar 30, 2026    4 - Beta               N/A
   :pypi:`pytest-assertcount`                               Plugin to count actual number of asserts in pytest                                                                                                                                                                                                                                                                                                                                      Oct 23, 2022    N/A                    pytest (>=5.0.0)
   :pypi:`pytest-assertions`                                Pytest Assertions                                                                                                                                                                                                                                                                                                                                                                       Apr 27, 2022    N/A                    N/A
   :pypi:`pytest-assert-type`                               Use typing.assert_type() to test runtime behavior                                                                                                                                                                                                                                                                                                                                       Oct 26, 2025    3 - Alpha              pytest>=6.2.0
   :pypi:`pytest-assertutil`                                pytest-assertutil                                                                                                                                                                                                                                                                                                                                                                       May 10, 2019    N/A                    N/A
   :pypi:`pytest-assert-utils`                              Useful assertion utilities for use with pytest                                                                                                                                                                                                                                                                                                                                          Apr 14, 2022    3 - Alpha              N/A
   :pypi:`pytest-assist`                                    pytest plugin library                                                                                                                                                                                                                                                                                                                                                                   Oct 29, 2025    4 - Beta               pytest
   :pypi:`pytest-assume`                                    A pytest plugin that allows multiple failures per test                                                                                                                                                                                                                                                                                                                                  Jun 24, 2021    N/A                    pytest (>=2.7)
   :pypi:`pytest-assurka`                                   A pytest plugin for Assurka Studio                                                                                                                                                                                                                                                                                                                                                      Aug 04, 2022    N/A                    N/A
   :pypi:`pytest-ast-back-to-python`                        A plugin for pytest devs to view how assertion rewriting recodes the AST                                                                                                                                                                                                                                                                                                                Sep 29, 2019    4 - Beta               N/A
   :pypi:`pytest-asteroid`                                  PyTest plugin for docker-based testing on database images                                                                                                                                                                                                                                                                                                                               Aug 15, 2022    N/A                    pytest (>=6.2.5,<8.0.0)
   :pypi:`pytest-astropy`                                   Meta-package containing dependencies for testing                                                                                                                                                                                                                                                                                                                                        Sep 26, 2023    5 - Production/Stable  pytest >=4.6
   :pypi:`pytest-astropy-header`                            pytest plugin to add diagnostic information to the header of the test output                                                                                                                                                                                                                                                                                                            Sep 06, 2022    3 - Alpha              pytest (>=4.6)
   :pypi:`pytest-ast-transformer`                                                                                                                                                                                                                                                                                                                                                                                                                   May 04, 2019    3 - Alpha              pytest
   :pypi:`pytest_async`                                     pytest-async - Run your coroutine in event loop without decorator                                                                                                                                                                                                                                                                                                                       Feb 26, 2020    N/A                    N/A
   :pypi:`pytest-async-benchmark`                           pytest-async-benchmark: Modern pytest benchmarking for async code. 🚀                                                                                                                                                                                                                                                                                                                   May 28, 2025    N/A                    pytest>=8.3.5
   :pypi:`pytest-async-generators`                          Pytest fixtures for async generators                                                                                                                                                                                                                                                                                                                                                    Jul 05, 2023    N/A                    N/A
   :pypi:`pytest-asyncio`                                   Pytest support for asyncio                                                                                                                                                                                                                                                                                                                                                              May 26, 2026    5 - Production/Stable  pytest<10,>=8.4
   :pypi:`pytest-asyncio-concurrent`                        Pytest plugin to execute python async tests concurrently.                                                                                                                                                                                                                                                                                                                               Apr 09, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-asyncio-cooperative`                       Run all your asynchronous tests cooperatively.                                                                                                                                                                                                                                                                                                                                          Jun 24, 2025    N/A                    N/A
   :pypi:`pytest-asyncio-network-simulator`                 pytest-asyncio-network-simulator: Plugin for pytest for simulator the network in tests                                                                                                                                                                                                                                                                                                  Jul 31, 2018    3 - Alpha              pytest (<3.7.0,>=3.3.2)
   :pypi:`pytest-async-mongodb`                             pytest plugin for async MongoDB                                                                                                                                                                                                                                                                                                                                                         Oct 18, 2017    5 - Production/Stable  pytest (>=2.5.2)
   :pypi:`pytest-async-sqlalchemy`                          Database testing fixtures using the SQLAlchemy asyncio API                                                                                                                                                                                                                                                                                                                              Oct 07, 2021    4 - Beta               pytest (>=6.0.0)
   :pypi:`pytest-atf-allure`                                基于allure-pytest进行自定义                                                                                                                                                                                                                                                                                                                                                             Nov 29, 2023    N/A                    pytest (>=7.4.2,<8.0.0)
   :pypi:`pytest-atomic`                                    Skip rest of tests if previous test failed.                                                                                                                                                                                                                                                                                                                                             Nov 24, 2018    4 - Beta               N/A
   :pypi:`pytest-atstack`                                   A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Jan 02, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-attempt-summary`                           Enhanced Allure Attempt Summary for Playwright + Pytest                                                                                                                                                                                                                                                                                                                                 Jan 04, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-attrib`                                    pytest plugin to select tests based on attributes similar to the nose-attrib plugin                                                                                                                                                                                                                                                                                                     May 24, 2016    4 - Beta               N/A
   :pypi:`pytest-attributes`                                A plugin that allows users to add attributes to their tests. These attributes can then be referenced by fixtures or the test itself.                                                                                                                                                                                                                                                    Jun 24, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-audioeval`                                 Pytest plugin for STT/TTS integration testing with httpx, metrics, and embedded audio samples.                                                                                                                                                                                                                                                                                          Mar 18, 2026    4 - Beta               pytest>=8.0
   :pypi:`pytest-austin`                                    Austin plugin for pytest                                                                                                                                                                                                                                                                                                                                                                Oct 11, 2020    4 - Beta               N/A
   :pypi:`pytest-auto-api2-cli`                             CLI for generating and running pytest-auto-api2 test cases.                                                                                                                                                                                                                                                                                                                             Mar 26, 2026    N/A                    pytest==8.4.1
   :pypi:`pytest-autocap`                                   automatically capture test & fixture stdout/stderr to files                                                                                                                                                                                                                                                                                                                             May 15, 2022    N/A                    pytest (<7.2,>=7.1.2)
   :pypi:`pytest-autochecklog`                              automatically check condition and log all the checks                                                                                                                                                                                                                                                                                                                                    Apr 25, 2015    4 - Beta               N/A
   :pypi:`pytest-autofixture`                               simplify pytest fixtures                                                                                                                                                                                                                                                                                                                                                                Aug 01, 2024    N/A                    pytest>=8
   :pypi:`pytest-autofocus`                                 Auto-focus plugin: run only @pytest.mark.focus tests when --auto-focus is set                                                                                                                                                                                                                                                                                                           Dec 02, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-automation`                                pytest plugin for building a test suite, using YAML files to extend pytest parameterize functionality.                                                                                                                                                                                                                                                                                  Apr 24, 2024    N/A                    pytest>=7.0.0
   :pypi:`pytest-automock`                                  Pytest plugin for automatical mocks creation                                                                                                                                                                                                                                                                                                                                            May 16, 2023    N/A                    pytest ; extra == 'dev'
   :pypi:`pytest-auto-parametrize`                          pytest plugin: avoid repeating arguments in parametrize                                                                                                                                                                                                                                                                                                                                 Oct 02, 2016    3 - Alpha              N/A
   :pypi:`pytest-autoprofile`                               \`line_profiler.autoprofile\`-ing your \`pytest\` test suite                                                                                                                                                                                                                                                                                                                            Mar 13, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-autotest`                                  This fixture provides a configured "driver" for Android Automated Testing, using uiautomator2.                                                                                                                                                                                                                                                                                          Aug 25, 2021    N/A                    pytest
   :pypi:`pytest-aviator`                                   Aviator's Flakybot pytest plugin that automatically reruns flaky tests.                                                                                                                                                                                                                                                                                                                 Nov 04, 2022    4 - Beta               pytest
   :pypi:`pytest-avoidance`                                 Makes pytest skip tests that don not need rerunning                                                                                                                                                                                                                                                                                                                                     May 23, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-awaiting-fix`                              A simple plugin to use with pytest for traceability across Jira and disabled automated tests                                                                                                                                                                                                                                                                                            Aug 09, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-aws`                                       pytest plugin for testing AWS resource configurations                                                                                                                                                                                                                                                                                                                                   Oct 04, 2017    4 - Beta               N/A
   :pypi:`pytest-aws-apigateway`                            pytest plugin for AWS ApiGateway                                                                                                                                                                                                                                                                                                                                                        May 24, 2024    4 - Beta               pytest
   :pypi:`pytest-aws-config`                                Protect your AWS credentials in unit tests                                                                                                                                                                                                                                                                                                                                              May 28, 2021    N/A                    N/A
   :pypi:`pytest-aws-fixtures`                              A series of fixtures to use in integration tests involving actual AWS services.                                                                                                                                                                                                                                                                                                         Nov 11, 2025    N/A                    pytest<10.0.0,>=8.0.0
   :pypi:`pytest-aws-fixtures-293984`                       AWS configuration utilities for Python applications                                                                                                                                                                                                                                                                                                                                     Dec 04, 2025    3 - Alpha              N/A
   :pypi:`pytest-axe`                                       pytest plugin for axe-selenium-python                                                                                                                                                                                                                                                                                                                                                   Nov 12, 2018    N/A                    pytest (>=3.0.0)
   :pypi:`pytest-axe-playwright-snapshot`                   A pytest plugin that runs Axe-core on Playwright pages and takes snapshots of the results.                                                                                                                                                                                                                                                                                              Jul 25, 2023    N/A                    pytest
   :pypi:`pytest-azure`                                     Pytest utilities and mocks for Azure                                                                                                                                                                                                                                                                                                                                                    Jan 18, 2023    3 - Alpha              pytest
   :pypi:`pytest-azure-devops`                              Simplifies using azure devops parallel strategy (https://docs.microsoft.com/en-us/azure/devops/pipelines/test/parallel-testing-any-test-runner) with pytest.                                                                                                                                                                                                                            Jul 16, 2025    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-azurepipelines`                            Formatting PyTest output for Azure Pipelines UI                                                                                                                                                                                                                                                                                                                                         Oct 06, 2023    5 - Production/Stable  pytest (>=5.0.0)
   :pypi:`pytest-balance`                                   Intelligent test distribution for pytest based on actual execution times, not file count                                                                                                                                                                                                                                                                                                Apr 09, 2026    3 - Alpha              pytest>=8
   :pypi:`pytest-bandit`                                    A bandit plugin for pytest                                                                                                                                                                                                                                                                                                                                                              Feb 23, 2021    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-bandit-xayon`                              A bandit plugin for pytest                                                                                                                                                                                                                                                                                                                                                              Oct 17, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-base-url`                                  pytest plugin for URL based testing                                                                                                                                                                                                                                                                                                                                                     Jan 31, 2024    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-bashdoctest`                               A pytest plugin for testing bash command examples in markdown documentation                                                                                                                                                                                                                                                                                                             Oct 03, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-batch-regression`                          A pytest plugin to repeat the entire test suite in batches.                                                                                                                                                                                                                                                                                                                             May 08, 2024    N/A                    pytest>=6.0.0
   :pypi:`pytest-bazel`                                     A pytest runner with bazel support                                                                                                                                                                                                                                                                                                                                                      Oct 31, 2025    4 - Beta               pytest
   :pypi:`pytest-bdd`                                       BDD for pytest                                                                                                                                                                                                                                                                                                                                                                          Dec 05, 2024    6 - Mature             pytest>=7.0.0
   :pypi:`pytest-bdd-html`                                  pytest plugin to display BDD info in HTML test report                                                                                                                                                                                                                                                                                                                                   Nov 22, 2022    3 - Alpha              pytest (!=6.0.0,>=5.0)
   :pypi:`pytest-bdd-md-report`                             Markdown test report formatter for pytest-bdd with pytest-playwright screenshot support                                                                                                                                                                                                                                                                                                 Feb 07, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-bdd-ng`                                    BDD for pytest                                                                                                                                                                                                                                                                                                                                                                          Nov 26, 2024    4 - Beta               pytest>=5.2
   :pypi:`pytest-bdd-property`                              Property-based testing plugin for pytest-bdd — express universal invariants in standard Gherkin, executed by Hypothesis                                                                                                                                                                                                                                                                 Mar 12, 2026    3 - Alpha              pytest>=8.0
   :pypi:`pytest-bdd-report`                                A pytest-bdd plugin for generating useful and informative BDD test reports                                                                                                                                                                                                                                                                                                              Dec 29, 2025    N/A                    pytest>=7.1.3
   :pypi:`pytest-bdd-reporter`                              Enterprise-grade BDD test reporting with interactive dashboards, suite management, and comprehensive email integration                                                                                                                                                                                                                                                                  Oct 14, 2025    5 - Production/Stable  pytest>=6.0.0
   :pypi:`pytest-bdd-splinter`                              Common steps for pytest bdd and splinter integration                                                                                                                                                                                                                                                                                                                                    Aug 12, 2019    5 - Production/Stable  pytest (>=4.0.0)
   :pypi:`pytest-bdd-web`                                   A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Jan 02, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-bdd-wrappers`                                                                                                                                                                                                                                                                                                                                                                                                                      Feb 11, 2020    2 - Pre-Alpha          N/A
   :pypi:`pytest-beacon`                                    Highly customizable pytest reporting plugin combining AI-optimized CTRF reports and rich test metrics                                                                                                                                                                                                                                                                                   May 11, 2026    3 - Alpha              pytest>=9.0.0
   :pypi:`pytest-beakerlib`                                 A pytest plugin that reports test results to the BeakerLib framework                                                                                                                                                                                                                                                                                                                    Mar 17, 2017    5 - Production/Stable  pytest
   :pypi:`pytest-beartype`                                  Pytest plugin to run your tests with beartype checking enabled.                                                                                                                                                                                                                                                                                                                         Oct 31, 2024    N/A                    pytest
   :pypi:`pytest-beartype-tests`                            Pytest plugin that applies @beartype to every collected test function.                                                                                                                                                                                                                                                                                                                  Apr 26, 2026    4 - Beta               pytest>=8
   :pypi:`pytest-bec-e2e`                                   BEC pytest plugin for end-to-end tests                                                                                                                                                                                                                                                                                                                                                  Jun 05, 2026    3 - Alpha              pytest
   :pypi:`pytest-beds`                                      Fixtures for testing Google Appengine (GAE) apps                                                                                                                                                                                                                                                                                                                                        Jun 07, 2016    4 - Beta               N/A
   :pypi:`pytest-beehave`                                   A pytest plugin that generates test stubs from Gherkin feature files, checks consistency, and displays BDD steps in pytest output                                                                                                                                                                                                                                                       May 20, 2026    5 - Production/Stable  pytest>=9.0.3; extra == "dev"
   :pypi:`pytest-beeprint`                                  use icdiff for better error messages in pytest assertions                                                                                                                                                                                                                                                                                                                               Jul 04, 2023    4 - Beta               N/A
   :pypi:`pytest-bench`                                     Benchmark utility that plugs into pytest.                                                                                                                                                                                                                                                                                                                                               Jul 21, 2014    3 - Alpha              N/A
   :pypi:`pytest-benchmark`                                 A \`\`pytest\`\` fixture for benchmarking code. It will group the tests into rounds that are calibrated to the chosen timer.                                                                                                                                                                                                                                                            Nov 09, 2025    5 - Production/Stable  pytest>=8.1
   :pypi:`pytest-better-datadir`                            A small example package                                                                                                                                                                                                                                                                                                                                                                 Mar 13, 2023    N/A                    N/A
   :pypi:`pytest-better-parametrize`                        Better description of parametrized test cases                                                                                                                                                                                                                                                                                                                                           Mar 05, 2024    4 - Beta               pytest >=6.2.0
   :pypi:`pytest-bg-process`                                Pytest plugin to initialize background process                                                                                                                                                                                                                                                                                                                                          Jan 24, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-bigchaindb`                                A BigchainDB plugin for pytest.                                                                                                                                                                                                                                                                                                                                                         Jan 24, 2022    4 - Beta               N/A
   :pypi:`pytest-bigquery-mock`                             Provides a mock fixture for python bigquery client                                                                                                                                                                                                                                                                                                                                      Dec 28, 2022    N/A                    pytest (>=5.0)
   :pypi:`pytest-bisect-tests`                              Find tests leaking state and affecting other                                                                                                                                                                                                                                                                                                                                            Jun 09, 2024    N/A                    N/A
   :pypi:`pytest-black`                                     A pytest plugin to enable format checking with black                                                                                                                                                                                                                                                                                                                                    Dec 15, 2024    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-black-multipy`                             Allow '--black' on older Pythons                                                                                                                                                                                                                                                                                                                                                        Jan 14, 2021    5 - Production/Stable  pytest (!=3.7.3,>=3.5) ; extra == 'testing'
   :pypi:`pytest-black-ng`                                  A pytest plugin to enable format checking with black                                                                                                                                                                                                                                                                                                                                    Oct 20, 2022    4 - Beta               pytest (>=7.0.0)
   :pypi:`pytest-blame`                                     A pytest plugin helps developers to debug by providing useful commits history.                                                                                                                                                                                                                                                                                                          May 04, 2019    N/A                    pytest (>=4.4.0)
   :pypi:`pytest-blender`                                   Blender Pytest plugin.                                                                                                                                                                                                                                                                                                                                                                  Apr 18, 2026    N/A                    pytest
   :pypi:`pytest-blink1`                                    Pytest plugin to emit notifications via the Blink(1) RGB LED                                                                                                                                                                                                                                                                                                                            Jan 07, 2018    4 - Beta               N/A
   :pypi:`pytest-blockage`                                  Disable network requests during a test run.                                                                                                                                                                                                                                                                                                                                             Dec 21, 2021    N/A                    pytest
   :pypi:`pytest-blocker`                                   pytest plugin to mark a test as blocker and skip all other tests                                                                                                                                                                                                                                                                                                                        Sep 07, 2015    4 - Beta               N/A
   :pypi:`pytest-b-logger`                                  BLogger is a Pytest plugin for enhanced test logging and generating convenient and lightweight reports.                                                                                                                                                                                                                                                                                 Dec 16, 2025    N/A                    pytest
   :pypi:`pytest-blue`                                      A pytest plugin that adds a \`blue\` fixture for printing stuff in blue.                                                                                                                                                                                                                                                                                                                Sep 05, 2022    N/A                    N/A
   :pypi:`pytest-bluezenv`                                  pytest BlueZ environment plugin                                                                                                                                                                                                                                                                                                                                                         May 12, 2026    3 - Alpha              pytest>=8
   :pypi:`pytest-board`                                     Local continuous test runner with pytest and watchdog.                                                                                                                                                                                                                                                                                                                                  Jan 20, 2019    N/A                    N/A
   :pypi:`pytest_boardfarm3`                                Integrate boardfarm as a pytest plugin.                                                                                                                                                                                                                                                                                                                                                 May 13, 2026    N/A                    pytest
   :pypi:`pytest-bods-v04-fixtures`                         Pytest plugin providing a parametrized fixture over the canonical BODS v0.4 fixtures pack                                                                                                                                                                                                                                                                                               Apr 20, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-boilerplate`                               The pytest plugin for your Django Boilerplate.                                                                                                                                                                                                                                                                                                                                          Sep 12, 2024    5 - Production/Stable  pytest>=4.0.0
   :pypi:`pytest-bonsai`                                                                                                                                                                                                                                                                                                                                                                                                                            Apr 08, 2025    N/A                    pytest>=6
   :pypi:`pytest-boost-xml`                                 Plugin for pytest to generate boost xml reports                                                                                                                                                                                                                                                                                                                                         Nov 30, 2022    4 - Beta               N/A
   :pypi:`pytest-bootstrap`                                                                                                                                                                                                                                                                                                                                                                                                                         Mar 04, 2022    N/A                    N/A
   :pypi:`pytest-boto-mock`                                 Thin-wrapper around the mock package for easier use with pytest                                                                                                                                                                                                                                                                                                                         Jan 20, 2026    5 - Production/Stable  pytest>=8.2.0
   :pypi:`pytest-bpdb`                                      A py.test plug-in to enable drop to bpdb debugger on test failure.                                                                                                                                                                                                                                                                                                                      Jan 19, 2015    2 - Pre-Alpha          N/A
   :pypi:`pytest-bq`                                        BigQuery fixtures and fixture factories for Pytest.                                                                                                                                                                                                                                                                                                                                     May 08, 2024    5 - Production/Stable  pytest>=6.2
   :pypi:`pytest-bravado`                                   Pytest-bravado automatically generates from OpenAPI specification client fixtures.                                                                                                                                                                                                                                                                                                      Feb 15, 2022    N/A                    N/A
   :pypi:`pytest-breadcrumb`                                Self-healing test framework for Playwright. Your tests survive app changes.                                                                                                                                                                                                                                                                                                             Mar 09, 2026    2 - Pre-Alpha          pytest>=8.0; extra == "dev"
   :pypi:`pytest-breakword`                                 Use breakword with pytest                                                                                                                                                                                                                                                                                                                                                               Aug 04, 2021    N/A                    pytest (>=6.2.4,<7.0.0)
   :pypi:`pytest-breed-adapter`                             A simple plugin to connect with breed-server                                                                                                                                                                                                                                                                                                                                            Nov 07, 2018    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-briefcase`                                 A pytest plugin for running tests on a Briefcase project.                                                                                                                                                                                                                                                                                                                               Jun 14, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-brightest`                                 Bright ideas for improving your pytest experience                                                                                                                                                                                                                                                                                                                                       Jul 15, 2025    3 - Alpha              pytest>=8.4.1
   :pypi:`pytest-broadcaster`                               Pytest plugin to broadcast pytest output to various destinations                                                                                                                                                                                                                                                                                                                        Mar 02, 2025    3 - Alpha              pytest
   :pypi:`pytest-browser`                                   A pytest plugin for console based browser test selection just after the collection phase                                                                                                                                                                                                                                                                                                Dec 10, 2016    3 - Alpha              N/A
   :pypi:`pytest-browsermob-proxy`                          BrowserMob proxy plugin for py.test.                                                                                                                                                                                                                                                                                                                                                    Jun 11, 2013    4 - Beta               N/A
   :pypi:`pytest_browserstack`                              Py.test plugin for BrowserStack                                                                                                                                                                                                                                                                                                                                                         Jan 27, 2016    4 - Beta               N/A
   :pypi:`pytest-browserstack-local`                        \`\`py.test\`\` plugin to run \`\`BrowserStackLocal\`\` in background.                                                                                                                                                                                                                                                                                                                  Feb 09, 2018    N/A                    N/A
   :pypi:`pytest-budosystems`                               Budo Systems is a martial arts school management system. This module is the Budo Systems Pytest Plugin.                                                                                                                                                                                                                                                                                 May 07, 2023    3 - Alpha              pytest
   :pypi:`pytest-bug`                                       Pytest plugin for marking tests as a bug                                                                                                                                                                                                                                                                                                                                                Dec 30, 2025    5 - Production/Stable  pytest>=9.0.0
   :pypi:`pytest-bugtong-tag`                               pytest-bugtong-tag is a plugin for pytest                                                                                                                                                                                                                                                                                                                                               Jan 16, 2022    N/A                    N/A
   :pypi:`pytest-bugzilla`                                  py.test bugzilla integration plugin                                                                                                                                                                                                                                                                                                                                                     May 05, 2010    4 - Beta               N/A
   :pypi:`pytest-bugzilla-notifier`                         A plugin that allows you to execute create, update, and read information from BugZilla bugs                                                                                                                                                                                                                                                                                             Jun 15, 2018    4 - Beta               pytest (>=2.9.2)
   :pypi:`pytest-buildkite`                                 Plugin for pytest that automatically publishes coverage and pytest report annotations to Buildkite.                                                                                                                                                                                                                                                                                     Jul 13, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-builtin-types`                                                                                                                                                                                                                                                                                                                                                                                                                     Nov 17, 2021    N/A                    pytest
   :pypi:`pytest-bwrap`                                     Run your tests in Bubblewrap sandboxes                                                                                                                                                                                                                                                                                                                                                  Feb 25, 2024    3 - Alpha              N/A
   :pypi:`pytest-cache`                                     pytest plugin with mechanisms for caching across test runs                                                                                                                                                                                                                                                                                                                              Jun 04, 2013    3 - Alpha              N/A
   :pypi:`pytest-cache-assert`                              Cache assertion data to simplify regression testing of complex serializable data                                                                                                                                                                                                                                                                                                        Aug 14, 2023    5 - Production/Stable  pytest (>=6.0.0)
   :pypi:`pytest-cagoule`                                   Pytest plugin to only run tests affected by changes                                                                                                                                                                                                                                                                                                                                     Jan 01, 2020    3 - Alpha              N/A
   :pypi:`pytest-cairo`                                     Pytest support for cairo-lang and starknet                                                                                                                                                                                                                                                                                                                                              Apr 17, 2022    N/A                    pytest
   :pypi:`pytest-call-checker`                              Small pytest utility to easily create test doubles                                                                                                                                                                                                                                                                                                                                      Oct 16, 2022    4 - Beta               pytest (>=7.1.3,<8.0.0)
   :pypi:`pytest-camel-collect`                             Enable CamelCase-aware pytest class collection                                                                                                                                                                                                                                                                                                                                          Aug 02, 2020    N/A                    pytest (>=2.9)
   :pypi:`pytest-canonical-data`                            A plugin which allows to compare results with canonical results, based on previous runs                                                                                                                                                                                                                                                                                                 May 08, 2020    2 - Pre-Alpha          pytest (>=3.5.0)
   :pypi:`pytest-canvas`                                    A minimal pytest plugin that streamlines testing for projects using the Canvas SDK.                                                                                                                                                                                                                                                                                                     Jul 22, 2025    N/A                    pytest<9,>=8.4
   :pypi:`pytest-capquery`                                  A pytest fixture for high-precision SQL testing in SQLAlchemy.                                                                                                                                                                                                                                                                                                                          Apr 04, 2026    N/A                    pytest
   :pypi:`pytest-caprng`                                    A plugin that replays pRNG state on failure.                                                                                                                                                                                                                                                                                                                                            May 02, 2018    4 - Beta               N/A
   :pypi:`pytest-capsqlalchemy`                             Pytest plugin to allow capturing SQLAlchemy queries.                                                                                                                                                                                                                                                                                                                                    Mar 19, 2025    4 - Beta               N/A
   :pypi:`pytest-capture-deprecatedwarnings`                pytest plugin to capture all deprecatedwarnings and put them in one file                                                                                                                                                                                                                                                                                                                Apr 30, 2019    N/A                    N/A
   :pypi:`pytest-capture-warnings`                          pytest plugin to capture all warnings and put them in one file of your choice                                                                                                                                                                                                                                                                                                           May 03, 2022    N/A                    pytest
   :pypi:`pytest-case`                                      A clean, modern, wrapper for pytest.mark.parametrize                                                                                                                                                                                                                                                                                                                                    Nov 25, 2024    N/A                    pytest<9.0.0,>=8.3.3
   :pypi:`pytest-case-provider`                             Advanced pytest parametrization plugin that generates test case instances from sync or async factories.                                                                                                                                                                                                                                                                                 Dec 15, 2025    3 - Alpha              pytest>=8
   :pypi:`pytest-cases`                                     Separate test code from test cases in pytest.                                                                                                                                                                                                                                                                                                                                           Mar 02, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-case-start-from`                           A pytest plugin to start test execution from a specific test case                                                                                                                                                                                                                                                                                                                       Oct 28, 2025    4 - Beta               pytest>=6.0.0
   :pypi:`pytest-casewise-package-install`                  A pytest plugin for test case-level dynamic dependency management                                                                                                                                                                                                                                                                                                                       Oct 31, 2025    3 - Alpha              pytest>=6.0.0
   :pypi:`pytest-cassandra`                                 Cassandra CCM Test Fixtures for pytest                                                                                                                                                                                                                                                                                                                                                  Nov 04, 2017    1 - Planning           N/A
   :pypi:`pytest-catchlog`                                  py.test plugin to catch log messages. This is a fork of pytest-capturelog.                                                                                                                                                                                                                                                                                                              Jan 24, 2016    4 - Beta               pytest (>=2.6)
   :pypi:`pytest-catch-server`                              Pytest plugin with server for catching HTTP requests.                                                                                                                                                                                                                                                                                                                                   Dec 12, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-cdist`                                     A pytest plugin to split your test suite into multiple parts                                                                                                                                                                                                                                                                                                                            Jan 08, 2026    N/A                    pytest>=8
   :pypi:`pytest-celery`                                    Pytest plugin for Celery                                                                                                                                                                                                                                                                                                                                                                Mar 02, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-celery-py37`                               Pytest plugin for Celery (compatible with python 3.7)                                                                                                                                                                                                                                                                                                                                   May 23, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-celery-utils`                              Pytest plugin for inspecting Celery task queues in Redis during tests                                                                                                                                                                                                                                                                                                                   Jan 28, 2026    N/A                    pytest>=9.0.1
   :pypi:`pytest-cfg-fetcher`                               Pass config options to your unit tests.                                                                                                                                                                                                                                                                                                                                                 Feb 26, 2024    N/A                    N/A
   :pypi:`pytest-chainmaker`                                pytest plugin for chainmaker                                                                                                                                                                                                                                                                                                                                                            Oct 15, 2021    N/A                    N/A
   :pypi:`pytest-chalice`                                   A set of py.test fixtures for AWS Chalice                                                                                                                                                                                                                                                                                                                                               Jul 01, 2020    4 - Beta               N/A
   :pypi:`pytest-change-assert`                             修改报错中文为英文                                                                                                                                                                                                                                                                                                                                                                      Oct 19, 2022    N/A                    N/A
   :pypi:`pytest-changed`                                   Run pytest for tests related to staged Python files in pre-commit.                                                                                                                                                                                                                                                                                                                      May 28, 2026    3 - Alpha              pytest>=8.0
   :pypi:`pytest-change-demo`                               turn . into √，turn F into x                                                                                                                                                                                                                                                                                                                                                            Mar 02, 2022    N/A                    pytest
   :pypi:`pytest-change-report`                             turn . into √，turn F into x                                                                                                                                                                                                                                                                                                                                                            Sep 14, 2020    N/A                    pytest
   :pypi:`pytest-change-xds`                                turn . into √，turn F into x                                                                                                                                                                                                                                                                                                                                                            Apr 16, 2022    N/A                    pytest
   :pypi:`pytest-chdir`                                     A pytest fixture for changing current working directory                                                                                                                                                                                                                                                                                                                                 Jan 28, 2020    N/A                    pytest (>=5.0.0,<6.0.0)
   :pypi:`pytest-check`                                     A pytest plugin that allows multiple failures per test.                                                                                                                                                                                                                                                                                                                                 Mar 22, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-checkdocs`                                 check the README when running tests                                                                                                                                                                                                                                                                                                                                                     Dec 26, 2025    5 - Production/Stable  pytest!=8.1.*,>=6; extra == "test"
   :pypi:`pytest-checkers`                                  Pytest Plugin for dry-run checks LSPs, Type Checkers, Linters, and Formatters during testing                                                                                                                                                                                                                                                                                            Dec 27, 2025    N/A                    pytest>=9.0.2
   :pypi:`pytest-checkipdb`                                 plugin to check if there are ipdb debugs left                                                                                                                                                                                                                                                                                                                                           Dec 04, 2023    5 - Production/Stable  pytest >=2.9.2
   :pypi:`pytest-check-library`                             check your missing library                                                                                                                                                                                                                                                                                                                                                              Jul 17, 2022    N/A                    N/A
   :pypi:`pytest-check-libs`                                check your missing library                                                                                                                                                                                                                                                                                                                                                              Jul 17, 2022    N/A                    N/A
   :pypi:`pytest-check-links`                               Check links in files                                                                                                                                                                                                                                                                                                                                                                    Jul 29, 2020    N/A                    pytest<9,>=7.0
   :pypi:`pytest-checklist`                                 Pytest plugin to track and report unit/function coverage.                                                                                                                                                                                                                                                                                                                               May 23, 2025    N/A                    N/A
   :pypi:`pytest-check-mk`                                  pytest plugin to test Check_MK checks                                                                                                                                                                                                                                                                                                                                                   Nov 19, 2015    4 - Beta               pytest
   :pypi:`pytest-checkpoint`                                Restore a checkpoint in pytest                                                                                                                                                                                                                                                                                                                                                          Oct 04, 2025    N/A                    pytest>=8.0.0
   :pypi:`pytest-ch-framework`                              My pytest framework                                                                                                                                                                                                                                                                                                                                                                     Apr 17, 2024    N/A                    pytest==8.0.1
   :pypi:`pytest-chic-report`                               Simple pytest plugin for generating and sending report to messengers.                                                                                                                                                                                                                                                                                                                   Nov 01, 2024    N/A                    pytest>=6.0
   :pypi:`pytest-chinesereport`                                                                                                                                                                                                                                                                                                                                                                                                                     Apr 16, 2025    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-choose`                                    Provide the pytest with the ability to collect use cases based on rules in text files                                                                                                                                                                                                                                                                                                   Feb 04, 2024    N/A                    pytest >=7.0.0
   :pypi:`pytest-chronicle`                                 Reusable pytest results ingestion tooling with database export and CLI helpers.                                                                                                                                                                                                                                                                                                         Dec 15, 2025    N/A                    pytest>=8.0; extra == "dev"
   :pypi:`pytest-chunks`                                    Run only a chunk of your test suite                                                                                                                                                                                                                                                                                                                                                     Jul 05, 2022    N/A                    pytest (>=6.0.0)
   :pypi:`pytest_cid`                                       Compare data structures containing matching CIDs of different versions and encoding                                                                                                                                                                                                                                                                                                     Sep 01, 2023    4 - Beta               pytest >= 5.0, < 7.0
   :pypi:`pytest-circleci`                                  py.test plugin for CircleCI                                                                                                                                                                                                                                                                                                                                                             May 03, 2019    N/A                    N/A
   :pypi:`pytest-circleci-parallelized`                     Parallelize pytest across CircleCI workers.                                                                                                                                                                                                                                                                                                                                             Oct 20, 2022    N/A                    N/A
   :pypi:`pytest-circleci-parallelized-rjp`                 Parallelize pytest across CircleCI workers.                                                                                                                                                                                                                                                                                                                                             Jun 21, 2022    N/A                    pytest
   :pypi:`pytest-ckan`                                      Backport of CKAN 2.9 pytest plugin and fixtures to CAKN 2.8                                                                                                                                                                                                                                                                                                                             Apr 28, 2020    4 - Beta               pytest
   :pypi:`pytest-clab`                                      A pytest plugin for managing containerlab topologies in tests.                                                                                                                                                                                                                                                                                                                          Mar 02, 2026    N/A                    pytest>=9.0.2
   :pypi:`pytest-clang-tidy`                                A pytest plugin that runs clang-tidy static analysis on C/C++ source files                                                                                                                                                                                                                                                                                                              Mar 27, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-clarity`                                   A plugin providing an alternative, colourful diff output for failing assertions.                                                                                                                                                                                                                                                                                                        Jun 11, 2021    N/A                    N/A
   :pypi:`pytest-class-fixtures`                            Class as PyTest fixtures (and BDD steps)                                                                                                                                                                                                                                                                                                                                                Nov 15, 2024    N/A                    pytest<9.0.0,>=8.3.3
   :pypi:`pytest-claude-agent-sdk`                          Use Claude Code in your pytests, or pytest your own Claude Code agents — or both                                                                                                                                                                                                                                                                                                        Jan 19, 2026    3 - Alpha              pytest>=6.0
   :pypi:`pytest-cldf`                                      Easy quality control for CLDF datasets using pytest                                                                                                                                                                                                                                                                                                                                     Nov 07, 2022    N/A                    pytest (>=3.6)
   :pypi:`pytest-clean-database`                            A pytest plugin that cleans your database up after every test.                                                                                                                                                                                                                                                                                                                          Mar 14, 2025    3 - Alpha              pytest<9,>=7.0
   :pypi:`pytest-cleanslate`                                Collects and executes pytest tests separately                                                                                                                                                                                                                                                                                                                                           Apr 10, 2025    N/A                    pytest
   :pypi:`pytest_cleanup`                                   Automated, comprehensive and well-organised pytest test cases.                                                                                                                                                                                                                                                                                                                          Jan 28, 2020    N/A                    N/A
   :pypi:`pytest-cleanuptotal`                              A cleanup plugin for pytest                                                                                                                                                                                                                                                                                                                                                             Jul 22, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-clerk`                                     A set of pytest fixtures to help with integration testing with Clerk.                                                                                                                                                                                                                                                                                                                   Feb 04, 2026    N/A                    pytest<10.0.0,>=8.0.0
   :pypi:`pytest-clerk-mock`                                A pytest plugin for mocking Clerk authentication                                                                                                                                                                                                                                                                                                                                        Apr 01, 2026    N/A                    N/A
   :pypi:`pytest-cli2-ansible`                                                                                                                                                                                                                                                                                                                                                                                                                      Mar 05, 2025    N/A                    N/A
   :pypi:`pytest-click`                                     Pytest plugin for Click                                                                                                                                                                                                                                                                                                                                                                 Feb 11, 2022    5 - Production/Stable  pytest (>=5.0)
   :pypi:`pytest-clickhouse-mock`                           Pytest fixtures that mock clickhouse-driver Client for unit tests.                                                                                                                                                                                                                                                                                                                      May 29, 2026    4 - Beta               pytest>=8.0
   :pypi:`pytest-cli-fixtures`                              Automatically register fixtures for custom CLI arguments                                                                                                                                                                                                                                                                                                                                Jul 28, 2022    N/A                    pytest (~=7.0)
   :pypi:`pytest-clld`                                                                                                                                                                                                                                                                                                                                                                                                                              Oct 23, 2024    N/A                    pytest>=3.9
   :pypi:`pytest-cloud`                                     Distributed tests planner plugin for pytest testing framework.                                                                                                                                                                                                                                                                                                                          Oct 05, 2020    6 - Mature             N/A
   :pypi:`pytest-cloudflare-worker`                         pytest plugin for testing cloudflare workers                                                                                                                                                                                                                                                                                                                                            Mar 30, 2021    4 - Beta               pytest (>=6.0.0)
   :pypi:`pytest-cloudist`                                  Distribute tests to cloud machines without fuss                                                                                                                                                                                                                                                                                                                                         Sep 02, 2022    4 - Beta               pytest (>=7.1.2,<8.0.0)
   :pypi:`pytest-cloudreport`                               pytest plugin for test analytics and flaky-test detection. Free local HTML reports out of the box, or upload to cloudreport.dev for cloud history and team dashboards.                                                                                                                                                                                                                  May 04, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-cmake`                                     Provide CMake module for Pytest                                                                                                                                                                                                                                                                                                                                                         Jan 03, 2026    N/A                    pytest<10,>=4
   :pypi:`pytest-cmake-presets`                             Execute CMake Presets via pytest                                                                                                                                                                                                                                                                                                                                                        Dec 26, 2022    N/A                    pytest (>=7.2.0,<8.0.0)
   :pypi:`pytest-cmdline-add-args`                          Pytest plugin for custom argument handling and Allure reporting. This plugin allows you to add arguments before running a test.                                                                                                                                                                                                                                                         Sep 01, 2024    N/A                    N/A
   :pypi:`pytest-cobra`                                     PyTest plugin for testing Smart Contracts for Ethereum blockchain.                                                                                                                                                                                                                                                                                                                      Jun 29, 2019    3 - Alpha              pytest (<4.0.0,>=3.7.1)
   :pypi:`pytest-cocotb`                                    Pytest plugin that enables using pytest as the regression manager for running cocotb tests.                                                                                                                                                                                                                                                                                             Nov 09, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-cocotb-cov`                                Pytest plugin for measuring HDL coverage.                                                                                                                                                                                                                                                                                                                                               Nov 09, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-cocotb-fusesoc`                            Pytest plugin to integrate FuseSoC with Cocotb.                                                                                                                                                                                                                                                                                                                                         Jan 07, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-cocotb-pyuvm`                              Pytest plugin that enables using pytest as the regression manager for running pyuvm tests.                                                                                                                                                                                                                                                                                              Nov 09, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-codeblock`                                 Pytest plugin to collect and test code blocks in reStructuredText and Markdown files.                                                                                                                                                                                                                                                                                                   Apr 07, 2026    4 - Beta               pytest
   :pypi:`pytest_codeblocks`                                Test code blocks in your READMEs                                                                                                                                                                                                                                                                                                                                                        Sep 17, 2023    5 - Production/Stable  pytest >= 7.0.0
   :pypi:`pytest-codecarbon`                                Pytest plugin for measuring carbon emissions                                                                                                                                                                                                                                                                                                                                            Jun 15, 2022    N/A                    pytest
   :pypi:`pytest-codecheckers`                              pytest plugin to add source code sanity checks (pep8 and friends)                                                                                                                                                                                                                                                                                                                       Feb 13, 2010    N/A                    N/A
   :pypi:`pytest-codecov`                                   Pytest plugin for uploading pytest-cov results to codecov.io                                                                                                                                                                                                                                                                                                                            Mar 25, 2025    4 - Beta               pytest>=4.6.0
   :pypi:`pytest-codegen`                                   Automatically create pytest test signatures                                                                                                                                                                                                                                                                                                                                             Aug 23, 2020    2 - Pre-Alpha          N/A
   :pypi:`pytest-codeowners`                                Pytest plugin for selecting tests by GitHub CODEOWNERS.                                                                                                                                                                                                                                                                                                                                 Mar 30, 2022    4 - Beta               pytest (>=6.0.0)
   :pypi:`pytest-codestyle`                                 pytest plugin to run pycodestyle                                                                                                                                                                                                                                                                                                                                                        Mar 23, 2020    3 - Alpha              N/A
   :pypi:`pytest-codspeed`                                  Pytest plugin to create CodSpeed benchmarks                                                                                                                                                                                                                                                                                                                                             May 22, 2026    5 - Production/Stable  pytest>=3.8
   :pypi:`pytest-collect-appoint-info`                      set your encoding                                                                                                                                                                                                                                                                                                                                                                       Aug 03, 2023    N/A                    pytest
   :pypi:`pytest-collect-formatter`                         Formatter for pytest collect output                                                                                                                                                                                                                                                                                                                                                     Mar 29, 2021    5 - Production/Stable  N/A
   :pypi:`pytest-collect-formatter2`                        Formatter for pytest collect output                                                                                                                                                                                                                                                                                                                                                     May 31, 2021    5 - Production/Stable  N/A
   :pypi:`pytest-collect-interface-info-plugin`             Get executed interface information in pytest interface automation framework                                                                                                                                                                                                                                                                                                             Sep 25, 2023    4 - Beta               N/A
   :pypi:`pytest-collect-markers`                           A pytest plugin to collect and output test markers to JSON                                                                                                                                                                                                                                                                                                                              Jan 24, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-collector`                                 Python package for collecting pytest.                                                                                                                                                                                                                                                                                                                                                   Aug 02, 2022    N/A                    pytest (>=7.0,<8.0)
   :pypi:`pytest-collect-pytest-interinfo`                  A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Sep 26, 2023    4 - Beta               N/A
   :pypi:`pytest-collect-requirements`                      A pytest plugin to collect test requirements from requirements marker.                                                                                                                                                                                                                                                                                                                  May 19, 2026    5 - Production/Stable  pytest>=9.0.1
   :pypi:`pytest-colordots`                                 Colorizes the progress indicators                                                                                                                                                                                                                                                                                                                                                       Oct 06, 2017    5 - Production/Stable  N/A
   :pypi:`pytest-comfyui`                                   Integration testing framework for ComfyUI nodes and workflows.                                                                                                                                                                                                                                                                                                                          Jan 09, 2026    N/A                    N/A
   :pypi:`pytest-commander`                                 An interactive GUI test runner for PyTest                                                                                                                                                                                                                                                                                                                                               Aug 17, 2021    N/A                    pytest (<7.0.0,>=6.2.4)
   :pypi:`pytest-common-subject`                            pytest framework for testing different aspects of a common method                                                                                                                                                                                                                                                                                                                       Oct 22, 2025    N/A                    pytest<9,>=3.6
   :pypi:`pytest-compare`                                   pytest plugin for comparing call arguments.                                                                                                                                                                                                                                                                                                                                             Jun 22, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-concurrency`                               A pytest plugin for parallel test execution with configurable concurrency                                                                                                                                                                                                                                                                                                               Apr 02, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-concurrent`                                Concurrently execute test cases with multithread, multiprocess and gevent                                                                                                                                                                                                                                                                                                               Jan 12, 2019    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-conductor`                                 Pytest plugin for coordinating the order in which marked tests run.                                                                                                                                                                                                                                                                                                                     Jul 30, 2025    N/A                    pytest<8.4; python_version == "3.8"
   :pypi:`pytest-config`                                    Base configurations and utilities for developing    your Python project test suite with pytest.                                                                                                                                                                                                                                                                                         Nov 07, 2014    5 - Production/Stable  N/A
   :pypi:`pytest-confiq`                                    pytest-confiq                                                                                                                                                                                                                                                                                                                                                                           May 25, 2026    1 - Planning           N/A
   :pypi:`pytest-confluence-report`                         Package stands for pytest plugin to upload results into Confluence page.                                                                                                                                                                                                                                                                                                                Apr 17, 2022    N/A                    N/A
   :pypi:`pytest-console-scripts`                           Pytest plugin for testing console scripts                                                                                                                                                                                                                                                                                                                                               May 31, 2023    4 - Beta               pytest (>=4.0.0)
   :pypi:`pytest-consul`                                    pytest plugin with fixtures for testing consul aware apps                                                                                                                                                                                                                                                                                                                               Nov 24, 2018    3 - Alpha              pytest
   :pypi:`pytest-container`                                 Pytest fixtures for writing container based tests                                                                                                                                                                                                                                                                                                                                       Jun 30, 2025    4 - Beta               pytest>=3.10
   :pypi:`pytest-contextfixture`                            Define pytest fixtures as context managers.                                                                                                                                                                                                                                                                                                                                             Mar 12, 2013    4 - Beta               N/A
   :pypi:`pytest-contexts`                                  A plugin to run tests written with the Contexts framework using pytest                                                                                                                                                                                                                                                                                                                  May 19, 2021    4 - Beta               N/A
   :pypi:`pytest-continuous`                                A pytest plugin to run tests continuously until failure or interruption.                                                                                                                                                                                                                                                                                                                Apr 23, 2024    N/A                    N/A
   :pypi:`pytest-conversational`                            pytest plugin for multi-turn dialogue testing with a pluggable bot adapter. Rule-based, no LLM dependency.                                                                                                                                                                                                                                                                              May 23, 2026    3 - Alpha              pytest>=7.0; extra == "dev"
   :pypi:`pytest-cookies`                                   The pytest plugin for your Cookiecutter templates. 🍪                                                                                                                                                                                                                                                                                                                                   Mar 22, 2023    5 - Production/Stable  pytest (>=3.9.0)
   :pypi:`pytest-copie`                                     The pytest plugin for your copier templates 📒                                                                                                                                                                                                                                                                                                                                          Sep 29, 2025    3 - Alpha              pytest
   :pypi:`pytest-copier`                                    A pytest plugin to help testing Copier templates                                                                                                                                                                                                                                                                                                                                        Dec 11, 2023    4 - Beta               pytest>=7.3.2
   :pypi:`pytest-couchdbkit`                                py.test extension for per-test couchdb databases using couchdbkit                                                                                                                                                                                                                                                                                                                       Apr 17, 2012    N/A                    N/A
   :pypi:`pytest-count`                                     count erros and send email                                                                                                                                                                                                                                                                                                                                                              Jan 12, 2018    4 - Beta               N/A
   :pypi:`pytest-cov`                                       Pytest plugin for measuring coverage.                                                                                                                                                                                                                                                                                                                                                   Mar 21, 2026    5 - Production/Stable  pytest>=7
   :pypi:`pytest-cov-affected`                              Run pytest and report coverage only for git-affected modules.                                                                                                                                                                                                                                                                                                                           May 03, 2026    N/A                    pytest>=8
   :pypi:`pytest-cov-container`                             Pytest plugin to collect code coverage from applications running inside Docker containers                                                                                                                                                                                                                                                                                               May 16, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-cover`                                     Pytest plugin for measuring coverage. Forked from \`pytest-cov\`.                                                                                                                                                                                                                                                                                                                       Aug 01, 2015    5 - Production/Stable  N/A
   :pypi:`pytest-coverage`                                                                                                                                                                                                                                                                                                                                                                                                                          Jun 17, 2015    N/A                    N/A
   :pypi:`pytest-coverage-context`                          Coverage dynamic context support for PyTest, including sub-processes                                                                                                                                                                                                                                                                                                                    Jun 28, 2023    4 - Beta               N/A
   :pypi:`pytest-coverage-gate`                             A pre-commit hook that enforces a coverage quality gate using coverage.xml and a baseline file                                                                                                                                                                                                                                                                                          Apr 14, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-coverage-impact`                           Sensoria: High-fidelity coverage impact analysis for Python.                                                                                                                                                                                                                                                                                                                            Jan 16, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-coveragemarkers`                           Using pytest markers to track functional coverage and filtering of tests                                                                                                                                                                                                                                                                                                                May 15, 2025    N/A                    pytest<8.0.0,>=7.1.2
   :pypi:`pytest-cov-exclude`                               Pytest plugin for excluding tests based on coverage data                                                                                                                                                                                                                                                                                                                                Apr 29, 2016    4 - Beta               pytest (>=2.8.0,<2.9.0); extra == 'dev'
   :pypi:`pytest_covid`                                     Too many faillure, less tests.                                                                                                                                                                                                                                                                                                                                                          Jun 24, 2020    N/A                    N/A
   :pypi:`pytest-cpp`                                       Use pytest's runner to discover and execute C++ tests                                                                                                                                                                                                                                                                                                                                   Sep 18, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-cppcheck`                                  A pytest plugin that runs cppcheck static analysis on C/C++ source files                                                                                                                                                                                                                                                                                                                Mar 26, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-cpplint`                                   A pytest plugin that runs cpplint style checking on C/C++ source files                                                                                                                                                                                                                                                                                                                  Mar 26, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-cqase`                                     Custom qase pytest plugin                                                                                                                                                                                                                                                                                                                                                               Aug 22, 2022    N/A                    pytest (>=7.1.2,<8.0.0)
   :pypi:`pytest-cram`                                      Run cram tests with pytest.                                                                                                                                                                                                                                                                                                                                                             Aug 08, 2020    N/A                    N/A
   :pypi:`pytest-crap`                                      pytest plugin that calculates CRAP scores to guide test writing                                                                                                                                                                                                                                                                                                                         Dec 02, 2025    4 - Beta               pytest>=7.0
   :pypi:`pytest-crate`                                     Manages CrateDB instances during your integration tests                                                                                                                                                                                                                                                                                                                                 May 28, 2019    3 - Alpha              pytest (>=4.0)
   :pypi:`pytest-cratedb`                                   Manage CrateDB instances for integration tests                                                                                                                                                                                                                                                                                                                                          Jan 05, 2026    4 - Beta               pytest<10
   :pypi:`pytest-cratedb-reporter`                          A pytest plugin for reporting test results to CrateDB                                                                                                                                                                                                                                                                                                                                   Mar 11, 2025    N/A                    pytest>=6.0.0
   :pypi:`pytest-crayons`                                   A pytest plugin for colorful print statements                                                                                                                                                                                                                                                                                                                                           Oct 14, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-cream`                                     The cream of test execution - smooth pytest workflows with intelligent orchestration                                                                                                                                                                                                                                                                                                    Oct 26, 2025    N/A                    pytest
   :pypi:`pytest-create`                                    pytest-create                                                                                                                                                                                                                                                                                                                                                                           Feb 15, 2023    1 - Planning           N/A
   :pypi:`pytest-cricri`                                    A Cricri plugin for pytest.                                                                                                                                                                                                                                                                                                                                                             Jan 27, 2018    N/A                    pytest
   :pypi:`pytest-crontab`                                   add crontab task in crontab                                                                                                                                                                                                                                                                                                                                                             Dec 09, 2019    N/A                    N/A
   :pypi:`pytest-csv`                                       CSV output for pytest.                                                                                                                                                                                                                                                                                                                                                                  Apr 22, 2021    N/A                    pytest (>=6.0)
   :pypi:`pytest-csv-params`                                Pytest plugin for Test Case Parametrization with CSV files                                                                                                                                                                                                                                                                                                                              May 29, 2025    5 - Production/Stable  pytest<9,>=8.3
   :pypi:`pytest-culprit`                                   Find the last Git commit where a pytest test started failing                                                                                                                                                                                                                                                                                                                            May 15, 2025    N/A                    N/A
   :pypi:`pytest-curio`                                     Pytest support for curio.                                                                                                                                                                                                                                                                                                                                                               Oct 06, 2024    N/A                    pytest
   :pypi:`pytest-curl-report`                               pytest plugin to generate curl command line report                                                                                                                                                                                                                                                                                                                                      Dec 11, 2016    4 - Beta               N/A
   :pypi:`pytest-custom-concurrency`                        Custom grouping concurrence for pytest                                                                                                                                                                                                                                                                                                                                                  Feb 08, 2021    N/A                    N/A
   :pypi:`pytest-custom-exit-code`                          Exit pytest test session with custom exit code in different scenarios                                                                                                                                                                                                                                                                                                                   Aug 07, 2019    4 - Beta               pytest (>=4.0.2)
   :pypi:`pytest-custom-nodeid`                             Custom grouping for pytest-xdist, rename test cases name and test cases nodeid, support allure report                                                                                                                                                                                                                                                                                   Mar 07, 2021    N/A                    N/A
   :pypi:`pytest-custom-outputs`                            A plugin that allows users to create and use custom outputs instead of the standard Pass and Fail. Also allows users to retrieve test results in fixtures.                                                                                                                                                                                                                              Jul 10, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-custom-report`                             Configure the symbols displayed for test outcomes                                                                                                                                                                                                                                                                                                                                       Jan 30, 2019    N/A                    pytest
   :pypi:`pytest-custom-scheduling`                         Custom grouping for pytest-xdist, rename test cases name and test cases nodeid, support allure report                                                                                                                                                                                                                                                                                   Mar 01, 2021    N/A                    N/A
   :pypi:`pytest-custom-timeout`                            Use custom logic when a test times out. Based on pytest-timeout.                                                                                                                                                                                                                                                                                                                        Jan 08, 2025    4 - Beta               pytest>=8.0.0
   :pypi:`pytest-cython`                                    A plugin for testing Cython extension modules.                                                                                                                                                                                                                                                                                                                                          Mar 11, 2026    5 - Production/Stable  pytest>=8
   :pypi:`pytest-cython-collect`                                                                                                                                                                                                                                                                                                                                                                                                                    Jun 17, 2022    N/A                    pytest
   :pypi:`pytest-dag`                                       A pytest plugin that enforces test execution order via a dependency DAG                                                                                                                                                                                                                                                                                                                 Jun 02, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-darker`                                    A pytest plugin for checking of modified code using Darker                                                                                                                                                                                                                                                                                                                              Feb 25, 2024    N/A                    pytest <7,>=6.0.1
   :pypi:`pytest-dash`                                      pytest fixtures to run dash applications.                                                                                                                                                                                                                                                                                                                                               Mar 18, 2019    N/A                    N/A
   :pypi:`pytest-dashboard`                                                                                                                                                                                                                                                                                                                                                                                                                         Jun 02, 2025    N/A                    pytest<8.0.0,>=7.4.3
   :pypi:`pytest-data`                                      Useful functions for managing data for pytest fixtures                                                                                                                                                                                                                                                                                                                                  Nov 01, 2016    5 - Production/Stable  N/A
   :pypi:`pytest-databases`                                 Reusable database fixtures for any and all databases.                                                                                                                                                                                                                                                                                                                                   May 23, 2026    4 - Beta               pytest
   :pypi:`pytest-databricks`                                Pytest plugin for remote Databricks notebooks testing                                                                                                                                                                                                                                                                                                                                   Jul 29, 2020    N/A                    pytest
   :pypi:`pytest-datadir`                                   pytest plugin for test data directories and files                                                                                                                                                                                                                                                                                                                                       Jul 30, 2025    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-datadir-mgr`                               Manager for test data: downloads, artifact caching, and a tmpdir context.                                                                                                                                                                                                                                                                                                               Apr 06, 2023    5 - Production/Stable  pytest (>=7.1)
   :pypi:`pytest-datadir-ng`                                Fixtures for pytest allowing test functions/methods to easily retrieve test resources from the local filesystem.                                                                                                                                                                                                                                                                        Dec 25, 2019    5 - Production/Stable  pytest
   :pypi:`pytest-datadir-nng`                               Fixtures for pytest allowing test functions/methods to easily retrieve test resources from the local filesystem.                                                                                                                                                                                                                                                                        Nov 09, 2022    5 - Production/Stable  pytest (>=7.0.0,<8.0.0)
   :pypi:`pytest-data-extractor`                            A pytest plugin to extract relevant metadata about tests into an external file (currently only json support)                                                                                                                                                                                                                                                                            Jul 19, 2022    N/A                    pytest (>=7.0.1)
   :pypi:`pytest-datafaker`                                 Pytest plugin with Faker class and fixture                                                                                                                                                                                                                                                                                                                                              May 30, 2026    6 - Mature             pytest<10.0.0,>=9.0.3
   :pypi:`pytest-data-file`                                 Fixture "data" and "case_data" for test from yaml file                                                                                                                                                                                                                                                                                                                                  Dec 04, 2019    N/A                    N/A
   :pypi:`pytest-datafiles`                                 py.test plugin to create a 'tmp_path' containing predefined files/directories.                                                                                                                                                                                                                                                                                                          Jan 04, 2026    5 - Production/Stable  pytest>=6.2.0
   :pypi:`pytest-datafixtures`                              Data fixtures for pytest made simple.                                                                                                                                                                                                                                                                                                                                                   May 15, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-data-from-files`                           pytest plugin to provide data from files loaded automatically                                                                                                                                                                                                                                                                                                                           Oct 13, 2021    4 - Beta               pytest
   :pypi:`pytest-dataguard`                                 Data validation and integrity testing for your datasets using pytest.                                                                                                                                                                                                                                                                                                                   Oct 08, 2025    N/A                    pytest>=8.4.2
   :pypi:`pytest-data-loader`                               Pytest plugin for loading test data for data-driven testing (DDT)                                                                                                                                                                                                                                                                                                                       May 20, 2026    4 - Beta               pytest<10,>=7.0.0
   :pypi:`pytest-dataplugin`                                A pytest plugin for managing an archive of test data.                                                                                                                                                                                                                                                                                                                                   Sep 16, 2017    1 - Planning           N/A
   :pypi:`pytest-datarecorder`                              A py.test plugin recording and comparing test output.                                                                                                                                                                                                                                                                                                                                   Jul 31, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-dataset`                                   Plugin for loading different datasets for pytest by prefix from json or yaml files                                                                                                                                                                                                                                                                                                      Sep 01, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-data-suites`                               Class-based pytest parametrization                                                                                                                                                                                                                                                                                                                                                      Apr 06, 2024    N/A                    pytest<9.0,>=6.0
   :pypi:`pytest-datatest`                                  A pytest plugin for test driven data-wrangling (this is the development version of datatest's pytest integration).                                                                                                                                                                                                                                                                      Oct 15, 2020    4 - Beta               pytest (>=3.3)
   :pypi:`pytest-db`                                        Session scope fixture "db" for mysql query or change                                                                                                                                                                                                                                                                                                                                    Nov 11, 2025    N/A                    pytest
   :pypi:`pytest-dbfixtures`                                Databases fixtures plugin for py.test.                                                                                                                                                                                                                                                                                                                                                  Dec 07, 2016    4 - Beta               N/A
   :pypi:`pytest-db-plugin`                                                                                                                                                                                                                                                                                                                                                                                                                         Nov 27, 2021    N/A                    pytest (>=5.0)
   :pypi:`pytest-dbt`                                       Unit test dbt models with standard python tooling                                                                                                                                                                                                                                                                                                                                       Jun 08, 2023    2 - Pre-Alpha          pytest (>=7.0.0,<8.0.0)
   :pypi:`pytest-dbt-adapter`                               A pytest plugin for testing dbt adapter plugins                                                                                                                                                                                                                                                                                                                                         Nov 24, 2021    N/A                    pytest (<7,>=6)
   :pypi:`pytest-dbt-conventions`                           A pytest plugin for linting a dbt project's conventions                                                                                                                                                                                                                                                                                                                                 Mar 02, 2022    N/A                    pytest (>=6.2.5,<7.0.0)
   :pypi:`pytest-dbt-core`                                  Pytest extension for dbt.                                                                                                                                                                                                                                                                                                                                                               Jun 04, 2024    N/A                    pytest>=6.2.5; extra == "test"
   :pypi:`pytest-dbt-duckdb`                                Fearless testing for dbt models, powered by DuckDB.                                                                                                                                                                                                                                                                                                                                     Apr 28, 2026    4 - Beta               pytest>=8.3.4
   :pypi:`pytest-dbt-postgres`                              Pytest tooling to unittest DBT & Postgres models                                                                                                                                                                                                                                                                                                                                        Sep 03, 2024    N/A                    pytest<9.0.0,>=8.3.2
   :pypi:`pytest-dbus-notification`                         D-BUS notifications for pytest results.                                                                                                                                                                                                                                                                                                                                                 Mar 05, 2014    5 - Production/Stable  N/A
   :pypi:`pytest-dbx`                                       Pytest plugin to run unit tests for dbx (Databricks CLI extensions) related code                                                                                                                                                                                                                                                                                                        Nov 29, 2022    N/A                    pytest (>=7.1.3,<8.0.0)
   :pypi:`pytest-dc`                                        Manages Docker containers during your integration tests                                                                                                                                                                                                                                                                                                                                 Aug 16, 2023    5 - Production/Stable  pytest >=3.3
   :pypi:`pytest-deadfixtures`                              A simple plugin to list unused fixtures in pytest                                                                                                                                                                                                                                                                                                                                       Jan 15, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-deduplicate`                               Identifies duplicate unit tests                                                                                                                                                                                                                                                                                                                                                         Aug 12, 2023    4 - Beta               pytest
   :pypi:`pytest-deepassert`                                A pytest plugin for enhanced assertion reporting with detailed diffs                                                                                                                                                                                                                                                                                                                    Nov 04, 2025    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-deepcov`                                   deepcov                                                                                                                                                                                                                                                                                                                                                                                 Mar 30, 2021    N/A                    N/A
   :pypi:`pytest_defer`                                     A 'defer' fixture for pytest                                                                                                                                                                                                                                                                                                                                                            Nov 13, 2024    N/A                    pytest>=8.3
   :pypi:`pytest-delta`                                     Run only tests impacted by your code changes (delta-based selection) for pytest.                                                                                                                                                                                                                                                                                                        Feb 12, 2026    4 - Beta               pytest<10.0.0,>=9.0.2
   :pypi:`pytest-demo-plugin`                               pytest示例插件                                                                                                                                                                                                                                                                                                                                                                          May 15, 2021    N/A                    N/A
   :pypi:`pytest-dependency`                                Manage dependencies of tests                                                                                                                                                                                                                                                                                                                                                            Feb 15, 2026    4 - Beta               N/A
   :pypi:`pytest-depends`                                   Tests that depend on other tests                                                                                                                                                                                                                                                                                                                                                        Apr 05, 2020    5 - Production/Stable  pytest (>=3)
   :pypi:`pytest-depends-on`                                A Python package for managing test dependencies in pytest.                                                                                                                                                                                                                                                                                                                              May 18, 2026    5 - Production/Stable  pytest>=9.0.1
   :pypi:`pytest-depper`                                    Smart test selection based on AST-level code dependency analysis                                                                                                                                                                                                                                                                                                                        Oct 23, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-deprecate`                                 Mark tests as testing a deprecated feature with a warning note.                                                                                                                                                                                                                                                                                                                         Jul 01, 2019    N/A                    N/A
   :pypi:`pytest-deprecator`                                A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Dec 02, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-describe`                                  Describe-style plugin for pytest                                                                                                                                                                                                                                                                                                                                                        Dec 12, 2025    5 - Production/Stable  pytest<10,>=6
   :pypi:`pytest-describe-beautifully`                      Beautiful terminal and HTML output for pytest-describe.                                                                                                                                                                                                                                                                                                                                 Jan 28, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-describe-it`                               plugin for rich text descriptions                                                                                                                                                                                                                                                                                                                                                       Jul 19, 2019    4 - Beta               pytest
   :pypi:`pytest-deselect-if`                               A plugin to deselect pytests tests rather than using skipif                                                                                                                                                                                                                                                                                                                             Dec 26, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-devant-cloud`                              pytest plugin that streams runs, results, and step trees to Devant Cloud's /v1/runs API.                                                                                                                                                                                                                                                                                                May 11, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-devpi-server`                              DevPI server fixture for py.test                                                                                                                                                                                                                                                                                                                                                        Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-devtools`                                  Pytest plugin providing debug fixtures, ANSI-stripped capsys, whitespace-visible assertions, and terminal column management.                                                                                                                                                                                                                                                            May 07, 2026    N/A                    pytest>=7
   :pypi:`pytest-dfm`                                       pytest-dfm provides a pytest integration for DV Flow Manager, a build system for silicon design                                                                                                                                                                                                                                                                                         Nov 23, 2025    N/A                    pytest
   :pypi:`pytest-dhos`                                      Common fixtures for pytest in DHOS services and libraries                                                                                                                                                                                                                                                                                                                               Sep 07, 2022    N/A                    N/A
   :pypi:`pytest-diamond`                                   pytest plugin for diamond                                                                                                                                                                                                                                                                                                                                                               Aug 31, 2015    4 - Beta               N/A
   :pypi:`pytest-dicom`                                     pytest plugin to provide DICOM fixtures                                                                                                                                                                                                                                                                                                                                                 Dec 19, 2018    3 - Alpha              pytest
   :pypi:`pytest-dictsdiff`                                                                                                                                                                                                                                                                                                                                                                                                                         Jul 26, 2019    N/A                    N/A
   :pypi:`pytest-diff`                                      A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Mar 30, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-diff-selector`                             Get tests affected by code changes (using git)                                                                                                                                                                                                                                                                                                                                          Feb 24, 2022    4 - Beta               pytest (>=6.2.2) ; extra == 'all'
   :pypi:`pytest-difftest`                                  Blazingly fast test selection for pytest - only run tests affected by your changes (Rust-powered)                                                                                                                                                                                                                                                                                       Feb 23, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-difido`                                    PyTest plugin for generating Difido reports                                                                                                                                                                                                                                                                                                                                             Oct 23, 2022    4 - Beta               pytest (>=4.0.0)
   :pypi:`pytest-directives`                                Control your tests flow                                                                                                                                                                                                                                                                                                                                                                 Aug 11, 2025    3 - Alpha              pytest
   :pypi:`pytest-dir-equal`                                 pytest-dir-equals is a pytest plugin providing helpers to assert directories equality allowing golden testing                                                                                                                                                                                                                                                                           Dec 11, 2023    4 - Beta               pytest>=7.3.2
   :pypi:`pytest-dirty`                                     Static import analysis for thrifty testing.                                                                                                                                                                                                                                                                                                                                             Jun 08, 2025    3 - Alpha              pytest>=8.2; extra == "dev"
   :pypi:`pytest-disable`                                   pytest plugin to disable a test and skip it from testrun                                                                                                                                                                                                                                                                                                                                Sep 10, 2015    4 - Beta               N/A
   :pypi:`pytest-disable-plugin`                            Disable plugins per test                                                                                                                                                                                                                                                                                                                                                                Feb 28, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-discord`                                   A pytest plugin to notify test results to a Discord channel.                                                                                                                                                                                                                                                                                                                            May 11, 2024    4 - Beta               pytest!=6.0.0,<9,>=3.3.2
   :pypi:`pytest-discover`                                  Pytest plugin to record discovered tests in a file                                                                                                                                                                                                                                                                                                                                      Mar 26, 2024    N/A                    pytest
   :pypi:`pytest-ditto`                                     Snapshot testing pytest plugin with minimal ceremony and flexible recorders.                                                                                                                                                                                                                                                                                                            Mar 22, 2026    5 - Production/Stable  pytest>=3.5.0
   :pypi:`pytest-ditto-pandas`                              pytest-ditto plugin for pandas DataFrame snapshots.                                                                                                                                                                                                                                                                                                                                     Mar 22, 2026    5 - Production/Stable  pytest>=3.5.0
   :pypi:`pytest-ditto-pyarrow`                             pytest-ditto plugin for pyarrow table snapshots.                                                                                                                                                                                                                                                                                                                                        Mar 22, 2026    5 - Production/Stable  pytest>=3.5.0
   :pypi:`pytest-django`                                    A Django plugin for pytest.                                                                                                                                                                                                                                                                                                                                                             Feb 14, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-django-ahead`                              A Django plugin for pytest.                                                                                                                                                                                                                                                                                                                                                             Oct 27, 2016    5 - Production/Stable  pytest (>=2.9)
   :pypi:`pytest-djangoapp`                                 Nice pytest plugin to help you with Django pluggable application testing.                                                                                                                                                                                                                                                                                                               Apr 25, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-django-asyncio`                            Temporary pytest plugin backport for async Django DB fixture handling.                                                                                                                                                                                                                                                                                                                  Mar 26, 2026    4 - Beta               pytest>=8.0
   :pypi:`pytest-django-cache-xdist`                        A djangocachexdist plugin for pytest                                                                                                                                                                                                                                                                                                                                                    May 12, 2020    4 - Beta               N/A
   :pypi:`pytest-django-casperjs`                           Integrate CasperJS with your django tests as a pytest fixture.                                                                                                                                                                                                                                                                                                                          Mar 15, 2015    2 - Pre-Alpha          N/A
   :pypi:`pytest-django-class`                              A pytest plugin for running django in class-scoped fixtures                                                                                                                                                                                                                                                                                                                             Aug 08, 2023    4 - Beta               N/A
   :pypi:`pytest-django-docker-pg`                                                                                                                                                                                                                                                                                                                                                                                                                  Jun 13, 2024    5 - Production/Stable  pytest<9.0.0,>=7.0.0
   :pypi:`pytest-django-dotenv`                             Pytest plugin used to setup environment variables with django-dotenv                                                                                                                                                                                                                                                                                                                    Nov 26, 2019    4 - Beta               pytest (>=2.6.0)
   :pypi:`pytest-django-factories`                          Factories for your Django models that can be used as Pytest fixtures.                                                                                                                                                                                                                                                                                                                   Nov 12, 2020    4 - Beta               N/A
   :pypi:`pytest-django-filefield`                          Replaces FileField.storage with something you can patch globally.                                                                                                                                                                                                                                                                                                                       May 09, 2022    5 - Production/Stable  pytest >= 5.2
   :pypi:`pytest-django-gcir`                               A Django plugin for pytest.                                                                                                                                                                                                                                                                                                                                                             Mar 06, 2018    5 - Production/Stable  N/A
   :pypi:`pytest-django-haystack`                           Cleanup your Haystack indexes between tests                                                                                                                                                                                                                                                                                                                                             Sep 03, 2017    5 - Production/Stable  pytest (>=2.3.4)
   :pypi:`pytest-django-ifactory`                           A model instance factory for pytest-django                                                                                                                                                                                                                                                                                                                                              Apr 30, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-django-lite`                               The bare minimum to integrate py.test with Django.                                                                                                                                                                                                                                                                                                                                      Jan 30, 2014    N/A                    N/A
   :pypi:`pytest-django-liveserver-ssl`                                                                                                                                                                                                                                                                                                                                                                                                             Jan 09, 2025    3 - Alpha              N/A
   :pypi:`pytest-django-model`                              A Simple Way to Test your Django Models                                                                                                                                                                                                                                                                                                                                                 Feb 14, 2019    4 - Beta               N/A
   :pypi:`pytest-django-ordering`                           A pytest plugin for preserving the order in which Django runs tests.                                                                                                                                                                                                                                                                                                                    Jul 25, 2019    5 - Production/Stable  pytest (>=2.3.0)
   :pypi:`pytest-django-queries`                            Generate performance reports from your django database performance tests.                                                                                                                                                                                                                                                                                                               Mar 01, 2026    5 - Production/Stable  pytest>=7.2.0
   :pypi:`pytest-djangorestframework`                       A djangorestframework plugin for pytest                                                                                                                                                                                                                                                                                                                                                 Aug 11, 2019    4 - Beta               N/A
   :pypi:`pytest-django-rq`                                 A pytest plugin to help writing unit test for django-rq                                                                                                                                                                                                                                                                                                                                 Apr 13, 2020    4 - Beta               N/A
   :pypi:`pytest-django-sqlcounts`                          py.test plugin for reporting the number of SQLs executed per django testcase.                                                                                                                                                                                                                                                                                                           Jun 16, 2015    4 - Beta               N/A
   :pypi:`pytest-django-testing-postgresql`                 Use a temporary PostgreSQL database with pytest-django                                                                                                                                                                                                                                                                                                                                  Jan 31, 2022    4 - Beta               N/A
   :pypi:`pytest-doc`                                       A documentation plugin for py.test.                                                                                                                                                                                                                                                                                                                                                     Jun 28, 2015    5 - Production/Stable  N/A
   :pypi:`pytest-docfiles`                                  pytest plugin to test codeblocks in your documentation.                                                                                                                                                                                                                                                                                                                                 Dec 22, 2021    4 - Beta               pytest (>=3.7.0)
   :pypi:`pytest-docgen`                                    An RST Documentation Generator for pytest-based test suites                                                                                                                                                                                                                                                                                                                             Apr 17, 2020    N/A                    N/A
   :pypi:`pytest-docker`                                    Simple pytest fixtures for Docker and Docker Compose based tests                                                                                                                                                                                                                                                                                                                        Nov 12, 2025    N/A                    pytest<10.0,>=4.0
   :pypi:`pytest-docker-apache-fixtures`                    Pytest fixtures for testing with apache2 (httpd).                                                                                                                                                                                                                                                                                                                                       Aug 12, 2024    4 - Beta               pytest
   :pypi:`pytest-docker-butla`                                                                                                                                                                                                                                                                                                                                                                                                                      Jun 16, 2019    3 - Alpha              N/A
   :pypi:`pytest-dockerc`                                   Run, manage and stop Docker Compose project from Docker API                                                                                                                                                                                                                                                                                                                             Oct 09, 2020    5 - Production/Stable  pytest (>=3.0)
   :pypi:`pytest-docker-compose`                            Manages Docker containers during your integration tests                                                                                                                                                                                                                                                                                                                                 Jan 26, 2021    5 - Production/Stable  pytest (>=3.3)
   :pypi:`pytest-docker-compose-v2`                         Manages Docker containers during your integration tests                                                                                                                                                                                                                                                                                                                                 Dec 17, 2025    4 - Beta               pytest<10,>=7.2.2
   :pypi:`pytest-docker-db`                                 A plugin to use docker databases for pytests                                                                                                                                                                                                                                                                                                                                            Mar 20, 2021    5 - Production/Stable  pytest (>=3.1.1)
   :pypi:`pytest-docker-fixtures`                           pytest docker fixtures                                                                                                                                                                                                                                                                                                                                                                  May 07, 2026    3 - Alpha              pytest
   :pypi:`pytest-docker-git-fixtures`                       Pytest fixtures for testing with git scm.                                                                                                                                                                                                                                                                                                                                               Aug 12, 2024    4 - Beta               pytest
   :pypi:`pytest-docker-haproxy-fixtures`                   Pytest fixtures for testing with haproxy.                                                                                                                                                                                                                                                                                                                                               Aug 12, 2024    4 - Beta               pytest
   :pypi:`pytest-docker-pexpect`                            pytest plugin for writing functional tests with pexpect and docker                                                                                                                                                                                                                                                                                                                      Jan 14, 2019    N/A                    pytest
   :pypi:`pytest-docker-postgresql`                         A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Sep 24, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-docker-py`                                 Easy to use, simple to extend, pytest plugin that minimally leverages docker-py.                                                                                                                                                                                                                                                                                                        Nov 27, 2018    N/A                    pytest (==4.0.0)
   :pypi:`pytest-docker-registry-fixtures`                  Pytest fixtures for testing with docker registries.                                                                                                                                                                                                                                                                                                                                     Aug 12, 2024    4 - Beta               pytest
   :pypi:`pytest-docker-service`                            pytest plugin to start docker container                                                                                                                                                                                                                                                                                                                                                 Jan 03, 2024    3 - Alpha              pytest (>=7.1.3)
   :pypi:`pytest-docker-squid-fixtures`                     Pytest fixtures for testing with squid.                                                                                                                                                                                                                                                                                                                                                 Aug 12, 2024    4 - Beta               pytest
   :pypi:`pytest-docker-tools`                              Docker integration tests for pytest                                                                                                                                                                                                                                                                                                                                                     Mar 16, 2025    4 - Beta               pytest>=6.0.1
   :pypi:`pytest-docs`                                      Documentation tool for pytest                                                                                                                                                                                                                                                                                                                                                           Nov 11, 2018    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-docstyle`                                  pytest plugin to run pydocstyle                                                                                                                                                                                                                                                                                                                                                         Mar 23, 2020    3 - Alpha              N/A
   :pypi:`pytest-doctest-custom`                            A py.test plugin for customizing string representations of doctest results.                                                                                                                                                                                                                                                                                                             Jul 25, 2016    4 - Beta               N/A
   :pypi:`pytest-doctest-ellipsis-markers`                  Setup additional values for ELLIPSIS_MARKER for doctests                                                                                                                                                                                                                                                                                                                                Jan 12, 2018    4 - Beta               N/A
   :pypi:`pytest-doctest-import`                            A simple pytest plugin to import names and add them to the doctest namespace.                                                                                                                                                                                                                                                                                                           Nov 13, 2018    4 - Beta               pytest (>=3.3.0)
   :pypi:`pytest-doctest-mkdocstrings`                      Run pytest --doctest-modules with markdown docstrings in code blocks (\`\`\`)                                                                                                                                                                                                                                                                                                           Mar 02, 2024    N/A                    pytest
   :pypi:`pytest-doctest-only`                              A plugin to run only doctest                                                                                                                                                                                                                                                                                                                                                            Jul 30, 2025    4 - Beta               pytest>=8.3.0
   :pypi:`pytest-doctestplus`                               Pytest plugin with advanced doctest features.                                                                                                                                                                                                                                                                                                                                           Jan 26, 2026    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-doctor`                                    A CLI tool that diagnoses weak or broken pytest suites and provides a 0-100 health score with actionable recommendations                                                                                                                                                                                                                                                                Mar 22, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-documentary`                               A simple pytest plugin to generate test documentation                                                                                                                                                                                                                                                                                                                                   Jul 11, 2024    N/A                    pytest
   :pypi:`pytest-dogu-report`                               pytest plugin for dogu report                                                                                                                                                                                                                                                                                                                                                           Jul 07, 2023    N/A                    N/A
   :pypi:`pytest-dogu-sdk`                                  pytest plugin for the Dogu                                                                                                                                                                                                                                                                                                                                                              Dec 14, 2023    N/A                    N/A
   :pypi:`pytest-dolphin`                                   Some extra stuff that we use ininternally                                                                                                                                                                                                                                                                                                                                               Nov 30, 2016    4 - Beta               pytest (==3.0.4)
   :pypi:`pytest-donde`                                     record pytest session characteristics per test item (coverage and duration) into a persistent file and use them in your own plugin or script.                                                                                                                                                                                                                                           Oct 01, 2023    4 - Beta               pytest >=7.3.1
   :pypi:`pytest-doorstop`                                  A pytest plugin for adding test results into doorstop items.                                                                                                                                                                                                                                                                                                                            Jun 09, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-dotenv`                                    A py.test plugin that parses environment files before running tests                                                                                                                                                                                                                                                                                                                     Jun 16, 2020    4 - Beta               pytest (>=5.0.0)
   :pypi:`pytest-dotenv-modern`                             A modern pytest plugin that loads environment variables from dotenv files                                                                                                                                                                                                                                                                                                               Sep 27, 2025    4 - Beta               pytest>=6.0.0
   :pypi:`pytest-dot-only-pkcopley`                         A Pytest marker for only running a single test                                                                                                                                                                                                                                                                                                                                          Oct 27, 2023    N/A                    N/A
   :pypi:`pytest-dparam`                                    A more readable alternative to @pytest.mark.parametrize.                                                                                                                                                                                                                                                                                                                                Aug 27, 2024    6 - Mature             pytest
   :pypi:`pytest-dpg`                                       pytest-dpg is a pytest plugin for testing Dear PyGui (DPG) applications                                                                                                                                                                                                                                                                                                                 Aug 13, 2024    N/A                    N/A
   :pypi:`pytest-draw`                                      Pytest plugin for randomly selecting a specific number of tests                                                                                                                                                                                                                                                                                                                         Mar 21, 2023    3 - Alpha              pytest
   :pypi:`pytest-drf`                                       A Django REST framework plugin for pytest.                                                                                                                                                                                                                                                                                                                                              Jul 12, 2022    5 - Production/Stable  pytest (>=3.7)
   :pypi:`pytest-drift`                                     Pytest plugin for regression testing via branch comparison                                                                                                                                                                                                                                                                                                                              May 09, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-drill-sergeant`                            A pytest plugin that enforces test quality standards through automatic marker detection and AAA structure validation                                                                                                                                                                                                                                                                    Feb 20, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-drivings`                                  Tool to allow webdriver automation to be ran locally or remotely                                                                                                                                                                                                                                                                                                                        Jan 13, 2021    N/A                    N/A
   :pypi:`pytest-drop-dup-tests`                            A Pytest plugin to drop duplicated tests during collection                                                                                                                                                                                                                                                                                                                              Mar 04, 2024    5 - Production/Stable  pytest >=7
   :pypi:`pytest-dryci`                                     Test caching plugin for pytest                                                                                                                                                                                                                                                                                                                                                          Sep 27, 2024    4 - Beta               N/A
   :pypi:`pytest-dryrun`                                    A Pytest plugin to ignore tests during collection without reporting them in the test summary.                                                                                                                                                                                                                                                                                           May 26, 2026    5 - Production/Stable  pytest<10,>=7.40
   :pypi:`pytest-dsl`                                       A DSL testing framework based on pytest                                                                                                                                                                                                                                                                                                                                                 Jun 01, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-dsl-ssh`                                   SSH/SFTP关键字插件，为pytest-dsl提供SSH和SFTP操作能力                                                                                                                                                                                                                                                                                                                                   Jul 25, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-dsl-ui`                                    Playwright-based UI automation keywords for pytest-dsl framework                                                                                                                                                                                                                                                                                                                        Jun 05, 2026    N/A                    pytest>=7.0.0; extra == "dev"
   :pypi:`pytest-duckdb`                                    pytest plugin for SQL pipeline testing with DuckDB — load fixtures, run queries, snapshot results                                                                                                                                                                                                                                                                                       May 10, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-dummynet`                                  A py.test plugin providing access to a dummynet.                                                                                                                                                                                                                                                                                                                                        Dec 15, 2021    5 - Production/Stable  pytest
   :pypi:`pytest-dump2json`                                 A pytest plugin for dumping test results to json.                                                                                                                                                                                                                                                                                                                                       Jun 29, 2015    N/A                    N/A
   :pypi:`pytest-duration-insights`                                                                                                                                                                                                                                                                                                                                                                                                                 Jul 15, 2024    N/A                    N/A
   :pypi:`pytest-durations`                                 Pytest plugin reporting fixtures and test functions execution time.                                                                                                                                                                                                                                                                                                                     Mar 13, 2026    5 - Production/Stable  pytest>=4.6
   :pypi:`pytest-dynamic-parameterize`                      A pytest plugin to dynamically parameterize tests based on external data sources.                                                                                                                                                                                                                                                                                                       May 27, 2026    5 - Production/Stable  pytest>=9.0.1
   :pypi:`pytest-dynamicrerun`                              A pytest plugin to rerun tests dynamically based off of test outcome and output.                                                                                                                                                                                                                                                                                                        Aug 15, 2020    4 - Beta               N/A
   :pypi:`pytest-dynamodb`                                  DynamoDB fixtures for pytest                                                                                                                                                                                                                                                                                                                                                            Mar 13, 2026    5 - Production/Stable  pytest>=8.4.0
   :pypi:`pytest-easy-addoption`                            pytest-easy-addoption: Easy way to work with pytest addoption                                                                                                                                                                                                                                                                                                                           Jan 22, 2020    N/A                    N/A
   :pypi:`pytest-easyMPI`                                   Package that supports mpi tests in pytest                                                                                                                                                                                                                                                                                                                                               Oct 21, 2020    N/A                    N/A
   :pypi:`pytest-easyread`                                  pytest plugin that makes terminal printouts of the reports easier to read                                                                                                                                                                                                                                                                                                               Nov 17, 2017    N/A                    N/A
   :pypi:`pytest-easy-server`                               Pytest plugin for easy testing against servers                                                                                                                                                                                                                                                                                                                                          May 01, 2021    4 - Beta               pytest (<5.0.0,>=4.3.1) ; python_version < "3.5"
   :pypi:`pytest-ebics-sandbox`                             A pytest plugin for testing against an EBICS sandbox server. Requires docker.                                                                                                                                                                                                                                                                                                           Aug 15, 2022    N/A                    N/A
   :pypi:`pytest-ec2`                                       Pytest execution on EC2 instance                                                                                                                                                                                                                                                                                                                                                        Oct 22, 2019    3 - Alpha              N/A
   :pypi:`pytest-echo`                                      pytest plugin that allows to dump environment variables, package version and generic attributes                                                                                                                                                                                                                                                                                         Apr 27, 2025    5 - Production/Stable  pytest>=8.3.3
   :pypi:`pytest-edit`                                      Edit the source code of a failed test with \`pytest --edit\`.                                                                                                                                                                                                                                                                                                                           Nov 17, 2024    N/A                    pytest
   :pypi:`pytest-egg`                                       A pytest plugin that prints egg ascii art at the end of a test run.                                                                                                                                                                                                                                                                                                                     Apr 17, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-ekstazi`                                   Pytest plugin to select test using Ekstazi algorithm                                                                                                                                                                                                                                                                                                                                    Sep 10, 2022    N/A                    pytest
   :pypi:`pytest-elastic-reporter`                                                                                                                                                                                                                                                                                                                                                                                                                  Mar 13, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-elasticsearch`                             Elasticsearch fixtures and fixture factories for Pytest.                                                                                                                                                                                                                                                                                                                                Feb 16, 2026    5 - Production/Stable  pytest>=8.4.0
   :pypi:`pytest-elasticsearch-test`                        Elasticsearch fixtures and fixture factories for Pytest.                                                                                                                                                                                                                                                                                                                                Apr 20, 2025    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-elegant`                                   A pytest plugin that provides elegant, beautiful test output                                                                                                                                                                                                                                                                                                                            Apr 13, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-elements`                                  Tool to help automate user interfaces                                                                                                                                                                                                                                                                                                                                                   Jan 13, 2021    N/A                    pytest (>=5.4,<6.0)
   :pypi:`pytest-eliot`                                     An eliot plugin for pytest.                                                                                                                                                                                                                                                                                                                                                             Aug 31, 2022    1 - Planning           pytest (>=5.4.0)
   :pypi:`pytest-elk-reporter`                              A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Jul 25, 2024    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-email`                                     Send execution result email                                                                                                                                                                                                                                                                                                                                                             Jul 08, 2020    N/A                    pytest
   :pypi:`pytest-embedded`                                  A pytest plugin that designed for embedded testing.                                                                                                                                                                                                                                                                                                                                     May 15, 2026    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-embedded-arduino`                          Make pytest-embedded plugin work with Arduino.                                                                                                                                                                                                                                                                                                                                          May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-arduino-cli`                      A pytest plugin to test Arduino projects using pytest-embedded and arduino-cli                                                                                                                                                                                                                                                                                                          May 20, 2026    N/A                    pytest>=8
   :pypi:`pytest-embedded-idf`                              Make pytest-embedded plugin work with ESP-IDF.                                                                                                                                                                                                                                                                                                                                          May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-jtag`                             Make pytest-embedded plugin work with JTAG.                                                                                                                                                                                                                                                                                                                                             May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-nuttx`                            Make pytest-embedded plugin work with NuttX.                                                                                                                                                                                                                                                                                                                                            May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-qemu`                             Make pytest-embedded plugin work with QEMU.                                                                                                                                                                                                                                                                                                                                             May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-serial`                           Make pytest-embedded plugin work with Serial.                                                                                                                                                                                                                                                                                                                                           May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-serial-esp`                       Make pytest-embedded plugin work with Espressif target boards.                                                                                                                                                                                                                                                                                                                          May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embedded-wokwi`                            Make pytest-embedded plugin work with the Wokwi CLI.                                                                                                                                                                                                                                                                                                                                    May 15, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-embrace`                                   💝  Dataclasses-as-tests. Describe the runtime once and multiply coverage with no boilerplate.                                                                                                                                                                                                                                                                                          Mar 25, 2023    N/A                    pytest (>=7.0,<8.0)
   :pypi:`pytest-emoji`                                     A pytest plugin that adds emojis to your test result report                                                                                                                                                                                                                                                                                                                             Feb 19, 2019    4 - Beta               pytest (>=4.2.1)
   :pypi:`pytest-emoji-output`                              Pytest plugin to represent test output with emoji support                                                                                                                                                                                                                                                                                                                               Apr 09, 2023    4 - Beta               pytest (==7.0.1)
   :pypi:`pytest-enabler`                                   Enable installed pytest plugins                                                                                                                                                                                                                                                                                                                                                         May 16, 2025    5 - Production/Stable  pytest!=8.1.*,>=6; extra == "test"
   :pypi:`pytest-encode`                                    set your encoding and logger                                                                                                                                                                                                                                                                                                                                                            Nov 06, 2021    N/A                    N/A
   :pypi:`pytest-encode-kane`                               set your encoding and logger                                                                                                                                                                                                                                                                                                                                                            Nov 16, 2021    N/A                    pytest
   :pypi:`pytest-encoding`                                  set your encoding and logger                                                                                                                                                                                                                                                                                                                                                            Aug 11, 2023    N/A                    pytest
   :pypi:`pytest_energy_reporter`                           An energy estimation reporter for pytest                                                                                                                                                                                                                                                                                                                                                Mar 28, 2024    3 - Alpha              pytest<9.0.0,>=8.1.1
   :pypi:`pytest-enhanced-reports`                          Enhanced test reports for pytest                                                                                                                                                                                                                                                                                                                                                        Dec 15, 2022    N/A                    N/A
   :pypi:`pytest-enhancements`                              Improvements for pytest (rejected upstream)                                                                                                                                                                                                                                                                                                                                             Oct 30, 2019    4 - Beta               N/A
   :pypi:`pytest-env`                                       pytest plugin that allows you to add environment variables.                                                                                                                                                                                                                                                                                                                             Mar 12, 2026    5 - Production/Stable  pytest>=9.0.2
   :pypi:`pytest-envfiles`                                  A py.test plugin that parses environment files before running tests                                                                                                                                                                                                                                                                                                                     Oct 08, 2015    3 - Alpha              N/A
   :pypi:`pytest-env-info`                                  Push information about the running pytest into envvars                                                                                                                                                                                                                                                                                                                                  Nov 25, 2017    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-environment`                               Pytest Environment                                                                                                                                                                                                                                                                                                                                                                      Mar 17, 2024    1 - Planning           N/A
   :pypi:`pytest-envraw`                                    py.test plugin that allows you to add environment variables.                                                                                                                                                                                                                                                                                                                            Aug 27, 2020    4 - Beta               pytest (>=2.6.0)
   :pypi:`pytest-envvars`                                   Pytest plugin to validate use of envvars on your tests                                                                                                                                                                                                                                                                                                                                  Jun 13, 2020    5 - Production/Stable  pytest (>=3.0.0)
   :pypi:`pytest-envx`                                      Pytest plugin for managing environment variables with interpolation and .env file support.                                                                                                                                                                                                                                                                                              Jun 28, 2025    4 - Beta               pytest>=8.4.1
   :pypi:`pytest-env-yaml`                                                                                                                                                                                                                                                                                                                                                                                                                          Apr 02, 2019    N/A                    N/A
   :pypi:`pytest-ephemeral-container`                       Spawn epehemeral containers in pytest                                                                                                                                                                                                                                                                                                                                                   Apr 14, 2026    N/A                    pytest
   :pypi:`pytest-eradicate`                                 pytest plugin to check for commented out code                                                                                                                                                                                                                                                                                                                                           Sep 08, 2020    N/A                    pytest (>=2.4.2)
   :pypi:`pytest_erp`                                       py.test plugin to send test info to report portal dynamically                                                                                                                                                                                                                                                                                                                           Jan 13, 2015    N/A                    N/A
   :pypi:`pytest-error-for-skips`                           Pytest plugin to treat skipped tests a test failure                                                                                                                                                                                                                                                                                                                                     Dec 19, 2019    4 - Beta               pytest (>=4.6)
   :pypi:`pytest-errxfail`                                  pytest plugin to mark a test as xfailed if it fails with the specified error message in the captured output                                                                                                                                                                                                                                                                             Jan 06, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-essentials`                                A Pytest plugin providing essential utilities like soft assertions.                                                                                                                                                                                                                                                                                                                     May 19, 2025    3 - Alpha              pytest>=7.0
   :pypi:`pytest-eth`                                       PyTest plugin for testing Smart Contracts for Ethereum Virtual Machine (EVM).                                                                                                                                                                                                                                                                                                           Aug 14, 2020    1 - Planning           N/A
   :pypi:`pytest-ethereum`                                  pytest-ethereum: Pytest library for ethereum projects.                                                                                                                                                                                                                                                                                                                                  Jun 24, 2019    3 - Alpha              pytest (==3.3.2); extra == 'dev'
   :pypi:`pytest-eucalyptus`                                Pytest Plugin for BDD                                                                                                                                                                                                                                                                                                                                                                   Jun 28, 2022    N/A                    pytest (>=4.2.0)
   :pypi:`pytest-eval`                                      LLM testing for humans.                                                                                                                                                                                                                                                                                                                                                                 Feb 11, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-evals`                                     A pytest plugin for running and analyzing LLM evaluation tests                                                                                                                                                                                                                                                                                                                          Feb 02, 2025    N/A                    pytest>=7.0.0
   :pypi:`pytest-eventlet`                                  Applies eventlet monkey-patch as a pytest plugin.                                                                                                                                                                                                                                                                                                                                       Oct 04, 2021    N/A                    pytest ; extra == 'dev'
   :pypi:`pytest-everyfunc`                                 A pytest plugin to detect completely untested functions using coverage                                                                                                                                                                                                                                                                                                                  Apr 30, 2025    4 - Beta               pytest
   :pypi:`pytest_evm`                                       The testing package containing tools to test Web3-based projects                                                                                                                                                                                                                                                                                                                        Sep 23, 2024    4 - Beta               pytest<9.0.0,>=8.1.1
   :pypi:`pytest_exact_fixtures`                            Parse queries in Lucene and Elasticsearch syntaxes                                                                                                                                                                                                                                                                                                                                      Feb 04, 2019    N/A                    N/A
   :pypi:`pytest-examples`                                  Pytest plugin for testing examples in docstrings and markdown files.                                                                                                                                                                                                                                                                                                                    May 06, 2025    N/A                    pytest>=7
   :pypi:`pytest-exasol-backend`                                                                                                                                                                                                                                                                                                                                                                                                                    May 05, 2026    N/A                    pytest<10,>=7
   :pypi:`pytest-exasol-extension`                                                                                                                                                                                                                                                                                                                                                                                                                  May 05, 2026    N/A                    pytest<10,>=7
   :pypi:`pytest-exasol-itde`                                                                                                                                                                                                                                                                                                                                                                                                                       Nov 22, 2024    N/A                    pytest<9,>=7
   :pypi:`pytest-exasol-saas`                                                                                                                                                                                                                                                                                                                                                                                                                       Nov 22, 2024    N/A                    pytest<9,>=7
   :pypi:`pytest-exasol-slc`                                                                                                                                                                                                                                                                                                                                                                                                                        May 05, 2026    N/A                    pytest<10,>=7
   :pypi:`pytest-excel`                                     pytest plugin for generating excel reports                                                                                                                                                                                                                                                                                                                                              Jul 22, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-exceptional`                               Better exceptions                                                                                                                                                                                                                                                                                                                                                                       Mar 16, 2017    4 - Beta               N/A
   :pypi:`pytest-exception-script`                          Walk your code through exception script to check it's resiliency to failures.                                                                                                                                                                                                                                                                                                           Aug 04, 2020    3 - Alpha              pytest
   :pypi:`pytest-executable`                                pytest plugin for testing executables                                                                                                                                                                                                                                                                                                                                                   Oct 07, 2023    N/A                    pytest <8,>=5
   :pypi:`pytest-execution-timer`                           A timer for the phases of Pytest's execution.                                                                                                                                                                                                                                                                                                                                           Dec 24, 2021    4 - Beta               N/A
   :pypi:`pytest-exit-code`                                 A pytest plugin that overrides the built-in exit codes to retain more information about the test results.                                                                                                                                                                                                                                                                               May 06, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-exit-status`                               Enhance.                                                                                                                                                                                                                                                                                                                                                                                Jan 25, 2025    N/A                    pytest>=8.0.0
   :pypi:`pytest-expect`                                    py.test plugin to store test expectations and mark tests based on them                                                                                                                                                                                                                                                                                                                  Apr 21, 2016    4 - Beta               N/A
   :pypi:`pytest-expectdir`                                 A pytest plugin to provide initial/expected directories, and check a test transforms the initial directory to the expected one                                                                                                                                                                                                                                                          Mar 19, 2023    5 - Production/Stable  pytest (>=5.0)
   :pypi:`pytest-expected`                                  Record and play back your expectations                                                                                                                                                                                                                                                                                                                                                  Feb 26, 2025    N/A                    pytest
   :pypi:`pytest-expecter`                                  Better testing with expecter and pytest.                                                                                                                                                                                                                                                                                                                                                Sep 18, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-expectr`                                   This plugin is used to expect multiple assert using pytest framework.                                                                                                                                                                                                                                                                                                                   Oct 05, 2018    N/A                    pytest (>=2.4.2)
   :pypi:`pytest-expect-test`                               A fixture to support expect tests in pytest                                                                                                                                                                                                                                                                                                                                             Apr 10, 2023    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-experiments`                               A pytest plugin to help developers of research-oriented software projects keep track of the results of their numerical experiments.                                                                                                                                                                                                                                                     Dec 13, 2021    4 - Beta               pytest (>=6.2.5,<7.0.0)
   :pypi:`pytest-explicit`                                  A Pytest plugin to ignore certain marked tests by default                                                                                                                                                                                                                                                                                                                               Jun 15, 2021    5 - Production/Stable  pytest
   :pypi:`pytest-exploratory`                               Interactive console for pytest.                                                                                                                                                                                                                                                                                                                                                         Sep 18, 2024    N/A                    pytest>=6.2
   :pypi:`pytest-explorer`                                  terminal ui for exploring and running tests                                                                                                                                                                                                                                                                                                                                             Aug 01, 2023    N/A                    N/A
   :pypi:`pytest-ext`                                       pytest plugin for automation test                                                                                                                                                                                                                                                                                                                                                       Mar 31, 2024    N/A                    pytest>=5.3
   :pypi:`pytest-extended-mock`                             a pytest extension for easy mock setup                                                                                                                                                                                                                                                                                                                                                  Mar 12, 2025    N/A                    pytest<9.0.0,>=8.3.5
   :pypi:`pytest-extensions`                                A collection of helpers for pytest to ease testing                                                                                                                                                                                                                                                                                                                                      Aug 17, 2022    4 - Beta               pytest ; extra == 'testing'
   :pypi:`pytest-external-blockers`                         a special outcome for tests that are blocked for external reasons                                                                                                                                                                                                                                                                                                                       Oct 05, 2021    N/A                    pytest
   :pypi:`pytest_extra`                                     Some helpers for writing tests with pytest.                                                                                                                                                                                                                                                                                                                                             Aug 14, 2014    N/A                    N/A
   :pypi:`pytest-extra-durations`                           A pytest plugin to get durations on a per-function basis and per module basis.                                                                                                                                                                                                                                                                                                          Apr 21, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-extra-markers`                             Additional pytest markers to dynamically enable/disable tests viia CLI flags                                                                                                                                                                                                                                                                                                            Mar 05, 2023    4 - Beta               pytest
   :pypi:`pytest-f3ts`                                      Pytest Plugin for communicating test results and information to a FixturFab Test Runner GUI                                                                                                                                                                                                                                                                                             Mar 09, 2026    N/A                    pytest<8.0.0,>=7.2.1
   :pypi:`pytest-fabric`                                    Provides test utilities to run fabric task tests by using docker containers                                                                                                                                                                                                                                                                                                             Sep 12, 2018    5 - Production/Stable  N/A
   :pypi:`pytest-factory`                                   Use factories for test setup with py.test                                                                                                                                                                                                                                                                                                                                               Sep 06, 2020    3 - Alpha              pytest (>4.3)
   :pypi:`pytest-factoryboy`                                Factory Boy support for pytest.                                                                                                                                                                                                                                                                                                                                                         Jul 01, 2025    6 - Mature             pytest>=7.0
   :pypi:`pytest-factoryboy-fixtures`                       Generates pytest fixtures that allow the use of type hinting                                                                                                                                                                                                                                                                                                                            Jun 25, 2020    N/A                    N/A
   :pypi:`pytest-factoryboy-state`                          Simple factoryboy random state management                                                                                                                                                                                                                                                                                                                                               Mar 22, 2022    5 - Production/Stable  pytest (>=5.0)
   :pypi:`pytest-fahhh`                                     A pytest plugin that plays the fahhh meme sound when a test fails.                                                                                                                                                                                                                                                                                                                      Apr 16, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-failed-screen-record`                      Create a video of the screen when pytest fails                                                                                                                                                                                                                                                                                                                                          Jan 05, 2023    4 - Beta               pytest (>=7.1.2d,<8.0.0)
   :pypi:`pytest-failed-screenshot`                         Test case fails,take a screenshot,save it,attach it to the allure                                                                                                                                                                                                                                                                                                                       Apr 21, 2021    N/A                    N/A
   :pypi:`pytest-failed-to-verify`                          A pytest plugin that helps better distinguishing real test failures from setup flakiness.                                                                                                                                                                                                                                                                                               Aug 08, 2019    5 - Production/Stable  pytest (>=4.1.0)
   :pypi:`pytest-fail-slow`                                 Fail tests that take too long to run                                                                                                                                                                                                                                                                                                                                                    Jun 01, 2024    N/A                    pytest>=7.0
   :pypi:`pytest-failure-tracker`                           A pytest plugin for tracking test failures over multiple runs                                                                                                                                                                                                                                                                                                                           Jul 17, 2024    N/A                    pytest>=6.0.0
   :pypi:`pytest-fakellm`                                   Pytest fixtures for the fakellm mock OpenAI/Anthropic server — spin up, reset, and assert with zero boilerplate.                                                                                                                                                                                                                                                                        May 21, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-faker`                                     Faker integration with the pytest framework.                                                                                                                                                                                                                                                                                                                                            Dec 19, 2016    6 - Mature             N/A
   :pypi:`pytest-falcon`                                    Pytest helpers for Falcon.                                                                                                                                                                                                                                                                                                                                                              Sep 07, 2016    4 - Beta               N/A
   :pypi:`pytest-fantasy`                                   Pytest plugin for Flask Fantasy Framework                                                                                                                                                                                                                                                                                                                                               Mar 14, 2019    N/A                    N/A
   :pypi:`pytest-fastapi`                                                                                                                                                                                                                                                                                                                                                                                                                           Dec 27, 2020    N/A                    N/A
   :pypi:`pytest-fastapi-deps`                              A fixture which allows easy replacement of fastapi dependencies for testing                                                                                                                                                                                                                                                                                                             Jul 20, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-fastcollect`                               A high-performance pytest plugin that replaces test collection with a Rust-based implementation                                                                                                                                                                                                                                                                                         Nov 19, 2025    N/A                    pytest>=7.0.0
   :pypi:`pytest-fastest`                                   Use SCM and coverage to run only needed tests                                                                                                                                                                                                                                                                                                                                           Oct 04, 2023    4 - Beta               pytest (>=4.4)
   :pypi:`pytest-fast-first`                                Pytest plugin that runs fast tests first                                                                                                                                                                                                                                                                                                                                                Jan 19, 2023    3 - Alpha              pytest
   :pypi:`pytest-fastprom`                                  Isolated Prometheus metrics assertions for FastAPI tests                                                                                                                                                                                                                                                                                                                                May 22, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-faulthandler`                              py.test plugin that activates the fault handler module for tests (dummy package)                                                                                                                                                                                                                                                                                                        Jul 04, 2019    6 - Mature             pytest (>=5.0)
   :pypi:`pytest-fauna`                                     A collection of helpful test fixtures for Fauna DB.                                                                                                                                                                                                                                                                                                                                     Jan 03, 2025    N/A                    N/A
   :pypi:`pytest-fauxfactory`                               Integration of fauxfactory into pytest.                                                                                                                                                                                                                                                                                                                                                 Dec 06, 2017    5 - Production/Stable  pytest (>=3.2)
   :pypi:`pytest-figleaf`                                   py.test figleaf coverage plugin                                                                                                                                                                                                                                                                                                                                                         Jan 18, 2010    5 - Production/Stable  N/A
   :pypi:`pytest-file`                                      Pytest File                                                                                                                                                                                                                                                                                                                                                                             Mar 18, 2024    1 - Planning           N/A
   :pypi:`pytest-filecov`                                   A pytest plugin to detect unused files                                                                                                                                                                                                                                                                                                                                                  Jun 27, 2021    4 - Beta               pytest
   :pypi:`pytest-filedata`                                  easily load test data from files                                                                                                                                                                                                                                                                                                                                                        Apr 29, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-filemarker`                                A pytest plugin that runs marked tests when files change.                                                                                                                                                                                                                                                                                                                               Dec 01, 2020    N/A                    pytest
   :pypi:`pytest-file-watcher`                              Pytest-File-Watcher is a CLI tool that watches for changes in your code and runs pytest on the changed files.                                                                                                                                                                                                                                                                           Mar 23, 2023    N/A                    pytest
   :pypi:`pytest-filter-case`                               run test cases filter by mark                                                                                                                                                                                                                                                                                                                                                           Nov 05, 2020    N/A                    N/A
   :pypi:`pytest-filterfixtures`                            pytest plugin to execute or ignore tests based on fixtures                                                                                                                                                                                                                                                                                                                              Jan 09, 2026    N/A                    pytest>=9.0.2
   :pypi:`pytest-filter-subpackage`                         Pytest plugin for filtering based on sub-packages                                                                                                                                                                                                                                                                                                                                       Mar 04, 2024    5 - Production/Stable  pytest >=4.6
   :pypi:`pytest-find-dependencies`                         A pytest plugin to find dependencies between tests                                                                                                                                                                                                                                                                                                                                      Jul 16, 2025    5 - Production/Stable  pytest>=6.2.4
   :pypi:`pytest-finer-verdicts`                            A pytest plugin to treat non-assertion failures as test errors.                                                                                                                                                                                                                                                                                                                         Jun 18, 2020    N/A                    pytest (>=5.4.3)
   :pypi:`pytest-firefox`                                                                                                                                                                                                                                                                                                                                                                                                                           Feb 28, 2025    N/A                    N/A
   :pypi:`pytest-firestore`                                 A Pytest fixture for managing Google Cloud Firestore emulator                                                                                                                                                                                                                                                                                                                           Mar 10, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-fixedpoint`                                Pytest plugin for recording and replaying deterministic function calls                                                                                                                                                                                                                                                                                                                  Mar 12, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-fixkit`                                    A set of useful pytest fixtures that I use everyday.                                                                                                                                                                                                                                                                                                                                    May 12, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-fixture-cache`                             Smart fixture caching for pytest with SQLite storage                                                                                                                                                                                                                                                                                                                                    Jan 25, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-fixturecheck`                              A pytest plugin to check fixture validity before test execution                                                                                                                                                                                                                                                                                                                         Jun 02, 2025    3 - Alpha              pytest>=6.0.0
   :pypi:`pytest-fixture-classes`                           Fixtures as classes that work well with dependency injection, autocompletetion, type checkers, and language servers                                                                                                                                                                                                                                                                     Oct 12, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-fixture-collect`                           A utility to collect pytest fixture file paths.                                                                                                                                                                                                                                                                                                                                         Jul 25, 2025    N/A                    pytest; extra == "test"
   :pypi:`pytest-fixturecollection`                         A pytest plugin to collect tests based on fixtures being used by tests                                                                                                                                                                                                                                                                                                                  Feb 22, 2024    4 - Beta               pytest >=3.5.0
   :pypi:`pytest-fixture-config`                            Fixture configuration utils for py.test                                                                                                                                                                                                                                                                                                                                                 Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-fixture-forms`                             A pytest plugin for creating fixtures that holds different forms between tests.                                                                                                                                                                                                                                                                                                         Dec 06, 2024    N/A                    pytest<9.0.0,>=7.0.0
   :pypi:`pytest-fixture-maker`                             Pytest plugin to load fixtures from YAML files                                                                                                                                                                                                                                                                                                                                          Sep 21, 2021    N/A                    N/A
   :pypi:`pytest-fixture-marker`                            A pytest plugin to add markers based on fixtures used.                                                                                                                                                                                                                                                                                                                                  Oct 11, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-fixture-order`                             pytest plugin to control fixture evaluation order                                                                                                                                                                                                                                                                                                                                       Oct 22, 2025    5 - Production/Stable  pytest>=3.0
   :pypi:`pytest-fixture-ref`                               Lets users reference fixtures without name matching magic.                                                                                                                                                                                                                                                                                                                              Nov 17, 2022    4 - Beta               N/A
   :pypi:`pytest-fixture-remover`                           A LibCST codemod to remove pytest fixtures applied via the usefixtures decorator, as well as its parametrizations.                                                                                                                                                                                                                                                                      Feb 14, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-fixture-rtttg`                             Warn or fail on fixture name clash                                                                                                                                                                                                                                                                                                                                                      Feb 23, 2022    N/A                    pytest (>=7.0.1,<8.0.0)
   :pypi:`pytest-fixtures`                                  Common fixtures for pytest                                                                                                                                                                                                                                                                                                                                                              May 01, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-fixtures-fixtures`                         Handy fixtues to access your fixtures from your _pytest tests.                                                                                                                                                                                                                                                                                                                          Nov 06, 2025    4 - Beta               pytest>=8.4.1
   :pypi:`pytest-fixture-timing`                            Tiny plugin to report total duration per fixture                                                                                                                                                                                                                                                                                                                                        Dec 11, 2025    N/A                    pytest>=7.0
   :pypi:`pytest-fixture-tools`                             Plugin for pytest which provides tools for fixtures                                                                                                                                                                                                                                                                                                                                     Apr 30, 2025    6 - Mature             pytest
   :pypi:`pytest-fixture-typecheck`                         A pytest plugin to assert type annotations at runtime.                                                                                                                                                                                                                                                                                                                                  Aug 24, 2021    N/A                    pytest
   :pypi:`pytest-fkit`                                      A pytest plugin that prevents crashes from killing your test suite                                                                                                                                                                                                                                                                                                                      Apr 21, 2026    N/A                    pytest>=6.0.0
   :pypi:`pytest-flake8`                                    pytest plugin to check FLAKE8 requirements                                                                                                                                                                                                                                                                                                                                              Nov 09, 2024    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-flake8-path`                               A pytest fixture for testing flake8 plugins.                                                                                                                                                                                                                                                                                                                                            Sep 09, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-flake8-v2`                                 pytest plugin to check FLAKE8 requirements                                                                                                                                                                                                                                                                                                                                              Mar 01, 2022    5 - Production/Stable  pytest (>=7.0)
   :pypi:`pytest-flake-detection`                           Continuously runs your tests to detect flaky tests                                                                                                                                                                                                                                                                                                                                      Nov 29, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-flakefighters`                             Pytest plugin implementing flaky test failure detection and classification.                                                                                                                                                                                                                                                                                                             Mar 05, 2026    N/A                    pytest>=6.2.0
   :pypi:`pytest-flakefinder`                               Runs tests multiple times to expose flakiness.                                                                                                                                                                                                                                                                                                                                          Oct 26, 2022    4 - Beta               pytest (>=2.7.1)
   :pypi:`pytest-flakehunter`                               Re-run tests N times, visualize failure heatmaps, and get AI root cause hypotheses                                                                                                                                                                                                                                                                                                      Apr 07, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-flakemark`                                 Differential execution tracer that finds the exact file, line, and root cause of any flaky test.                                                                                                                                                                                                                                                                                        May 01, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-flakes`                                    pytest plugin to check source code with pyflakes                                                                                                                                                                                                                                                                                                                                        Dec 02, 2021    5 - Production/Stable  pytest (>=5)
   :pypi:`pytest-flakiness`                                 Pytest reporter for Flakiness.io                                                                                                                                                                                                                                                                                                                                                        May 15, 2026    N/A                    pytest>=9.0.2
   :pypi:`pytest-flaptastic`                                Flaptastic py.test plugin                                                                                                                                                                                                                                                                                                                                                               Mar 17, 2019    N/A                    N/A
   :pypi:`pytest-flask`                                     A set of py.test fixtures to test Flask applications.                                                                                                                                                                                                                                                                                                                                   Oct 23, 2023    5 - Production/Stable  pytest >=5.2
   :pypi:`pytest-flask-ligand`                                                                                                                                                                                                                                                                                                                                                                                                                      May 14, 2026    4 - Beta               pytest>=7.3
   :pypi:`pytest-flask-sqlalchemy`                          A pytest plugin for preserving test isolation in Flask-SQlAlchemy using database transactions.                                                                                                                                                                                                                                                                                          Apr 30, 2022    4 - Beta               pytest (>=3.2.1)
   :pypi:`pytest-flask-sqlalchemy-transactions`             Run tests in transactions using pytest, Flask, and SQLalchemy.                                                                                                                                                                                                                                                                                                                          Aug 02, 2018    4 - Beta               pytest (>=3.2.1)
   :pypi:`pytest-flexreport`                                                                                                                                                                                                                                                                                                                                                                                                                        Apr 15, 2023    4 - Beta               pytest
   :pypi:`pytest-fluent`                                    A pytest plugin in order to provide logs via fluentd                                                                                                                                                                                                                                                                                                                                    Aug 14, 2024    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-fluentbit`                                 A pytest plugin in order to provide logs via fluentbit                                                                                                                                                                                                                                                                                                                                  Jun 16, 2023    4 - Beta               pytest (>=7.0.0)
   :pypi:`pytest-fly`                                       pytest runner and observer                                                                                                                                                                                                                                                                                                                                                              Jun 06, 2026    3 - Alpha              pytest
   :pypi:`pytest-flyte`                                     Pytest fixtures for simplifying Flyte integration testing                                                                                                                                                                                                                                                                                                                               May 03, 2021    N/A                    pytest
   :pypi:`pytest-fmu-filter`                                A pytest plugin to filter fmus                                                                                                                                                                                                                                                                                                                                                          Jun 23, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-focus`                                     A pytest plugin that alerts user of failed test cases with screen notifications                                                                                                                                                                                                                                                                                                         May 04, 2019    4 - Beta               pytest
   :pypi:`pytest-forbid`                                                                                                                                                                                                                                                                                                                                                                                                                            Mar 07, 2023    N/A                    pytest (>=7.2.2,<8.0.0)
   :pypi:`pytest-forcefail`                                 py.test plugin to make the test failing regardless of pytest.mark.xfail                                                                                                                                                                                                                                                                                                                 May 15, 2018    4 - Beta               N/A
   :pypi:`pytest-forger`                                    Automatic test scaffolding and mock generation for Python                                                                                                                                                                                                                                                                                                                               Mar 09, 2026    N/A                    pytest>=7.4.0
   :pypi:`pytest-forward-compatability`                     A name to avoid typosquating pytest-foward-compatibility                                                                                                                                                                                                                                                                                                                                Sep 06, 2020    N/A                    N/A
   :pypi:`pytest-forward-compatibility`                     A pytest plugin to shim pytest commandline options for fowards compatibility                                                                                                                                                                                                                                                                                                            Sep 29, 2020    N/A                    N/A
   :pypi:`pytest-frappe`                                    Pytest Frappe Plugin - A set of pytest fixtures to test Frappe applications                                                                                                                                                                                                                                                                                                             Jul 30, 2024    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-freethreaded`                              pytest plugin for running parallel tests                                                                                                                                                                                                                                                                                                                                                Oct 03, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-freeze`                                    Pytest plugin to simplify writing freeze tests.                                                                                                                                                                                                                                                                                                                                         Jan 27, 2026    N/A                    N/A
   :pypi:`pytest-freezeblaster`                             Wrap tests with fixtures in freeze_time                                                                                                                                                                                                                                                                                                                                                 Oct 13, 2025    N/A                    pytest>=6.2.5
   :pypi:`pytest-freezegun`                                 Wrap tests with fixtures in freeze_time                                                                                                                                                                                                                                                                                                                                                 Jul 19, 2020    4 - Beta               pytest (>=3.0.0)
   :pypi:`pytest-freezer`                                   Pytest plugin providing a fixture interface for spulec/freezegun                                                                                                                                                                                                                                                                                                                        Dec 12, 2024    N/A                    pytest>=3.6
   :pypi:`pytest-freeze-reqs`                               Check if requirement files are frozen                                                                                                                                                                                                                                                                                                                                                   Apr 29, 2021    N/A                    N/A
   :pypi:`pytest-frozen-uuids`                              Deterministically frozen UUID's for your tests                                                                                                                                                                                                                                                                                                                                          Apr 17, 2022    N/A                    pytest (>=3.0)
   :pypi:`pytest-fsd`                                       Feature-Sliced Design (FSD) architecture validation plugin for pytest                                                                                                                                                                                                                                                                                                                   May 13, 2026    4 - Beta               N/A
   :pypi:`pytest_ftpserver`                                 A PyTest plugin which provides an FTP fixture for your tests                                                                                                                                                                                                                                                                                                                            Feb 10, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-func-cov`                                  Pytest plugin for measuring function coverage                                                                                                                                                                                                                                                                                                                                           Apr 15, 2021    3 - Alpha              pytest (>=5)
   :pypi:`pytest-funcnodes`                                 Testing plugin for funcnodes                                                                                                                                                                                                                                                                                                                                                            Dec 21, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-funparam`                                  An alternative way to parametrize test cases.                                                                                                                                                                                                                                                                                                                                           Dec 02, 2021    4 - Beta               pytest >=4.6.0
   :pypi:`pytest-fusesoc`                                   Pytest plugin to run FuseSoC simulation targets.                                                                                                                                                                                                                                                                                                                                        May 31, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-fv`                                        pytest extensions to support running functional-verification jobs                                                                                                                                                                                                                                                                                                                       Jun 06, 2025    N/A                    pytest
   :pypi:`pytest-fxa`                                       pytest plugin for Firefox Accounts                                                                                                                                                                                                                                                                                                                                                      Aug 28, 2018    5 - Production/Stable  N/A
   :pypi:`pytest-fxa-mte`                                   pytest plugin for Firefox Accounts                                                                                                                                                                                                                                                                                                                                                      May 21, 2026    4 - Beta               N/A
   :pypi:`pytest-fxtest`                                                                                                                                                                                                                                                                                                                                                                                                                            Oct 27, 2020    N/A                    N/A
   :pypi:`pytest-fzf`                                       fzf-based test selector for pytest                                                                                                                                                                                                                                                                                                                                                      Jan 06, 2025    4 - Beta               pytest>=6.0.0
   :pypi:`pytest_gae`                                       pytest plugin for apps written with Google's AppEngine                                                                                                                                                                                                                                                                                                                                  Aug 03, 2016    3 - Alpha              N/A
   :pypi:`pytest-gak`                                       A Pytest plugin and command line tool for interactive testing with Pytest                                                                                                                                                                                                                                                                                                               Apr 10, 2025    N/A                    N/A
   :pypi:`pytest-gather-fixtures`                           set up asynchronous pytest fixtures concurrently                                                                                                                                                                                                                                                                                                                                        Aug 18, 2024    N/A                    pytest>=7.0.0
   :pypi:`pytest-gc`                                        The garbage collector plugin for py.test                                                                                                                                                                                                                                                                                                                                                Feb 01, 2018    N/A                    N/A
   :pypi:`pytest-gcov`                                      Uses gcov to measure test coverage of a C library                                                                                                                                                                                                                                                                                                                                       Feb 01, 2018    3 - Alpha              N/A
   :pypi:`pytest-gcppubsub`                                 A Pytest fixture for managing Google Cloud Platform PubSub emulator                                                                                                                                                                                                                                                                                                                     Mar 10, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-gcpsecretmanager`                          A PyTest plugin for mocking GCP's Secret Manager                                                                                                                                                                                                                                                                                                                                        Feb 18, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-gcs`                                       GCS fixtures and fixture factories for Pytest.                                                                                                                                                                                                                                                                                                                                          Jan 24, 2025    5 - Production/Stable  pytest>=6.2
   :pypi:`pytest-gee`                                       The Python plugin for your GEE based packages.                                                                                                                                                                                                                                                                                                                                          Oct 16, 2025    3 - Alpha              pytest
   :pypi:`pytest-gevent`                                    Ensure that gevent is properly patched when invoking pytest                                                                                                                                                                                                                                                                                                                             Feb 25, 2020    N/A                    pytest
   :pypi:`pytest-gherkin`                                   A flexible framework for executing BDD gherkin tests                                                                                                                                                                                                                                                                                                                                    Jul 27, 2019    3 - Alpha              pytest (>=5.0.0)
   :pypi:`pytest-gh-log-group`                              pytest plugin for gh actions                                                                                                                                                                                                                                                                                                                                                            Jan 11, 2022    3 - Alpha              pytest
   :pypi:`pytest-ghostinspector`                            For finding/executing Ghost Inspector tests                                                                                                                                                                                                                                                                                                                                             May 17, 2016    3 - Alpha              N/A
   :pypi:`pytest-girder`                                    A set of pytest fixtures for testing Girder applications.                                                                                                                                                                                                                                                                                                                               Jun 02, 2026    N/A                    pytest>=3.6
   :pypi:`pytest-git`                                       Git repository fixture for py.test                                                                                                                                                                                                                                                                                                                                                      Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-gitconfig`                                 Provide a Git config sandbox for testing                                                                                                                                                                                                                                                                                                                                                Dec 28, 2025    4 - Beta               pytest>=7.1.2
   :pypi:`pytest-gitcov`                                    Pytest plugin for reporting on coverage of the last git commit.                                                                                                                                                                                                                                                                                                                         Jan 11, 2020    2 - Pre-Alpha          N/A
   :pypi:`pytest-git-diff`                                  Pytest plugin that allows the user to select the tests affected by a range of git commits                                                                                                                                                                                                                                                                                               Apr 02, 2024    N/A                    N/A
   :pypi:`pytest-git-fixtures`                              Pytest fixtures for testing with git.                                                                                                                                                                                                                                                                                                                                                   Mar 11, 2021    4 - Beta               pytest
   :pypi:`pytest-github`                                    Plugin for py.test that associates tests with github issues using a marker.                                                                                                                                                                                                                                                                                                             Mar 07, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-github-actions-annotate-failures`          pytest plugin to annotate failed tests with a workflow command for GitHub Actions                                                                                                                                                                                                                                                                                                       Mar 02, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-github-report`                             Generate a GitHub report using pytest in GitHub Workflows                                                                                                                                                                                                                                                                                                                               Jun 03, 2022    4 - Beta               N/A
   :pypi:`pytest-gitignore`                                 py.test plugin to ignore the same files as git                                                                                                                                                                                                                                                                                                                                          Jul 17, 2015    4 - Beta               N/A
   :pypi:`pytest-gitlab`                                    Pytest Plugin for Gitlab                                                                                                                                                                                                                                                                                                                                                                Oct 16, 2024    N/A                    N/A
   :pypi:`pytest-gitlabci-parallelized`                     Parallelize pytest across GitLab CI workers.                                                                                                                                                                                                                                                                                                                                            Mar 08, 2023    N/A                    N/A
   :pypi:`pytest-gitlab-code-quality`                       Collects warnings while testing and generates a GitLab Code Quality Report.                                                                                                                                                                                                                                                                                                             Apr 27, 2026    N/A                    pytest>=5.0.0
   :pypi:`pytest-gitlab-fold`                               Folds output sections in GitLab CI build log                                                                                                                                                                                                                                                                                                                                            Dec 31, 2023    4 - Beta               pytest >=2.6.0
   :pypi:`pytest-gitscope`                                  A pragmatic pytest plugin that runs only the tests that matter, and ship faster                                                                                                                                                                                                                                                                                                         Sep 24, 2025    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-git-selector`                              Utility to select tests that have had its dependencies modified (as identified by git diff)                                                                                                                                                                                                                                                                                             Nov 17, 2022    N/A                    N/A
   :pypi:`pytest-glamor-allure`                             Extends allure-pytest functionality                                                                                                                                                                                                                                                                                                                                                     Jan 30, 2026    5 - Production/Stable  pytest<=9.0.2
   :pypi:`pytest-glaze`                                     A thin, transparent coat that makes your test output shine.                                                                                                                                                                                                                                                                                                                             May 20, 2026    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-glow-report`                               Beautiful, glowing HTML test reports for PyTest and unittest.                                                                                                                                                                                                                                                                                                                           Dec 08, 2025    4 - Beta               pytest>=6.0; extra == "dev"
   :pypi:`pytest-gnupg-fixtures`                            Pytest fixtures for testing with gnupg.                                                                                                                                                                                                                                                                                                                                                 Mar 04, 2021    4 - Beta               pytest
   :pypi:`pytest-golden`                                    Plugin for pytest that offloads expected outputs to data files                                                                                                                                                                                                                                                                                                                          Jan 06, 2026    5 - Production/Stable  pytest>=6.1.2
   :pypi:`pytest-goldie`                                    A plugin to support golden tests with pytest.                                                                                                                                                                                                                                                                                                                                           May 23, 2023    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-google-chat`                               Notify google chat channel for test results                                                                                                                                                                                                                                                                                                                                             Mar 27, 2022    4 - Beta               pytest
   :pypi:`pytest-google-cloud-storage`                      Pytest custom features, e.g. fixtures and various tests. Aimed to emulate Google Cloud Storage service                                                                                                                                                                                                                                                                                  Sep 11, 2025    N/A                    pytest>=8.0.0
   :pypi:`pytest-grader`                                    Pytest extension for scoring programming assignments.                                                                                                                                                                                                                                                                                                                                   Aug 25, 2025    N/A                    pytest>=8
   :pypi:`pytest-gradescope`                                A pytest plugin for Gradescope integration                                                                                                                                                                                                                                                                                                                                              Apr 29, 2025    N/A                    N/A
   :pypi:`pytest-graphql-schema`                            Get graphql schema as fixture for pytest                                                                                                                                                                                                                                                                                                                                                Oct 18, 2019    N/A                    N/A
   :pypi:`pytest-greendots`                                 Green progress dots                                                                                                                                                                                                                                                                                                                                                                     Feb 08, 2014    3 - Alpha              N/A
   :pypi:`pytest-greener`                                   Pytest plugin for Greener                                                                                                                                                                                                                                                                                                                                                               Dec 24, 2025    N/A                    pytest<9.0.0,>=8.3.3
   :pypi:`pytest-green-light`                               Pytest plugin that gives SQLAlchemy async engines the green light - automatically fixes MissingGreenlet errors                                                                                                                                                                                                                                                                          Nov 03, 2025    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-greet`                                                                                                                                                                                                                                                                                                                                                                                                                             Oct 21, 2025    N/A                    N/A
   :pypi:`pytest-gremlins`                                  Fast-first mutation testing for pytest. Let the gremlins loose, see which ones survive.                                                                                                                                                                                                                                                                                                 Apr 03, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-group-by-class`                            A Pytest plugin for running a subset of your tests by splitting them in to groups of classes.                                                                                                                                                                                                                                                                                           Jun 27, 2023    5 - Production/Stable  pytest (>=2.5)
   :pypi:`pytest-growl`                                     Growl notifications for pytest results.                                                                                                                                                                                                                                                                                                                                                 Jan 13, 2014    5 - Production/Stable  N/A
   :pypi:`pytest-grpc`                                      pytest plugin for grpc                                                                                                                                                                                                                                                                                                                                                                  May 01, 2020    N/A                    pytest (>=3.6.0)
   :pypi:`pytest-grpc-aio`                                  pytest plugin for grpc.aio                                                                                                                                                                                                                                                                                                                                                              Oct 28, 2025    N/A                    pytest>=3.6.0
   :pypi:`pytest-grunnur`                                   Py.Test plugin for Grunnur-based packages.                                                                                                                                                                                                                                                                                                                                              Jul 26, 2024    N/A                    pytest>=6
   :pypi:`pytest_gui_status`                                Show pytest status in gui                                                                                                                                                                                                                                                                                                                                                               Jan 23, 2016    N/A                    pytest
   :pypi:`pytest-hammer`                                    tools such as db tools of pytest                                                                                                                                                                                                                                                                                                                                                        Mar 27, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-hammertime`                                Display "🔨 " instead of "." for passed pytest tests.                                                                                                                                                                                                                                                                                                                                   Jul 28, 2018    N/A                    pytest
   :pypi:`pytest-hardware-test-report`                      A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Apr 01, 2024    4 - Beta               pytest<9.0.0,>=8.0.0
   :pypi:`pytest-harmony`                                   Chain tests and data with pytest                                                                                                                                                                                                                                                                                                                                                        Jan 17, 2023    N/A                    pytest (>=7.2.1,<8.0.0)
   :pypi:`pytest-harvest`                                   Store data created during your pytest tests execution, and retrieve it at the end of the session, e.g. for applicative benchmarking purposes.                                                                                                                                                                                                                                           Mar 16, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-hbtn`                                      Shared pytest fixtures for hbtn-portal task grading                                                                                                                                                                                                                                                                                                                                     May 19, 2026    N/A                    pytest>=8
   :pypi:`pytest-helm`                                      Simple, ergonomic Helm manifest fixtures for pytest.                                                                                                                                                                                                                                                                                                                                    Feb 21, 2026    3 - Alpha              pytest>=8.0.0
   :pypi:`pytest-helm-charts`                               A plugin to provide different types and configs of Kubernetes clusters that can be used for testing.                                                                                                                                                                                                                                                                                    Dec 23, 2025    4 - Beta               pytest<9,>=8.0.0
   :pypi:`pytest-helm-templates`                            Pytest fixtures for unit testing the output of helm templates                                                                                                                                                                                                                                                                                                                           Aug 07, 2024    N/A                    pytest~=7.4.0; extra == "dev"
   :pypi:`pytest-helper`                                    Functions to help in using the pytest testing framework                                                                                                                                                                                                                                                                                                                                 May 31, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-helpers`                                   pytest helpers                                                                                                                                                                                                                                                                                                                                                                          May 17, 2020    N/A                    pytest
   :pypi:`pytest-helpers-namespace`                         Pytest Helpers Namespace Plugin                                                                                                                                                                                                                                                                                                                                                         Dec 29, 2021    5 - Production/Stable  pytest (>=6.0.0)
   :pypi:`pytest-henry`                                                                                                                                                                                                                                                                                                                                                                                                                             Aug 29, 2023    N/A                    N/A
   :pypi:`pytest-hidecaptured`                              Hide captured output                                                                                                                                                                                                                                                                                                                                                                    May 04, 2018    4 - Beta               pytest (>=2.8.5)
   :pypi:`pytest-himark`                                    This plugin aims to create markers automatically based on a json configuration.                                                                                                                                                                                                                                                                                                         Jun 05, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-historic`                                  Custom report to display pytest historical execution records                                                                                                                                                                                                                                                                                                                            Apr 08, 2020    N/A                    pytest
   :pypi:`pytest-historic-hook`                             Custom listener to store execution results into MYSQL DB, which is used for pytest-historic report                                                                                                                                                                                                                                                                                      Apr 08, 2020    N/A                    pytest
   :pypi:`pytest-history`                                   Pytest plugin to keep a history of your pytest runs                                                                                                                                                                                                                                                                                                                                     Jan 14, 2024    N/A                    pytest (>=7.4.3,<8.0.0)
   :pypi:`pytest-home`                                      Home directory fixtures                                                                                                                                                                                                                                                                                                                                                                 Jul 28, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-homeassistant`                             A pytest plugin for use with homeassistant custom components.                                                                                                                                                                                                                                                                                                                           Aug 12, 2020    4 - Beta               N/A
   :pypi:`pytest-homeassistant-custom-component`            Experimental package to automatically extract test plugins for Home Assistant custom components                                                                                                                                                                                                                                                                                         Jun 06, 2026    3 - Alpha              pytest==9.0.3
   :pypi:`pytest-homeassistant-custom-component-framework`  Experimental package to automatically extract test plugins for Home Assistant custom components                                                                                                                                                                                                                                                                                         Jun 06, 2026    3 - Alpha              pytest==9.0.3
   :pypi:`pytest-Honda-report`                              Enterprise-grade pytest HTML report plugin with Chinese UI, API details, and historical trends                                                                                                                                                                                                                                                                                          Apr 11, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-honey`                                     A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Jan 07, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-honors`                                    Report on tests that honor constraints, and guard against regressions                                                                                                                                                                                                                                                                                                                   Mar 06, 2020    4 - Beta               N/A
   :pypi:`pytest-hot-reloading`                                                                                                                                                                                                                                                                                                                                                                                                                     Sep 23, 2024    N/A                    N/A
   :pypi:`pytest-hot-test`                                  A plugin that tracks test changes                                                                                                                                                                                                                                                                                                                                                       Dec 10, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-houdini`                                   pytest plugin for testing code in Houdini                                                                                                                                                                                                                                                                                                                                               May 27, 2026    N/A                    pytest<10.0.0,>=9.0.3
   :pypi:`pytest-hoverfly`                                  Simplify working with Hoverfly from pytest                                                                                                                                                                                                                                                                                                                                              Jan 30, 2023    N/A                    pytest (>=5.0)
   :pypi:`pytest-hoverfly-wrapper`                          Integrates the Hoverfly HTTP proxy into Pytest                                                                                                                                                                                                                                                                                                                                          Feb 27, 2023    5 - Production/Stable  pytest (>=3.7.0)
   :pypi:`pytest-hpfeeds`                                   Helpers for testing hpfeeds in your python project                                                                                                                                                                                                                                                                                                                                      Feb 28, 2023    4 - Beta               pytest (>=6.2.4,<7.0.0)
   :pypi:`pytest-html`                                      pytest plugin for generating HTML reports                                                                                                                                                                                                                                                                                                                                               Jan 19, 2026    5 - Production/Stable  pytest>=7
   :pypi:`pytest-html5`                                     the best report for pytest                                                                                                                                                                                                                                                                                                                                                              Dec 18, 2025    N/A                    N/A
   :pypi:`pytest-html-cn`                                   pytest plugin for generating HTML reports                                                                                                                                                                                                                                                                                                                                               Aug 19, 2024    5 - Production/Stable  pytest!=6.0.0,>=5.0
   :pypi:`pytest-html-dashboard`                            Beautiful dashboard-style HTML reports for pytest with charts, error analysis, and visual insights                                                                                                                                                                                                                                                                                      Nov 24, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-html-lee`                                  optimized pytest plugin for generating HTML reports                                                                                                                                                                                                                                                                                                                                     Jun 30, 2020    5 - Production/Stable  pytest (>=5.0)
   :pypi:`pytest-html-merger`                               Pytest HTML reports merging utility                                                                                                                                                                                                                                                                                                                                                     Jul 12, 2024    N/A                    N/A
   :pypi:`pytest-html-nova-act`                             A Pytest Plugin for Amazon Nova Act Python SDK.                                                                                                                                                                                                                                                                                                                                         Mar 30, 2026    N/A                    N/A
   :pypi:`pytest-html-object-storage`                       Pytest report plugin for send HTML report on object-storage                                                                                                                                                                                                                                                                                                                             Jan 17, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-html-plus`                                 Generate Actionable, automatic screenshots, unified Mobile friendly Pytest HTML report in less than 3 seconds — no hooks, merge plugins, no config, xdist-ready.                                                                                                                                                                                                                        May 07, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-html-profiling`                            Pytest plugin for generating HTML reports with per-test profiling and optionally call graph visualizations. Based on pytest-html by Dave Hunt.                                                                                                                                                                                                                                          Feb 11, 2020    5 - Production/Stable  pytest (>=3.0)
   :pypi:`pytest-html-report`                               Enhanced HTML reporting for pytest with categories, specifications, and detailed logging                                                                                                                                                                                                                                                                                                Jun 24, 2025    4 - Beta               pytest>=6.0
   :pypi:`pytest-html-report-builder`                       A pytest plugin that generates self-contained HTML automation reports with visual charts.                                                                                                                                                                                                                                                                                               Apr 22, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-html-reporter`                             Generates a static html report based on pytest framework                                                                                                                                                                                                                                                                                                                                Feb 13, 2022    N/A                    N/A
   :pypi:`pytest-html-report-merger`                                                                                                                                                                                                                                                                                                                                                                                                                May 22, 2024    N/A                    N/A
   :pypi:`pytest-html-thread`                               pytest plugin for generating HTML reports                                                                                                                                                                                                                                                                                                                                               Dec 29, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-htmlx`                                     Custom HTML report plugin for Pytest with charts and tables                                                                                                                                                                                                                                                                                                                             Sep 09, 2025    4 - Beta               pytest
   :pypi:`pytest-http`                                      Fixture "http" for http requests                                                                                                                                                                                                                                                                                                                                                        Aug 22, 2024    N/A                    pytest
   :pypi:`pytest-httpbin`                                   Easily test your HTTP library against a local copy of httpbin                                                                                                                                                                                                                                                                                                                           Sep 18, 2024    5 - Production/Stable  pytest; extra == "test"
   :pypi:`pytest-httpchain`                                 pytest plugin for HTTP testing using JSON files                                                                                                                                                                                                                                                                                                                                         Jun 04, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-httpchain-core`                            Shared base types for pytest-httpchain                                                                                                                                                                                                                                                                                                                                                  Jun 04, 2026    N/A                    N/A
   :pypi:`pytest-httpchain-jsonref`                         JSON reference ($ref) support for pytest-httpchain                                                                                                                                                                                                                                                                                                                                      Jun 04, 2026    N/A                    N/A
   :pypi:`pytest-httpchain-mcp`                             MCP server for pytest-httpchain                                                                                                                                                                                                                                                                                                                                                         Apr 02, 2026    N/A                    N/A
   :pypi:`pytest-httpchain-models`                          Pydantic models for pytest-httpchain                                                                                                                                                                                                                                                                                                                                                    Jun 04, 2026    N/A                    N/A
   :pypi:`pytest-httpchain-templates`                       Templating support for pytest-httpchain                                                                                                                                                                                                                                                                                                                                                 Jun 04, 2026    N/A                    N/A
   :pypi:`pytest-httpchain-userfunc`                        User functions support for pytest-httpchain                                                                                                                                                                                                                                                                                                                                             Jun 04, 2026    N/A                    N/A
   :pypi:`pytest-httpdbg`                                   A pytest plugin to record HTTP(S) requests with stack trace.                                                                                                                                                                                                                                                                                                                            Mar 29, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-http-mocker`                               Pytest plugin for http mocking (via https://github.com/vilus/mocker)                                                                                                                                                                                                                                                                                                                    Oct 20, 2019    N/A                    N/A
   :pypi:`pytest-httpretty`                                 A thin wrapper of HTTPretty for pytest                                                                                                                                                                                                                                                                                                                                                  Feb 16, 2014    3 - Alpha              N/A
   :pypi:`pytest_httpserver`                                pytest-httpserver is a httpserver for pytest                                                                                                                                                                                                                                                                                                                                            Feb 14, 2026    3 - Alpha              N/A
   :pypi:`pytest-httptesting`                               http_testing framework on top of pytest                                                                                                                                                                                                                                                                                                                                                 Dec 19, 2024    N/A                    pytest>=8.2.0
   :pypi:`pytest-httpx`                                     Send responses to httpx.                                                                                                                                                                                                                                                                                                                                                                Apr 09, 2026    5 - Production/Stable  pytest==9.*
   :pypi:`pytest-httpx2`                                    A pytest plugin for mocking out httpx2 using respx.                                                                                                                                                                                                                                                                                                                                     May 20, 2026    N/A                    N/A
   :pypi:`pytest-httpx-blockage`                            Disable httpx requests during a test run                                                                                                                                                                                                                                                                                                                                                Feb 16, 2023    N/A                    pytest (>=7.2.1)
   :pypi:`pytest-httpx-recorder`                            Recorder feature based on pytest_httpx, like recorder feature in responses.                                                                                                                                                                                                                                                                                                             Jan 04, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-hue`                                       Visualise PyTest status via your Phillips Hue lights                                                                                                                                                                                                                                                                                                                                    May 09, 2019    N/A                    N/A
   :pypi:`pytest-human`                                     A beautiful nested pytest HTML test report                                                                                                                                                                                                                                                                                                                                              Jan 25, 2026    4 - Beta               pytest>=8
   :pypi:`pytest-hy`                                        Pytest plugin for discovering and running Hy test files                                                                                                                                                                                                                                                                                                                                 Feb 11, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-hylang`                                    Pytest plugin to allow running tests written in hylang                                                                                                                                                                                                                                                                                                                                  Mar 28, 2021    N/A                    pytest
   :pypi:`pytest-hypo-25`                                   help hypo module for pytest                                                                                                                                                                                                                                                                                                                                                             Jan 12, 2020    3 - Alpha              N/A
   :pypi:`pytest-hypothesis`                                                                                                                                                                                                                                                                                                                                                                                                                        Feb 09, 2026    N/A                    N/A
   :pypi:`pytest-iam`                                       A fully functional OAUTH2 / OpenID Connect (OIDC) / SCIM server to be used in your testsuite                                                                                                                                                                                                                                                                                            Nov 02, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-ibutsu`                                    A plugin to sent pytest results to an Ibutsu server                                                                                                                                                                                                                                                                                                                                     Feb 23, 2026    4 - Beta               pytest
   :pypi:`pytest-icdiff`                                    use icdiff for better error messages in pytest assertions                                                                                                                                                                                                                                                                                                                               Dec 05, 2023    4 - Beta               pytest
   :pypi:`pytest-idapro`                                    A pytest plugin for idapython. Allows a pytest setup to run tests outside and inside IDA in an automated manner by runnig pytest inside IDA and by mocking idapython api                                                                                                                                                                                                                Nov 03, 2018    N/A                    N/A
   :pypi:`pytest-idem`                                      A pytest plugin to help with testing idem projects                                                                                                                                                                                                                                                                                                                                      Dec 13, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-idempotent`                                Pytest plugin for testing function idempotence.                                                                                                                                                                                                                                                                                                                                         Jul 25, 2022    N/A                    N/A
   :pypi:`pytest-ignore-flaky`                              ignore failures from flaky tests (pytest plugin)                                                                                                                                                                                                                                                                                                                                        Apr 20, 2024    5 - Production/Stable  pytest>=6.0
   :pypi:`pytest-ignore-test-results`                       A pytest plugin to ignore test results.                                                                                                                                                                                                                                                                                                                                                 Feb 03, 2025    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-image-diff`                                                                                                                                                                                                                                                                                                                                                                                                                        Dec 31, 2024    3 - Alpha              pytest
   :pypi:`pytest-image-snapshot`                            A pytest plugin for image snapshot management and comparison.                                                                                                                                                                                                                                                                                                                           Jun 02, 2026    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-impacted`                                  A pytest plugin that selectively runs tests impacted by code changes via git introspection, AST parsing, and dependency graph analysis.                                                                                                                                                                                                                                                 May 19, 2026    4 - Beta               pytest>=8.0.0
   :pypi:`pytest-impacted-rs`                               Rust-accelerated import parsing for pytest-impacted (ruff parser + rayon parallelism).                                                                                                                                                                                                                                                                                                  May 19, 2026    4 - Beta               N/A
   :pypi:`pytest-imply`                                     Pytest plugin for test implication — skip tests implied by stronger ones                                                                                                                                                                                                                                                                                                                Mar 21, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-import-check`                              pytest plugin to check whether Python modules can be imported                                                                                                                                                                                                                                                                                                                           Jul 19, 2024    3 - Alpha              pytest>=8.1
   :pypi:`pytest-incremental`                               an incremental test runner (pytest plugin)                                                                                                                                                                                                                                                                                                                                              Apr 24, 2021    5 - Production/Stable  N/A
   :pypi:`pytest-in-docker`                                 Seamlessly run pytest tests inside docker containers                                                                                                                                                                                                                                                                                                                                    Feb 09, 2026    3 - Alpha              pytest>=9.0.2
   :pypi:`pytest-infinity`                                                                                                                                                                                                                                                                                                                                                                                                                          Jun 09, 2024    N/A                    pytest<9.0.0,>=8.0.0
   :pypi:`pytest-influx`                                    Pytest plugin for managing your influx instance between test runs                                                                                                                                                                                                                                                                                                                       Oct 16, 2024    N/A                    pytest<9.0.0,>=8.3.3
   :pypi:`pytest-influxdb`                                  Plugin for influxdb and pytest integration.                                                                                                                                                                                                                                                                                                                                             Apr 20, 2021    N/A                    N/A
   :pypi:`pytest-info-collector`                            pytest plugin to collect information from tests                                                                                                                                                                                                                                                                                                                                         May 26, 2019    3 - Alpha              N/A
   :pypi:`pytest-info-plugin`                               Get executed interface information in pytest interface automation framework                                                                                                                                                                                                                                                                                                             Sep 14, 2023    N/A                    N/A
   :pypi:`pytest-informative-node`                          display more node ininformation.                                                                                                                                                                                                                                                                                                                                                        Apr 25, 2019    4 - Beta               N/A
   :pypi:`pytest-infrahouse`                                A set of fixtures to use with pytest                                                                                                                                                                                                                                                                                                                                                    Mar 17, 2026    4 - Beta               pytest~=9.0
   :pypi:`pytest-infrastructure`                            pytest stack validation prior to testing executing                                                                                                                                                                                                                                                                                                                                      Apr 12, 2020    4 - Beta               N/A
   :pypi:`pytest-ini`                                       Reuse pytest.ini to store env variables                                                                                                                                                                                                                                                                                                                                                 Apr 26, 2022    N/A                    N/A
   :pypi:`pytest-initry`                                    Plugin for sending automation test data from Pytest to the initry                                                                                                                                                                                                                                                                                                                       Apr 30, 2024    N/A                    pytest<9.0.0,>=8.1.1
   :pypi:`pytest-inject`                                    A pytest plugin that allows you to inject arguments into fixtures and parametrized tests using pytest command-line options.                                                                                                                                                                                                                                                             Nov 25, 2025    N/A                    pytest>=6.0.0
   :pypi:`pytest-inline`                                    A pytest plugin for writing inline tests                                                                                                                                                                                                                                                                                                                                                Oct 24, 2024    4 - Beta               pytest<9.0,>=7.0
   :pypi:`pytest-inline-snapshot`                           inline-snapshot is the package you are looking for                                                                                                                                                                                                                                                                                                                                      Nov 09, 2025    N/A                    N/A
   :pypi:`pytest-inline-tdd`                                A pytest plugin for writing inline tests                                                                                                                                                                                                                                                                                                                                                Mar 09, 2026    4 - Beta               pytest<9.0,>=7.0
   :pypi:`pytest-inmanta`                                   A py.test plugin providing fixtures to simplify inmanta modules testing.                                                                                                                                                                                                                                                                                                                Nov 18, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-inmanta-extensions`                        Inmanta tests package                                                                                                                                                                                                                                                                                                                                                                   Jun 02, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-inmanta-lsm`                               Common fixtures used in inmanta LSM related modules                                                                                                                                                                                                                                                                                                                                     Apr 29, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-inmanta-srlinux`                           Pytest library to facilitate end to end testing of inmanta projects                                                                                                                                                                                                                                                                                                                     Apr 22, 2025    3 - Alpha              N/A
   :pypi:`pytest-inmanta-yang`                              Common fixtures used in inmanta yang related modules                                                                                                                                                                                                                                                                                                                                    Oct 28, 2025    4 - Beta               pytest
   :pypi:`pytest-Inomaly`                                   A simple image diff plugin for pytest                                                                                                                                                                                                                                                                                                                                                   Feb 13, 2018    4 - Beta               N/A
   :pypi:`pytest-in-robotframework`                         The extension enables easy execution of pytest tests within the Robot Framework environment.                                                                                                                                                                                                                                                                                            Nov 23, 2024    N/A                    pytest
   :pypi:`pytest-insper`                                    Pytest plugin for courses at Insper                                                                                                                                                                                                                                                                                                                                                     Mar 21, 2024    N/A                    pytest
   :pypi:`pytest-insta`                                     A practical snapshot testing plugin for pytest                                                                                                                                                                                                                                                                                                                                          Nov 22, 2025    N/A                    pytest>=9.0.0
   :pypi:`pytest-instafail`                                 pytest plugin to show failures instantly                                                                                                                                                                                                                                                                                                                                                Mar 31, 2023    4 - Beta               pytest (>=5)
   :pypi:`pytest-instrument`                                pytest plugin to instrument tests                                                                                                                                                                                                                                                                                                                                                       Apr 05, 2020    5 - Production/Stable  pytest (>=5.1.0)
   :pypi:`pytest-insubprocess`                              A pytest plugin to execute test cases in a subprocess                                                                                                                                                                                                                                                                                                                                   Dec 08, 2025    4 - Beta               pytest>=7.4
   :pypi:`pytest-integration`                               Organizing pytests by integration or not                                                                                                                                                                                                                                                                                                                                                Nov 17, 2022    N/A                    N/A
   :pypi:`pytest-integration-mark`                          Automatic integration test marking and excluding plugin for pytest                                                                                                                                                                                                                                                                                                                      May 22, 2023    N/A                    pytest (>=5.2)
   :pypi:`pytest-intent`                                    A pytest plugin for tracking requirement coverage.                                                                                                                                                                                                                                                                                                                                      Dec 17, 2025    N/A                    pytest<10.0.0,>=9.0.0
   :pypi:`pytest-interactive`                               A pytest plugin for console based interactive test selection just after the collection phase                                                                                                                                                                                                                                                                                            Nov 30, 2017    3 - Alpha              N/A
   :pypi:`pytest-intercept-remote`                          Pytest plugin for intercepting outgoing connection requests during pytest run.                                                                                                                                                                                                                                                                                                          May 24, 2021    4 - Beta               pytest (>=4.6)
   :pypi:`pytest-interface-tester`                          Pytest plugin for checking charm relation interface protocol compliance.                                                                                                                                                                                                                                                                                                                Feb 11, 2026    4 - Beta               pytest
   :pypi:`pytest-invenio`                                   Pytest fixtures for Invenio.                                                                                                                                                                                                                                                                                                                                                            Mar 16, 2026    5 - Production/Stable  pytest<9.0.0,>=6
   :pypi:`pytest-involve`                                   Run tests covering a specific file or changeset                                                                                                                                                                                                                                                                                                                                         Feb 02, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-iovis`                                     A Pytest plugin to enable Jupyter Notebook testing with Papermill                                                                                                                                                                                                                                                                                                                       Nov 06, 2024    4 - Beta               pytest>=7.1.0
   :pypi:`pytest-ipdb`                                      A py.test plug-in to enable drop to ipdb debugger on test failure.                                                                                                                                                                                                                                                                                                                      Mar 20, 2013    2 - Pre-Alpha          N/A
   :pypi:`pytest-ipso`                                      pytest plugin for running ipso notebook cell tests                                                                                                                                                                                                                                                                                                                                      Mar 24, 2026    N/A                    pytest
   :pypi:`pytest-ipynb`                                     THIS PROJECT IS ABANDONED                                                                                                                                                                                                                                                                                                                                                               Jan 29, 2019    3 - Alpha              N/A
   :pypi:`pytest-ipynb2`                                    Pytest plugin to run tests in Jupyter Notebooks                                                                                                                                                                                                                                                                                                                                         Mar 09, 2025    N/A                    pytest
   :pypi:`pytest-ipywidgets`                                                                                                                                                                                                                                                                                                                                                                                                                        May 14, 2026    N/A                    pytest
   :pypi:`pytest-isolate`                                   Run pytest tests in isolated subprocesses                                                                                                                                                                                                                                                                                                                                               Jun 01, 2026    4 - Beta               pytest
   :pypi:`pytest-isolated`                                  Run marked pytest tests in grouped subprocesses (cross-platform).                                                                                                                                                                                                                                                                                                                       Mar 04, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-isolate-mpi`                               pytest-isolate-mpi allows for MPI-parallel tests being executed in a segfault and MPI_Abort safe manner                                                                                                                                                                                                                                                                                 Feb 24, 2025    4 - Beta               pytest>=5
   :pypi:`pytest-isort`                                     py.test plugin to check import ordering using isort                                                                                                                                                                                                                                                                                                                                     Mar 05, 2024    5 - Production/Stable  pytest (>=5.0)
   :pypi:`pytest-issues`                                    Decorators for pytest tests that should issue exceptions or warnings                                                                                                                                                                                                                                                                                                                    May 29, 2026    5 - Production/Stable  pytest>=8
   :pypi:`pytest-it`                                        Pytest plugin to display test reports as a plaintext spec, inspired by Rspec: https://github.com/mattduck/pytest-it.                                                                                                                                                                                                                                                                    Jan 29, 2024    4 - Beta               N/A
   :pypi:`pytest-item-dict`                                 Get a hierarchical dict of session.items                                                                                                                                                                                                                                                                                                                                                May 22, 2026    5 - Production/Stable  pytest>=8.3.0
   :pypi:`pytest-iterassert`                                Nicer list and iterable assertion messages for pytest                                                                                                                                                                                                                                                                                                                                   May 11, 2020    3 - Alpha              N/A
   :pypi:`pytest-iteration`                                 Add iteration mark for tests                                                                                                                                                                                                                                                                                                                                                            Aug 22, 2024    N/A                    pytest
   :pypi:`pytest-iters`                                     A contextmanager pytest fixture for handling multiple mock iters                                                                                                                                                                                                                                                                                                                        May 09, 2026    4 - Beta               pytest>=3.5.0
   :pypi:`pytest_jar_yuan`                                  A allure and pytest used package                                                                                                                                                                                                                                                                                                                                                        Dec 12, 2022    N/A                    N/A
   :pypi:`pytest-jasmine`                                   Run jasmine tests from your pytest test suite                                                                                                                                                                                                                                                                                                                                           Nov 04, 2017    1 - Planning           N/A
   :pypi:`pytest-jax-bench`                                 Pytest plugin to profile jitted JAX functions (compile time, runtime, memory).                                                                                                                                                                                                                                                                                                          Apr 06, 2026    N/A                    pytest>=7
   :pypi:`pytest-jelastic`                                  Pytest plugin defining the necessary command-line options to pass to pytests testing a Jelastic environment.                                                                                                                                                                                                                                                                            Nov 16, 2022    N/A                    pytest (>=7.2.0,<8.0.0)
   :pypi:`pytest-jest`                                      A custom jest-pytest oriented Pytest reporter                                                                                                                                                                                                                                                                                                                                           May 22, 2018    4 - Beta               pytest (>=3.3.2)
   :pypi:`pytest-jinja`                                     A plugin to generate customizable jinja-based HTML reports in pytest                                                                                                                                                                                                                                                                                                                    Oct 04, 2022    3 - Alpha              pytest (>=6.2.5,<7.0.0)
   :pypi:`pytest-jinja-check`                               Pytest plugin to lint Jinja2 templates in FastAPI applications                                                                                                                                                                                                                                                                                                                          Mar 14, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-jira`                                      py.test JIRA integration plugin, using markers                                                                                                                                                                                                                                                                                                                                          Mar 19, 2026    4 - Beta               pytest>=2.2.4
   :pypi:`pytest-jira-xfail`                                Plugin skips (xfail) tests if unresolved Jira issue(s) linked                                                                                                                                                                                                                                                                                                                           Jul 09, 2024    N/A                    pytest>=7.2.0
   :pypi:`pytest-jira-xray`                                 pytest plugin to integrate tests with JIRA XRAY                                                                                                                                                                                                                                                                                                                                         Apr 24, 2026    4 - Beta               pytest>=6.2.4
   :pypi:`pytest-job-selection`                             A pytest plugin for load balancing test suites                                                                                                                                                                                                                                                                                                                                          Jan 30, 2023    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-jobserver`                                 Limit parallel tests with posix jobserver.                                                                                                                                                                                                                                                                                                                                              Feb 02, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-joke`                                      Test failures are better served with humor.                                                                                                                                                                                                                                                                                                                                             Oct 08, 2019    4 - Beta               pytest (>=4.2.1)
   :pypi:`pytest-jscov`                                     Pytest plugin for JavaScript coverage via Playwright CDP                                                                                                                                                                                                                                                                                                                                Apr 04, 2026    N/A                    pytest
   :pypi:`pytest-json`                                      Generate JSON test reports                                                                                                                                                                                                                                                                                                                                                              Jan 18, 2016    4 - Beta               N/A
   :pypi:`pytest-json-ctrf`                                 Pytest plugin to generate json report in CTRF (Common Test Report Format)                                                                                                                                                                                                                                                                                                               Apr 30, 2026    N/A                    pytest>6.0.0
   :pypi:`pytest-json-fixtures`                             JSON output for the --fixtures flag                                                                                                                                                                                                                                                                                                                                                     Mar 14, 2023    4 - Beta               N/A
   :pypi:`pytest-jsonlint`                                  UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                 Aug 04, 2016    N/A                    N/A
   :pypi:`pytest-json-report`                               A pytest plugin to report test results as JSON files                                                                                                                                                                                                                                                                                                                                    Mar 15, 2022    4 - Beta               pytest (>=3.8.0)
   :pypi:`pytest-json-report-wip`                           A pytest plugin to report test results as JSON files                                                                                                                                                                                                                                                                                                                                    Jul 23, 2025    4 - Beta               pytest >=3.8.0
   :pypi:`pytest-jsonschema`                                A pytest plugin to perform JSONSchema validations                                                                                                                                                                                                                                                                                                                                       Nov 07, 2025    5 - Production/Stable  pytest>=6.2.0
   :pypi:`pytest-jsonschema-snapshot`                       Pytest plugin for automatic JSON Schema generation and validation from examples                                                                                                                                                                                                                                                                                                         Mar 29, 2026    N/A                    pytest
   :pypi:`pytest-jtr`                                       pytest plugin supporting json test report output                                                                                                                                                                                                                                                                                                                                        Jul 21, 2024    N/A                    pytest<8.0.0,>=7.1.2
   :pypi:`pytest-jubilant`                                  Add your description here                                                                                                                                                                                                                                                                                                                                                               Apr 07, 2026    N/A                    pytest>=8.3.5
   :pypi:`pytest-junit-logging`                             A pytest plugin for embedding log output into JUnit XML reports                                                                                                                                                                                                                                                                                                                         Nov 27, 2025    4 - Beta               pytest>=6.0
   :pypi:`pytest-junit-xray-xml`                            Export test results in an augmented JUnit format for usage with Xray ()                                                                                                                                                                                                                                                                                                                 Jan 01, 2025    4 - Beta               pytest
   :pypi:`pytest-jupyter`                                   A pytest plugin for testing Jupyter libraries and extensions.                                                                                                                                                                                                                                                                                                                           Oct 16, 2025    4 - Beta               pytest>=7.0
   :pypi:`pytest-jupyter-deploy`                            Pytest plugin for E2E testing of jupyter-deploy templates                                                                                                                                                                                                                                                                                                                               May 27, 2026    3 - Alpha              pytest>=8.3.5
   :pypi:`pytest-jupyterhub`                                A reusable JupyterHub pytest plugin                                                                                                                                                                                                                                                                                                                                                     Apr 25, 2023    5 - Production/Stable  pytest
   :pypi:`pytest-just`                                      A pytest plugin for testing justfile recipes                                                                                                                                                                                                                                                                                                                                            Mar 22, 2026    3 - Alpha              pytest>=8.0.0
   :pypi:`pytest-jux`                                       A pytest plugin for signing and publishing JUnit XML test reports to the Jux REST API                                                                                                                                                                                                                                                                                                   Jan 08, 2026    3 - Alpha              pytest>=7.4
   :pypi:`pytest-k8s`                                       Kubernetes-based testing for pytest                                                                                                                                                                                                                                                                                                                                                     Jul 07, 2025    N/A                    pytest>=8.4.1
   :pypi:`pytest-kafka`                                     Zookeeper, Kafka server, and Kafka consumer fixtures for Pytest                                                                                                                                                                                                                                                                                                                         Aug 14, 2024    N/A                    pytest
   :pypi:`pytest-kafka-broker`                              Pytest plugin to run a single-broker Kafka cluster                                                                                                                                                                                                                                                                                                                                      Apr 03, 2026    N/A                    N/A
   :pypi:`pytest-kafka-contract`                            A pytest plugin and CLI for validating Kafka JSON and Avro messages against contracts.                                                                                                                                                                                                                                                                                                  May 10, 2026    3 - Alpha              pytest>=8.0.0
   :pypi:`pytest-kafkavents`                                A plugin to send pytest events to Kafka                                                                                                                                                                                                                                                                                                                                                 Sep 08, 2021    4 - Beta               pytest
   :pypi:`pytest-kairos`                                    Pytest plugin with random number generation, reproducibility, and test repetition                                                                                                                                                                                                                                                                                                       Aug 08, 2024    5 - Production/Stable  pytest>=5.0.0
   :pypi:`pytest-kasima`                                    Display horizontal lines above and below the captured standard output for easy viewing.                                                                                                                                                                                                                                                                                                 Jan 26, 2023    5 - Production/Stable  pytest (>=7.2.1,<8.0.0)
   :pypi:`pytest-kedge`                                     Agent-friendly structured test data collector for pytest                                                                                                                                                                                                                                                                                                                                Jan 10, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-keep-together`                             Pytest plugin to customize test ordering by running all 'related' tests together                                                                                                                                                                                                                                                                                                        Dec 07, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-kexi`                                                                                                                                                                                                                                                                                                                                                                                                                              Apr 29, 2022    N/A                    pytest (>=7.1.2,<8.0.0)
   :pypi:`pytest-keyring`                                   A Pytest plugin to access the system's keyring to provide credentials for tests                                                                                                                                                                                                                                                                                                         Apr 10, 2026    N/A                    pytest>=8.0.2
   :pypi:`pytest-kind`                                      Kubernetes test support with KIND for pytest                                                                                                                                                                                                                                                                                                                                            Nov 30, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-kivy`                                      Kivy GUI tests fixtures using pytest                                                                                                                                                                                                                                                                                                                                                    Jul 06, 2021    4 - Beta               pytest (>=3.6)
   :pypi:`pytest-knows`                                     A pytest plugin that can automaticly skip test case based on dependence info calculated by trace                                                                                                                                                                                                                                                                                        Aug 22, 2014    N/A                    N/A
   :pypi:`pytest-konira`                                    Run Konira DSL tests with py.test                                                                                                                                                                                                                                                                                                                                                       Oct 09, 2011    N/A                    N/A
   :pypi:`pytest-kookit`                                    Your simple but kooky integration testing with pytest                                                                                                                                                                                                                                                                                                                                   Sep 10, 2024    N/A                    N/A
   :pypi:`pytest-koopmans`                                  A plugin for testing the koopmans package                                                                                                                                                                                                                                                                                                                                               Nov 21, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-krtech-common`                             pytest krtech common library                                                                                                                                                                                                                                                                                                                                                            Nov 28, 2016    4 - Beta               N/A
   :pypi:`pytest-kubernetes`                                A lightweight pytest plugin for managing local Kubernetes clusters (minikube, k3d, kind)                                                                                                                                                                                                                                                                                                Apr 14, 2026    N/A                    pytest<10.0.0,>=9.0.0
   :pypi:`pytest_kustomize`                                 Parse and validate kustomize output                                                                                                                                                                                                                                                                                                                                                     Dec 08, 2025    N/A                    N/A
   :pypi:`pytest-kuunda`                                    pytest plugin to help with test data setup for PySpark tests                                                                                                                                                                                                                                                                                                                            Feb 25, 2024    4 - Beta               pytest >=6.2.0
   :pypi:`pytest-kwparametrize`                             Alternate syntax for @pytest.mark.parametrize with test cases as dictionaries and default value fallbacks                                                                                                                                                                                                                                                                               Jan 22, 2021    N/A                    pytest (>=6)
   :pypi:`pytest-lambda`                                    Define pytest fixtures with lambda functions.                                                                                                                                                                                                                                                                                                                                           May 27, 2024    5 - Production/Stable  pytest<9,>=3.6
   :pypi:`pytest-lamp`                                                                                                                                                                                                                                                                                                                                                                                                                              Jan 06, 2017    3 - Alpha              N/A
   :pypi:`pytest-langchain`                                 Pytest-style test runner for langchain agents                                                                                                                                                                                                                                                                                                                                           Feb 26, 2023    N/A                    pytest
   :pypi:`pytest-language-server`                           A blazingly fast Language Server Protocol implementation for pytest                                                                                                                                                                                                                                                                                                                     Jun 04, 2026    4 - Beta               N/A
   :pypi:`pytest-lark`                                      Create fancy and clear HTML test reports.                                                                                                                                                                                                                                                                                                                                               Nov 05, 2023    N/A                    N/A
   :pypi:`pytest-latin-hypercube`                           Implementation of Latin Hypercube Sampling for pytest.                                                                                                                                                                                                                                                                                                                                  Jun 26, 2025    N/A                    pytest
   :pypi:`pytest-launchable`                                Launchable Pytest Plugin                                                                                                                                                                                                                                                                                                                                                                Apr 05, 2023    N/A                    pytest (>=4.2.0)
   :pypi:`pytest-layab`                                     Pytest fixtures for layab.                                                                                                                                                                                                                                                                                                                                                              Oct 05, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-lazy-fixture`                              It helps to use fixtures in pytest.mark.parametrize                                                                                                                                                                                                                                                                                                                                     Feb 01, 2020    4 - Beta               pytest (>=3.2.5)
   :pypi:`pytest-lazy-fixtures`                             Allows you to use fixtures in @pytest.mark.parametrize.                                                                                                                                                                                                                                                                                                                                 Sep 16, 2025    N/A                    pytest>=7
   :pypi:`pytest-ldap`                                      python-ldap fixtures for pytest                                                                                                                                                                                                                                                                                                                                                         Aug 18, 2020    N/A                    pytest
   :pypi:`pytest-leak-finder`                               Find the test that's leaking before the one that fails                                                                                                                                                                                                                                                                                                                                  Dec 19, 2025    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-leaks`                                     A pytest plugin to trace resource leaks.                                                                                                                                                                                                                                                                                                                                                Nov 27, 2019    1 - Planning           N/A
   :pypi:`pytest-leaping`                                   A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Mar 27, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-leela`                                     Type-aware mutation testing for Python — fast, opinionated, pytest-native                                                                                                                                                                                                                                                                                                               Apr 27, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-leo-interface`                             Pytest extension tool for leo projects.                                                                                                                                                                                                                                                                                                                                                 Mar 19, 2025    N/A                    N/A
   :pypi:`pytest-level`                                     Select tests of a given level or lower                                                                                                                                                                                                                                                                                                                                                  Oct 21, 2019    N/A                    pytest
   :pypi:`pytest-lf-skip`                                   A pytest plugin which makes \`--last-failed\` skip instead of deselect tests.                                                                                                                                                                                                                                                                                                           Feb 27, 2026    4 - Beta               pytest>=8.3.5
   :pypi:`pytest-libfaketime`                               A python-libfaketime plugin for pytest                                                                                                                                                                                                                                                                                                                                                  Apr 12, 2024    4 - Beta               pytest>=3.0.0
   :pypi:`pytest-libiio`                                    A pytest plugin for testing libiio based devices                                                                                                                                                                                                                                                                                                                                        Jun 06, 2026    N/A                    pytest>=3.5.0
   :pypi:`pytest-libnotify`                                 Pytest plugin that shows notifications about the test run                                                                                                                                                                                                                                                                                                                               Apr 02, 2021    3 - Alpha              pytest
   :pypi:`pytest-ligo`                                                                                                                                                                                                                                                                                                                                                                                                                              Jan 16, 2020    4 - Beta               N/A
   :pypi:`pytest-lineno`                                    A pytest plugin to show the line numbers of test functions                                                                                                                                                                                                                                                                                                                              Dec 04, 2020    N/A                    pytest
   :pypi:`pytest-line-profiler`                             Profile code executed by pytest                                                                                                                                                                                                                                                                                                                                                         Aug 10, 2023    4 - Beta               pytest >=3.5.0
   :pypi:`pytest-line-profiler-apn`                         Profile code executed by pytest                                                                                                                                                                                                                                                                                                                                                         Dec 05, 2022    N/A                    pytest (>=3.5.0)
   :pypi:`pytest-line-runner`                               Run pytest tests by line number instead of exact test name                                                                                                                                                                                                                                                                                                                              Feb 08, 2026    N/A                    N/A
   :pypi:`pytest-lisa`                                      Pytest plugin for organizing tests.                                                                                                                                                                                                                                                                                                                                                     Jan 21, 2021    3 - Alpha              pytest (>=6.1.2,<7.0.0)
   :pypi:`pytest-listener`                                  A simple network listener                                                                                                                                                                                                                                                                                                                                                               Nov 29, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-litf`                                      A pytest plugin that stream output in LITF format                                                                                                                                                                                                                                                                                                                                       Jan 18, 2021    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-litter`                                    Pytest plugin which verifies that tests do not modify file trees.                                                                                                                                                                                                                                                                                                                       Nov 23, 2023    4 - Beta               pytest >=6.1
   :pypi:`pytest-live`                                      Live results for pytest                                                                                                                                                                                                                                                                                                                                                                 Mar 08, 2020    N/A                    pytest
   :pypi:`pytest-liveview`                                  Pytest plugin that shows a real-time test dashboard in a local web server                                                                                                                                                                                                                                                                                                               Mar 09, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-llm`                                       pytest-llm: A pytest plugin for testing LLM outputs with success rate thresholds.                                                                                                                                                                                                                                                                                                       Oct 03, 2025    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-llm-agent`                                 LLM Agent for working with pytest                                                                                                                                                                                                                                                                                                                                                       Dec 16, 2025    N/A                    pytest>=9.0.2
   :pypi:`pytest-llm-assert`                                Simple LLM-powered assertions for any pytest test                                                                                                                                                                                                                                                                                                                                       Mar 31, 2026    3 - Alpha              pytest>=9.0
   :pypi:`pytest-llmeval`                                   A pytest plugin to evaluate/benchmark LLM prompts                                                                                                                                                                                                                                                                                                                                       Mar 19, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-llm-report`                                Human-friendly pytest test reports with optional LLM annotations                                                                                                                                                                                                                                                                                                                        Jan 21, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-llm-rubric`                                A pytest plugin for rubric-based LLM-as-judge testing with auto-discovery and preflight                                                                                                                                                                                                                                                                                                 Apr 07, 2026    3 - Alpha              pytest>=7.2
   :pypi:`pytest-llmtest`                                   The pytest for LLMs — fast, Pydantic-based assertions for AI applications                                                                                                                                                                                                                                                                                                               Mar 08, 2026    3 - Alpha              pytest>=7.0; extra == "dev"
   :pypi:`pytest-lobster`                                   Pytest to generate lobster tracing files                                                                                                                                                                                                                                                                                                                                                Jul 26, 2025    N/A                    pytest>=7.0
   :pypi:`pytest-local-badge`                               Pytest plugin that writes self-hosted SVG status and coverage badges to your repo — no third-party shield service required.                                                                                                                                                                                                                                                             May 22, 2026    5 - Production/Stable  pytest>=8.4
   :pypi:`pytest-localftpserver`                            A PyTest plugin which provides an FTP fixture for your tests                                                                                                                                                                                                                                                                                                                            Nov 16, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-localserver`                               pytest plugin to test server connections locally.                                                                                                                                                                                                                                                                                                                                       Nov 24, 2025    4 - Beta               N/A
   :pypi:`pytest-localstack`                                Pytest plugin for AWS integration tests                                                                                                                                                                                                                                                                                                                                                 Jun 07, 2023    4 - Beta               pytest (>=6.0.0,<7.0.0)
   :pypi:`pytest-lock`                                      pytest-lock is a pytest plugin that allows you to "lock" the results of unit tests, storing them in a local cache. This is particularly useful for tests that are resource-intensive or don't need to be run every time. When the tests are run subsequently, pytest-lock will compare the current results with the locked results and issue a warning if there are any discrepancies.  Feb 03, 2024    N/A                    pytest (>=7.4.3,<8.0.0)
   :pypi:`pytest-lockable`                                  lockable resource plugin for pytest                                                                                                                                                                                                                                                                                                                                                     Sep 08, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-locker`                                    Used to lock object during testing. Essentially changing assertions from being hard coded to asserting that nothing changed                                                                                                                                                                                                                                                             Dec 20, 2024    N/A                    pytest>=5.4
   :pypi:`pytest-loco`                                      Another one YAML-based DSL for testing                                                                                                                                                                                                                                                                                                                                                  Mar 08, 2026    3 - Alpha              pytest<10.0.0,>=9.0.2
   :pypi:`pytest-loco-allure`                               Allure support for pytest-loco                                                                                                                                                                                                                                                                                                                                                          Mar 08, 2026    3 - Alpha              N/A
   :pypi:`pytest-loco-http`                                 HTTP support for pytest-loco                                                                                                                                                                                                                                                                                                                                                            Feb 25, 2026    3 - Alpha              N/A
   :pypi:`pytest-loco-json`                                 JSON support for pytest-loco                                                                                                                                                                                                                                                                                                                                                            Feb 25, 2026    3 - Alpha              N/A
   :pypi:`pytest-log`                                       print log                                                                                                                                                                                                                                                                                                                                                                               Aug 15, 2021    N/A                    pytest (>=3.8)
   :pypi:`pytest-logbook`                                   py.test plugin to capture logbook log messages                                                                                                                                                                                                                                                                                                                                          Nov 23, 2015    5 - Production/Stable  pytest (>=2.8)
   :pypi:`pytest-logdog`                                    Pytest plugin to test logging                                                                                                                                                                                                                                                                                                                                                           Jun 15, 2021    1 - Planning           pytest (>=6.2.0)
   :pypi:`pytest-logfest`                                   Pytest plugin providing three logger fixtures with basic or full writing to log files                                                                                                                                                                                                                                                                                                   Jul 21, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-log-filter`                                Ignore some loggers' log for pytest                                                                                                                                                                                                                                                                                                                                                     Nov 13, 2025    N/A                    pytest
   :pypi:`pytest-logger`                                    Plugin configuring handlers for loggers from Python logging module.                                                                                                                                                                                                                                                                                                                     Mar 10, 2024    5 - Production/Stable  pytest (>=3.2)
   :pypi:`pytest-logger-db`                                 Add your description here                                                                                                                                                                                                                                                                                                                                                               Sep 14, 2025    N/A                    N/A
   :pypi:`pytest-logging`                                   Configures logging and allows tweaking the log level with a py.test flag                                                                                                                                                                                                                                                                                                                Nov 04, 2015    4 - Beta               N/A
   :pypi:`pytest-logging-end-to-end-test-tool`                                                                                                                                                                                                                                                                                                                                                                                                      Sep 23, 2022    N/A                    pytest (>=7.1.2,<8.0.0)
   :pypi:`pytest-logging-strict`                            pytest fixture logging configured from packaged YAML                                                                                                                                                                                                                                                                                                                                    May 20, 2025    3 - Alpha              pytest
   :pypi:`pytest-logikal`                                   Common testing environment                                                                                                                                                                                                                                                                                                                                                              May 29, 2026    5 - Production/Stable  pytest==9.0.3
   :pypi:`pytest-log-report`                                Package for creating a pytest test run reprot                                                                                                                                                                                                                                                                                                                                           Dec 26, 2019    N/A                    N/A
   :pypi:`pytest-logscanner`                                Pytest plugin for logscanner (A logger for python logging outputting to easily viewable (and filterable) html files. Good for people not grep savey, and color higlighting and quickly changing filters might even bye useful for commandline wizards.)                                                                                                                                 Sep 30, 2024    4 - Beta               pytest>=8.2.2
   :pypi:`pytest-loguru`                                    Pytest Loguru                                                                                                                                                                                                                                                                                                                                                                           May 16, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-loop`                                      pytest plugin for looping tests                                                                                                                                                                                                                                                                                                                                                         Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-lsp`                                       A pytest plugin for end-to-end testing of language servers                                                                                                                                                                                                                                                                                                                              Oct 25, 2025    5 - Production/Stable  pytest>=8.0
   :pypi:`pytest-lw-realtime-result`                        Pytest plugin to generate realtime test results to a file                                                                                                                                                                                                                                                                                                                               Mar 13, 2025    N/A                    pytest>=3.5.0
   :pypi:`pytest-manifest`                                  PyTest plugin for recording and asserting against a manifest file                                                                                                                                                                                                                                                                                                                       Apr 07, 2025    N/A                    pytest
   :pypi:`pytest-manual-marker`                             pytest marker for marking manual tests                                                                                                                                                                                                                                                                                                                                                  Aug 04, 2022    3 - Alpha              pytest>=7
   :pypi:`pytest-mark-ac`                                   Provides a marker to reference acceptance criteria from PyTest tests through annotations                                                                                                                                                                                                                                                                                                Mar 02, 2026    5 - Production/Stable  pytest<10,>=8.4
   :pypi:`pytest-mark-count`                                Get a count of the number of tests marked, unmarked, and unique tests if tests have multiple markers                                                                                                                                                                                                                                                                                    Nov 13, 2024    4 - Beta               pytest>=8.0.0
   :pypi:`pytest-markdir`                                                                                                                                                                                                                                                                                                                                                                                                                           Feb 01, 2026    N/A                    pytest<10,>=8.0
   :pypi:`pytest-markdoctest`                               A pytest plugin to doctest your markdown files                                                                                                                                                                                                                                                                                                                                          Jul 22, 2022    4 - Beta               pytest (>=6)
   :pypi:`pytest-markdown`                                  Test your markdown docs with pytest                                                                                                                                                                                                                                                                                                                                                     Jan 15, 2021    4 - Beta               pytest (>=6.0.1,<7.0.0)
   :pypi:`pytest-markdown-console`                          A pytest extension to test console code blocks in markdown files.                                                                                                                                                                                                                                                                                                                       May 31, 2026    N/A                    pytest>=8
   :pypi:`pytest-markdown-docs`                             Run markdown code fences through pytest                                                                                                                                                                                                                                                                                                                                                 Mar 23, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-markdown-report`                           Token-efficient markdown test reports for LLM-based TDD agents                                                                                                                                                                                                                                                                                                                          Jan 10, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-markdown-summary`                          A Pytest plugin for generating reports in Markdown format.                                                                                                                                                                                                                                                                                                                              Apr 30, 2026    3 - Alpha              pytest<10,>=7
   :pypi:`pytest-marker-bugzilla`                           py.test bugzilla integration plugin, using markers                                                                                                                                                                                                                                                                                                                                      Apr 02, 2025    5 - Production/Stable  pytest>=2.2.4
   :pypi:`pytest-markers-presence`                          A simple plugin to detect missed pytest tags and markers"                                                                                                                                                                                                                                                                                                                               Oct 30, 2024    4 - Beta               pytest>=6.0
   :pypi:`pytest-mark-filter`                               Filter pytest marks by name using match kw                                                                                                                                                                                                                                                                                                                                              May 11, 2025    N/A                    pytest>=8.3.0
   :pypi:`pytest-markfiltration`                            UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                 Nov 08, 2011    3 - Alpha              N/A
   :pypi:`pytest-mark-integration`                          Pytest plugin for automatic integration test marking and management                                                                                                                                                                                                                                                                                                                     Jan 13, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-mark-manage`                               用例标签化管理                                                                                                                                                                                                                                                                                                                                                                          Aug 15, 2024    N/A                    pytest
   :pypi:`pytest-mark-no-py3`                               pytest plugin and bowler codemod to help migrate tests to Python 3                                                                                                                                                                                                                                                                                                                      May 17, 2019    N/A                    pytest
   :pypi:`pytest-marks`                                     UNKNOWN                                                                                                                                                                                                                                                                                                                                                                                 Nov 23, 2012    3 - Alpha              N/A
   :pypi:`pytest-mask-secrets`                              Pytest plugin to hide sensitive data in test reports                                                                                                                                                                                                                                                                                                                                    Dec 17, 2025    N/A                    N/A
   :pypi:`pytest-matcher`                                   Easy way to match captured \`pytest\` output against expectations stored in files                                                                                                                                                                                                                                                                                                       Aug 07, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-matchers`                                  Matchers for pytest                                                                                                                                                                                                                                                                                                                                                                     Dec 19, 2025    N/A                    pytest<10.0,>=7.0
   :pypi:`pytest-match-skip`                                Skip matching marks. Matches partial marks using wildcards.                                                                                                                                                                                                                                                                                                                             May 15, 2019    4 - Beta               pytest (>=4.4.1)
   :pypi:`pytest-mat-report`                                this is report                                                                                                                                                                                                                                                                                                                                                                          Jan 20, 2021    N/A                    N/A
   :pypi:`pytest-matrix`                                    Provide tools for generating tests from combinations of fixtures.                                                                                                                                                                                                                                                                                                                       Jun 24, 2020    5 - Production/Stable  pytest (>=5.4.3,<6.0.0)
   :pypi:`pytest-maxcov`                                    Compute the maximum coverage available through pytest with the minimum execution time cost                                                                                                                                                                                                                                                                                              Sep 24, 2023    N/A                    pytest (>=7.4.0,<8.0.0)
   :pypi:`pytest-max-warnings`                              A Pytest plugin to exit non-zero exit code when the configured maximum warnings has been exceeded.                                                                                                                                                                                                                                                                                      Oct 23, 2024    4 - Beta               pytest>=8.3.3
   :pypi:`pytest-maybe-context`                             Simplify tests with warning and exception cases.                                                                                                                                                                                                                                                                                                                                        Apr 16, 2023    N/A                    pytest (>=7,<8)
   :pypi:`pytest-maybe-raises`                              Pytest fixture for optional exception testing.                                                                                                                                                                                                                                                                                                                                          May 27, 2022    N/A                    pytest ; extra == 'dev'
   :pypi:`pytest-mccabe`                                    pytest plugin to run the mccabe code complexity checker.                                                                                                                                                                                                                                                                                                                                Jul 22, 2020    3 - Alpha              pytest (>=5.4.0)
   :pypi:`pytest-mcp`                                       Pytest-style framework for evaluating Model Context Protocol (MCP) servers.                                                                                                                                                                                                                                                                                                             Jul 07, 2025    N/A                    pytest>=8.4.0
   :pypi:`pytest-mcp-assert`                                pytest plugin for mcp-assert: run MCP server assertions as pytest test items                                                                                                                                                                                                                                                                                                            Jun 04, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-mcp-plugin`                                pytest for MCP servers — the testing framework for the Model Context Protocol                                                                                                                                                                                                                                                                                                           May 05, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-mcp-tools`                                 \`pytest --mcp-tools\` an opinionated black box tester to call a live MCP server and test it live against its own contracts                                                                                                                                                                                                                                                             Apr 25, 2026    N/A                    pytest>=7.0.0; extra == "test"
   :pypi:`pytest-md`                                        Plugin for generating Markdown reports for pytest results                                                                                                                                                                                                                                                                                                                               Jul 11, 2019    3 - Alpha              pytest (>=4.2.1)
   :pypi:`pytest-md-report`                                 A pytest plugin to generate test outcomes reports with markdown table format.                                                                                                                                                                                                                                                                                                           May 04, 2026    4 - Beta               pytest!=6.0.0,<10,>=3.3.2
   :pypi:`pytest-meilisearch`                               Pytest helpers for testing projects using Meilisearch                                                                                                                                                                                                                                                                                                                                   Oct 08, 2024    N/A                    pytest>=7.4.3
   :pypi:`pytest-memlog`                                    Log memory usage during tests                                                                                                                                                                                                                                                                                                                                                           May 03, 2023    N/A                    pytest (>=7.3.0,<8.0.0)
   :pypi:`pytest-memprof`                                   Estimates memory consumption of test functions                                                                                                                                                                                                                                                                                                                                          Mar 29, 2019    4 - Beta               N/A
   :pypi:`pytest-memray`                                    A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Aug 18, 2025    N/A                    pytest>=7.2
   :pypi:`pytest-menu`                                      A pytest plugin for console based interactive test selection just after the collection phase                                                                                                                                                                                                                                                                                            Oct 04, 2017    3 - Alpha              pytest (>=2.4.2)
   :pypi:`pytest-mercurial`                                 pytest plugin to write integration tests for projects using Mercurial Python internals                                                                                                                                                                                                                                                                                                  Nov 21, 2020    1 - Planning           N/A
   :pypi:`pytest-mergify`                                   Pytest plugin for Mergify                                                                                                                                                                                                                                                                                                                                                               May 27, 2026    N/A                    pytest>=6.0.0
   :pypi:`pytest-mesh`                                      pytest_mesh插件                                                                                                                                                                                                                                                                                                                                                                         Aug 05, 2022    N/A                    pytest (==7.1.2)
   :pypi:`pytest-message`                                   Pytest plugin for sending report message of marked tests execution                                                                                                                                                                                                                                                                                                                      Aug 04, 2022    N/A                    pytest (>=6.2.5)
   :pypi:`pytest-messenger`                                 Pytest to Slack reporting plugin                                                                                                                                                                                                                                                                                                                                                        Nov 24, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-metadata`                                  pytest plugin for test session metadata                                                                                                                                                                                                                                                                                                                                                 Feb 12, 2024    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-metaexport`                                Pytest plugin for exporting custom test metadata to JSON.                                                                                                                                                                                                                                                                                                                               Jun 24, 2025    N/A                    pytest>=7.1.0
   :pypi:`pytest-metrics`                                   Custom metrics report for pytest                                                                                                                                                                                                                                                                                                                                                        Apr 04, 2020    N/A                    pytest
   :pypi:`pytest-mfd-config`                                Pytest Plugin that handles test and topology configs and all their belongings like helper fixtures.                                                                                                                                                                                                                                                                                     May 19, 2026    N/A                    pytest<9,>=7.2.1
   :pypi:`pytest-mfd-logging`                               Module for handling PyTest logging.                                                                                                                                                                                                                                                                                                                                                     Nov 14, 2025    N/A                    pytest<9,>=7.2.1
   :pypi:`pytest-mg`                                        A tiny plugin for pytest which runs MongoDB in Docker                                                                                                                                                                                                                                                                                                                                   May 11, 2026    5 - Production/Stable  pytest>=8.0
   :pypi:`pytest-mh`                                        Pytest multihost plugin                                                                                                                                                                                                                                                                                                                                                                 Oct 16, 2025    N/A                    pytest
   :pypi:`pytest-mimesis`                                   Mimesis integration with the pytest test runner                                                                                                                                                                                                                                                                                                                                         Mar 21, 2020    5 - Production/Stable  pytest (>=4.2)
   :pypi:`pytest-mimic`                                     Easily record function calls while testing                                                                                                                                                                                                                                                                                                                                              Apr 24, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-minecraft`                                 A pytest plugin for running tests against Minecraft releases                                                                                                                                                                                                                                                                                                                            Apr 06, 2022    N/A                    pytest (>=6.0.1)
   :pypi:`pytest-mini`                                      A plugin to test mp                                                                                                                                                                                                                                                                                                                                                                     Feb 06, 2023    N/A                    pytest (>=7.2.0,<8.0.0)
   :pypi:`pytest-minio-mock`                                A pytest plugin for mocking Minio S3 interactions                                                                                                                                                                                                                                                                                                                                       Aug 06, 2025    N/A                    pytest>=5.0.0
   :pypi:`pytest-mirror`                                    A pluggy-based pytest plugin and CLI tool for ensuring your test suite mirrors your source code structure                                                                                                                                                                                                                                                                               Jul 30, 2025    4 - Beta               N/A
   :pypi:`pytest-missing-fixtures`                          Pytest plugin that creates missing fixtures                                                                                                                                                                                                                                                                                                                                             Oct 14, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-missing-modules`                           Pytest plugin to easily fake missing modules                                                                                                                                                                                                                                                                                                                                            Nov 17, 2025    N/A                    pytest>=8.3.2
   :pypi:`pytest-mitmproxy`                                 pytest plugin for mitmproxy tests                                                                                                                                                                                                                                                                                                                                                       May 09, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-mitmproxy-plugin`                          Use MITM Proxy in autotests with full control from code                                                                                                                                                                                                                                                                                                                                 Apr 10, 2025    4 - Beta               pytest>=7.2.0
   :pypi:`pytest-ml`                                        Test your machine learning!                                                                                                                                                                                                                                                                                                                                                             May 04, 2019    4 - Beta               N/A
   :pypi:`pytest-mocha`                                     pytest plugin to display test execution output like a mochajs                                                                                                                                                                                                                                                                                                                           Apr 02, 2020    4 - Beta               pytest (>=5.4.0)
   :pypi:`pytest-mock`                                      Thin-wrapper around the mock package for easier use with pytest                                                                                                                                                                                                                                                                                                                         Sep 16, 2025    5 - Production/Stable  pytest>=6.2.5
   :pypi:`pytest-mock-api`                                  A mock API server with configurable routes and responses available as a fixture.                                                                                                                                                                                                                                                                                                        Feb 13, 2019    1 - Planning           pytest (>=4.0.0)
   :pypi:`pytest-mock-generator`                            A pytest fixture wrapper for https://pypi.org/project/mock-generator                                                                                                                                                                                                                                                                                                                    May 16, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-mock-helper`                               Help you mock HTTP call and generate mock code                                                                                                                                                                                                                                                                                                                                          Jan 24, 2018    N/A                    pytest
   :pypi:`pytest-mockito`                                   Base fixtures for mockito                                                                                                                                                                                                                                                                                                                                                               Feb 10, 2026    5 - Production/Stable  pytest>=6
   :pypi:`pytest-mockllm`                                   🚀 Zero-config pytest plugin for mocking LLM APIs - OpenAI, Anthropic, Gemini, LangChain & more                                                                                                                                                                                                                                                                                         Dec 22, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-mockredis`                                 An in-memory mock of a Redis server that runs in a separate thread. This is to be used for unit-tests that require a Redis database.                                                                                                                                                                                                                                                    Jan 02, 2018    2 - Pre-Alpha          N/A
   :pypi:`pytest-mock-resources`                            A pytest plugin for easily instantiating reproducible mock resources.                                                                                                                                                                                                                                                                                                                   Sep 17, 2025    N/A                    pytest>=1.0
   :pypi:`pytest-mock-server`                               Mock server plugin for pytest                                                                                                                                                                                                                                                                                                                                                           Jan 09, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-mockservers`                               A set of fixtures to test your requests to HTTP/UDP servers                                                                                                                                                                                                                                                                                                                             Mar 31, 2020    N/A                    pytest (>=4.3.0)
   :pypi:`pytest-mocktcp`                                   A pytest plugin for testing TCP clients                                                                                                                                                                                                                                                                                                                                                 Oct 11, 2022    N/A                    pytest
   :pypi:`pytest-mock-unity-catalog`                        Unity Catalog pyspark fixtures                                                                                                                                                                                                                                                                                                                                                          Mar 12, 2026    N/A                    pytest
   :pypi:`pytest-modalt`                                    Massively distributed pytest runs using modal.com                                                                                                                                                                                                                                                                                                                                       Feb 27, 2024    4 - Beta               pytest >=6.2.0
   :pypi:`pytest-model-lib`                                 pytest plugin for model-lib                                                                                                                                                                                                                                                                                                                                                             Feb 22, 2026    N/A                    N/A
   :pypi:`pytest-modern`                                    A more modern pytest                                                                                                                                                                                                                                                                                                                                                                    Aug 19, 2025    4 - Beta               pytest>=8
   :pypi:`pytest-modified-env`                              Pytest plugin to fail a test if it leaves modified \`os.environ\` afterwards.                                                                                                                                                                                                                                                                                                           Jan 29, 2022    4 - Beta               N/A
   :pypi:`pytest-modifyjunit`                               Utility for adding additional properties to junit xml for IDM QE                                                                                                                                                                                                                                                                                                                        Jan 10, 2019    N/A                    N/A
   :pypi:`pytest-molecule`                                  PyTest Molecule Plugin :: discover and run molecule tests                                                                                                                                                                                                                                                                                                                               Mar 29, 2022    5 - Production/Stable  pytest (>=7.0.0)
   :pypi:`pytest-molecule-JC`                               PyTest Molecule Plugin :: discover and run molecule tests                                                                                                                                                                                                                                                                                                                               Jul 18, 2023    5 - Production/Stable  pytest (>=7.0.0)
   :pypi:`pytest-mongo`                                     MongoDB process and client fixtures plugin for Pytest.                                                                                                                                                                                                                                                                                                                                  Feb 04, 2026    5 - Production/Stable  pytest>=8.4
   :pypi:`pytest-mongodb`                                   pytest plugin for MongoDB fixtures                                                                                                                                                                                                                                                                                                                                                      May 16, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-mongodb-nono`                              pytest plugin for MongoDB                                                                                                                                                                                                                                                                                                                                                               Jan 07, 2025    N/A                    N/A
   :pypi:`pytest-mongodb-ry`                                pytest plugin for MongoDB                                                                                                                                                                                                                                                                                                                                                               Sep 25, 2025    N/A                    N/A
   :pypi:`pytest-mongo-docker`                              A tiny plugin for pytest which runs MongoDB in Docker                                                                                                                                                                                                                                                                                                                                   May 14, 2026    5 - Production/Stable  pytest>=8.0
   :pypi:`pytest-monitor`                                   Pytest plugin for analyzing resource usage.                                                                                                                                                                                                                                                                                                                                             Jun 25, 2023    5 - Production/Stable  pytest
   :pypi:`pytest-monkeyplus`                                pytest's monkeypatch subclass with extra functionalities                                                                                                                                                                                                                                                                                                                                Sep 18, 2012    5 - Production/Stable  N/A
   :pypi:`pytest-monkeytype`                                pytest-monkeytype: Generate Monkeytype annotations from your pytest tests.                                                                                                                                                                                                                                                                                                              Jul 29, 2020    4 - Beta               N/A
   :pypi:`pytest-moto`                                      Fixtures for integration tests of AWS services,uses moto mocking library.                                                                                                                                                                                                                                                                                                               Aug 28, 2015    1 - Planning           N/A
   :pypi:`pytest-moto-fixtures`                             Fixtures for testing code that interacts with AWS                                                                                                                                                                                                                                                                                                                                       Nov 17, 2025    1 - Planning           pytest<9.1,>=8.3; extra == "pytest"
   :pypi:`pytest-motor`                                     A pytest plugin for motor, the non-blocking MongoDB driver.                                                                                                                                                                                                                                                                                                                             Jul 21, 2021    3 - Alpha              pytest
   :pypi:`pytest-mp`                                        A test batcher for multiprocessed Pytest runs                                                                                                                                                                                                                                                                                                                                           May 23, 2018    4 - Beta               pytest
   :pypi:`pytest-mpi`                                       pytest plugin to collect information from tests                                                                                                                                                                                                                                                                                                                                         Jan 08, 2022    3 - Alpha              pytest
   :pypi:`pytest-mpiexec`                                   pytest plugin for running individual tests with mpiexec                                                                                                                                                                                                                                                                                                                                 Jul 29, 2024    3 - Alpha              pytest
   :pypi:`pytest-mpi-tmweigand`                             forked pytest plugin to collect information from tests                                                                                                                                                                                                                                                                                                                                  Dec 27, 2025    3 - Alpha              pytest
   :pypi:`pytest-mpl`                                       pytest plugin to help with testing figures output from Matplotlib                                                                                                                                                                                                                                                                                                                       Mar 25, 2026    5 - Production/Stable  pytest>=6.2.5
   :pypi:`pytest-mpl-oggm`                                  pytest plugin to help with testing figures output from Matplotlib - OGGM fork                                                                                                                                                                                                                                                                                                           Mar 09, 2026    5 - Production/Stable  pytest>=6.2.5
   :pypi:`pytest-mproc`                                     low-startup-overhead, scalable, distributed-testing pytest plugin                                                                                                                                                                                                                                                                                                                       Mar 27, 2026    4 - Beta               pytest>=6
   :pypi:`pytest-mqtt`                                      pytest-mqtt supports testing systems based on MQTT                                                                                                                                                                                                                                                                                                                                      Jan 28, 2026    5 - Production/Stable  pytest<10; extra == "test"
   :pypi:`pytest-mrt`                                       Catch database migration rollback failures before they reach production                                                                                                                                                                                                                                                                                                                 Jun 06, 2026    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-multihost`                                 Utility for writing multi-host tests for pytest                                                                                                                                                                                                                                                                                                                                         Apr 07, 2020    4 - Beta               N/A
   :pypi:`pytest-multilog`                                  Multi-process logs handling and other helpers for pytest                                                                                                                                                                                                                                                                                                                                Dec 28, 2025    N/A                    pytest
   :pypi:`pytest-multithreading`                            a pytest plugin for th and concurrent testing                                                                                                                                                                                                                                                                                                                                           Aug 05, 2024    N/A                    N/A
   :pypi:`pytest-multithreading-allure`                     pytest_multithreading_allure                                                                                                                                                                                                                                                                                                                                                            Nov 25, 2022    N/A                    N/A
   :pypi:`pytest-mutagen`                                   Add the mutation testing feature to pytest                                                                                                                                                                                                                                                                                                                                              Jul 24, 2020    N/A                    pytest (>=5.4)
   :pypi:`pytest-my-cool-lib`                                                                                                                                                                                                                                                                                                                                                                                                                       Nov 02, 2023    N/A                    pytest (>=7.1.3,<8.0.0)
   :pypi:`pytest-my-plugin`                                 A pytest plugin that does awesome things                                                                                                                                                                                                                                                                                                                                                Jan 27, 2025    N/A                    pytest>=6.0
   :pypi:`pytest-mypy`                                      A Pytest Plugin for Mypy                                                                                                                                                                                                                                                                                                                                                                Apr 02, 2025    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-mypyd`                                     Mypy static type checker plugin for Pytest                                                                                                                                                                                                                                                                                                                                              Aug 20, 2019    4 - Beta               pytest (<4.7,>=2.8) ; python_version < "3.5"
   :pypi:`pytest-mypy-plugins`                              pytest plugin for writing tests for mypy plugins                                                                                                                                                                                                                                                                                                                                        May 14, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-mypy-plugins-shim`                         Substitute for "pytest-mypy-plugins" for Python implementations which aren't supported by mypy.                                                                                                                                                                                                                                                                                         Feb 14, 2025    N/A                    pytest>=6.0.0
   :pypi:`pytest-mypy-runner`                               Run the mypy static type checker as a pytest test case                                                                                                                                                                                                                                                                                                                                  Apr 23, 2024    N/A                    pytest>=8.0
   :pypi:`pytest-mypy-testing`                              Pytest plugin to check mypy output                                                                                                                                                                                                                                                                                                                                                      Jan 26, 2026    N/A                    pytest>=8
   :pypi:`pytest-mysql`                                     MySQL process and client fixtures for pytest                                                                                                                                                                                                                                                                                                                                            Apr 12, 2026    5 - Production/Stable  pytest>=8.4
   :pypi:`pytest-nb`                                        Seedable Jupyter Notebook testing tool                                                                                                                                                                                                                                                                                                                                                  Jul 26, 2025    N/A                    pytest==8.4.1
   :pypi:`pytest-nb-as-test`                                Use notebooks as pytests. Keep your notebooks working.                                                                                                                                                                                                                                                                                                                                  Feb 25, 2026    4 - Beta               pytest<9.1.0,>=7.0.0; python_version < "3.14"
   :pypi:`pytest-nbgrader`                                  Pytest plugin for using with nbgrader and generating test cases.                                                                                                                                                                                                                                                                                                                        Mar 31, 2026    3 - Alpha              pytest>=8
   :pypi:`pytest-ndb`                                       pytest notebook debugger                                                                                                                                                                                                                                                                                                                                                                Apr 28, 2024    N/A                    pytest
   :pypi:`pytest-needle`                                    pytest plugin for visual testing websites using selenium                                                                                                                                                                                                                                                                                                                                Dec 10, 2018    4 - Beta               pytest (<5.0.0,>=3.0.0)
   :pypi:`pytest-neo`                                       pytest-neo is a plugin for pytest that shows tests like screen of Matrix.                                                                                                                                                                                                                                                                                                               Jan 08, 2022    3 - Alpha              pytest (>=6.2.0)
   :pypi:`pytest-neon`                                      Pytest plugin for Neon database branch isolation in tests                                                                                                                                                                                                                                                                                                                               Feb 05, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-neos`                                      Pytest plugin for neos                                                                                                                                                                                                                                                                                                                                                                  Sep 10, 2024    5 - Production/Stable  pytest<8.0,>=7.2; extra == "dev"
   :pypi:`pytest-netconf`                                   A pytest plugin that provides a mock NETCONF (RFC6241/RFC6242) server for local testing.                                                                                                                                                                                                                                                                                                Nov 03, 2025    N/A                    N/A
   :pypi:`pytest-netdut`                                    "Automated software testing for switches using pytest"                                                                                                                                                                                                                                                                                                                                  Oct 09, 2025    N/A                    pytest>=3.5.0
   :pypi:`pytest-network`                                   A simple plugin to disable network on socket level.                                                                                                                                                                                                                                                                                                                                     May 07, 2020    N/A                    N/A
   :pypi:`pytest-network-endpoints`                         Network endpoints plugin for pytest                                                                                                                                                                                                                                                                                                                                                     Mar 06, 2022    N/A                    pytest
   :pypi:`pytest-never-sleep`                               pytest plugin helps to avoid adding tests without mock \`time.sleep\`                                                                                                                                                                                                                                                                                                                   May 05, 2021    3 - Alpha              pytest (>=3.5.1)
   :pypi:`pytest-nginx`                                     nginx fixture for pytest                                                                                                                                                                                                                                                                                                                                                                May 03, 2025    5 - Production/Stable  pytest>=3.0.0
   :pypi:`pytest-nginx-iplweb`                              nginx fixture for pytest - iplweb temporary fork                                                                                                                                                                                                                                                                                                                                        Mar 01, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-ngrok`                                                                                                                                                                                                                                                                                                                                                                                                                             Jan 20, 2022    3 - Alpha              pytest
   :pypi:`pytest-ngsfixtures`                               pytest ngs fixtures                                                                                                                                                                                                                                                                                                                                                                     Sep 06, 2019    2 - Pre-Alpha          pytest (>=5.0.0)
   :pypi:`pytest-nhsd-apim`                                 Pytest plugin accessing NHSDigital's APIM proxies                                                                                                                                                                                                                                                                                                                                       Jun 03, 2026    N/A                    pytest<10.0.0,>=8.2.0
   :pypi:`pytest-nice`                                      A pytest plugin that alerts user of failed test cases with screen notifications                                                                                                                                                                                                                                                                                                         May 04, 2019    4 - Beta               pytest
   :pypi:`pytest-nice-parametrize`                          A small snippet for nicer PyTest's Parametrize                                                                                                                                                                                                                                                                                                                                          Apr 17, 2021    5 - Production/Stable  N/A
   :pypi:`pytest_nlcov`                                     Pytest plugin to get the coverage of the new lines (based on git diff) only                                                                                                                                                                                                                                                                                                             Aug 05, 2024    N/A                    N/A
   :pypi:`pytest-nocustom`                                  Run all tests without custom markers                                                                                                                                                                                                                                                                                                                                                    Aug 05, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-node-dependency`                           pytest plugin for controlling execution flow                                                                                                                                                                                                                                                                                                                                            Apr 10, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-nodev`                                     Test-driven source code search for Python.                                                                                                                                                                                                                                                                                                                                              Jul 21, 2016    4 - Beta               pytest (>=2.8.1)
   :pypi:`pytest-nogarbage`                                 Ensure a test produces no garbage                                                                                                                                                                                                                                                                                                                                                       Feb 24, 2025    5 - Production/Stable  pytest>=4.6.0
   :pypi:`pytest-no-problem`                                Pytest plugin to tell you when there's no problem                                                                                                                                                                                                                                                                                                                                       Jan 11, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-nose-attrib`                               pytest plugin to use nose @attrib marks decorators and pick tests based on attributes and partially uses nose-attrib plugin approach                                                                                                                                                                                                                                                    Aug 13, 2023    N/A                    N/A
   :pypi:`pytest_notebook`                                  A pytest plugin for testing Jupyter Notebooks.                                                                                                                                                                                                                                                                                                                                          Nov 28, 2023    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-notebook-policy`                           Pytest plugin for notebook policy and quality checks                                                                                                                                                                                                                                                                                                                                    May 30, 2026    3 - Alpha              pytest>=8.0
   :pypi:`pytest-notice`                                    Send pytest execution result email                                                                                                                                                                                                                                                                                                                                                      Nov 05, 2020    N/A                    N/A
   :pypi:`pytest-notification`                              A pytest plugin for sending a desktop notification and playing a sound upon completion of tests                                                                                                                                                                                                                                                                                         Jun 19, 2020    N/A                    pytest (>=4)
   :pypi:`pytest-notifier`                                  A pytest plugin to notify test result                                                                                                                                                                                                                                                                                                                                                   Jun 12, 2020    3 - Alpha              pytest
   :pypi:`pytest-notifier-plugin`                           Pytest plugin для отправки нотификаций в различные каналы связи о статуе прохождения тестов.                                                                                                                                                                                                                                                                                            Dec 22, 2025    N/A                    pytest>=7.0
   :pypi:`pytest_notify`                                    Get notifications when your tests ends                                                                                                                                                                                                                                                                                                                                                  Jul 05, 2017    N/A                    pytest>=3.0.0
   :pypi:`pytest-notimplemented`                            Pytest markers for not implemented features and tests.                                                                                                                                                                                                                                                                                                                                  Aug 27, 2019    N/A                    pytest (>=5.1,<6.0)
   :pypi:`pytest-notion`                                    A PyTest Reporter to send test runs to Notion.so                                                                                                                                                                                                                                                                                                                                        Aug 07, 2019    N/A                    N/A
   :pypi:`pytest-nunit`                                     A pytest plugin for generating NUnit3 test result XML output                                                                                                                                                                                                                                                                                                                            Feb 26, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-oar`                                       PyTest plugin for the OAR testing framework                                                                                                                                                                                                                                                                                                                                             May 12, 2025    N/A                    pytest>=6.0.1
   :pypi:`pytest-oarepo`                                                                                                                                                                                                                                                                                                                                                                                                                            Jun 06, 2026    N/A                    pytest>=7.1.2; extra == "dev"
   :pypi:`pytest-object-getter`                             Import any object from a 3rd party module while mocking its namespace on demand.                                                                                                                                                                                                                                                                                                        Jul 31, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-ochrus`                                    pytest results data-base and HTML reporter                                                                                                                                                                                                                                                                                                                                              Feb 21, 2018    4 - Beta               N/A
   :pypi:`pytest-odc`                                       A pytest plugin for simplifying ODC database tests                                                                                                                                                                                                                                                                                                                                      Aug 04, 2023    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-odoo`                                      py.test plugin to run Odoo tests                                                                                                                                                                                                                                                                                                                                                        May 20, 2025    5 - Production/Stable  pytest>=8
   :pypi:`pytest-odoo-fixtures`                             Project description                                                                                                                                                                                                                                                                                                                                                                     Jun 25, 2019    N/A                    N/A
   :pypi:`pytest-oduit`                                     py.test plugin to run Odoo tests                                                                                                                                                                                                                                                                                                                                                        May 12, 2026    5 - Production/Stable  pytest>=8
   :pypi:`pytest-oerp`                                      pytest plugin to test OpenERP modules                                                                                                                                                                                                                                                                                                                                                   Feb 28, 2012    3 - Alpha              N/A
   :pypi:`pytest-offline`                                                                                                                                                                                                                                                                                                                                                                                                                           Mar 09, 2023    1 - Planning           pytest (>=7.0.0,<8.0.0)
   :pypi:`pytest-ogsm-plugin`                               针对特定项目定制化插件，优化了pytest报告展示方式,并添加了项目所需特定参数                                                                                                                                                                                                                                                                                                               May 16, 2023    N/A                    N/A
   :pypi:`pytest-ok`                                        The ultimate pytest output plugin                                                                                                                                                                                                                                                                                                                                                       Apr 01, 2019    4 - Beta               N/A
   :pypi:`pytest-once`                                      xdist-safe 'run once' fixture decorator for pytest (setup/teardown across workers)                                                                                                                                                                                                                                                                                                      Oct 10, 2025    3 - Alpha              pytest>=8.4.0
   :pypi:`pytest-only`                                      Use @pytest.mark.only to run a single test                                                                                                                                                                                                                                                                                                                                              May 27, 2024    5 - Production/Stable  pytest<9,>=3.6.0
   :pypi:`pytest-only-markers`                              A pytest plugin that isolates test execution to only tests decorated with ONLY\* markers, stripping all other markers from matching items.                                                                                                                                                                                                                                              Mar 17, 2026    5 - Production/Stable  pytest>=9.0.1
   :pypi:`pytest-oof`                                       A Pytest plugin providing structured, programmatic access to a test run's results                                                                                                                                                                                                                                                                                                       Dec 11, 2023    4 - Beta               N/A
   :pypi:`pytest-oot`                                       Run object-oriented tests in a simple format                                                                                                                                                                                                                                                                                                                                            Sep 18, 2016    4 - Beta               N/A
   :pypi:`pytest-openapi`                                   \`pytest --openapi\` - an opinionated, lightweight black-box contract tester against a live API using its OpenAPI specification as the source of truth                                                                                                                                                                                                                                  Apr 21, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-openfeature`                               Drive pytest configuration from an OpenFeature provider.                                                                                                                                                                                                                                                                                                                                Apr 28, 2026    4 - Beta               pytest>=8.0
   :pypi:`pytest-openfiles`                                 Pytest plugin for detecting inadvertent open file handles                                                                                                                                                                                                                                                                                                                               Jun 05, 2024    3 - Alpha              pytest>=4.6
   :pypi:`pytest-open-html`                                 Auto-open HTML reports after pytest runs                                                                                                                                                                                                                                                                                                                                                Mar 31, 2025    N/A                    pytest>=6.0
   :pypi:`pytest-opentelemetry`                             A pytest plugin for instrumenting test runs via OpenTelemetry                                                                                                                                                                                                                                                                                                                           Apr 25, 2025    N/A                    pytest
   :pypi:`pytest-opentmi`                                   pytest plugin for publish results to opentmi                                                                                                                                                                                                                                                                                                                                            Feb 09, 2026    5 - Production/Stable  pytest>=5.0
   :pypi:`pytest-operator`                                  Fixtures for Charmed Operators                                                                                                                                                                                                                                                                                                                                                          Sep 28, 2022    N/A                    pytest
   :pypi:`pytest-optional`                                  include/exclude values of fixtures in pytest                                                                                                                                                                                                                                                                                                                                            Oct 07, 2015    N/A                    N/A
   :pypi:`pytest-optional-tests`                            Easy declaration of optional tests (i.e., that are not run by default)                                                                                                                                                                                                                                                                                                                  Jul 21, 2025    4 - Beta               pytest; extra == "dev"
   :pypi:`pytest-orchestration`                             A pytest plugin for orchestrating tests                                                                                                                                                                                                                                                                                                                                                 Jul 18, 2019    N/A                    N/A
   :pypi:`pytest-order`                                     pytest plugin to run tests in a specific order                                                                                                                                                                                                                                                                                                                                          Apr 26, 2026    5 - Production/Stable  pytest>=6.2.4; python_version < "3.14"
   :pypi:`pytest-ordered`                                   Declare the order in which tests should run in your pytest.ini                                                                                                                                                                                                                                                                                                                          Nov 09, 2025    N/A                    pytest>=6.2.0
   :pypi:`pytest-ordering`                                  pytest plugin to run your tests in a specific order                                                                                                                                                                                                                                                                                                                                     Nov 14, 2018    4 - Beta               pytest
   :pypi:`pytest-order-modify`                              新增run_marker 来自定义用例的执行顺序                                                                                                                                                                                                                                                                                                                                                   Nov 04, 2022    N/A                    N/A
   :pypi:`pytest-osxnotify`                                 OS X notifications for py.test results.                                                                                                                                                                                                                                                                                                                                                 May 15, 2015    N/A                    N/A
   :pypi:`pytest-ot`                                        A pytest plugin for instrumenting test runs via OpenTelemetry                                                                                                                                                                                                                                                                                                                           Mar 21, 2024    N/A                    pytest; extra == "dev"
   :pypi:`pytest-otel`                                      OpenTelemetry plugin for Pytest                                                                                                                                                                                                                                                                                                                                                         Apr 29, 2026    N/A                    pytest==9.0.3
   :pypi:`pytest-otelmark`                                  Pytest plugin for otelmark.                                                                                                                                                                                                                                                                                                                                                             Sep 14, 2025    3 - Alpha              pytest>=8.3.5
   :pypi:`pytest-override-env-var`                          Pytest mark to override a value of an environment variable.                                                                                                                                                                                                                                                                                                                             Feb 25, 2023    N/A                    N/A
   :pypi:`pytest-owner`                                     Add owner mark for tests                                                                                                                                                                                                                                                                                                                                                                Aug 19, 2024    N/A                    pytest
   :pypi:`pytest-pact`                                      A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Jan 07, 2019    4 - Beta               N/A
   :pypi:`pytest-pagerduty`                                 Pytest plugin for PagerDuty integration via automation testing.                                                                                                                                                                                                                                                                                                                         Mar 22, 2025    N/A                    pytest<9.0.0,>=7.4.0
   :pypi:`pytest-pahrametahrize`                            Parametrize your tests with a Boston accent.                                                                                                                                                                                                                                                                                                                                            Nov 24, 2021    4 - Beta               pytest (>=6.0,<7.0)
   :pypi:`pytest-paia-blockly`                              pytest plugin for PAIA Blockly: verify get_solution() against test cases                                                                                                                                                                                                                                                                                                                Mar 19, 2026    N/A                    pytest>=8.0
   :pypi:`pytest-paraflow`                                  Deterministic pytest test sharding across CI machines                                                                                                                                                                                                                                                                                                                                   Feb 26, 2026    3 - Alpha              pytest>=9.0.0
   :pypi:`pytest-parallel`                                  a pytest plugin for parallel and concurrent testing                                                                                                                                                                                                                                                                                                                                     Oct 10, 2021    3 - Alpha              pytest (>=3.0.0)
   :pypi:`pytest-parallel-39`                               a pytest plugin for parallel and concurrent testing                                                                                                                                                                                                                                                                                                                                     Jul 12, 2021    3 - Alpha              pytest (>=3.0.0)
   :pypi:`pytest-parallelize-tests`                         pytest plugin that parallelizes test execution across multiple hosts                                                                                                                                                                                                                                                                                                                    Jan 27, 2023    4 - Beta               N/A
   :pypi:`pytest-param`                                     pytest plugin to test all, first, last or random params                                                                                                                                                                                                                                                                                                                                 Sep 11, 2016    4 - Beta               pytest (>=2.6.0)
   :pypi:`pytest-parametrization`                           Simpler PyTest parametrization                                                                                                                                                                                                                                                                                                                                                          May 22, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-parametrization-annotation`                A pytest library for parametrizing tests using type hints.                                                                                                                                                                                                                                                                                                                              Dec 10, 2024    5 - Production/Stable  pytest>=7
   :pypi:`pytest-parametrize`                               pytest decorator for parametrizing test cases in a dict-way                                                                                                                                                                                                                                                                                                                             Apr 03, 2026    5 - Production/Stable  pytest<10.0,>=8.3
   :pypi:`pytest-parametrize-cases`                         A more user-friendly way to write parametrized tests.                                                                                                                                                                                                                                                                                                                                   Mar 13, 2022    N/A                    pytest (>=6.1.2)
   :pypi:`pytest-parametrized`                              Pytest decorator for parametrizing tests with default iterables.                                                                                                                                                                                                                                                                                                                        Dec 21, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-parametrize-suite`                         A simple pytest extension for creating a named test suite.                                                                                                                                                                                                                                                                                                                              Jan 19, 2023    5 - Production/Stable  pytest
   :pypi:`pytest_param_files`                               Create pytest parametrize decorators from external files.                                                                                                                                                                                                                                                                                                                               Jul 29, 2023    N/A                    pytest
   :pypi:`pytest-params`                                    Simplified pytest test case parameters.                                                                                                                                                                                                                                                                                                                                                 Mar 14, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-param-scope`                               pytest parametrize scope fixture workaround                                                                                                                                                                                                                                                                                                                                             Oct 18, 2023    N/A                    pytest
   :pypi:`pytest-parawtf`                                   Finally spell paramete?ri[sz]e correctly                                                                                                                                                                                                                                                                                                                                                Dec 03, 2018    4 - Beta               pytest (>=3.6.0)
   :pypi:`pytest-park`                                      Organise and analyse your pytest benchmarks                                                                                                                                                                                                                                                                                                                                             Mar 20, 2026    N/A                    N/A
   :pypi:`pytest-pass`                                      Check out https://github.com/elilutsky/pytest-pass                                                                                                                                                                                                                                                                                                                                      Dec 04, 2019    N/A                    N/A
   :pypi:`pytest-passrunner`                                Pytest plugin providing the 'run_on_pass' marker                                                                                                                                                                                                                                                                                                                                        Feb 10, 2021    5 - Production/Stable  pytest (>=4.6.0)
   :pypi:`pytest-pastebin`                                  Submit pytest failure or test session information to a pastebin service                                                                                                                                                                                                                                                                                                                 May 10, 2026    6 - Mature             pytest>=7
   :pypi:`pytest-paste-config`                              Allow setting the path to a paste config file                                                                                                                                                                                                                                                                                                                                           Sep 18, 2013    3 - Alpha              N/A
   :pypi:`pytest-patch`                                     An automagic \`patch\` fixture that can patch objects directly or by name.                                                                                                                                                                                                                                                                                                              Apr 29, 2023    3 - Alpha              pytest (>=7.0.0)
   :pypi:`pytest-patches`                                   A contextmanager pytest fixture for handling multiple mock patches                                                                                                                                                                                                                                                                                                                      May 09, 2026    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-patterns`                                  pytest plugin to make testing complicated long string output easy to write and easy to debug                                                                                                                                                                                                                                                                                            Oct 22, 2024    4 - Beta               pytest>=6
   :pypi:`pytest-pdb`                                       pytest plugin which adds pdb helper commands related to pytest.                                                                                                                                                                                                                                                                                                                         Jul 31, 2018    N/A                    N/A
   :pypi:`pytest-peach`                                     pytest plugin for fuzzing with Peach API Security                                                                                                                                                                                                                                                                                                                                       Apr 12, 2019    4 - Beta               pytest (>=2.8.7)
   :pypi:`pytest-pep257`                                    py.test plugin for pep257                                                                                                                                                                                                                                                                                                                                                               Jul 09, 2016    N/A                    N/A
   :pypi:`pytest-pep723`                                    Pytest plugin to verify PEP 723 inline script metadata covers all imports.                                                                                                                                                                                                                                                                                                              Apr 06, 2026    4 - Beta               pytest>=7
   :pypi:`pytest-pep8`                                      pytest plugin to check PEP8 requirements                                                                                                                                                                                                                                                                                                                                                Apr 27, 2014    N/A                    N/A
   :pypi:`pytest-percent`                                   Change the exit code of pytest test sessions when a required percent of tests pass.                                                                                                                                                                                                                                                                                                     May 21, 2020    N/A                    pytest (>=5.2.0)
   :pypi:`pytest-percents`                                                                                                                                                                                                                                                                                                                                                                                                                          Mar 16, 2024    N/A                    N/A
   :pypi:`pytest-perf`                                      Run performance tests against the mainline code.                                                                                                                                                                                                                                                                                                                                        May 20, 2024    5 - Production/Stable  pytest!=8.1.*,>=6; extra == "testing"
   :pypi:`pytest-performance`                               A simple plugin to ensure the execution of critical sections of code has not been impacted                                                                                                                                                                                                                                                                                              Sep 11, 2020    5 - Production/Stable  pytest (>=3.7.0)
   :pypi:`pytest-performancetotal`                          A performance plugin for pytest                                                                                                                                                                                                                                                                                                                                                         Mar 24, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-persistence`                               Pytest tool for persistent objects                                                                                                                                                                                                                                                                                                                                                      Aug 21, 2024    N/A                    N/A
   :pypi:`pytest-pexpect`                                   Pytest pexpect plugin.                                                                                                                                                                                                                                                                                                                                                                  Sep 10, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest_pg`                                        A tiny plugin for pytest which runs PostgreSQL in Docker                                                                                                                                                                                                                                                                                                                                Jun 02, 2026    5 - Production/Stable  pytest>=8.0
   :pypi:`pytest-pgsql`                                     Pytest plugins and helpers for tests using a Postgres database.                                                                                                                                                                                                                                                                                                                         May 13, 2020    5 - Production/Stable  pytest (>=3.0.0)
   :pypi:`pytest-pgtap`                                     Pytest plugin for running pgTAP tests                                                                                                                                                                                                                                                                                                                                                   May 29, 2026    3 - Alpha              N/A
   :pypi:`pytest-phmdoctest`                                pytest plugin to test Python examples in Markdown using phmdoctest.                                                                                                                                                                                                                                                                                                                     Apr 15, 2022    4 - Beta               pytest (>=5.4.3)
   :pypi:`pytest-phoenix-interface`                         Pytest extension tool for phoenix projects.                                                                                                                                                                                                                                                                                                                                             Mar 19, 2025    N/A                    N/A
   :pypi:`pytest-picked`                                    Run the tests related to the changed files                                                                                                                                                                                                                                                                                                                                              Nov 06, 2024    N/A                    pytest>=3.7.0
   :pypi:`pytest-pickle-cache`                              A pytest plugin for caching test results using pickle.                                                                                                                                                                                                                                                                                                                                  Feb 06, 2026    4 - Beta               pytest>=9
   :pypi:`pytest-pigeonhole`                                                                                                                                                                                                                                                                                                                                                                                                                        Jun 25, 2018    5 - Production/Stable  pytest (>=3.4)
   :pypi:`pytest-pikachu`                                   Show surprise when tests are passing                                                                                                                                                                                                                                                                                                                                                    Aug 05, 2021    5 - Production/Stable  pytest
   :pypi:`pytest-pilot`                                     Slice in your test base thanks to powerful markers.                                                                                                                                                                                                                                                                                                                                     Dec 17, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-pingguo-pytest-plugin`                     pingguo test                                                                                                                                                                                                                                                                                                                                                                            Oct 26, 2022    4 - Beta               N/A
   :pypi:`pytest-pings`                                     🦊 The pytest plugin for Firefox Telemetry 📊                                                                                                                                                                                                                                                                                                                                           Jun 29, 2019    3 - Alpha              pytest (>=5.0.0)
   :pypi:`pytest-pinned`                                    A simple pytest plugin for pinning tests                                                                                                                                                                                                                                                                                                                                                Sep 17, 2021    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-pinpoint`                                  A pytest plugin which runs SBFL algorithms to detect faults.                                                                                                                                                                                                                                                                                                                            Sep 25, 2020    N/A                    pytest (>=4.4.0)
   :pypi:`pytest-pipeline`                                  Pytest plugin for functional testing of data analysispipelines                                                                                                                                                                                                                                                                                                                          Jan 24, 2017    3 - Alpha              N/A
   :pypi:`pytest-pitch`                                     runs tests in an order such that coverage increases as fast as possible                                                                                                                                                                                                                                                                                                                 Nov 02, 2023    4 - Beta               pytest >=7.3.1
   :pypi:`pytest-platform-adapter`                          Pytest集成自动化平台插件                                                                                                                                                                                                                                                                                                                                                                Mar 23, 2026    5 - Production/Stable  pytest>=6.2.5
   :pypi:`pytest-platform-markers`                          Markers for pytest to skip tests on specific platforms                                                                                                                                                                                                                                                                                                                                  Sep 09, 2019    4 - Beta               pytest (>=3.6.0)
   :pypi:`pytest-play`                                      pytest plugin that let you automate actions and assertions with test metrics reporting executing plain YAML files                                                                                                                                                                                                                                                                       Jun 12, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-playbook`                                  Pytest plugin for reading playbooks.                                                                                                                                                                                                                                                                                                                                                    Jan 21, 2021    3 - Alpha              pytest (>=6.1.2,<7.0.0)
   :pypi:`pytest-playwright`                                A pytest wrapper with fixtures for Playwright to automate web browsers                                                                                                                                                                                                                                                                                                                  May 18, 2026    N/A                    pytest<10.0.0,>=6.2.4
   :pypi:`pytest-playwright-artifacts`                      Capture screenshots, HTML, and console logs on Playwright test failures                                                                                                                                                                                                                                                                                                                 May 21, 2026    N/A                    N/A
   :pypi:`pytest_playwright_async`                          ASYNC Pytest plugin for Playwright                                                                                                                                                                                                                                                                                                                                                      Sep 28, 2024    N/A                    N/A
   :pypi:`pytest-playwright-asyncio`                        A pytest wrapper with async fixtures for Playwright to automate web browsers                                                                                                                                                                                                                                                                                                            May 18, 2026    N/A                    pytest<10.0.0,>=6.2.4
   :pypi:`pytest-playwright-axe`                            An axe-core integration for accessibility testing using Playwright Python.                                                                                                                                                                                                                                                                                                              Jun 05, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-playwright-enhanced`                       A pytest plugin for playwright python                                                                                                                                                                                                                                                                                                                                                   Mar 24, 2024    N/A                    pytest<9.0.0,>=8.0.0
   :pypi:`pytest-playwright-json`                           Generate Playwright-compatible JSON reports from pytest-playwright test runs                                                                                                                                                                                                                                                                                                            Jan 06, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-playwrights`                               A pytest wrapper with fixtures for Playwright to automate web browsers                                                                                                                                                                                                                                                                                                                  Dec 02, 2021    N/A                    N/A
   :pypi:`pytest-playwright-snapshot`                       A pytest wrapper for snapshot testing with playwright                                                                                                                                                                                                                                                                                                                                   Aug 19, 2021    N/A                    N/A
   :pypi:`pytest-playwright-visual`                         A pytest fixture for visual testing with Playwright                                                                                                                                                                                                                                                                                                                                     Apr 28, 2022    N/A                    N/A
   :pypi:`pytest-playwright-visual-snapshot`                Easy pytest visual regression testing using playwright                                                                                                                                                                                                                                                                                                                                  Feb 05, 2026    N/A                    N/A
   :pypi:`pytest-pl-grader`                                 A pytest plugin for autograding Python code. Designed for use with the PrairieLearn platform.                                                                                                                                                                                                                                                                                           Nov 12, 2025    3 - Alpha              pytest
   :pypi:`pytest-plone`                                     Pytest plugin to test Plone addons                                                                                                                                                                                                                                                                                                                                                      May 18, 2026    3 - Alpha              pytest>=8.4.0
   :pypi:`pytest-plt`                                       Fixtures for quickly making Matplotlib plots in tests                                                                                                                                                                                                                                                                                                                                   Jan 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-plugin-helpers`                            A plugin to help developing and testing other plugins                                                                                                                                                                                                                                                                                                                                   Nov 23, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-plugins`                                   A Python package for managing pytest plugins.                                                                                                                                                                                                                                                                                                                                           May 18, 2026    5 - Production/Stable  pytest>=9.0.1
   :pypi:`pytest-plugin-utils`                              Reusable configuration and artifact utilities for building pytest plugins                                                                                                                                                                                                                                                                                                               May 04, 2026    N/A                    N/A
   :pypi:`pytest-plus`                                      PyTest Plus Plugin :: extends pytest functionality                                                                                                                                                                                                                                                                                                                                      Feb 02, 2025    5 - Production/Stable  pytest>=7.4.2
   :pypi:`pytest-pmisc`                                                                                                                                                                                                                                                                                                                                                                                                                             Mar 21, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-podman`                                    Pytest plugin for Podman integration                                                                                                                                                                                                                                                                                                                                                    Feb 03, 2026    N/A                    N/A
   :pypi:`pytest-pogo`                                      Pytest plugin for pogo-migrate                                                                                                                                                                                                                                                                                                                                                          Jan 20, 2026    4 - Beta               pytest>=7
   :pypi:`pytest-pointers`                                  Pytest plugin to define functions you test with special marks for better navigation and reports                                                                                                                                                                                                                                                                                         Dec 26, 2022    N/A                    N/A
   :pypi:`pytest-pokie`                                     Pokie plugin for pytest                                                                                                                                                                                                                                                                                                                                                                 Oct 19, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-polarion-cfme`                             pytest plugin for collecting test cases and recording test results                                                                                                                                                                                                                                                                                                                      Nov 13, 2017    3 - Alpha              N/A
   :pypi:`pytest-polarion-collect`                          pytest plugin for collecting polarion test cases data                                                                                                                                                                                                                                                                                                                                   Jun 18, 2020    3 - Alpha              pytest
   :pypi:`pytest-polaroid`                                  A pytest plugin for snapshot testing.                                                                                                                                                                                                                                                                                                                                                   Apr 23, 2026    N/A                    N/A
   :pypi:`pytest-polecat`                                   Provides Polecat pytest fixtures                                                                                                                                                                                                                                                                                                                                                        Aug 12, 2019    4 - Beta               N/A
   :pypi:`pytest-polymeric-report`                          A polymeric test report plugin for pytest                                                                                                                                                                                                                                                                                                                                               Feb 24, 2026    N/A                    N/A
   :pypi:`pytest-ponyorm`                                   PonyORM in Pytest                                                                                                                                                                                                                                                                                                                                                                       Oct 31, 2018    N/A                    pytest (>=3.1.1)
   :pypi:`pytest-poo`                                       Visualize your crappy tests                                                                                                                                                                                                                                                                                                                                                             Mar 25, 2021    5 - Production/Stable  pytest (>=2.3.4)
   :pypi:`pytest-poo-fail`                                  Visualize your failed tests with poo                                                                                                                                                                                                                                                                                                                                                    Feb 12, 2015    5 - Production/Stable  N/A
   :pypi:`pytest-pook`                                      Pytest plugin for pook                                                                                                                                                                                                                                                                                                                                                                  Feb 15, 2024    4 - Beta               pytest
   :pypi:`pytest-pop`                                       A pytest plugin to help with testing pop projects                                                                                                                                                                                                                                                                                                                                       May 09, 2023    5 - Production/Stable  pytest
   :pypi:`pytest-porcochu`                                  Show surprise when tests are passing                                                                                                                                                                                                                                                                                                                                                    Nov 28, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-portion`                                   Select a portion of the collected tests                                                                                                                                                                                                                                                                                                                                                 Mar 04, 2026    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-postgres`                                  Run PostgreSQL in Docker container in Pytest.                                                                                                                                                                                                                                                                                                                                           Mar 22, 2020    N/A                    pytest
   :pypi:`pytest-postgresql`                                Postgresql fixtures and fixture factories for Pytest.                                                                                                                                                                                                                                                                                                                                   May 15, 2026    5 - Production/Stable  pytest>=8.2
   :pypi:`pytest-power`                                     pytest plugin with powerful fixtures                                                                                                                                                                                                                                                                                                                                                    Dec 31, 2020    N/A                    pytest (>=5.4)
   :pypi:`pytest-powerpack`                                 A plugin containing extra batteries for pytest                                                                                                                                                                                                                                                                                                                                          Jan 04, 2025    N/A                    pytest<9.0.0,>=8.1.1
   :pypi:`pytest-prairielearn-grader`                       A pytest plugin for autograding Python code. Designed for use with the PrairieLearn platform.                                                                                                                                                                                                                                                                                           May 21, 2026    3 - Alpha              pytest
   :pypi:`pytest-prefer-nested-dup-tests`                   A Pytest plugin to drop duplicated tests during collection, but will prefer keeping nested packages.                                                                                                                                                                                                                                                                                    Apr 27, 2022    4 - Beta               pytest (>=7.1.1,<8.0.0)
   :pypi:`pytest-pretty`                                    pytest plugin for printing summary data as I want it                                                                                                                                                                                                                                                                                                                                    Jun 04, 2025    5 - Production/Stable  pytest>=7
   :pypi:`pytest-pretty-terminal`                           pytest plugin for generating prettier terminal output                                                                                                                                                                                                                                                                                                                                   Jan 31, 2022    N/A                    pytest (>=3.4.1)
   :pypi:`pytest-pride`                                     Minitest-style test colors                                                                                                                                                                                                                                                                                                                                                              Apr 02, 2016    3 - Alpha              N/A
   :pypi:`pytest-print`                                     pytest-print adds the printer fixture you can use to print messages to the user (directly to the pytest runner, not stdout)                                                                                                                                                                                                                                                             Feb 11, 2026    5 - Production/Stable  pytest>=9.0.2
   :pypi:`pytest-priority`                                  pytest plugin for add priority for tests                                                                                                                                                                                                                                                                                                                                                Aug 19, 2024    N/A                    pytest
   :pypi:`pytest-proceed`                                                                                                                                                                                                                                                                                                                                                                                                                           Oct 01, 2024    N/A                    pytest
   :pypi:`pytest-profiles`                                  pytest plugin for configuration profiles                                                                                                                                                                                                                                                                                                                                                Dec 09, 2021    4 - Beta               pytest (>=3.7.0)
   :pypi:`pytest-profiling`                                 Profiling plugin for py.test                                                                                                                                                                                                                                                                                                                                                            Nov 29, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-progress`                                  pytest plugin for instant test progress status                                                                                                                                                                                                                                                                                                                                          Nov 11, 2025    5 - Production/Stable  pytest>=6.0
   :pypi:`pytest-prometheus`                                Report test pass / failures to a Prometheus PushGateway                                                                                                                                                                                                                                                                                                                                 Oct 03, 2017    N/A                    N/A
   :pypi:`pytest-prometheus-pushgateway`                    Pytest report plugin for Zulip                                                                                                                                                                                                                                                                                                                                                          Sep 27, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-prometheus-pushgw`                         Pytest plugin to export test metrics to Prometheus Pushgateway                                                                                                                                                                                                                                                                                                                          May 19, 2025    N/A                    pytest>=6.0.0
   :pypi:`pytest-prompts`                                   pytest for LLM prompts — tests, regressions, CI.                                                                                                                                                                                                                                                                                                                                        Apr 23, 2026    3 - Alpha              pytest>=8.0
   :pypi:`pytest-proofy`                                    Pytest plugin for Proofy test reporting                                                                                                                                                                                                                                                                                                                                                 Nov 13, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-prosper`                                   Test helpers for Prosper projects                                                                                                                                                                                                                                                                                                                                                       Sep 24, 2018    N/A                    N/A
   :pypi:`pytest-prysk`                                     Pytest plugin for prysk                                                                                                                                                                                                                                                                                                                                                                 Dec 10, 2024    4 - Beta               pytest>=7.3.2
   :pypi:`pytest-pspec`                                     A rspec format reporter for Python ptest                                                                                                                                                                                                                                                                                                                                                Jun 02, 2020    4 - Beta               pytest (>=3.0.0)
   :pypi:`pytest-psqlgraph`                                 pytest plugin for testing applications that use psqlgraph                                                                                                                                                                                                                                                                                                                               Oct 19, 2021    4 - Beta               pytest (>=6.0)
   :pypi:`pytest-pt`                                        pytest plugin to use \*.pt files as tests                                                                                                                                                                                                                                                                                                                                               May 20, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-ptera`                                     Use ptera probes in tests                                                                                                                                                                                                                                                                                                                                                               Mar 01, 2022    N/A                    pytest (>=6.2.4,<7.0.0)
   :pypi:`pytest-publish`                                                                                                                                                                                                                                                                                                                                                                                                                           Jun 04, 2024    N/A                    pytest<9.0.0,>=8.0.0
   :pypi:`pytest-pudb`                                      Pytest PuDB debugger integration                                                                                                                                                                                                                                                                                                                                                        Oct 25, 2018    3 - Alpha              pytest (>=2.0)
   :pypi:`pytest-pudb-resurrected`                          Pytest PuDB debugger integration                                                                                                                                                                                                                                                                                                                                                        Mar 12, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-pulse-report`                              A pytest reporter and dashboard for visualizing Playwright (pytest-playwright) test results — Python port of playwright-pulse                                                                                                                                                                                                                                                           May 14, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-pumpkin-spice`                             A pytest plugin that makes your test reporting pumpkin-spiced                                                                                                                                                                                                                                                                                                                           Sep 18, 2022    4 - Beta               N/A
   :pypi:`pytest-purkinje`                                  py.test plugin for purkinje test runner                                                                                                                                                                                                                                                                                                                                                 Oct 28, 2017    2 - Pre-Alpha          N/A
   :pypi:`pytest-pusher`                                    pytest plugin for push report to minio                                                                                                                                                                                                                                                                                                                                                  Jan 06, 2023    5 - Production/Stable  pytest (>=3.6)
   :pypi:`pytest-pvcr`                                      PyTest Process VCR                                                                                                                                                                                                                                                                                                                                                                      Feb 25, 2026    3 - Alpha              pytest>=3.5.0
   :pypi:`pytest-pve-cloud`                                                                                                                                                                                                                                                                                                                                                                                                                         Feb 27, 2026    N/A                    pytest==8.4.2
   :pypi:`pytest-pw-config-gen`                             Generate pytest-playwright configuration files (pytest.ini, pyproject.toml, conftest.py) via CLI                                                                                                                                                                                                                                                                                        Mar 14, 2026    N/A                    pytest>=7.4; extra == "dev"
   :pypi:`pytest-py125`                                                                                                                                                                                                                                                                                                                                                                                                                             Dec 03, 2022    N/A                    N/A
   :pypi:`pytest-pycharm`                                   Plugin for py.test to enter PyCharm debugger on uncaught exceptions                                                                                                                                                                                                                                                                                                                     Aug 13, 2020    5 - Production/Stable  pytest (>=2.3)
   :pypi:`pytest-pycodestyle`                               pytest plugin to run pycodestyle                                                                                                                                                                                                                                                                                                                                                        Jul 20, 2025    3 - Alpha              pytest>=7.0
   :pypi:`pytest-pydantic-schema-sync`                      Pytest plugin to synchronise Pydantic model schemas with JSONSchema files                                                                                                                                                                                                                                                                                                               Aug 29, 2024    N/A                    pytest>=6
   :pypi:`pytest-pydev`                                     py.test plugin to connect to a remote debug server with PyDev or PyCharm.                                                                                                                                                                                                                                                                                                               Nov 15, 2017    3 - Alpha              N/A
   :pypi:`pytest-pydocstyle`                                pytest plugin to run pydocstyle                                                                                                                                                                                                                                                                                                                                                         Oct 09, 2024    3 - Alpha              pytest>=7.0
   :pypi:`pytest-pyeval`                                    pytest plugin integrating pydantic-evals                                                                                                                                                                                                                                                                                                                                                Apr 13, 2026    N/A                    pytest>=8.0
   :pypi:`pytest-pylembic`                                  This package provides pytest plugin for validating Alembic migrations using the pylembic package.                                                                                                                                                                                                                                                                                       Jul 22, 2025    3 - Alpha              N/A
   :pypi:`pytest-pylint`                                    pytest plugin to check source code with pylint                                                                                                                                                                                                                                                                                                                                          Oct 06, 2023    5 - Production/Stable  pytest >=7.0
   :pypi:`pytest-pylyzer`                                   A pytest plugin for pylyzer                                                                                                                                                                                                                                                                                                                                                             Feb 15, 2025    4 - Beta               N/A
   :pypi:`pytest-pymysql-autorecord`                        Record PyMySQL queries and mock with the stored data.                                                                                                                                                                                                                                                                                                                                   Sep 02, 2022    N/A                    N/A
   :pypi:`pytest-pyodide`                                   Pytest plugin for testing applications that use Pyodide                                                                                                                                                                                                                                                                                                                                 Apr 27, 2026    N/A                    pytest
   :pypi:`pytest-pypi`                                      Easily test your HTTP library against a local copy of pypi                                                                                                                                                                                                                                                                                                                              Mar 04, 2018    3 - Alpha              N/A
   :pypi:`pytest-pypom-navigation`                          Core engine for cookiecutter-qa and pytest-play packages                                                                                                                                                                                                                                                                                                                                Feb 18, 2019    4 - Beta               pytest (>=3.0.7)
   :pypi:`pytest-pyppeteer`                                 A plugin to run pyppeteer in pytest                                                                                                                                                                                                                                                                                                                                                     Apr 28, 2022    N/A                    pytest (>=6.2.5,<7.0.0)
   :pypi:`pytest-pyq`                                       Pytest fixture "q" for pyq                                                                                                                                                                                                                                                                                                                                                              Mar 10, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-pyramid`                                   pytest_pyramid - provides fixtures for testing pyramid applications with pytest test suite                                                                                                                                                                                                                                                                                              Sep 30, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-pyramid-server`                            Pyramid server fixture for py.test                                                                                                                                                                                                                                                                                                                                                      Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-pyreport`                                  PyReport is a lightweight reporting plugin for Pytest that provides concise HTML report                                                                                                                                                                                                                                                                                                 May 05, 2024    N/A                    pytest
   :pypi:`pytest-pyright`                                   Pytest plugin for type checking code with Pyright                                                                                                                                                                                                                                                                                                                                       Jan 26, 2024    4 - Beta               pytest >=7.0.0
   :pypi:`pytest-pyspark-plugin`                            Pytest pyspark plugin (p3)                                                                                                                                                                                                                                                                                                                                                              Nov 23, 2025    4 - Beta               pytest>=8.0.0
   :pypi:`pytest-pyspark-utils`                             A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      May 20, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-pyspec`                                    The pytest-pyspec plugin transforms pytest output into a beautiful, readable format similar to RSpec. It provides semantic meaning to your tests by organizing them into descriptive hierarchies, using the prefixes \`Describe\`/\`Test\`, \`With\`/\`Without\`/\`When\`, and \`test\`/\`it\`, while allowing docstrings and decorators to override the descriptions.                  Nov 18, 2025    5 - Production/Stable  pytest<10,>=9
   :pypi:`pytest-pystack`                                   Plugin to run pystack after a timeout for a test suite.                                                                                                                                                                                                                                                                                                                                 Nov 16, 2024    N/A                    pytest>=3.5.0
   :pypi:`pytest-pytestdb`                                  Add your description here                                                                                                                                                                                                                                                                                                                                                               Sep 14, 2025    N/A                    N/A
   :pypi:`pytest-pytestrail`                                Pytest plugin for interaction with TestRail                                                                                                                                                                                                                                                                                                                                             Aug 27, 2020    4 - Beta               pytest (>=3.8.0)
   :pypi:`pytest-pytestrail-internal`                       Pytest plugin for interaction with TestRail, Pytest plugin for TestRail (internal fork from: https://github.com/tolstislon/pytest-pytestrail with PR #25 fix)                                                                                                                                                                                                                           Jun 12, 2025    4 - Beta               pytest>=3.8.0
   :pypi:`pytest-pythonhashseed`                            Pytest plugin to set PYTHONHASHSEED env var.                                                                                                                                                                                                                                                                                                                                            Nov 16, 2025    4 - Beta               pytest>=3.0.0
   :pypi:`pytest-pythonpath`                                pytest plugin for adding to the PYTHONPATH from command line or configs.                                                                                                                                                                                                                                                                                                                Feb 10, 2022    5 - Production/Stable  pytest (<7,>=2.5.2)
   :pypi:`pytest-python-test-engineer-sort`                 Sort plugin for Pytest                                                                                                                                                                                                                                                                                                                                                                  May 13, 2024    N/A                    pytest>=6.2.0
   :pypi:`pytest-pytorch`                                   pytest plugin for a better developer experience when working with the PyTorch test suite                                                                                                                                                                                                                                                                                                May 25, 2021    4 - Beta               pytest
   :pypi:`pytest-pyvenv`                                    A package for create venv in tests                                                                                                                                                                                                                                                                                                                                                      Feb 27, 2024    N/A                    pytest ; extra == 'test'
   :pypi:`pytest-pyvista`                                   Pytest-pyvista package.                                                                                                                                                                                                                                                                                                                                                                 Apr 13, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-qanova`                                    A pytest plugin to collect test information                                                                                                                                                                                                                                                                                                                                             Sep 05, 2024    3 - Alpha              pytest
   :pypi:`pytest-qaseio`                                    Pytest plugin for Qase.io integration                                                                                                                                                                                                                                                                                                                                                   Dec 10, 2025    5 - Production/Stable  pytest>=7.2.2
   :pypi:`pytest-qasync`                                    Pytest support for qasync.                                                                                                                                                                                                                                                                                                                                                              Jul 12, 2021    4 - Beta               pytest (>=5.4.0)
   :pypi:`pytest-qatouch`                                   Pytest plugin for uploading test results to your QA Touch Testrun.                                                                                                                                                                                                                                                                                                                      Feb 14, 2023    4 - Beta               pytest (>=6.2.0)
   :pypi:`pytest-qemu-pic32mk`                              pytest plugin for QEMU-based functional tests targeting PIC32MK (MIPS32) firmware                                                                                                                                                                                                                                                                                                       May 17, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-qfield`                                    A pytest plugin for testing QField qml plugins                                                                                                                                                                                                                                                                                                                                          Jun 05, 2026    N/A                    N/A
   :pypi:`pytest-qgis`                                      A pytest plugin for testing QGIS python plugins                                                                                                                                                                                                                                                                                                                                         Apr 01, 2026    5 - Production/Stable  pytest>=6.0
   :pypi:`pytest-qml`                                       Run QML Tests with pytest                                                                                                                                                                                                                                                                                                                                                               Dec 02, 2020    4 - Beta               pytest (>=6.0.0)
   :pypi:`pytest-qr`                                        pytest plugin to generate test result QR codes                                                                                                                                                                                                                                                                                                                                          Nov 25, 2021    4 - Beta               N/A
   :pypi:`pytest-qt`                                        pytest support for PyQt and PySide applications                                                                                                                                                                                                                                                                                                                                         Jul 01, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-qt-app`                                    QT app fixture for py.test                                                                                                                                                                                                                                                                                                                                                              Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-quantum`                                   A cross-framework pytest plugin for quantum program testing                                                                                                                                                                                                                                                                                                                             Mar 22, 2026    5 - Production/Stable  pytest>=8.0
   :pypi:`pytest-quarantine`                                A plugin for pytest to manage expected test failures                                                                                                                                                                                                                                                                                                                                    Nov 24, 2019    5 - Production/Stable  pytest (>=4.6)
   :pypi:`pytest-quickcheck`                                pytest plugin to generate random data inspired by QuickCheck                                                                                                                                                                                                                                                                                                                            Nov 05, 2022    4 - Beta               pytest (>=4.0)
   :pypi:`pytest_quickify`                                  Run test suites with pytest-quickify.                                                                                                                                                                                                                                                                                                                                                   Jun 14, 2019    N/A                    pytest
   :pypi:`pytest-rabbitmq`                                  RabbitMQ process and client fixtures for pytest                                                                                                                                                                                                                                                                                                                                         Mar 22, 2026    5 - Production/Stable  pytest>=6.2
   :pypi:`pytest-race`                                      Race conditions tester for pytest                                                                                                                                                                                                                                                                                                                                                       Jun 07, 2022    4 - Beta               N/A
   :pypi:`pytest-rage`                                      pytest plugin to implement PEP712                                                                                                                                                                                                                                                                                                                                                       Oct 21, 2011    3 - Alpha              N/A
   :pypi:`pytest-rail`                                      pytest plugin for creating TestRail runs and adding results                                                                                                                                                                                                                                                                                                                             May 02, 2022    N/A                    pytest (>=3.6)
   :pypi:`pytest-railflow-testrail-reporter`                Generate json reports along with specified metadata defined in test markers.                                                                                                                                                                                                                                                                                                            Jun 29, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-raises`                                    An implementation of pytest.raises as a pytest.mark fixture                                                                                                                                                                                                                                                                                                                             Apr 23, 2020    N/A                    pytest (>=3.2.2)
   :pypi:`pytest-raisesregexp`                              Simple pytest plugin to look for regex in Exceptions                                                                                                                                                                                                                                                                                                                                    Dec 18, 2015    N/A                    N/A
   :pypi:`pytest-raisin`                                    Plugin enabling the use of exception instances with pytest.raises                                                                                                                                                                                                                                                                                                                       Feb 06, 2022    N/A                    pytest
   :pypi:`pytest-random`                                    py.test plugin to randomize tests                                                                                                                                                                                                                                                                                                                                                       Apr 28, 2013    3 - Alpha              N/A
   :pypi:`pytest-randomly`                                  Pytest plugin to randomly order tests and control random.seed.                                                                                                                                                                                                                                                                                                                          Apr 20, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-randomness`                                Pytest plugin about random seed management                                                                                                                                                                                                                                                                                                                                              May 30, 2019    3 - Alpha              N/A
   :pypi:`pytest-random-num`                                Randomise the order in which pytest tests are run with some control over the randomness                                                                                                                                                                                                                                                                                                 Oct 19, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-random-order`                              Randomise the order in which pytest tests are run with some control over the randomness                                                                                                                                                                                                                                                                                                 Jun 22, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-ranking`                                   A Pytest plugin for faster fault detection via regression test prioritization                                                                                                                                                                                                                                                                                                           Apr 08, 2025    4 - Beta               pytest>=7.4.3
   :pypi:`pytest-rca-report`                                Interactive RCA report generator for pytest runs, with AI-based analysis and visual dashboard                                                                                                                                                                                                                                                                                           Aug 04, 2025    N/A                    N/A
   :pypi:`pytest-readable`                                  Pytest plugin that renders readable test specifications and exports documentation                                                                                                                                                                                                                                                                                                       Mar 23, 2026    3 - Alpha              pytest<10.0,>=9.0
   :pypi:`pytest-readme`                                    Test your README.md file                                                                                                                                                                                                                                                                                                                                                                Aug 01, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-reana`                                     Pytest fixtures for REANA.                                                                                                                                                                                                                                                                                                                                                              May 12, 2026    3 - Alpha              N/A
   :pypi:`pytest-recap`                                     Capture your test sessions. Recap the results.                                                                                                                                                                                                                                                                                                                                          Jun 16, 2025    N/A                    pytest>=6.2.0
   :pypi:`pytest-recorder`                                  Pytest plugin, meant to facilitate unit tests writing for tools consumming Web APIs.                                                                                                                                                                                                                                                                                                    Apr 13, 2026    N/A                    pytest>=8.4.1
   :pypi:`pytest-recording`                                 A pytest plugin powered by VCR.py to record and replay HTTP traffic                                                                                                                                                                                                                                                                                                                     May 08, 2025    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-recordings`                                Provides pytest plugins for reporting request/response traffic, screenshots, and more to ReportPortal                                                                                                                                                                                                                                                                                   Aug 13, 2020    N/A                    N/A
   :pypi:`pytest-record-video`                              用例执行过程中录制视频                                                                                                                                                                                                                                                                                                                                                                  Oct 31, 2024    N/A                    N/A
   :pypi:`pytest-redis`                                     Redis fixtures and fixture factories for Pytest.                                                                                                                                                                                                                                                                                                                                        Feb 28, 2026    5 - Production/Stable  pytest>=8.4.0
   :pypi:`pytest-redislite`                                 Pytest plugin for testing code using Redis                                                                                                                                                                                                                                                                                                                                              Apr 22, 2026    4 - Beta               pytest
   :pypi:`pytest-redmine`                                   Pytest plugin for redmine                                                                                                                                                                                                                                                                                                                                                               Mar 19, 2018    1 - Planning           N/A
   :pypi:`pytest-ref`                                       A plugin to store reference files to ease regression testing                                                                                                                                                                                                                                                                                                                            Nov 23, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-reference-formatter`                       Conveniently run pytest with a dot-formatted test reference.                                                                                                                                                                                                                                                                                                                            Oct 01, 2019    4 - Beta               N/A
   :pypi:`pytest-regex`                                     Select pytest tests with regular expressions                                                                                                                                                                                                                                                                                                                                            May 29, 2023    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-regex-dependency`                          Management of Pytest dependencies via regex patterns                                                                                                                                                                                                                                                                                                                                    Jun 12, 2022    N/A                    pytest
   :pypi:`pytest-regressions`                               Easy to use fixtures to write regression tests.                                                                                                                                                                                                                                                                                                                                         May 25, 2026    5 - Production/Stable  pytest>=6.2.0
   :pypi:`pytest-regtest`                                   pytest plugin for snapshot regression testing                                                                                                                                                                                                                                                                                                                                           May 05, 2026    N/A                    pytest>7.2
   :pypi:`pytest-relative-order`                            a pytest plugin that sorts tests using "before" and "after" markers                                                                                                                                                                                                                                                                                                                     May 17, 2021    4 - Beta               N/A
   :pypi:`pytest-relative-path`                             Handle relative path in pytest options or ini configs                                                                                                                                                                                                                                                                                                                                   Nov 13, 2025    N/A                    pytest
   :pypi:`pytest-relaxed`                                   Relaxed test discovery/organization for pytest                                                                                                                                                                                                                                                                                                                                          Mar 29, 2024    5 - Production/Stable  pytest>=7
   :pypi:`pytest_relay`                                     A plugin to relay test information and control from and to pytest                                                                                                                                                                                                                                                                                                                       Jan 31, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-relay-run`                                 A pytest wrapper using for pytest-relay with pytest-relay-ws to control pytest executions.                                                                                                                                                                                                                                                                                              Jan 31, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest_relay_ws`                                  An extension plugin to pytest-relay to relay pytest information via websockets                                                                                                                                                                                                                                                                                                          Jan 31, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-remaster`                                  Pytest plugin for golden master (characterisation) testing with automatic expected file regeneration.                                                                                                                                                                                                                                                                                   Apr 09, 2026    3 - Alpha              pytest>=7
   :pypi:`pytest-remfiles`                                  Pytest plugin to create a temporary directory with remote files                                                                                                                                                                                                                                                                                                                         Jul 01, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-remotedata`                                Pytest plugin for controlling remote data access.                                                                                                                                                                                                                                                                                                                                       Sep 26, 2023    5 - Production/Stable  pytest >=4.6
   :pypi:`pytest-remote-response`                           Pytest plugin for capturing and mocking connection requests.                                                                                                                                                                                                                                                                                                                            Apr 26, 2023    5 - Production/Stable  pytest (>=4.6)
   :pypi:`pytest-remove-stale-bytecode`                     py.test plugin to remove stale byte code files.                                                                                                                                                                                                                                                                                                                                         Nov 19, 2025    4 - Beta               pytest
   :pypi:`pytest-reorder`                                   Reorder tests depending on their paths and names.                                                                                                                                                                                                                                                                                                                                       May 31, 2018    4 - Beta               pytest
   :pypi:`pytest-repeat`                                    pytest plugin for repeating tests                                                                                                                                                                                                                                                                                                                                                       Apr 07, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-repeated`                                  A pytest module for very basic statistical tests. Repeat test multiple times and pass if the underlying test passes a threshold.                                                                                                                                                                                                                                                        Feb 24, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest_repeater`                                  py.test plugin for repeating single test multiple times.                                                                                                                                                                                                                                                                                                                                Feb 09, 2018    1 - Planning           N/A
   :pypi:`pytest-replay`                                    Saves previous test runs and allow re-execute previous pytest runs to reproduce crashes or flaky tests                                                                                                                                                                                                                                                                                  Dec 23, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-repo-health`                               A pytest plugin to report on repository standards conformance                                                                                                                                                                                                                                                                                                                           Dec 09, 2025    3 - Alpha              pytest
   :pypi:`pytest-report`                                    Creates json report that is compatible with atom.io's linter message format                                                                                                                                                                                                                                                                                                             May 11, 2016    4 - Beta               N/A
   :pypi:`pytest-reporter`                                  Generate Pytest reports with templates                                                                                                                                                                                                                                                                                                                                                  Feb 28, 2024    4 - Beta               pytest
   :pypi:`pytest-reporter-html`                             Pytest plugin that generates rich HTML test reports with step tracking, log capture, and interactive filtering                                                                                                                                                                                                                                                                          Apr 27, 2026    5 - Production/Stable  pytest>=7.0
   :pypi:`pytest-reporter-html1`                            A basic HTML report template for Pytest                                                                                                                                                                                                                                                                                                                                                 Oct 10, 2025    4 - Beta               N/A
   :pypi:`pytest-reporter-html-dots`                        A basic HTML report for pytest using Jinja2 template engine.                                                                                                                                                                                                                                                                                                                            Apr 26, 2025    N/A                    N/A
   :pypi:`pytest-reporter-plus`                             Lightweight enhanced HTML reporter for Pytest                                                                                                                                                                                                                                                                                                                                           Jul 16, 2025    N/A                    N/A
   :pypi:`pytest-report-extras`                             Pytest plugin to enhance pytest-html and allure reports by adding comments, screenshots, webpage sources and attachments.                                                                                                                                                                                                                                                               Dec 24, 2025    N/A                    pytest>=8.4.0
   :pypi:`pytest-reportinfra`                               Pytest plugin for reportinfra                                                                                                                                                                                                                                                                                                                                                           Aug 11, 2019    3 - Alpha              N/A
   :pypi:`pytest-reporting`                                 A plugin to report summarized results in a table format                                                                                                                                                                                                                                                                                                                                 Oct 25, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-reportlog`                                 Replacement for the --resultlog option, focused in simplicity and extensibility                                                                                                                                                                                                                                                                                                         Nov 11, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-report-me`                                 A pytest plugin to generate report.                                                                                                                                                                                                                                                                                                                                                     Dec 31, 2020    N/A                    pytest
   :pypi:`pytest-report-parameters`                         pytest plugin for adding tests' parameters to junit report                                                                                                                                                                                                                                                                                                                              Jun 18, 2020    3 - Alpha              pytest (>=2.4.2)
   :pypi:`pytest-reportportal`                              Agent for Reporting results of tests to the Report Portal                                                                                                                                                                                                                                                                                                                               Jun 03, 2026    N/A                    N/A
   :pypi:`pytest-report-stream`                             A pytest plugin which allows to stream test reports at runtime                                                                                                                                                                                                                                                                                                                          Oct 22, 2023    4 - Beta               N/A
   :pypi:`pytest-repo-structure`                            Pytest Repo Structure                                                                                                                                                                                                                                                                                                                                                                   Mar 18, 2024    1 - Planning           N/A
   :pypi:`pytest-req`                                       pytest requests plugin                                                                                                                                                                                                                                                                                                                                                                  Apr 26, 2026    5 - Production/Stable  pytest>=8.4.2
   :pypi:`pytest-reqcov`                                    A pytest plugin for requirement coverage tracking                                                                                                                                                                                                                                                                                                                                       Jul 04, 2025    3 - Alpha              pytest>=6.0
   :pypi:`pytest-reqs`                                      pytest plugin to check pinned requirements                                                                                                                                                                                                                                                                                                                                              May 12, 2019    N/A                    pytest (>=2.4.2)
   :pypi:`pytest-requests`                                  A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Jun 24, 2019    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-requestselapsed`                           collect and show http requests elapsed time                                                                                                                                                                                                                                                                                                                                             Aug 14, 2022    N/A                    N/A
   :pypi:`pytest-requests-futures`                          Pytest Plugin to Mock Requests Futures                                                                                                                                                                                                                                                                                                                                                  Jul 06, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-requirements`                              pytest plugin for using custom markers to relate tests to requirements and usecases                                                                                                                                                                                                                                                                                                     Jun 05, 2026    N/A                    pytest
   :pypi:`pytest-requires`                                  A pytest plugin to elegantly skip tests with optional requirements                                                                                                                                                                                                                                                                                                                      Dec 21, 2021    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-reqyaml`                                   This is a plugin where generate requests test cases from yaml.                                                                                                                                                                                                                                                                                                                          Aug 16, 2025    N/A                    pytest>=8.4.1
   :pypi:`pytest-reraise`                                   Make multi-threaded pytest test cases fail when they should                                                                                                                                                                                                                                                                                                                             Sep 20, 2022    5 - Production/Stable  pytest (>=4.6)
   :pypi:`pytest-rerun`                                     Re-run only changed files in specified branch                                                                                                                                                                                                                                                                                                                                           Jul 08, 2019    N/A                    pytest (>=3.6)
   :pypi:`pytest-rerun-all`                                 Rerun testsuite for a certain time or iterations                                                                                                                                                                                                                                                                                                                                        Jul 30, 2025    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-rerunclassfailures`                        pytest rerun class failures plugin                                                                                                                                                                                                                                                                                                                                                      Apr 24, 2024    5 - Production/Stable  pytest>=7.2
   :pypi:`pytest-rerunfailures`                             pytest plugin to re-run tests to eliminate flaky failures                                                                                                                                                                                                                                                                                                                               May 22, 2026    5 - Production/Stable  pytest!=8.2.2,>=8.1
   :pypi:`pytest-rerunfailures-all-logs`                    pytest plugin to re-run tests to eliminate flaky failures                                                                                                                                                                                                                                                                                                                               Mar 07, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-reserial`                                  Pytest fixture for recording and replaying serial port traffic.                                                                                                                                                                                                                                                                                                                         Dec 30, 2025    4 - Beta               pytest
   :pypi:`pytest-resilient-circuits`                        Resilient Circuits fixtures for PyTest                                                                                                                                                                                                                                                                                                                                                  Apr 29, 2026    N/A                    pytest~=7.0
   :pypi:`pytest-resource`                                  Load resource fixture plugin to use with pytest                                                                                                                                                                                                                                                                                                                                         Nov 14, 2018    4 - Beta               N/A
   :pypi:`pytest-resource-path`                             Provides path for uniform access to test resources in isolated directory                                                                                                                                                                                                                                                                                                                May 17, 2026    5 - Production/Stable  pytest>=3.5.0
   :pypi:`pytest-resource-usage`                            Pytest plugin for reporting running time and peak memory usage                                                                                                                                                                                                                                                                                                                          Nov 06, 2022    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-respect`                                   Pytest plugin to load resource files relative to test code and to expect values to match them.                                                                                                                                                                                                                                                                                          Apr 08, 2026    5 - Production/Stable  pytest>=8.0.0
   :pypi:`pytest-responsemock`                              Simplified requests calls mocking for pytest                                                                                                                                                                                                                                                                                                                                            Mar 10, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-responses`                                 py.test integration for responses                                                                                                                                                                                                                                                                                                                                                       Oct 11, 2022    N/A                    pytest (>=2.5)
   :pypi:`pytest-rest-api`                                                                                                                                                                                                                                                                                                                                                                                                                          Aug 08, 2022    N/A                    pytest (>=7.1.2,<8.0.0)
   :pypi:`pytest-restrict`                                  Pytest plugin to restrict the test types allowed                                                                                                                                                                                                                                                                                                                                        Feb 09, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-resttest`                                  A REST API testing framework for Python, as plugin for pytest. Uses simple and readable YAML files for specifying test cases.                                                                                                                                                                                                                                                           May 26, 2026    5 - Production/Stable  pytest<10,>=9
   :pypi:`pytest-result-log`                                A pytest plugin that records the start, end, and result information of each use case in a log file                                                                                                                                                                                                                                                                                      Jan 10, 2024    N/A                    pytest>=7.2.0
   :pypi:`pytest-result-notify`                             Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        Apr 27, 2025    N/A                    pytest>=8.3.5
   :pypi:`pytest-results`                                   Easily spot regressions in your tests.                                                                                                                                                                                                                                                                                                                                                  Oct 08, 2025    4 - Beta               pytest
   :pypi:`pytest-result-sender`                                                                                                                                                                                                                                                                                                                                                                                                                     Apr 20, 2023    N/A                    pytest>=7.3.1
   :pypi:`pytest-result-sender-fanrenbufan`                 Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        Mar 12, 2026    N/A                    pytest>=8.4.2
   :pypi:`pytest-result-sender-jms`                         Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        May 22, 2025    N/A                    pytest>=8.3.5
   :pypi:`pytest-result-sender-lj`                          Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        Dec 17, 2024    N/A                    pytest>=8.3.4
   :pypi:`pytest-result-sender-lyt`                         Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        Mar 14, 2025    N/A                    pytest>=8.3.5
   :pypi:`pytest-result-sender-misszhang`                   Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        Mar 21, 2025    N/A                    pytest>=8.3.5
   :pypi:`pytest-result-sender-r`                           Default template for PDM package                                                                                                                                                                                                                                                                                                                                                        Dec 26, 2025    N/A                    pytest>=8.4.2
   :pypi:`pytest-resume`                                    A Pytest plugin to resuming from the last run test                                                                                                                                                                                                                                                                                                                                      Apr 22, 2023    4 - Beta               pytest (>=7.0)
   :pypi:`pytest-rethinkdb`                                 A RethinkDB plugin for pytest.                                                                                                                                                                                                                                                                                                                                                          Jul 24, 2016    4 - Beta               N/A
   :pypi:`pytest-retry`                                     Adds the ability to retry flaky tests in CI environments                                                                                                                                                                                                                                                                                                                                Jan 19, 2025    N/A                    pytest>=7.0.0
   :pypi:`pytest-retry-class`                               A pytest plugin to rerun entire class on failure                                                                                                                                                                                                                                                                                                                                        Nov 24, 2024    N/A                    pytest>=5.3
   :pypi:`pytest-reusable-testcases`                                                                                                                                                                                                                                                                                                                                                                                                                Apr 28, 2023    N/A                    N/A
   :pypi:`pytest-revealtype-injector`                       Pytest plugin for replacing reveal_type() calls inside test functions with static and runtime type checking result comparison, for confirming type annotation validity.                                                                                                                                                                                                                 Feb 03, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-reverse`                                   Pytest plugin to reverse test order.                                                                                                                                                                                                                                                                                                                                                    Sep 09, 2025    5 - Production/Stable  pytest
   :pypi:`pytest-review`                                    A pytest plugin that reviews the quality of your tests                                                                                                                                                                                                                                                                                                                                  Apr 12, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-rich`                                      Leverage rich for richer test session output                                                                                                                                                                                                                                                                                                                                            Dec 12, 2024    4 - Beta               pytest>=7.0
   :pypi:`pytest-richer`                                    Pytest plugin providing a Rich based reporter.                                                                                                                                                                                                                                                                                                                                          Oct 27, 2023    3 - Alpha              pytest
   :pypi:`pytest-rich-reporter`                             A pytest plugin using Rich for beautiful test result formatting.                                                                                                                                                                                                                                                                                                                        Feb 17, 2022    1 - Planning           pytest (>=5.0.0)
   :pypi:`pytest-richtrace`                                 A pytest plugin that displays the names and information of the pytest hook functions as they are executed.                                                                                                                                                                                                                                                                              Jun 20, 2023    N/A                    N/A
   :pypi:`pytest-ringo`                                     pytest plugin to test webapplications using the Ringo webframework                                                                                                                                                                                                                                                                                                                      Sep 27, 2017    3 - Alpha              N/A
   :pypi:`pytest-rmsis`                                     Sycronise pytest results to Jira RMsis                                                                                                                                                                                                                                                                                                                                                  Aug 10, 2022    N/A                    pytest (>=5.3.5)
   :pypi:`pytest-rmysql`                                    This is a plugin which is able to connet MySQL easyly.                                                                                                                                                                                                                                                                                                                                  Aug 17, 2025    N/A                    pytest>=8.4.1
   :pypi:`pytest-rng`                                       Fixtures for seeding tests and making randomness reproducible                                                                                                                                                                                                                                                                                                                           Aug 08, 2019    5 - Production/Stable  pytest
   :pypi:`pytest-roast`                                     pytest plugin for ROAST configuration override and fixtures                                                                                                                                                                                                                                                                                                                             Nov 09, 2022    5 - Production/Stable  pytest
   :pypi:`pytest_robotframework`                            a pytest plugin that can run both python and robotframework tests while generating robot reports for them                                                                                                                                                                                                                                                                               Dec 22, 2025    N/A                    pytest<10,>=7
   :pypi:`pytest-rocketchat`                                Pytest to Rocket.Chat reporting plugin                                                                                                                                                                                                                                                                                                                                                  Apr 18, 2021    5 - Production/Stable  N/A
   :pypi:`pytest-rotest`                                    Pytest integration with rotest                                                                                                                                                                                                                                                                                                                                                          Sep 08, 2019    N/A                    pytest (>=3.5.0)
   :pypi:`pytest-route-coverage`                            pytest plugin to generate reports on routes coverage for web applications.                                                                                                                                                                                                                                                                                                              Apr 02, 2026    N/A                    pytest>=7.2.2
   :pypi:`pytest-routes`                                    Property-based smoke testing for ASGI application routes                                                                                                                                                                                                                                                                                                                                Dec 01, 2025    3 - Alpha              pytest>=7.0
   :pypi:`pytest-rpc`                                       Extend py.test for RPC OpenStack testing.                                                                                                                                                                                                                                                                                                                                               Feb 22, 2019    4 - Beta               pytest (~=3.6)
   :pypi:`pytest-rs`                                        A fast, drop-in compatible pytest runner written in Rust                                                                                                                                                                                                                                                                                                                                Jun 06, 2026    3 - Alpha              N/A
   :pypi:`pytest-r-snapshot`                                A pytest plugin for snapshot testing against R code outputs                                                                                                                                                                                                                                                                                                                             Jan 02, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-rst`                                       Test code from RST documents with pytest                                                                                                                                                                                                                                                                                                                                                Feb 22, 2026    N/A                    N/A
   :pypi:`pytest-rt`                                        pytest data collector plugin for Testgr                                                                                                                                                                                                                                                                                                                                                 May 05, 2022    N/A                    N/A
   :pypi:`pytest-rts`                                       Coverage-based regression test selection (RTS) plugin for pytest                                                                                                                                                                                                                                                                                                                        May 17, 2021    N/A                    pytest
   :pypi:`pytest-ruff`                                      pytest plugin to check ruff requirements.                                                                                                                                                                                                                                                                                                                                               Jun 19, 2025    4 - Beta               pytest>=5
   :pypi:`pytest-run-changed`                               Pytest plugin that runs changed tests only                                                                                                                                                                                                                                                                                                                                              Apr 02, 2021    3 - Alpha              pytest
   :pypi:`pytest-runfailed`                                 implement a --failed option for pytest                                                                                                                                                                                                                                                                                                                                                  Mar 24, 2016    N/A                    N/A
   :pypi:`pytest-run-parallel`                              A simple pytest plugin to run tests concurrently                                                                                                                                                                                                                                                                                                                                        Jun 03, 2026    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-run-subprocess`                            Pytest Plugin for running and testing subprocesses.                                                                                                                                                                                                                                                                                                                                     Nov 12, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-runtime-types`                             Checks type annotations on runtime while running tests.                                                                                                                                                                                                                                                                                                                                 Feb 09, 2023    N/A                    pytest
   :pypi:`pytest-runtime-xfail`                             Call runtime_xfail() to mark running test as xfail.                                                                                                                                                                                                                                                                                                                                     Oct 10, 2025    5 - Production/Stable  pytest>=5.0.0
   :pypi:`pytest-runtime-yoyo`                              run case mark timeout                                                                                                                                                                                                                                                                                                                                                                   Jun 12, 2023    N/A                    pytest (>=7.2.0)
   :pypi:`pytest-rxdist`                                    Rust-accelerated next-generation execution engine for pytest (planned).                                                                                                                                                                                                                                                                                                                 Mar 17, 2026    1 - Planning           N/A
   :pypi:`pytest-saccharin`                                 pytest-saccharin is a updated fork of pytest-sugar, a plugin for pytest that changes the default look and feel of pytest (e.g. progressbar, show tests that fail instantly).                                                                                                                                                                                                            Oct 31, 2022    3 - Alpha              N/A
   :pypi:`pytest-salt`                                      Pytest Salt Plugin                                                                                                                                                                                                                                                                                                                                                                      Jan 27, 2020    4 - Beta               N/A
   :pypi:`pytest-salt-containers`                           A Pytest plugin that builds and creates docker containers                                                                                                                                                                                                                                                                                                                               Nov 09, 2016    4 - Beta               N/A
   :pypi:`pytest-salt-factories`                            Pytest Salt Plugin                                                                                                                                                                                                                                                                                                                                                                      Jul 08, 2025    5 - Production/Stable  pytest>=7.4.0
   :pypi:`pytest-salt-from-filenames`                       Simple PyTest Plugin For Salt's Test Suite Specifically                                                                                                                                                                                                                                                                                                                                 Jan 29, 2019    4 - Beta               pytest (>=4.1)
   :pypi:`pytest-salt-runtests-bridge`                      Simple PyTest Plugin For Salt's Test Suite Specifically                                                                                                                                                                                                                                                                                                                                 Dec 05, 2019    4 - Beta               pytest (>=4.1)
   :pypi:`pytest-sample-argvalues`                          A utility function to help choose a random sample from your argvalues in pytest.                                                                                                                                                                                                                                                                                                        May 07, 2024    N/A                    pytest
   :pypi:`pytest-sanic`                                     a pytest plugin for Sanic                                                                                                                                                                                                                                                                                                                                                               Oct 25, 2021    N/A                    pytest (>=5.2)
   :pypi:`pytest-sanitizer`                                 A pytest plugin to sanitize output for LLMs (personal tool, no warranty or liability)                                                                                                                                                                                                                                                                                                   Mar 16, 2025    3 - Alpha              pytest>=6.0.0
   :pypi:`pytest-sanity`                                                                                                                                                                                                                                                                                                                                                                                                                            Dec 07, 2020    N/A                    N/A
   :pypi:`pytest-sa-pg`                                                                                                                                                                                                                                                                                                                                                                                                                             May 14, 2019    N/A                    N/A
   :pypi:`pytest_sauce`                                     pytest_sauce provides sane and helpful methods worked    out in clearcode to run py.test tests with selenium/saucelabs                                                                                                                                                                                                                                                                  Jul 14, 2014    3 - Alpha              N/A
   :pypi:`pytest-sbase`                                     A complete web automation framework for end-to-end testing.                                                                                                                                                                                                                                                                                                                             Jun 05, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-scenario`                                  pytest plugin for test scenarios                                                                                                                                                                                                                                                                                                                                                        Feb 06, 2017    3 - Alpha              N/A
   :pypi:`pytest-scenario-files`                            A pytest plugin that generates unit test scenarios from data files.                                                                                                                                                                                                                                                                                                                     May 18, 2026    5 - Production/Stable  pytest<10,>=7.4
   :pypi:`pytest-scenarios`                                 Add your description here                                                                                                                                                                                                                                                                                                                                                               Jan 03, 2026    N/A                    N/A
   :pypi:`pytest-schedule`                                  Automate and customize test scheduling effortlessly on local machines.                                                                                                                                                                                                                                                                                                                  Oct 31, 2024    N/A                    N/A
   :pypi:`pytest-schema`                                    👍 Validate return values against a schema-like object in testing                                                                                                                                                                                                                                                                                                                       Feb 16, 2024    5 - Production/Stable  pytest >=3.5.0
   :pypi:`pytest-scim2-server`                              SCIM2 server fixture for Pytest                                                                                                                                                                                                                                                                                                                                                         Nov 14, 2025    4 - Beta               pytest>=8.3.4
   :pypi:`pytest-screenshot-on-failure`                     Saves a screenshot when a test case from a pytest execution fails                                                                                                                                                                                                                                                                                                                       Jul 21, 2023    4 - Beta               N/A
   :pypi:`pytest-scrutinize`                                Scrutinize your pytest test suites for slow fixtures, tests and more.                                                                                                                                                                                                                                                                                                                   Aug 19, 2024    4 - Beta               pytest>=6
   :pypi:`pytest-securestore`                               An encrypted password store for use within pytest cases                                                                                                                                                                                                                                                                                                                                 Nov 08, 2021    4 - Beta               N/A
   :pypi:`pytest-select`                                    A pytest plugin which allows to (de-)select tests from a file.                                                                                                                                                                                                                                                                                                                          Jan 18, 2019    3 - Alpha              pytest (>=3.0)
   :pypi:`pytest-selenium`                                  pytest plugin for Selenium                                                                                                                                                                                                                                                                                                                                                              Feb 01, 2024    5 - Production/Stable  pytest>=6.0.0
   :pypi:`pytest-selenium-auto`                             pytest plugin to automatically capture screenshots upon selenium webdriver events                                                                                                                                                                                                                                                                                                       Nov 07, 2023    N/A                    pytest >= 7.0.0
   :pypi:`pytest-seleniumbase`                              A complete web automation framework for end-to-end testing.                                                                                                                                                                                                                                                                                                                             Jun 05, 2026    5 - Production/Stable  N/A
   :pypi:`pytest-selenium-driver`                           A zero-boilerplate Selenium WebDriver fixture for pytest                                                                                                                                                                                                                                                                                                                                Mar 07, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-selenium-enhancer`                         pytest plugin for Selenium                                                                                                                                                                                                                                                                                                                                                              Apr 29, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-selenium-pdiff`                            A pytest package implementing perceptualdiff for Selenium tests.                                                                                                                                                                                                                                                                                                                        Apr 06, 2017    2 - Pre-Alpha          N/A
   :pypi:`pytest-selfie`                                    A pytest plugin for selfie snapshot testing.                                                                                                                                                                                                                                                                                                                                            Dec 16, 2024    N/A                    pytest>=8.0.0
   :pypi:`pytest-semantic`                                  A pytest plugin for testing LLM outputs using semantic similarity matching                                                                                                                                                                                                                                                                                                              Nov 11, 2025    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-semantic-assert`                           Pytest plugin for semantic LLM output assertions using embeddings. Test meaning, not strings.                                                                                                                                                                                                                                                                                           Jan 09, 2026    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-semantic-llm`                              Semantic assertions for pytest using LLMs                                                                                                                                                                                                                                                                                                                                               Mar 10, 2026    N/A                    pytest>=7.0.0
   :pypi:`pytest-semantix`                                  pytest plugin for semantic LLM output testing — validate meaning, not just shape.                                                                                                                                                                                                                                                                                                       Apr 13, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-send-email`                                Send pytest execution result email                                                                                                                                                                                                                                                                                                                                                      Sep 02, 2024    N/A                    pytest
   :pypi:`pytest-sentry`                                    A pytest plugin to send testrun information to Sentry.io                                                                                                                                                                                                                                                                                                                                Jul 01, 2025    N/A                    pytest
   :pypi:`pytest-sequence-markers`                          Pytest plugin for sequencing markers for execution of tests                                                                                                                                                                                                                                                                                                                             May 23, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-server`                                    test server exec cmd                                                                                                                                                                                                                                                                                                                                                                    Sep 09, 2024    N/A                    N/A
   :pypi:`pytest-server-fixtures`                           Extensible server fixtures for py.test                                                                                                                                                                                                                                                                                                                                                  Nov 29, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-serverless`                                Automatically mocks resources from serverless.yml in pytest using moto.                                                                                                                                                                                                                                                                                                                 May 09, 2022    4 - Beta               N/A
   :pypi:`pytest-servers`                                   pytest servers                                                                                                                                                                                                                                                                                                                                                                          Dec 21, 2025    3 - Alpha              pytest>=6.2
   :pypi:`pytest-service`                                                                                                                                                                                                                                                                                                                                                                                                                           Aug 06, 2024    5 - Production/Stable  pytest>=6.0.0
   :pypi:`pytest-services`                                  Services plugin for pytest testing framework                                                                                                                                                                                                                                                                                                                                            Jul 16, 2025    6 - Mature             pytest
   :pypi:`pytest-session2file`                              pytest-session2file (aka: pytest-session_to_file for v0.1.0 - v0.1.2) is a py.test plugin for capturing and saving to file the stdout of py.test.                                                                                                                                                                                                                                       Jan 26, 2021    3 - Alpha              pytest
   :pypi:`pytest-session-fixture-globalize`                 py.test plugin to make session fixtures behave as if written in conftest, even if it is written in some modules                                                                                                                                                                                                                                                                         May 15, 2018    4 - Beta               N/A
   :pypi:`pytest-session_to_file`                           pytest-session_to_file is a py.test plugin for capturing and saving to file the stdout of py.test.                                                                                                                                                                                                                                                                                      Oct 01, 2015    3 - Alpha              N/A
   :pypi:`pytest-setupinfo`                                 Displaying setup info during pytest command run                                                                                                                                                                                                                                                                                                                                         Jan 23, 2023    N/A                    N/A
   :pypi:`pytest-sftpserver`                                py.test plugin to locally test sftp server connections.                                                                                                                                                                                                                                                                                                                                 Sep 16, 2019    4 - Beta               N/A
   :pypi:`pytest-shard`                                                                                                                                                                                                                                                                                                                                                                                                                             Dec 11, 2020    4 - Beta               pytest
   :pypi:`pytest-shard-cloudc`                              Shard tests to support parallelism across multiple machines.                                                                                                                                                                                                                                                                                                                            Apr 02, 2026    4 - Beta               pytest
   :pypi:`pytest-shard-fork`                                Shard tests to support parallelism across multiple machines                                                                                                                                                                                                                                                                                                                             Jun 13, 2025    4 - Beta               pytest
   :pypi:`pytest-shared-session-scope`                      Pytest session-scoped fixture that works with xdist                                                                                                                                                                                                                                                                                                                                     Oct 31, 2025    N/A                    pytest>=7.0.0
   :pypi:`pytest-share-hdf`                                 Plugin to save test data in HDF files and retrieve them for comparison                                                                                                                                                                                                                                                                                                                  Sep 21, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-sharkreport`                               this is pytest report plugin.                                                                                                                                                                                                                                                                                                                                                           Jul 11, 2022    N/A                    pytest (>=3.5)
   :pypi:`pytest-shell`                                     A pytest plugin to help with testing shell scripts / black box commands                                                                                                                                                                                                                                                                                                                 Mar 27, 2022    N/A                    N/A
   :pypi:`pytest-shell-utilities`                           Pytest plugin to simplify running shell commands against the system                                                                                                                                                                                                                                                                                                                     Oct 22, 2024    5 - Production/Stable  pytest>=7.4.0
   :pypi:`pytest-sheraf`                                    Versatile ZODB abstraction layer - pytest fixtures                                                                                                                                                                                                                                                                                                                                      Feb 11, 2020    N/A                    pytest
   :pypi:`pytest-sherlock`                                  pytest plugin help to find coupled tests                                                                                                                                                                                                                                                                                                                                                Aug 14, 2023    5 - Production/Stable  pytest >=3.5.1
   :pypi:`pytest-shortcuts`                                 Expand command-line shortcuts listed in pytest configuration                                                                                                                                                                                                                                                                                                                            Oct 29, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-shutil`                                    A goodie-bag of unix shell and environment tools for py.test                                                                                                                                                                                                                                                                                                                            Nov 29, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-sigil`                                     Proper fixture resource cleanup by handling signals                                                                                                                                                                                                                                                                                                                                     Oct 21, 2025    N/A                    pytest<9.0.0,>=7.0.0
   :pypi:`pytest-simbind`                                   Pytest plugin to operate with objects generated by Simbind tool.                                                                                                                                                                                                                                                                                                                        Mar 28, 2024    N/A                    pytest>=7.0.0
   :pypi:`pytest-simplehttpserver`                          Simple pytest fixture to spin up an HTTP server                                                                                                                                                                                                                                                                                                                                         Jun 24, 2021    4 - Beta               N/A
   :pypi:`pytest-simple-plugin`                             Simple pytest plugin                                                                                                                                                                                                                                                                                                                                                                    Nov 27, 2019    N/A                    N/A
   :pypi:`pytest-simple-settings`                           simple-settings plugin for pytest                                                                                                                                                                                                                                                                                                                                                       Nov 17, 2020    4 - Beta               pytest
   :pypi:`pytest-simplified`                                A PyTest plugin to simplify testing classes.                                                                                                                                                                                                                                                                                                                                            Jan 19, 2026    4 - Beta               pytest<9.0.0,>=8.3.5
   :pypi:`pytest-single-file-logging`                       Allow for multiple processes to log to a single file                                                                                                                                                                                                                                                                                                                                    May 05, 2016    4 - Beta               pytest (>=2.8.1)
   :pypi:`pytest-skill-engineering`                         The testing framework for skill engineering. Test tool descriptions, prompt templates, agent skills, and custom agents with real LLMs. AI analyzes results and tells you what to fix.                                                                                                                                                                                                   Apr 30, 2026    3 - Alpha              pytest>=9.0
   :pypi:`pytest-skip`                                      A pytest plugin which allows to (de-)select or skip tests from a file.                                                                                                                                                                                                                                                                                                                  Sep 12, 2025    3 - Alpha              pytest
   :pypi:`pytest-skip-markers`                              Pytest Salt Plugin                                                                                                                                                                                                                                                                                                                                                                      Aug 09, 2024    5 - Production/Stable  pytest>=7.1.0
   :pypi:`pytest-skipper`                                   A plugin that selects only tests with changes in execution path                                                                                                                                                                                                                                                                                                                         Mar 26, 2017    3 - Alpha              pytest (>=3.0.6)
   :pypi:`pytest-skippy`                                    Automatically skip tests that don't need to run!                                                                                                                                                                                                                                                                                                                                        Jan 27, 2018    3 - Alpha              pytest (>=2.3.4)
   :pypi:`pytest-skip-slow`                                 A pytest plugin to skip \`@pytest.mark.slow\` tests by default.                                                                                                                                                                                                                                                                                                                         May 27, 2026    N/A                    pytest>=6.2.0
   :pypi:`pytest-skipuntil`                                 A simple pytest plugin to skip flapping test with deadline                                                                                                                                                                                                                                                                                                                              Nov 25, 2023    4 - Beta               pytest >=3.8.0
   :pypi:`pytest-slack`                                     Pytest to Slack reporting plugin                                                                                                                                                                                                                                                                                                                                                        Dec 15, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-slow`                                      A pytest plugin to skip \`@pytest.mark.slow\` tests by default.                                                                                                                                                                                                                                                                                                                         Sep 28, 2021    N/A                    N/A
   :pypi:`pytest-slowest-first`                             Sort tests by their last duration, slowest first                                                                                                                                                                                                                                                                                                                                        Dec 11, 2022    4 - Beta               N/A
   :pypi:`pytest-slow-first`                                Prioritize running the slowest tests first.                                                                                                                                                                                                                                                                                                                                             Jan 30, 2024    4 - Beta               pytest >=3.5.0
   :pypi:`pytest-slow-last`                                 Run tests in order of execution time (faster tests first)                                                                                                                                                                                                                                                                                                                               Mar 16, 2025    4 - Beta               pytest>=3.5.0
   :pypi:`pytest-smartcollect`                              A plugin for collecting tests that touch changed code                                                                                                                                                                                                                                                                                                                                   Oct 04, 2018    N/A                    pytest (>=3.5.0)
   :pypi:`pytest-smartcov`                                  Smart coverage plugin for pytest.                                                                                                                                                                                                                                                                                                                                                       Sep 30, 2017    3 - Alpha              N/A
   :pypi:`pytest-smart-debugger-backend`                    Backend server for Pytest Smart Debugger                                                                                                                                                                                                                                                                                                                                                Sep 17, 2025    N/A                    N/A
   :pypi:`pytest-smart-rerun`                               A Pytest plugin for intelligent retrying of flaky tests.                                                                                                                                                                                                                                                                                                                                Oct 12, 2025    3 - Alpha              N/A
   :pypi:`pytest-smell`                                     Automated bad smell detection tool for Pytest                                                                                                                                                                                                                                                                                                                                           Jun 26, 2022    N/A                    N/A
   :pypi:`pytest-smoke`                                     Pytest plugin for smoke testing                                                                                                                                                                                                                                                                                                                                                         Nov 09, 2025    4 - Beta               pytest<10,>=7.0.0
   :pypi:`pytest-smtp`                                      Send email with pytest execution result                                                                                                                                                                                                                                                                                                                                                 Feb 20, 2021    N/A                    pytest
   :pypi:`pytest-smtp4dev`                                  Plugin for smtp4dev API                                                                                                                                                                                                                                                                                                                                                                 Jun 27, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-smtpd`                                     An SMTP server for testing built on aiosmtpd                                                                                                                                                                                                                                                                                                                                            May 15, 2023    N/A                    pytest
   :pypi:`pytest-smtp-test-server`                          pytest plugin for using \`smtp-test-server\` as a fixture                                                                                                                                                                                                                                                                                                                               Dec 03, 2023    2 - Pre-Alpha          pytest (>=7.4.3,<8.0.0)
   :pypi:`pytest-snail`                                     Plugin for adding a marker to slow running tests. 🐌                                                                                                                                                                                                                                                                                                                                    Nov 04, 2019    3 - Alpha              pytest (>=5.0.1)
   :pypi:`pytest-snap`                                      A text-based snapshot testing library implemented as a pytest plugin                                                                                                                                                                                                                                                                                                                    Aug 25, 2025    N/A                    pytest>=8.0.0
   :pypi:`pytest-snapcheck`                                 Minimal deterministic test-run snapshot capture for pytest.                                                                                                                                                                                                                                                                                                                             Sep 07, 2025    N/A                    pytest>=8.0
   :pypi:`pytest-snapci`                                    py.test plugin for Snap-CI                                                                                                                                                                                                                                                                                                                                                              Nov 12, 2015    N/A                    N/A
   :pypi:`pytest-snapmock`                                  Snapshots for your mocks.                                                                                                                                                                                                                                                                                                                                                               Nov 15, 2024    N/A                    N/A
   :pypi:`pytest-snapshot`                                  A plugin for snapshot testing with pytest.                                                                                                                                                                                                                                                                                                                                              Apr 23, 2022    4 - Beta               pytest (>=3.0.0)
   :pypi:`pytest-snapshot-with-message-generator`           A plugin for snapshot testing with pytest.                                                                                                                                                                                                                                                                                                                                              Jul 25, 2023    4 - Beta               pytest (>=3.0.0)
   :pypi:`pytest-snmpserver`                                                                                                                                                                                                                                                                                                                                                                                                                        May 12, 2021    N/A                    N/A
   :pypi:`pytest-snob`                                      A pytest plugin that only selects meaningful python tests to run.                                                                                                                                                                                                                                                                                                                       Jan 12, 2025    N/A                    pytest
   :pypi:`pytest-snowflake-bdd`                             Setup test data and run tests on snowflake in BDD style!                                                                                                                                                                                                                                                                                                                                Jan 05, 2022    4 - Beta               pytest (>=6.2.0)
   :pypi:`pytest-socket`                                    Pytest Plugin to disable socket calls during tests                                                                                                                                                                                                                                                                                                                                      May 21, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-sofaepione`                                Test the installation of SOFA and the SofaEpione plugin.                                                                                                                                                                                                                                                                                                                                Aug 17, 2022    N/A                    N/A
   :pypi:`pytest-soft-assert`                               Pytest plugin for soft assertions.                                                                                                                                                                                                                                                                                                                                                      Dec 07, 2025    N/A                    pytest>=8.4.0
   :pypi:`pytest-soft-assertions`                                                                                                                                                                                                                                                                                                                                                                                                                   May 05, 2020    3 - Alpha              pytest
   :pypi:`pytest-solidity`                                  A PyTest library plugin for Solidity language.                                                                                                                                                                                                                                                                                                                                          Jan 15, 2022    1 - Planning           pytest (<7,>=6.0.1) ; extra == 'tests'
   :pypi:`pytest-solr`                                      Solr process and client fixtures for py.test.                                                                                                                                                                                                                                                                                                                                           May 11, 2020    3 - Alpha              pytest (>=3.0.0)
   :pypi:`pytest-sort`                                      Tools for sorting test cases                                                                                                                                                                                                                                                                                                                                                            Apr 04, 2026    N/A                    pytest>=7.4.0
   :pypi:`pytest-sorter`                                    A simple plugin to first execute tests that historically failed more                                                                                                                                                                                                                                                                                                                    Apr 20, 2021    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-sosu`                                      Unofficial PyTest plugin for Sauce Labs                                                                                                                                                                                                                                                                                                                                                 Aug 04, 2023    2 - Pre-Alpha          pytest
   :pypi:`pytest-sourceorder`                               Test-ordering plugin for pytest                                                                                                                                                                                                                                                                                                                                                         Sep 01, 2021    4 - Beta               pytest
   :pypi:`pytest-spark`                                     pytest plugin to run the tests with support of pyspark.                                                                                                                                                                                                                                                                                                                                 May 21, 2025    4 - Beta               pytest
   :pypi:`pytest-spawner`                                   py.test plugin to spawn process and communicate with them.                                                                                                                                                                                                                                                                                                                              Jul 31, 2015    4 - Beta               N/A
   :pypi:`pytest-spec`                                      Library pytest-spec is a pytest plugin to display test execution output like a SPECIFICATION.                                                                                                                                                                                                                                                                                           May 17, 2026    N/A                    pytest; extra == "test"
   :pypi:`pytest-spec2md`                                   Library pytest-spec2md is a pytest plugin to create a markdown specification while running pytest.                                                                                                                                                                                                                                                                                      Apr 10, 2024    N/A                    pytest>7.0
   :pypi:`pytest-speed`                                     Modern benchmarking library for python with pytest integration.                                                                                                                                                                                                                                                                                                                         Jan 22, 2023    3 - Alpha              pytest>=7
   :pypi:`pytest-sphinx`                                    Doctest plugin for pytest with support for Sphinx-specific doctest-directives                                                                                                                                                                                                                                                                                                           Jan 21, 2026    4 - Beta               pytest>=8.1.1
   :pypi:`pytest-spiratest`                                 Exports unit tests as test runs in Spira (SpiraTest/Team/Plan)                                                                                                                                                                                                                                                                                                                          Feb 09, 2026    N/A                    pytest>=3.0.0
   :pypi:`pytest-splinter`                                  Splinter plugin for pytest testing framework                                                                                                                                                                                                                                                                                                                                            Sep 09, 2022    6 - Mature             pytest (>=3.0.0)
   :pypi:`pytest-splinter4`                                 Pytest plugin for the splinter automation library                                                                                                                                                                                                                                                                                                                                       Feb 01, 2024    6 - Mature             pytest >=8.0.0
   :pypi:`pytest-split`                                     Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.                                                                                                                                                                                                                                                                                     Feb 03, 2026    4 - Beta               pytest<10,>=5
   :pypi:`pytest-split-ct`                                  Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.                                                                                                                                                                                                                                                                                     Jan 23, 2026    4 - Beta               pytest<10,>=5
   :pypi:`pytest-split-ext`                                 Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.                                                                                                                                                                                                                                                                                     Sep 23, 2023    4 - Beta               pytest (>=5,<8)
   :pypi:`pytest-splitio`                                   Split.io SDK integration for e2e tests                                                                                                                                                                                                                                                                                                                                                  Sep 22, 2020    N/A                    pytest (<7,>=5.0)
   :pypi:`pytest-split-ng`                                  Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.                                                                                                                                                                                                                                                                                     Jan 05, 2026    4 - Beta               pytest<10,>=5
   :pypi:`pytest-split-tests`                               A Pytest plugin for running a subset of your tests by splitting them in to equally sized groups. Forked from Mark Adams' original project pytest-test-groups.                                                                                                                                                                                                                           Jul 30, 2021    5 - Production/Stable  pytest (>=2.5)
   :pypi:`pytest-split-tests-tresorit`                                                                                                                                                                                                                                                                                                                                                                                                              Feb 22, 2021    1 - Planning           N/A
   :pypi:`pytest-split-v2`                                  Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.                                                                                                                                                                                                                                                                                     Jan 14, 2026    4 - Beta               pytest<10,>=5
   :pypi:`pytest-splunk-addon`                              A Dynamic test tool for Splunk Apps and Add-ons                                                                                                                                                                                                                                                                                                                                         Apr 29, 2026    N/A                    pytest<8,>5.4.0
   :pypi:`pytest-splunk-addon-ui-smartx`                    Library to support testing Splunk Add-on UX                                                                                                                                                                                                                                                                                                                                             Apr 23, 2026    N/A                    N/A
   :pypi:`pytest-splunk-env`                                pytest fixtures for interaction with Splunk Enterprise and Splunk Cloud                                                                                                                                                                                                                                                                                                                 Oct 22, 2020    N/A                    pytest (>=6.1.1,<7.0.0)
   :pypi:`pytest-sqitch`                                    sqitch for pytest                                                                                                                                                                                                                                                                                                                                                                       Apr 06, 2020    4 - Beta               N/A
   :pypi:`pytest-sqlalchemy`                                pytest plugin with sqlalchemy related fixtures                                                                                                                                                                                                                                                                                                                                          Apr 19, 2025    3 - Alpha              pytest>=8.0
   :pypi:`pytest-sqlalchemy-alembic`                        Pytest plugin to manage databases, sessions and migrations for sqlalchemy-based projects                                                                                                                                                                                                                                                                                                Jun 05, 2026    N/A                    pytest>=8.4.0
   :pypi:`pytest-sqlalchemy-mock`                           pytest sqlalchemy plugin for mock                                                                                                                                                                                                                                                                                                                                                       Aug 10, 2024    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-sqlalchemy-session`                        A pytest plugin for preserving test isolation that use SQLAlchemy.                                                                                                                                                                                                                                                                                                                      May 19, 2023    4 - Beta               pytest (>=7.0)
   :pypi:`pytest-sql-bigquery`                              Yet another SQL-testing framework for BigQuery provided by pytest plugin                                                                                                                                                                                                                                                                                                                Dec 19, 2019    N/A                    pytest
   :pypi:`pytest-sqlfluff`                                  A pytest plugin to use sqlfluff to enable format checking of sql files.                                                                                                                                                                                                                                                                                                                 Dec 21, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-sqlguard`                                  Pytest fixture to record and check SQL Queries made by SQLAlchemy                                                                                                                                                                                                                                                                                                                       Jun 06, 2025    4 - Beta               pytest>=7
   :pypi:`pytest-squadcast`                                 Pytest report plugin for Squadcast                                                                                                                                                                                                                                                                                                                                                      Feb 22, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-srcpaths`                                  Add paths to sys.path                                                                                                                                                                                                                                                                                                                                                                   Oct 15, 2021    N/A                    pytest>=6.2.0
   :pypi:`pytest-ssh`                                       pytest plugin for ssh command run                                                                                                                                                                                                                                                                                                                                                       May 20, 2026    N/A                    pytest
   :pypi:`pytest-start-from`                                Start pytest run from a given point                                                                                                                                                                                                                                                                                                                                                     Apr 11, 2016    N/A                    N/A
   :pypi:`pytest-static`                                    pytest-static                                                                                                                                                                                                                                                                                                                                                                           May 25, 2025    3 - Alpha              pytest<8.0.0,>=7.4.3
   :pypi:`pytest-stats`                                     Collects tests metadata for future analysis, easy to extend for any data store                                                                                                                                                                                                                                                                                                          Jul 18, 2024    N/A                    pytest>=8.0.0
   :pypi:`pytest-statsd`                                    pytest plugin for reporting to graphite                                                                                                                                                                                                                                                                                                                                                 Nov 30, 2018    5 - Production/Stable  pytest (>=3.0.0)
   :pypi:`pytest-status`                                    Add status mark for tests                                                                                                                                                                                                                                                                                                                                                               Aug 22, 2024    N/A                    pytest
   :pypi:`pytest-stderr-db`                                 Add your description here                                                                                                                                                                                                                                                                                                                                                               Sep 14, 2025    N/A                    N/A
   :pypi:`pytest-stdout-db`                                 Add your description here                                                                                                                                                                                                                                                                                                                                                               Sep 14, 2025    N/A                    N/A
   :pypi:`pytest-stepfunctions`                             A small description                                                                                                                                                                                                                                                                                                                                                                     May 08, 2021    4 - Beta               pytest
   :pypi:`pytest-step-logger`                               Live Rich-rendered step trees in pytest terminal output                                                                                                                                                                                                                                                                                                                                 Mar 11, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-steps`                                     Create step-wise / incremental tests in pytest.                                                                                                                                                                                                                                                                                                                                         Sep 23, 2021    5 - Production/Stable  N/A
   :pypi:`pytest-stepthrough`                               Pause and wait for Enter after each test with --step                                                                                                                                                                                                                                                                                                                                    Aug 14, 2025    N/A                    N/A
   :pypi:`pytest-stepwise`                                  Run a test suite one failing test at a time.                                                                                                                                                                                                                                                                                                                                            Dec 01, 2015    4 - Beta               N/A
   :pypi:`pytest-stf`                                       pytest plugin for openSTF                                                                                                                                                                                                                                                                                                                                                               Sep 23, 2025    N/A                    pytest>=5.0
   :pypi:`pytest-stochastic`                                A pytest plugin for principled stochastic unit testing using concentration inequalities                                                                                                                                                                                                                                                                                                 Feb 24, 2026    4 - Beta               pytest>=7.0
   :pypi:`pytest-stochastics`                               pytest plugin that allows selectively running tests several times and accepting \*some\* failures.                                                                                                                                                                                                                                                                                      Dec 01, 2024    N/A                    pytest<9.0.0,>=8.0.0
   :pypi:`pytest-stogger`                                   AST-based convention checking helpers for pytest.                                                                                                                                                                                                                                                                                                                                       Jun 02, 2026    N/A                    N/A
   :pypi:`pytest-stoq`                                      A plugin to pytest stoq                                                                                                                                                                                                                                                                                                                                                                 Feb 09, 2021    4 - Beta               N/A
   :pypi:`pytest-storage`                                   Pytest plugin to store test artifacts                                                                                                                                                                                                                                                                                                                                                   Sep 12, 2025    3 - Alpha              pytest>=8.4.2
   :pypi:`pytest-store`                                     Pytest plugin to store values from test runs                                                                                                                                                                                                                                                                                                                                            Jul 30, 2025    3 - Alpha              pytest>=7.0.0
   :pypi:`pytest-streaming`                                 Plugin for testing pubsub, pulsar, and kafka systems with pytest locally and in ci/cd                                                                                                                                                                                                                                                                                                   Jan 14, 2026    5 - Production/Stable  pytest>=8.3.5
   :pypi:`pytest-stress`                                    A Pytest plugin that allows you to loop tests for a user defined amount of time.                                                                                                                                                                                                                                                                                                        Dec 07, 2019    4 - Beta               pytest (>=3.6.0)
   :pypi:`pytest-structlog`                                 Structured logging assertions                                                                                                                                                                                                                                                                                                                                                           Sep 10, 2025    N/A                    pytest
   :pypi:`pytest-structmpd`                                 provide structured temporary directory                                                                                                                                                                                                                                                                                                                                                  Oct 17, 2018    N/A                    N/A
   :pypi:`pytest-stub`                                      Stub packages, modules and attributes.                                                                                                                                                                                                                                                                                                                                                  Apr 28, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-stubprocess`                               Provide stub implementations for subprocesses in Python tests                                                                                                                                                                                                                                                                                                                           Sep 17, 2018    3 - Alpha              pytest (>=3.5.0)
   :pypi:`pytest-study`                                     A pytest plugin to organize long run tests (named studies) without interfering the regular tests                                                                                                                                                                                                                                                                                        Sep 26, 2017    3 - Alpha              pytest (>=2.0)
   :pypi:`pytest-subinterpreter`                            Run pytest in a subinterpreter                                                                                                                                                                                                                                                                                                                                                          Nov 25, 2023    N/A                    pytest>=7.0.0
   :pypi:`pytest-subket`                                    Pytest Plugin to disable socket calls during tests                                                                                                                                                                                                                                                                                                                                      Jul 31, 2025    4 - Beta               N/A
   :pypi:`pytest-subprocess`                                A plugin to fake subprocess for pytest                                                                                                                                                                                                                                                                                                                                                  May 10, 2026    5 - Production/Stable  pytest>=4.0.0
   :pypi:`pytest-subtesthack`                               A hack to explicitly set up and tear down fixtures.                                                                                                                                                                                                                                                                                                                                     Jul 16, 2022    N/A                    N/A
   :pypi:`pytest-subtests`                                  unittest subTest() support and subtests fixture                                                                                                                                                                                                                                                                                                                                         Oct 20, 2025    4 - Beta               pytest>=7.4
   :pypi:`pytest-subunit`                                   pytest-subunit is a plugin for py.test which outputs testsresult in subunit format.                                                                                                                                                                                                                                                                                                     Sep 17, 2023    N/A                    pytest (>=2.3)
   :pypi:`pytest-sugar`                                     pytest-sugar is a plugin for pytest that changes the default look and feel of pytest (e.g. progressbar, show tests that fail instantly).                                                                                                                                                                                                                                                Aug 23, 2025    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-suitemanager`                              A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Apr 28, 2023    4 - Beta               N/A
   :pypi:`pytest-suite-timeout`                             A pytest plugin for ensuring max suite time                                                                                                                                                                                                                                                                                                                                             Jan 26, 2024    N/A                    pytest>=7.0.0
   :pypi:`pytest-supercov`                                  Pytest plugin for measuring explicit test-file to source-file coverage                                                                                                                                                                                                                                                                                                                  Jul 02, 2023    N/A                    N/A
   :pypi:`pytest-svn`                                       SVN repository fixture for py.test                                                                                                                                                                                                                                                                                                                                                      Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-swag`                                      Generate OpenAPI documentation from pytest tests                                                                                                                                                                                                                                                                                                                                        Apr 14, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-swarm`                                     Run parametrized test variants in parallel threads — with correct fixture lifecycle                                                                                                                                                                                                                                                                                                     May 29, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-symbols`                                   pytest-symbols is a pytest plugin that adds support for passing test environment symbols into pytest tests.                                                                                                                                                                                                                                                                             Nov 20, 2017    3 - Alpha              N/A
   :pypi:`pytest-system-statistics`                         Pytest plugin to track and report system usage statistics                                                                                                                                                                                                                                                                                                                               Feb 16, 2022    5 - Production/Stable  pytest (>=6.0.0)
   :pypi:`pytest-system-test-plugin`                        Pyst - Pytest System-Test Plugin                                                                                                                                                                                                                                                                                                                                                        Feb 03, 2022    N/A                    N/A
   :pypi:`pytest_tagging`                                   a pytest plugin to tag tests                                                                                                                                                                                                                                                                                                                                                            Nov 08, 2024    N/A                    pytest>=7.1.3
   :pypi:`pytest-takeltest`                                 Fixtures for ansible, testinfra and molecule                                                                                                                                                                                                                                                                                                                                            Sep 07, 2024    N/A                    N/A
   :pypi:`pytest-talisker`                                                                                                                                                                                                                                                                                                                                                                                                                          Nov 28, 2021    N/A                    N/A
   :pypi:`pytest-tally`                                     A Pytest plugin to generate realtime summary stats, and display them in-console using a text-based dashboard.                                                                                                                                                                                                                                                                           May 22, 2023    4 - Beta               pytest (>=6.2.5)
   :pypi:`pytest-tap`                                       Test Anything Protocol (TAP) reporting plugin for pytest                                                                                                                                                                                                                                                                                                                                Jan 30, 2025    5 - Production/Stable  pytest>=3.0
   :pypi:`pytest-tape`                                      easy assertion with expected results saved to yaml files                                                                                                                                                                                                                                                                                                                                Mar 17, 2021    4 - Beta               N/A
   :pypi:`pytest-target`                                    Pytest plugin for remote target orchestration.                                                                                                                                                                                                                                                                                                                                          Jan 21, 2021    3 - Alpha              pytest (>=6.1.2,<7.0.0)
   :pypi:`pytest-taskgraph`                                 Add your description here                                                                                                                                                                                                                                                                                                                                                               Apr 09, 2025    N/A                    pytest
   :pypi:`pytest-tblineinfo`                                tblineinfo is a py.test plugin that insert the node id in the final py.test report when --tb=line option is used                                                                                                                                                                                                                                                                        Dec 01, 2015    3 - Alpha              pytest (>=2.0)
   :pypi:`pytest-tcpclient`                                 A pytest plugin for testing TCP clients                                                                                                                                                                                                                                                                                                                                                 Nov 16, 2022    N/A                    pytest (<8,>=7.1.3)
   :pypi:`pytest-tdd`                                       run pytest on a python module                                                                                                                                                                                                                                                                                                                                                           Aug 18, 2023    4 - Beta               N/A
   :pypi:`pytest-teamcity-logblock`                         py.test plugin to introduce block structure in teamcity build log, if output is not captured                                                                                                                                                                                                                                                                                            May 15, 2018    4 - Beta               N/A
   :pypi:`pytest-teardown`                                                                                                                                                                                                                                                                                                                                                                                                                          Apr 15, 2025    N/A                    pytest<9.0.0,>=7.4.1
   :pypi:`pytest-telegram`                                  Pytest to Telegram reporting plugin                                                                                                                                                                                                                                                                                                                                                     Apr 25, 2024    5 - Production/Stable  N/A
   :pypi:`pytest-telegram-notifier`                         Telegram notification plugin for Pytest                                                                                                                                                                                                                                                                                                                                                 Jun 27, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-tempdir`                                   Predictable and repeatable tempdir support.                                                                                                                                                                                                                                                                                                                                             Oct 11, 2019    4 - Beta               pytest (>=2.8.1)
   :pypi:`pytest-terra-fixt`                                Terraform and Terragrunt fixtures for pytest                                                                                                                                                                                                                                                                                                                                            Sep 15, 2022    N/A                    pytest (==6.2.5)
   :pypi:`pytest-terraform`                                 A pytest plugin for using terraform fixtures                                                                                                                                                                                                                                                                                                                                            May 21, 2024    N/A                    pytest>=6.0
   :pypi:`pytest-terraform-fixture`                         generate terraform resources to use with pytest                                                                                                                                                                                                                                                                                                                                         Nov 14, 2018    4 - Beta               N/A
   :pypi:`pytest-test-analyzer`                             A powerful tool for analyzing pytest test files and generating detailed reports                                                                                                                                                                                                                                                                                                         Jun 14, 2025    4 - Beta               N/A
   :pypi:`pytest-testbook`                                  Enables pytest to execute your Jupyter Notebook as a test                                                                                                                                                                                                                                                                                                                               May 29, 2026    N/A                    pytest>=5.4.0
   :pypi:`pytest-test-categories`                           A pytest plugin to enforce test timing constraints and size distributions.                                                                                                                                                                                                                                                                                                              Mar 04, 2026    5 - Production/Stable  pytest>=8.4.2
   :pypi:`pytest-testconfig`                                Test configuration plugin for pytest.                                                                                                                                                                                                                                                                                                                                                   Jan 11, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-testcontainers`                            Named pytest fixtures and a maker convention on top of testcontainers-python.                                                                                                                                                                                                                                                                                                           May 08, 2026    4 - Beta               pytest<9,>=7.4
   :pypi:`pytest-testcontainers-compose`                    Pytest plugin for Docker Compose                                                                                                                                                                                                                                                                                                                                                        Feb 11, 2026    N/A                    N/A
   :pypi:`pytest-testcontainers-django`                     Bridge between pytest-testcontainers and pytest-django: starts the DB container before Django imports settings.                                                                                                                                                                                                                                                                         Jun 01, 2026    4 - Beta               pytest<9,>=7.4
   :pypi:`pytest-testdata`                                  Get and load testdata in pytest projects                                                                                                                                                                                                                                                                                                                                                Aug 30, 2024    N/A                    pytest
   :pypi:`pytest-testdirectory`                             A py.test plugin providing temporary directories in unit tests.                                                                                                                                                                                                                                                                                                                         May 02, 2023    5 - Production/Stable  pytest
   :pypi:`pytest-testdox`                                   A testdox format reporter for pytest                                                                                                                                                                                                                                                                                                                                                    Jul 22, 2023    5 - Production/Stable  pytest (>=4.6.0)
   :pypi:`pytest-test-grouping`                             A Pytest plugin for running a subset of your tests by splitting them in to equally sized groups.                                                                                                                                                                                                                                                                                        Feb 01, 2023    5 - Production/Stable  pytest (>=2.5)
   :pypi:`pytest-test-groups`                               A Pytest plugin for running a subset of your tests by splitting them in to equally sized groups.                                                                                                                                                                                                                                                                                        May 08, 2025    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-testinel`                                  Testinel’s pytest plugin captures structured test execution data directly from pytest and sends it to Testinel, where your test results become searchable, comparable, and actually useful.                                                                                                                                                                                             May 26, 2026    4 - Beta               pytest>=7
   :pypi:`pytest-testinfra`                                 Test infrastructures                                                                                                                                                                                                                                                                                                                                                                    Mar 30, 2025    5 - Production/Stable  pytest>=6
   :pypi:`pytest-testinfra-jpic`                            Test infrastructures                                                                                                                                                                                                                                                                                                                                                                    Sep 21, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-testinfra-winrm-transport`                 Test infrastructures                                                                                                                                                                                                                                                                                                                                                                    Sep 21, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-testit-parametrize`                        A pytest plugin for uploading parameterized tests parameters into TMS TestIT                                                                                                                                                                                                                                                                                                            Dec 04, 2024    4 - Beta               pytest>=8.3.3
   :pypi:`pytest-testlink-adaptor`                          pytest reporting plugin for testlink                                                                                                                                                                                                                                                                                                                                                    Dec 20, 2018    4 - Beta               pytest (>=2.6)
   :pypi:`pytest-testmon`                                   selects tests affected by changed files and methods                                                                                                                                                                                                                                                                                                                                     Dec 01, 2025    4 - Beta               pytest<10,>=5
   :pypi:`pytest-testmon-dev`                               selects tests affected by changed files and methods                                                                                                                                                                                                                                                                                                                                     Mar 30, 2023    4 - Beta               pytest (<8,>=5)
   :pypi:`pytest-testmon-oc`                                nOly selects tests affected by changed files and methods                                                                                                                                                                                                                                                                                                                                Jun 01, 2022    4 - Beta               pytest (<8,>=5)
   :pypi:`pytest-testmon-skip-libraries`                    selects tests affected by changed files and methods                                                                                                                                                                                                                                                                                                                                     Mar 03, 2023    4 - Beta               pytest (<8,>=5)
   :pypi:`pytest-testobject`                                Plugin to use TestObject Suites with Pytest                                                                                                                                                                                                                                                                                                                                             Sep 24, 2019    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-test-observer`                             A pytest plugin for observing test execution events.                                                                                                                                                                                                                                                                                                                                    May 23, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-testpluggy`                                set your encoding                                                                                                                                                                                                                                                                                                                                                                       Jan 07, 2022    N/A                    pytest
   :pypi:`pytest-testrail`                                  A pytest plugin for creating TestRail runs and adding results                                                                                                                                                                                                                                                                                                                           Jan 25, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-testrail2`                                 A pytest plugin to upload results to TestRail.                                                                                                                                                                                                                                                                                                                                          Feb 10, 2023    N/A                    pytest (<8.0,>=7.2.0)
   :pypi:`pytest-testrail-api`                              TestRail Api Python Client                                                                                                                                                                                                                                                                                                                                                              Mar 17, 2025    N/A                    pytest
   :pypi:`pytest-testrail-api-client`                       TestRail Api Python Client                                                                                                                                                                                                                                                                                                                                                              Dec 14, 2021    N/A                    pytest
   :pypi:`pytest-testrail-appetize`                         pytest plugin for creating TestRail runs and adding results                                                                                                                                                                                                                                                                                                                             Sep 29, 2021    N/A                    N/A
   :pypi:`pytest-testrail-client`                           pytest plugin for Testrail                                                                                                                                                                                                                                                                                                                                                              Sep 29, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-testrail-e2e`                              pytest plugin for creating TestRail runs and adding results                                                                                                                                                                                                                                                                                                                             Oct 11, 2021    N/A                    pytest (>=3.6)
   :pypi:`pytest-testrail-integrator`                       Pytest plugin for sending report to testrail system.                                                                                                                                                                                                                                                                                                                                    Aug 01, 2022    N/A                    pytest (>=6.2.5)
   :pypi:`pytest-testrail-ns`                               pytest plugin for creating TestRail runs and adding results                                                                                                                                                                                                                                                                                                                             Aug 12, 2022    N/A                    N/A
   :pypi:`pytest-testrail-reporter`                                                                                                                                                                                                                                                                                                                                                                                                                 Sep 10, 2018    N/A                    N/A
   :pypi:`pytest-testrail-results`                          A pytest plugin to upload results to TestRail.                                                                                                                                                                                                                                                                                                                                          Mar 04, 2024    N/A                    pytest >=7.2.0
   :pypi:`pytest-testreport`                                                                                                                                                                                                                                                                                                                                                                                                                        Dec 01, 2022    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-testreport-new`                                                                                                                                                                                                                                                                                                                                                                                                                    Oct 07, 2023    4 - Beta               pytest >=3.5.0
   :pypi:`pytest-testslide`                                 TestSlide fixture for pytest                                                                                                                                                                                                                                                                                                                                                            Jan 07, 2021    5 - Production/Stable  pytest (~=6.2)
   :pypi:`pytest-test-this`                                 Plugin for py.test to run relevant tests, based on naively checking if a test contains a reference to the symbol you supply                                                                                                                                                                                                                                                             Sep 15, 2019    2 - Pre-Alpha          pytest (>=2.3)
   :pypi:`pytest-test-tracer-for-pytest`                    A plugin that allows coll test data for use on Test Tracer                                                                                                                                                                                                                                                                                                                              Jun 28, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-test-tracer-for-pytest-bdd`                A plugin that allows coll test data for use on Test Tracer                                                                                                                                                                                                                                                                                                                              Aug 20, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-test-utils`                                                                                                                                                                                                                                                                                                                                                                                                                        Feb 08, 2024    N/A                    pytest >=3.9
   :pypi:`pytest-tesults`                                   Tesults plugin for pytest                                                                                                                                                                                                                                                                                                                                                               Nov 12, 2024    5 - Production/Stable  pytest>=3.5.0
   :pypi:`pytest-texts-score`                               Texts content similarity scoring plugin                                                                                                                                                                                                                                                                                                                                                 Dec 17, 2025    4 - Beta               pytest>=8.4.2
   :pypi:`pytest-textual-snapshot`                          Snapshot testing for Textual apps                                                                                                                                                                                                                                                                                                                                                       Jan 23, 2025    5 - Production/Stable  pytest>=8.0.0
   :pypi:`pytest-tezos`                                     pytest-ligo                                                                                                                                                                                                                                                                                                                                                                             Jan 16, 2020    4 - Beta               N/A
   :pypi:`pytest-tf`                                        Test your OpenTofu and Terraform config using a PyTest plugin                                                                                                                                                                                                                                                                                                                           May 29, 2024    N/A                    pytest<9.0.0,>=8.2.1
   :pypi:`pytest-th2-bdd`                                   pytest_th2_bdd                                                                                                                                                                                                                                                                                                                                                                          May 13, 2022    N/A                    N/A
   :pypi:`pytest-thawgun`                                   Pytest plugin for time travel                                                                                                                                                                                                                                                                                                                                                           May 26, 2020    3 - Alpha              N/A
   :pypi:`pytest-thread`                                                                                                                                                                                                                                                                                                                                                                                                                            Jul 07, 2023    N/A                    N/A
   :pypi:`pytest-threadleak`                                Detects thread leaks                                                                                                                                                                                                                                                                                                                                                                    Jul 03, 2022    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-threadpool`                                Parallel test execution using threads — true parallelism on free-threaded Python, concurrent I/O on standard builds                                                                                                                                                                                                                                                                     Mar 19, 2026    4 - Beta               pytest<=9.0.2,>=9.0.0
   :pypi:`pytest-tick`                                      Ticking on tests                                                                                                                                                                                                                                                                                                                                                                        Aug 31, 2021    5 - Production/Stable  pytest (>=6.2.5,<7.0.0)
   :pypi:`pytest_time`                                                                                                                                                                                                                                                                                                                                                                                                                              Dec 01, 2025    3 - Alpha              pytest
   :pypi:`pytest-timeassert-ethan`                          execution duration                                                                                                                                                                                                                                                                                                                                                                      Dec 25, 2023    N/A                    pytest
   :pypi:`pytest-timeit`                                    A pytest plugin to time test function runs                                                                                                                                                                                                                                                                                                                                              Oct 13, 2016    4 - Beta               N/A
   :pypi:`pytest-timeout`                                   pytest plugin to abort hanging tests                                                                                                                                                                                                                                                                                                                                                    May 05, 2025    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-timeouts`                                  Linux-only Pytest plugin to control durations of various test case execution phases                                                                                                                                                                                                                                                                                                     Sep 21, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-timer`                                     A timer plugin for pytest                                                                                                                                                                                                                                                                                                                                                               Dec 26, 2023    N/A                    pytest
   :pypi:`pytest-timestamper`                               Pytest plugin to add a timestamp prefix to the pytest output                                                                                                                                                                                                                                                                                                                            Mar 27, 2024    N/A                    N/A
   :pypi:`pytest-timestamps`                                A simple plugin to view timestamps for each test                                                                                                                                                                                                                                                                                                                                        Sep 11, 2023    N/A                    pytest (>=7.3,<8.0)
   :pypi:`pytest-timing-plugin`                             pytest插件开发demo                                                                                                                                                                                                                                                                                                                                                                      Jul 21, 2025    N/A                    N/A
   :pypi:`pytest-tiny-api-client`                           The companion pytest plugin for tiny-api-client                                                                                                                                                                                                                                                                                                                                         Jan 04, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-tinybird`                                  A pytest plugin to report test results to tinybird                                                                                                                                                                                                                                                                                                                                      May 07, 2025    4 - Beta               pytest>=3.8.0
   :pypi:`pytest-tipsi-django`                              Better fixtures for django                                                                                                                                                                                                                                                                                                                                                              Feb 05, 2024    5 - Production/Stable  pytest>=6.0.0
   :pypi:`pytest-tipsi-testing`                             Better fixtures management. Various helpers                                                                                                                                                                                                                                                                                                                                             Feb 04, 2024    5 - Production/Stable  pytest>=3.3.0
   :pypi:`pytest-tldr`                                      A pytest plugin that limits the output to just the things you need.                                                                                                                                                                                                                                                                                                                     Nov 10, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-tm4j-reporter`                             Cloud Jira Test Management (TM4J) PyTest reporter plugin                                                                                                                                                                                                                                                                                                                                Sep 01, 2020    N/A                    pytest
   :pypi:`pytest-tmnet`                                     A small example package                                                                                                                                                                                                                                                                                                                                                                 Mar 01, 2022    N/A                    N/A
   :pypi:`pytest-tmp-files`                                 Utilities to create temporary file hierarchies in pytest.                                                                                                                                                                                                                                                                                                                               Dec 08, 2023    N/A                    pytest
   :pypi:`pytest-tmpfs`                                     A pytest plugin that helps you on using a temporary filesystem for testing.                                                                                                                                                                                                                                                                                                             Aug 29, 2022    N/A                    pytest
   :pypi:`pytest-tmreport`                                  this is a vue-element ui report for pytest                                                                                                                                                                                                                                                                                                                                              Aug 12, 2022    N/A                    N/A
   :pypi:`pytest-tmux`                                      A pytest plugin that enables tmux driven tests                                                                                                                                                                                                                                                                                                                                          Sep 01, 2025    4 - Beta               N/A
   :pypi:`pytest-todo`                                      A small plugin for the pytest testing framework, marking TODO comments as failure                                                                                                                                                                                                                                                                                                       May 23, 2019    4 - Beta               pytest
   :pypi:`pytest-tomato`                                                                                                                                                                                                                                                                                                                                                                                                                            Mar 01, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-toolbelt`                                  This is just a collection of utilities for pytest, but don't really belong in pytest proper.                                                                                                                                                                                                                                                                                            Aug 12, 2019    3 - Alpha              N/A
   :pypi:`pytest-toolbox`                                   Numerous useful plugins for pytest.                                                                                                                                                                                                                                                                                                                                                     Apr 07, 2018    N/A                    pytest (>=3.5.0)
   :pypi:`pytest-toolkit`                                   Useful utils for testing                                                                                                                                                                                                                                                                                                                                                                Jun 07, 2024    N/A                    N/A
   :pypi:`pytest-tools`                                     Pytest tools                                                                                                                                                                                                                                                                                                                                                                            Oct 21, 2022    4 - Beta               N/A
   :pypi:`pytest-topo`                                      Topological sorting for pytest                                                                                                                                                                                                                                                                                                                                                          Jun 05, 2024    N/A                    pytest>=7.0.0
   :pypi:`pytest-tornado`                                   A py.test plugin providing fixtures and markers to simplify testing of asynchronous tornado applications.                                                                                                                                                                                                                                                                               Jun 17, 2020    5 - Production/Stable  pytest (>=3.6)
   :pypi:`pytest-tornado5`                                  A py.test plugin providing fixtures and markers to simplify testing of asynchronous tornado applications.                                                                                                                                                                                                                                                                               Nov 16, 2018    5 - Production/Stable  pytest (>=3.6)
   :pypi:`pytest-tornado-yen3`                              A py.test plugin providing fixtures and markers to simplify testing of asynchronous tornado applications.                                                                                                                                                                                                                                                                               Oct 15, 2018    5 - Production/Stable  N/A
   :pypi:`pytest-tornasync`                                 py.test plugin for testing Python 3.5+ Tornado code                                                                                                                                                                                                                                                                                                                                     Jul 15, 2019    3 - Alpha              pytest (>=3.0)
   :pypi:`pytest-trace`                                     Save OpenTelemetry spans generated during testing                                                                                                                                                                                                                                                                                                                                       Jun 19, 2022    N/A                    pytest (>=4.6)
   :pypi:`pytest-track`                                                                                                                                                                                                                                                                                                                                                                                                                             Feb 26, 2021    3 - Alpha              pytest (>=3.0)
   :pypi:`pytest-translate`                                 pytest terminal output in your language — 134 languages supported, zero configuration                                                                                                                                                                                                                                                                                                   Apr 08, 2026    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-translations`                              Test your translation files.                                                                                                                                                                                                                                                                                                                                                            Sep 11, 2023    5 - Production/Stable  pytest (>=7)
   :pypi:`pytest-travis-fold`                               Folds captured output sections in Travis CI build log                                                                                                                                                                                                                                                                                                                                   Nov 29, 2017    4 - Beta               pytest (>=2.6.0)
   :pypi:`pytest-trello`                                    Plugin for py.test that integrates trello using markers                                                                                                                                                                                                                                                                                                                                 Nov 20, 2015    5 - Production/Stable  N/A
   :pypi:`pytest-trepan`                                    Pytest plugin for trepan debugger.                                                                                                                                                                                                                                                                                                                                                      Sep 11, 2025    5 - Production/Stable  pytest>=4.0.0
   :pypi:`pytest-trialtemp`                                 py.test plugin for using the same _trial_temp working directory as trial                                                                                                                                                                                                                                                                                                                Jun 08, 2015    N/A                    N/A
   :pypi:`pytest-trio`                                      Pytest plugin for trio                                                                                                                                                                                                                                                                                                                                                                  Nov 01, 2022    N/A                    pytest (>=7.2.0)
   :pypi:`pytest-tripwire`                                  Full-certainty test mocking: every call recorded and verified                                                                                                                                                                                                                                                                                                                           May 01, 2026    3 - Alpha              pytest>=7.4.0; extra == "dev"
   :pypi:`pytest-trytond`                                   Pytest plugin for the Tryton server framework                                                                                                                                                                                                                                                                                                                                           Nov 04, 2022    4 - Beta               pytest (>=5)
   :pypi:`pytest-tspwplib`                                  A simple plugin to use with tspwplib                                                                                                                                                                                                                                                                                                                                                    Jan 08, 2021    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-tst`                                       Customize pytest options, output and exit code to make it compatible with tst                                                                                                                                                                                                                                                                                                           Apr 27, 2022    N/A                    pytest (>=5.0.0)
   :pypi:`pytest-tstcls`                                    Test Class Base                                                                                                                                                                                                                                                                                                                                                                         Mar 23, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-tui`                                       Text User Interface (TUI) and HTML report for Pytest test runs                                                                                                                                                                                                                                                                                                                          Dec 08, 2023    4 - Beta               N/A
   :pypi:`pytest-tui-run`                                   TUI runner for \`pytest\` tests                                                                                                                                                                                                                                                                                                                                                         Jun 05, 2026    N/A                    pytest
   :pypi:`pytest-tui-runner`                                Textual-based terminal UI for running pytest tests                                                                                                                                                                                                                                                                                                                                      Dec 12, 2025    N/A                    pytest<=9.0.1,>=7.4
   :pypi:`pytest-tuitest`                                   pytest plugin for testing TUI and regular command-line applications.                                                                                                                                                                                                                                                                                                                    Apr 11, 2025    N/A                    pytest>=7.4.0
   :pypi:`pytest-tutorials`                                                                                                                                                                                                                                                                                                                                                                                                                         Mar 11, 2023    N/A                    N/A
   :pypi:`pytest-twilio-conversations-client-mock`                                                                                                                                                                                                                                                                                                                                                                                                  Aug 02, 2022    N/A                    N/A
   :pypi:`pytest-twisted`                                   A twisted plugin for pytest.                                                                                                                                                                                                                                                                                                                                                            Sep 10, 2024    5 - Production/Stable  pytest>=2.3
   :pypi:`pytest-ty`                                        A pytest plugin to run the ty type checker                                                                                                                                                                                                                                                                                                                                              Apr 24, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-typechecker`                               Run type checkers on specified test files                                                                                                                                                                                                                                                                                                                                               Feb 04, 2022    N/A                    pytest (>=6.2.5,<7.0.0)
   :pypi:`pytest-typed-schema-shot`                         Pytest plugin for automatic JSON Schema generation and validation from examples                                                                                                                                                                                                                                                                                                         Jun 14, 2025    N/A                    pytest
   :pypi:`pytest-typhoon-config`                            A Typhoon HIL plugin that facilitates test parameter configuration at runtime                                                                                                                                                                                                                                                                                                           Apr 07, 2022    5 - Production/Stable  N/A
   :pypi:`pytest-typhoon-polarion`                          Typhoontest plugin for Siemens Polarion                                                                                                                                                                                                                                                                                                                                                 Feb 01, 2024    4 - Beta               N/A
   :pypi:`pytest-typhoon-xray`                              Typhoon HIL plugin for pytest                                                                                                                                                                                                                                                                                                                                                           Aug 15, 2023    4 - Beta               N/A
   :pypi:`pytest-typing`                                    Test your types by running typecheckers on them.                                                                                                                                                                                                                                                                                                                                        Mar 24, 2026    3 - Alpha              pytest
   :pypi:`pytest-typing-runner`                             Pytest plugin to make it easier to run and check python code against static type checkers                                                                                                                                                                                                                                                                                               May 31, 2025    N/A                    N/A
   :pypi:`pytest-tytest`                                    Typhoon HIL plugin for pytest                                                                                                                                                                                                                                                                                                                                                           May 25, 2020    4 - Beta               pytest (>=5.4.2)
   :pypi:`pytest-tzshift`                                   A Pytest plugin that transparently re-runs tests under a matrix of timezones and locales.                                                                                                                                                                                                                                                                                               Jun 25, 2025    4 - Beta               pytest>=7.0
   :pypi:`pytest-ubersmith`                                 Easily mock calls to ubersmith at the \`requests\` level.                                                                                                                                                                                                                                                                                                                               Apr 13, 2015    N/A                    N/A
   :pypi:`pytest-ui`                                        Text User Interface for running python tests                                                                                                                                                                                                                                                                                                                                            Jul 05, 2021    4 - Beta               pytest
   :pypi:`pytest-ui-failed-screenshot`                      UI自动测试失败时自动截图，并将截图加入到测试报告中                                                                                                                                                                                                                                                                                                                                      Dec 06, 2022    N/A                    N/A
   :pypi:`pytest-ui-failed-screenshot-allure`               UI自动测试失败时自动截图，并将截图加入到Allure测试报告中                                                                                                                                                                                                                                                                                                                                Dec 06, 2022    N/A                    N/A
   :pypi:`pytest-uncollect-if`                              A plugin to uncollect pytests tests rather than using skipif                                                                                                                                                                                                                                                                                                                            Dec 26, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-unflakable`                                Unflakable plugin for PyTest                                                                                                                                                                                                                                                                                                                                                            Apr 30, 2024    4 - Beta               pytest>=6.2.0
   :pypi:`pytest-unhandled-exception-exit-code`             Plugin for py.test set a different exit code on uncaught exceptions                                                                                                                                                                                                                                                                                                                     Jun 22, 2020    5 - Production/Stable  pytest (>=2.3)
   :pypi:`pytest-unique`                                    Pytest fixture to generate unique values.                                                                                                                                                                                                                                                                                                                                               Mar 27, 2026    N/A                    pytest>=9.0.0
   :pypi:`pytest-unittest-filter`                           A pytest plugin for filtering unittest-based test classes                                                                                                                                                                                                                                                                                                                               Jan 12, 2019    4 - Beta               pytest (>=3.1.0)
   :pypi:`pytest-unittest-id-runner`                        A pytest plugin to run tests using unittest-style test IDs                                                                                                                                                                                                                                                                                                                              Feb 09, 2025    N/A                    pytest>=6.0.0
   :pypi:`pytest-unmagic`                                   Pytest fixtures with conventional import semantics                                                                                                                                                                                                                                                                                                                                      Jun 04, 2026    5 - Production/Stable  pytest
   :pypi:`pytest-unmarked`                                  Run only unmarked tests                                                                                                                                                                                                                                                                                                                                                                 Aug 27, 2019    5 - Production/Stable  N/A
   :pypi:`pytest-unordered`                                 Test equality of unordered collections in pytest                                                                                                                                                                                                                                                                                                                                        Jun 03, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-unstable`                                  Set a test as unstable to return 0 even if it failed                                                                                                                                                                                                                                                                                                                                    Sep 27, 2022    4 - Beta               N/A
   :pypi:`pytest-unused-fixtures`                           A pytest plugin to list unused fixtures after a test run.                                                                                                                                                                                                                                                                                                                               Dec 23, 2025    4 - Beta               pytest>7.3.2
   :pypi:`pytest-unused-port`                               pytest fixture finding an unused local port                                                                                                                                                                                                                                                                                                                                             Oct 22, 2025    N/A                    pytest
   :pypi:`pytest-upload-report`                             pytest-upload-report is a plugin for pytest that upload your test report for test results.                                                                                                                                                                                                                                                                                              Jun 18, 2021    5 - Production/Stable  N/A
   :pypi:`pytest-urllib3`                                   A pytest plugin to mock urllib3 requests                                                                                                                                                                                                                                                                                                                                                Mar 09, 2026    3 - Alpha              pytest>=7
   :pypi:`pytest-utils`                                     Some helpers for pytest.                                                                                                                                                                                                                                                                                                                                                                Feb 02, 2023    4 - Beta               pytest (>=7.0.0,<8.0.0)
   :pypi:`pytest-uuid`                                      A pytest plugin for mocking uuid.uuid4() calls                                                                                                                                                                                                                                                                                                                                          Feb 27, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-vagrant`                                   A py.test plugin providing access to vagrant.                                                                                                                                                                                                                                                                                                                                           Sep 07, 2021    5 - Production/Stable  pytest
   :pypi:`pytest-valgrind`                                                                                                                                                                                                                                                                                                                                                                                                                          May 19, 2021    N/A                    N/A
   :pypi:`pytest-variables`                                 pytest plugin for providing variables to tests/fixtures                                                                                                                                                                                                                                                                                                                                 Feb 01, 2024    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-variant`                                   Variant support for Pytest                                                                                                                                                                                                                                                                                                                                                              Jun 06, 2022    N/A                    N/A
   :pypi:`pytest-vcr`                                       Plugin for managing VCR.py cassettes                                                                                                                                                                                                                                                                                                                                                    Apr 26, 2019    5 - Production/Stable  pytest (>=3.6.0)
   :pypi:`pytest-vcr-delete-on-fail`                        A pytest plugin that automates vcrpy cassettes deletion on test failure.                                                                                                                                                                                                                                                                                                                Feb 16, 2024    5 - Production/Stable  pytest (>=8.0.0,<9.0.0)
   :pypi:`pytest-vcrpandas`                                 Test from HTTP interactions to dataframe processed.                                                                                                                                                                                                                                                                                                                                     Jan 12, 2019    4 - Beta               pytest
   :pypi:`pytest-vcs`                                                                                                                                                                                                                                                                                                                                                                                                                               Sep 22, 2022    4 - Beta               N/A
   :pypi:`pytest-venv`                                      py.test fixture for creating a virtual environment                                                                                                                                                                                                                                                                                                                                      Nov 23, 2023    4 - Beta               pytest
   :pypi:`pytest-verbose-parametrize`                       More descriptive output for parametrized py.test tests                                                                                                                                                                                                                                                                                                                                  Nov 29, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-verify`                                    A pytest plugin for snapshot verification with optional visual diff viewer.                                                                                                                                                                                                                                                                                                             Oct 25, 2025    5 - Production/Stable  N/A
   :pypi:`pytest-ves`                                       pytest fixtures and builders for ONAP VES 7.x events (fault, heartbeat, measurement, and more).                                                                                                                                                                                                                                                                                         Apr 18, 2026    3 - Alpha              N/A
   :pypi:`pytest-vigil`                                     A pytest plugin for enhanced test reliability and monitoring                                                                                                                                                                                                                                                                                                                            Apr 07, 2026    5 - Production/Stable  pytest>=9.0.0
   :pypi:`pytest-vimqf`                                     A simple pytest plugin that will shrink pytest output when specified, to fit vim quickfix window.                                                                                                                                                                                                                                                                                       Feb 08, 2021    4 - Beta               pytest (>=6.2.2,<7.0.0)
   :pypi:`pytest-virtualenv`                                Virtualenv fixture for py.test                                                                                                                                                                                                                                                                                                                                                          Nov 29, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-visionspec`                                Pytest plugin that auto-reports test results with screenshots to VisionSpec                                                                                                                                                                                                                                                                                                             Jun 02, 2026    N/A                    pytest>=7.0
   :pypi:`pytest-visual`                                                                                                                                                                                                                                                                                                                                                                                                                            Nov 28, 2024    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-vitro`                                     A pytest plugin to leverage the Vitro framework for test automation.                                                                                                                                                                                                                                                                                                                    May 25, 2026    N/A                    pytest>=8
   :pypi:`pytest-vnc`                                       VNC client for Pytest                                                                                                                                                                                                                                                                                                                                                                   Nov 06, 2023    N/A                    pytest
   :pypi:`pytest-voluptuous`                                Pytest plugin for asserting data against voluptuous schema.                                                                                                                                                                                                                                                                                                                             Jun 09, 2020    N/A                    pytest
   :pypi:`pytest-vscodedebug`                               A pytest plugin to easily enable debugging tests within Visual Studio Code                                                                                                                                                                                                                                                                                                              Dec 04, 2020    4 - Beta               N/A
   :pypi:`pytest-vscode-pycharm-cls`                        A PyTest helper to enable start remote debugger on test start or failure or when pytest.set_trace is used.                                                                                                                                                                                                                                                                              Feb 01, 2023    N/A                    pytest
   :pypi:`pytest-vtestify`                                  A pytest plugin for visual assertion using SSIM and image comparison.                                                                                                                                                                                                                                                                                                                   Feb 04, 2025    N/A                    pytest
   :pypi:`pytest-vts`                                       pytest plugin for automatic recording of http stubbed tests                                                                                                                                                                                                                                                                                                                             Jun 05, 2019    N/A                    pytest (>=2.3)
   :pypi:`pytest-vulture`                                   A pytest plugin to checks dead code with vulture                                                                                                                                                                                                                                                                                                                                        Nov 25, 2024    N/A                    pytest>=7.0.0
   :pypi:`pytest-vw`                                        pytest-vw makes your failing test cases succeed under CI tools scrutiny                                                                                                                                                                                                                                                                                                                 Oct 07, 2015    4 - Beta               N/A
   :pypi:`pytest-vyper`                                     Plugin for the vyper smart contract language.                                                                                                                                                                                                                                                                                                                                           May 28, 2020    2 - Pre-Alpha          N/A
   :pypi:`pytest-wa-e2e-plugin`                             Pytest plugin for testing whatsapp bots with end to end tests                                                                                                                                                                                                                                                                                                                           Feb 18, 2020    4 - Beta               pytest (>=3.5.0)
   :pypi:`pytest-wake`                                                                                                                                                                                                                                                                                                                                                                                                                              Nov 19, 2024    N/A                    pytest
   :pypi:`pytest-wardenbot`                                 Pytest plugin for testing chatbots and LLM apps — prompt injection, jailbreaks, system-prompt leaks, hallucinations, brand drift.                                                                                                                                                                                                                                                       May 26, 2026    3 - Alpha              pytest>=8.0
   :pypi:`pytest-warmup`                                    Batch preparation and distribution of expensive test resources for pytest.                                                                                                                                                                                                                                                                                                              Jun 02, 2026    3 - Alpha              pytest<10,>=8.4
   :pypi:`pytest-watch`                                     Local continuous test runner with pytest and watchdog.                                                                                                                                                                                                                                                                                                                                  May 20, 2018    N/A                    N/A
   :pypi:`pytest-watcher`                                   Automatically rerun your tests on file modifications                                                                                                                                                                                                                                                                                                                                    Jan 10, 2026    4 - Beta               N/A
   :pypi:`pytest-watch-ng`                                  Local continuous test runner with pytest and watchdog (maintained fork of pytest-watch with pyproject.toml support).                                                                                                                                                                                                                                                                    May 20, 2026    5 - Production/Stable  pytest>=2.6.4
   :pypi:`pytest-watch-plugin`                              Placeholder for internal package                                                                                                                                                                                                                                                                                                                                                        Sep 12, 2024    N/A                    N/A
   :pypi:`pytest_wdb`                                       Trace pytest tests with wdb to halt on error with --wdb.                                                                                                                                                                                                                                                                                                                                Jul 04, 2016    N/A                    N/A
   :pypi:`pytest-wdl`                                       Pytest plugin for testing WDL workflows.                                                                                                                                                                                                                                                                                                                                                Nov 17, 2020    5 - Production/Stable  N/A
   :pypi:`pytest-web`                                       Local web UI for running and monitoring pytest suites                                                                                                                                                                                                                                                                                                                                   May 10, 2026    3 - Alpha              pytest>=7.0
   :pypi:`pytest-web3-data`                                 A pytest plugin to fetch test data from IPFS HTTP gateways during pytest execution.                                                                                                                                                                                                                                                                                                     Oct 04, 2023    4 - Beta               pytest
   :pypi:`pytest-webdriver`                                 Selenium webdriver fixture for py.test                                                                                                                                                                                                                                                                                                                                                  Oct 17, 2024    5 - Production/Stable  pytest
   :pypi:`pytest-webstage`                                  Test web apps with pytest                                                                                                                                                                                                                                                                                                                                                               Sep 20, 2024    N/A                    pytest<9.0,>=7.0
   :pypi:`pytest-webtestpilot`                              Pytest plugin for running WebTestPilot JSON tests                                                                                                                                                                                                                                                                                                                                       Dec 28, 2025    N/A                    pytest>=9.0.2
   :pypi:`pytest-wetest`                                    Welian API Automation test framework pytest plugin                                                                                                                                                                                                                                                                                                                                      Nov 10, 2018    4 - Beta               N/A
   :pypi:`pytest-when`                                      Utility which makes mocking more readable and controllable                                                                                                                                                                                                                                                                                                                              Sep 25, 2025    N/A                    pytest>=7.3.1
   :pypi:`pytest-whirlwind`                                 Testing Tornado.                                                                                                                                                                                                                                                                                                                                                                        Jun 12, 2020    N/A                    N/A
   :pypi:`pytest-wholenodeid`                               pytest addon for displaying the whole node id for failures                                                                                                                                                                                                                                                                                                                              Aug 26, 2015    4 - Beta               pytest (>=2.0)
   :pypi:`pytest-win32consoletitle`                         Pytest progress in console title (Win32 only)                                                                                                                                                                                                                                                                                                                                           Aug 08, 2021    N/A                    N/A
   :pypi:`pytest-winnotify`                                 Windows tray notifications for py.test results.                                                                                                                                                                                                                                                                                                                                         Apr 22, 2016    N/A                    N/A
   :pypi:`pytest-wirefracture`                              Pytest fixtures for wirefracture                                                                                                                                                                                                                                                                                                                                                        Dec 31, 2025    N/A                    N/A
   :pypi:`pytest-wiremock`                                  A pytest plugin for programmatically using wiremock in integration tests                                                                                                                                                                                                                                                                                                                Mar 27, 2022    N/A                    pytest (>=7.1.1,<8.0.0)
   :pypi:`pytest-wiretap`                                   \`pytest\` plugin for recording call stacks                                                                                                                                                                                                                                                                                                                                             Mar 18, 2025    N/A                    pytest
   :pypi:`pytest-with-docker`                               pytest with docker helpers.                                                                                                                                                                                                                                                                                                                                                             Nov 09, 2021    N/A                    pytest
   :pypi:`pytest-workaround-12888`                          forces an import of readline early in the process to work around pytest bug #12888                                                                                                                                                                                                                                                                                                      Jan 15, 2025    N/A                    N/A
   :pypi:`pytest-workflow`                                  A pytest plugin for configuring workflow/pipeline tests using YAML files                                                                                                                                                                                                                                                                                                                Mar 18, 2024    5 - Production/Stable  pytest >=7.0.0
   :pypi:`pytest-xdist`                                     pytest xdist plugin for distributed testing, most importantly across multiple CPUs                                                                                                                                                                                                                                                                                                      Jul 01, 2025    5 - Production/Stable  pytest>=7.0.0
   :pypi:`pytest-xdist-debug-for-graingert`                 pytest xdist plugin for distributed testing and loop-on-failing modes                                                                                                                                                                                                                                                                                                                   Jul 24, 2019    5 - Production/Stable  pytest (>=4.4.0)
   :pypi:`pytest-xdist-forked`                              forked from pytest-xdist                                                                                                                                                                                                                                                                                                                                                                Feb 10, 2020    5 - Production/Stable  pytest (>=4.4.0)
   :pypi:`pytest-xdist-gnumake`                             A small example package                                                                                                                                                                                                                                                                                                                                                                 Jun 22, 2025    N/A                    pytest
   :pypi:`pytest-xdist-load-testing`                        xdist scheduler to repeately run tests                                                                                                                                                                                                                                                                                                                                                  Nov 22, 2025    4 - Beta               pytest>=8.4.2
   :pypi:`pytest-xdist-rate-limit`                          Shared state management and rate limiting for pytest-xdist workers                                                                                                                                                                                                                                                                                                                      Dec 31, 2025    4 - Beta               pytest>=8.4.2
   :pypi:`pytest-xdist-tracker`                             pytest plugin helps to reproduce failures for particular xdist node                                                                                                                                                                                                                                                                                                                     Nov 18, 2021    3 - Alpha              pytest (>=3.5.1)
   :pypi:`pytest-xdist-worker-stats`                        A pytest plugin to list worker statistics after a xdist run.                                                                                                                                                                                                                                                                                                                            Feb 16, 2026    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-xdocker`                                   Pytest fixture to run docker across test runs.                                                                                                                                                                                                                                                                                                                                          May 21, 2026    N/A                    pytest>=9.0.0
   :pypi:`pytest-xfaillist`                                 Maintain a xfaillist in an additional file to avoid merge-conflicts.                                                                                                                                                                                                                                                                                                                    Sep 17, 2021    N/A                    pytest (>=6.2.2,<7.0.0)
   :pypi:`pytest-xfiles`                                    Pytest fixtures providing data read from function, module or package related (x)files.                                                                                                                                                                                                                                                                                                  Feb 27, 2018    N/A                    N/A
   :pypi:`pytest-xflaky`                                    A simple plugin to use with pytest                                                                                                                                                                                                                                                                                                                                                      Oct 14, 2024    4 - Beta               pytest>=8.2.1
   :pypi:`pytest-xhtml`                                     pytest plugin for generating HTML reports                                                                                                                                                                                                                                                                                                                                               May 23, 2026    5 - Production/Stable  pytest>=7
   :pypi:`pytest-xiuyu`                                     This is a pytest plugin                                                                                                                                                                                                                                                                                                                                                                 Jul 25, 2023    5 - Production/Stable  N/A
   :pypi:`pytest-xlog`                                      Extended logging for test and decorators                                                                                                                                                                                                                                                                                                                                                May 31, 2020    4 - Beta               N/A
   :pypi:`pytest-xlsx`                                      pytest plugin for generating test cases by xlsx(excel)                                                                                                                                                                                                                                                                                                                                  Aug 07, 2024    N/A                    pytest~=8.2.2
   :pypi:`pytest-xml`                                       Create simple XML results for parsing                                                                                                                                                                                                                                                                                                                                                   Nov 14, 2024    4 - Beta               pytest>=8.0.0
   :pypi:`pytest-xpara`                                     An extended parametrizing plugin of pytest.                                                                                                                                                                                                                                                                                                                                             Aug 07, 2024    3 - Alpha              pytest
   :pypi:`pytest-xprocess`                                  A pytest plugin for managing processes across test runs.                                                                                                                                                                                                                                                                                                                                May 19, 2024    4 - Beta               pytest>=2.8
   :pypi:`pytest-xray`                                                                                                                                                                                                                                                                                                                                                                                                                              May 30, 2019    3 - Alpha              N/A
   :pypi:`pytest-xrayjira`                                                                                                                                                                                                                                                                                                                                                                                                                          Mar 17, 2020    3 - Alpha              pytest (==4.3.1)
   :pypi:`pytest-xray-reporter`                             Pytest plugin for generating Xray JSON reports                                                                                                                                                                                                                                                                                                                                          May 21, 2025    4 - Beta               pytest>=7.0.0
   :pypi:`pytest-xray-server`                                                                                                                                                                                                                                                                                                                                                                                                                       May 03, 2022    3 - Alpha              pytest (>=5.3.1)
   :pypi:`pytest-xstress`                                                                                                                                                                                                                                                                                                                                                                                                                           Jun 01, 2024    N/A                    pytest<9.0.0,>=8.0.0
   :pypi:`pytest-xtime`                                     pytest plugin for recording execution time                                                                                                                                                                                                                                                                                                                                              Jun 05, 2025    4 - Beta               pytest
   :pypi:`pytest-xvfb`                                      A pytest plugin to run Xvfb (or Xephyr/Xvnc) for tests.                                                                                                                                                                                                                                                                                                                                 Mar 12, 2025    4 - Beta               pytest>=2.8.1
   :pypi:`pytest-xvirt`                                     A pytest plugin to virtualize test. For example to transparently running them on a remote box.                                                                                                                                                                                                                                                                                          Dec 15, 2024    4 - Beta               pytest>=7.2.2
   :pypi:`pytest-yaml`                                      This plugin is used to load yaml output to your test using pytest framework.                                                                                                                                                                                                                                                                                                            Oct 05, 2018    N/A                    pytest
   :pypi:`pytest-yaml-fei`                                  a pytest yaml allure package                                                                                                                                                                                                                                                                                                                                                            Jul 27, 2025    N/A                    pytest
   :pypi:`pytest-yaml-sanmu`                                Pytest plugin for generating test cases with YAML. In test cases, you can use markers, fixtures, variables, and even call Python functions.                                                                                                                                                                                                                                             Sep 16, 2025    N/A                    pytest>=8.2.2
   :pypi:`pytest-yamltree`                                  Create or check file/directory trees described by YAML                                                                                                                                                                                                                                                                                                                                  Mar 02, 2020    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-yamlwsgi`                                  Run tests against wsgi apps defined in yaml                                                                                                                                                                                                                                                                                                                                             May 11, 2010    N/A                    N/A
   :pypi:`pytest-yaml-yoyo`                                 http/https API run by yaml                                                                                                                                                                                                                                                                                                                                                              Jun 19, 2023    N/A                    pytest (>=7.2.0)
   :pypi:`pytest-yapf`                                      Run yapf                                                                                                                                                                                                                                                                                                                                                                                Jul 06, 2017    4 - Beta               pytest (>=3.1.1)
   :pypi:`pytest-yapf3`                                     Validate your Python file format with yapf                                                                                                                                                                                                                                                                                                                                              Mar 29, 2023    5 - Production/Stable  pytest (>=7)
   :pypi:`pytest-yield`                                     PyTest plugin to run tests concurrently, each \`yield\` switch context to other one                                                                                                                                                                                                                                                                                                     Jan 23, 2019    N/A                    N/A
   :pypi:`pytest-yls`                                       Pytest plugin to test the YLS as a whole.                                                                                                                                                                                                                                                                                                                                               Apr 09, 2025    N/A                    pytest<9.0.0,>=8.3.3
   :pypi:`pytest-youqu-playwright`                          pytest-youqu-playwright                                                                                                                                                                                                                                                                                                                                                                 Jun 12, 2024    N/A                    pytest
   :pypi:`pytest-yuk`                                       Display tests you are uneasy with, using 🤢/🤮 for pass/fail of tests marked with yuk.                                                                                                                                                                                                                                                                                                  Mar 26, 2021    N/A                    pytest>=5.0.0
   :pypi:`pytest-zafira`                                    A Zafira plugin for pytest                                                                                                                                                                                                                                                                                                                                                              Sep 18, 2019    5 - Production/Stable  pytest (==4.1.1)
   :pypi:`pytest-zap`                                       OWASP ZAP plugin for py.test.                                                                                                                                                                                                                                                                                                                                                           May 12, 2014    4 - Beta               N/A
   :pypi:`pytest-zcc`                                       eee                                                                                                                                                                                                                                                                                                                                                                                     Jun 02, 2024    N/A                    N/A
   :pypi:`pytest-zebrunner`                                 Pytest connector for Zebrunner reporting                                                                                                                                                                                                                                                                                                                                                Jul 04, 2024    5 - Production/Stable  pytest>=4.5.0
   :pypi:`pytest-zeebe`                                     Pytest fixtures for testing Camunda 8 processes using a Zeebe test engine.                                                                                                                                                                                                                                                                                                              Feb 01, 2024    N/A                    pytest (>=7.4.2,<8.0.0)
   :pypi:`pytest-zephyr-scale-integration`                  A library for integrating Jira Zephyr Scale (Adaptavist\TM4J) with pytest                                                                                                                                                                                                                                                                                                               Jun 26, 2025    N/A                    pytest
   :pypi:`pytest-zephyr-telegram`                           Плагин для отправки данных автотестов в Телеграм и Зефир                                                                                                                                                                                                                                                                                                                                Sep 30, 2024    N/A                    pytest==8.3.2
   :pypi:`pytest-zest`                                      Zesty additions to pytest.                                                                                                                                                                                                                                                                                                                                                              Nov 17, 2022    N/A                    N/A
   :pypi:`pytest-zigzag`                                    Extend py.test for RPC OpenStack testing.                                                                                                                                                                                                                                                                                                                                               Feb 27, 2019    4 - Beta               pytest (~=3.6)
   :pypi:`pytest-zulip`                                     Pytest report plugin for Zulip                                                                                                                                                                                                                                                                                                                                                          May 07, 2022    5 - Production/Stable  pytest
   :pypi:`pytest-zy`                                        接口自动化测试框架                                                                                                                                                                                                                                                                                                                                                                      Mar 24, 2024    N/A                    pytest~=7.2.0
   :pypi:`tursu`                                            🎬 A pytest plugin that transpiles Gherkin feature files to Python using AST, enforcing typing for ease of use and debugging.                                                                                                                                                                                                                                                           Mar 02, 2026    5 - Production/Stable  pytest>=8.3.5
   =======================================================  ======================================================================================================================================================================================================================================================================================================================================================================================  ==============  =====================  ================================================

.. only:: latex


  :pypi:`databricks-labs-pytester`
     *last release*: Oct 17, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3

     Python Testing for Databricks

  :pypi:`logassert`
     *last release*: Aug 14, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest; extra == "dev"

     Simple but powerful assertion and verification of logged lines

  :pypi:`logot`
     *last release*: Mar 31, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=7; extra == "pytest"

     Test whether your code is logging correctly 🪵

  :pypi:`nuts`
     *last release*: May 17, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0

     Network Unit Testing System

  :pypi:`pytest-abort`
     *last release*: Feb 11, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Pytest plugin + helpers for attributing hard crashes (SIGSEGV/SIGABRT) to the last running test and keeping pytest-html reports mergeable.

  :pypi:`pytest-abq`
     *last release*: Apr 07, 2023,
     *status*: N/A,
     *requires*: N/A

     Pytest integration for the ABQ universal test runner.

  :pypi:`pytest-abstracts`
     *last release*: May 15, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.4.0

     A pytest fixture for testing abstract interface implementations

  :pypi:`pytest-accept`
     *last release*: Mar 01, 2026,
     *status*: N/A,
     *requires*: pytest>=7



  :pypi:`pytest-adaptavist`
     *last release*: Oct 13, 2022,
     *status*: N/A,
     *requires*: pytest (>=5.4.0)

     pytest plugin for generating test execution results within Jira Test Management (tm4j)

  :pypi:`pytest-adaptavist-fixed`
     *last release*: Jan 17, 2025,
     *status*: N/A,
     *requires*: pytest>=5.4.0

     pytest plugin for generating test execution results within Jira Test Management (tm4j)

  :pypi:`pytest-adbc-replay`
     *last release*: Mar 13, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0

     pytest plugin to record and replay ADBC database queries

  :pypi:`pytest-addons-test`
     *last release*: Aug 02, 2021,
     *status*: N/A,
     *requires*: pytest (>=6.2.4,<7.0.0)

     用于测试pytest的插件

  :pypi:`pytest-adf`
     *last release*: May 10, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Pytest plugin for writing Azure Data Factory integration tests

  :pypi:`pytest-adf-azure-identity`
     *last release*: Mar 06, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Pytest plugin for writing Azure Data Factory integration tests

  :pypi:`pytest-adk`
     *last release*: Jun 06, 2026,
     *status*: 1 - Planning,
     *requires*: pytest>=8; extra == "dev"

     Helpers for testing agents with Google's adk-python

  :pypi:`pytest-ads-testplan`
     *last release*: Sep 15, 2022,
     *status*: N/A,
     *requires*: N/A

     Azure DevOps Test Case reporting for pytest tests

  :pypi:`pytest-adversarial`
     *last release*: Jan 22, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Generate adversarial pytest tests using LLM

  :pypi:`pytest-affected`
     *last release*: Nov 06, 2023,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-agent`
     *last release*: Nov 25, 2021,
     *status*: N/A,
     *requires*: N/A

     Service that exposes a REST API that can be used to interract remotely with Pytest. It is shipped with a dashboard that enables running tests in a more convenient way.

  :pypi:`pytest-agentcontract`
     *last release*: Feb 18, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Deterministic CI tests for LLM agent trajectories — record once, replay offline, assert contracts

  :pypi:`pytest-agent-digest`
     *last release*: May 02, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     A Pytest plugin to generate a Markdown report for AI Agents

  :pypi:`pytest-agent-eval`
     *last release*: Apr 30, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.4

     A pytest plugin for LLM evaluation tests with threshold-based pass/fail

  :pypi:`pytest-agent-evals`
     *last release*: Mar 13, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Pytest plugin for evaluating AI Agents

  :pypi:`pytest-agentharness`
     *last release*: Apr 20, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Open-source test harness for AI agents that take real-world actions.

  :pypi:`pytest-agent-health`
     *last release*: Apr 03, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Catch silent agent failures in CI. Behavior lint for LLM agents, powered by agent-failure-debugger.

  :pypi:`pytest-agentkit`
     *last release*: May 03, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Pytest plugin for testing AI agents — mock LLMs, assert tool calls, track tokens, regression-test prompts.

  :pypi:`pytest-agent-observability`
     *last release*: Apr 27, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     pytest plugin that uploads LiveKit-agents eval results to agent-observability

  :pypi:`pytest-agentprobe`
     *last release*: Jun 01, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     pytest-compatible test harness for AI agents — deterministic record & replay for Anthropic Claude

  :pypi:`pytest-agents`
     *last release*: Feb 20, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0.0

     Pytest plugin framework with AI agent capabilities for multi-agent testing

  :pypi:`pytest-aggreport`
     *last release*: Mar 07, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.2)

     pytest plugin for pytest-repeat that generate aggregate report of the same test cases with additional statistics details.

  :pypi:`pytest-ai`
     *last release*: Jan 22, 2025,
     *status*: N/A,
     *requires*: N/A

     A Python package to generate regular, edge-case, and security HTTP tests.

  :pypi:`pytest-ai1899`
     *last release*: Mar 13, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for connecting to ai1899 smart system stack

  :pypi:`pytest-aio`
     *last release*: Feb 12, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin for testing async python code

  :pypi:`pytest-aioboto3`
     *last release*: Jan 17, 2025,
     *status*: N/A,
     *requires*: N/A

     Aioboto3 Pytest with Moto

  :pypi:`pytest-aiofiles`
     *last release*: May 14, 2017,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest fixtures for writing aiofiles tests with pyfakefs

  :pypi:`pytest-aiogram`
     *last release*: May 06, 2023,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-aiohttp`
     *last release*: Jan 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.1.0

     Pytest plugin for aiohttp support

  :pypi:`pytest-aiohttp-client`
     *last release*: Jan 10, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.0,<8.0.0)

     Pytest \`client\` fixture for the Aiohttp

  :pypi:`pytest-aiohttp-mock`
     *last release*: Sep 13, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8

     Send responses to aiohttp.

  :pypi:`pytest-aiohutils`
     *last release*: Apr 23, 2026,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin providing fixtures and configuration for aiohutils projects (offline, record, cleanup modes).

  :pypi:`pytest-aiomoto`
     *last release*: Jun 24, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.0,<8.0)

     pytest-aiomoto

  :pypi:`pytest-aioresponses`
     *last release*: Jan 02, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     py.test integration for aioresponses

  :pypi:`pytest-aioworkers`
     *last release*: Dec 26, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.3.4

     A plugin to test aioworkers project with pytest

  :pypi:`pytest-airflow`
     *last release*: Apr 03, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=4.4.0)

     pytest support for airflow.

  :pypi:`pytest-airflow-utils`
     *last release*: Nov 15, 2021,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-alembic`
     *last release*: May 27, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin for verifying alembic migrations.

  :pypi:`pytest-alerts`
     *last release*: Feb 21, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.4.0

     A pytest plugin for sending test results to Slack and Telegram

  :pypi:`pytest-allclose`
     *last release*: Jul 30, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest fixture extending Numpy's allclose function

  :pypi:`pytest-allure-adaptor`
     *last release*: Jan 10, 2018,
     *status*: N/A,
     *requires*: pytest (>=2.7.3)

     Plugin for py.test to generate allure xml reports

  :pypi:`pytest-allure-adaptor2`
     *last release*: Oct 14, 2020,
     *status*: N/A,
     *requires*: pytest (>=2.7.3)

     Plugin for py.test to generate allure xml reports

  :pypi:`pytest-allure-collection`
     *last release*: Apr 13, 2023,
     *status*: N/A,
     *requires*: pytest

     pytest plugin to collect allure markers without running any tests

  :pypi:`pytest-allure-dsl`
     *last release*: Oct 25, 2020,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin to test case doc string dls instructions

  :pypi:`pytest-allure-host`
     *last release*: Nov 03, 2025,
     *status*: 3 - Alpha,
     *requires*: N/A

     Publish Allure static reports to private S3 behind CloudFront with history preservation

  :pypi:`pytest-allure-id2history`
     *last release*: May 14, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Overwrite allure history id with testcase full name and testcase id if testcase has id, exclude parameters.

  :pypi:`pytest-allure-intersection`
     *last release*: Oct 27, 2022,
     *status*: N/A,
     *requires*: pytest (<5)



  :pypi:`pytest-allure-spec-coverage`
     *last release*: Oct 26, 2021,
     *status*: N/A,
     *requires*: pytest

     The pytest plugin aimed to display test coverage of the specs(requirements) in Allure

  :pypi:`pytest-allure-step`
     *last release*: Jul 13, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.0.0

     Enhanced logging integration with Allure reports for pytest

  :pypi:`pytest-alphamoon`
     *last release*: Dec 30, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.5.0)

     Static code checks used at Alphamoon

  :pypi:`pytest-amaranth-sim`
     *last release*: Feb 18, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Fixture to automate running Amaranth simulations

  :pypi:`pytest-ampel-core`
     *last release*: Dec 17, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin to provide AmpelContext fixtures in pytest

  :pypi:`pytest-analyzer`
     *last release*: Feb 21, 2024,
     *status*: N/A,
     *requires*: pytest <8.0.0,>=7.3.1

     this plugin allows to analyze tests in pytest project, collect test metadata and sync it with testomat.io TCM system

  :pypi:`pytest-android`
     *last release*: Feb 21, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest

     This fixture provides a configured "driver" for Android Automated Testing, using uiautomator2.

  :pypi:`pytest-anki`
     *last release*: Jul 31, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin for testing Anki add-ons

  :pypi:`pytest-annotate`
     *last release*: Jun 07, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest (<8.0.0,>=3.2.0)

     pytest-annotate: Generate PyAnnotate annotations from your pytest tests.

  :pypi:`pytest-annotated`
     *last release*: Sep 30, 2024,
     *status*: N/A,
     *requires*: pytest>=8.3.3

     Pytest plugin to allow use of Annotated in tests to resolve fixtures

  :pypi:`pytest-ansible`
     *last release*: Apr 01, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6

     Plugin for pytest to simplify calling ansible modules from tests or fixtures

  :pypi:`pytest-ansible-playbook`
     *last release*: Mar 08, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest fixture which runs given ansible playbook file.

  :pypi:`pytest-ansible-playbook-runner`
     *last release*: Dec 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.0)

     Pytest fixture which runs given ansible playbook file.

  :pypi:`pytest-ansible-units`
     *last release*: Apr 14, 2022,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for running unit tests within an ansible collection

  :pypi:`pytest-antilru`
     *last release*: May 03, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<9,>=3; python_version == "3.9"

     Bust functools.lru_cache when running pytest to avoid test pollution

  :pypi:`pytest-anyio`
     *last release*: Jun 29, 2021,
     *status*: N/A,
     *requires*: pytest

     The pytest anyio plugin is built into anyio. You don't need this package.

  :pypi:`pytest-anything`
     *last release*: Jan 18, 2024,
     *status*: N/A,
     *requires*: pytest

     Pytest fixtures to assert anything and something

  :pypi:`pytest-aoc`
     *last release*: Dec 02, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest ; extra == 'test'

     Downloads puzzle inputs for Advent of Code and synthesizes PyTest fixtures

  :pypi:`pytest-aoreporter`
     *last release*: Jun 27, 2022,
     *status*: N/A,
     *requires*: N/A

     pytest report

  :pypi:`pytest-api`
     *last release*: May 12, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.1,<8.0.0)

     An ASGI middleware to populate OpenAPI Specification examples from pytest functions

  :pypi:`pytest-apibean`
     *last release*: Dec 30, 2025,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin providing apibean-based API testing fixtures integrated with apibean-client, designed for testing apibean REST services and datacore backends.

  :pypi:`pytest-api-contract`
     *last release*: Jun 05, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     pytest plugin for automated API contract testing from OpenAPI specs

  :pypi:`pytest-api-core`
     *last release*: Jun 01, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.4

     Pytest API automation framework with custom HTML reporting, reusable fixtures, and fluent assertions

  :pypi:`pytest-api-cov`
     *last release*: May 04, 2026,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     Pytest Plugin to provide API Coverage statistics for Python Web Frameworks

  :pypi:`pytest-api-coverage`
     *last release*: Mar 24, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Pytest plugin for API test coverage analysis

  :pypi:`pytest-api-framework`
     *last release*: Jun 22, 2025,
     *status*: N/A,
     *requires*: pytest==7.2.2

     pytest framework

  :pypi:`pytest-api-framework-alpha`
     *last release*: Apr 14, 2026,
     *status*: N/A,
     *requires*: pytest==7.2.2



  :pypi:`pytest-api-kit`
     *last release*: Apr 23, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0

     Pragmatic scaffolding for API smoke / regression tests — zero-dep schema, snapshot drift, HTML reports, AWS ECS deploy.

  :pypi:`pytest-api-soup`
     *last release*: Aug 27, 2022,
     *status*: N/A,
     *requires*: N/A

     Validate multiple endpoints with unit testing using a single source of truth.

  :pypi:`pytest-apistellar`
     *last release*: Jun 18, 2019,
     *status*: N/A,
     *requires*: N/A

     apistellar plugin for pytest.

  :pypi:`pytest-apiver`
     *last release*: Jun 21, 2024,
     *status*: N/A,
     *requires*: pytest



  :pypi:`pytest-appengine`
     *last release*: Feb 27, 2017,
     *status*: N/A,
     *requires*: N/A

     AppEngine integration that works well with pytest-django

  :pypi:`pytest-appium`
     *last release*: Dec 05, 2019,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for appium

  :pypi:`pytest-appium-scheduler`
     *last release*: Apr 13, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin for Appium device scheduling and driver lifecycle management.

  :pypi:`pytest-approval`
     *last release*: May 05, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.3

     A simple approval test library utilizing external diff programs such as PyCharm and Visual Studio Code to compare approved and received output.

  :pypi:`pytest-approvaltests`
     *last release*: May 08, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.0.1)

     A plugin to use approvaltests with pytest

  :pypi:`pytest-approvaltests-geo`
     *last release*: Apr 29, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Extension for ApprovalTests.Python specific to geo data verification

  :pypi:`pytest-archon`
     *last release*: Sep 19, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.2

     Rule your architecture like a real developer

  :pypi:`pytest-argus`
     *last release*: Jun 24, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=6.2.4)

     pyest results colection plugin

  :pypi:`pytest-argus-reporter`
     *last release*: May 26, 2026,
     *status*: 4 - Beta,
     *requires*: pytest~=9.0.0; extra == "dev"

     A simple plugin to report results of test into argus

  :pypi:`pytest-argus-server`
     *last release*: Mar 05, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin that provides a running Argus API server for tests

  :pypi:`pytest-arrakis`
     *last release*: Jun 02, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin providing Arrakis fixtures for testing

  :pypi:`pytest-arraydiff`
     *last release*: Jun 02, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2

     pytest plugin to help with comparing array output from tests

  :pypi:`pytest-artifacts`
     *last release*: May 14, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Pytest plugin for managing test artifacts

  :pypi:`pytest-asdf-plugin`
     *last release*: Jun 04, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     Pytest plugin for testing ASDF schemas

  :pypi:`pytest-asgi-server`
     *last release*: Dec 12, 2020,
     *status*: N/A,
     *requires*: pytest (>=5.4.1)

     Convenient ASGI client/server fixtures for Pytest

  :pypi:`pytest-aspec`
     *last release*: Dec 20, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     A rspec format reporter for pytest

  :pypi:`pytest-asptest`
     *last release*: Apr 28, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     test Answer Set Programming programs

  :pypi:`pytest-assay`
     *last release*: Mar 30, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     Evaluation framework for Pydantic AI agents

  :pypi:`pytest-assertcount`
     *last release*: Oct 23, 2022,
     *status*: N/A,
     *requires*: pytest (>=5.0.0)

     Plugin to count actual number of asserts in pytest

  :pypi:`pytest-assertions`
     *last release*: Apr 27, 2022,
     *status*: N/A,
     *requires*: N/A

     Pytest Assertions

  :pypi:`pytest-assert-type`
     *last release*: Oct 26, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.2.0

     Use typing.assert_type() to test runtime behavior

  :pypi:`pytest-assertutil`
     *last release*: May 10, 2019,
     *status*: N/A,
     *requires*: N/A

     pytest-assertutil

  :pypi:`pytest-assert-utils`
     *last release*: Apr 14, 2022,
     *status*: 3 - Alpha,
     *requires*: N/A

     Useful assertion utilities for use with pytest

  :pypi:`pytest-assist`
     *last release*: Oct 29, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin library

  :pypi:`pytest-assume`
     *last release*: Jun 24, 2021,
     *status*: N/A,
     *requires*: pytest (>=2.7)

     A pytest plugin that allows multiple failures per test

  :pypi:`pytest-assurka`
     *last release*: Aug 04, 2022,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for Assurka Studio

  :pypi:`pytest-ast-back-to-python`
     *last release*: Sep 29, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     A plugin for pytest devs to view how assertion rewriting recodes the AST

  :pypi:`pytest-asteroid`
     *last release*: Aug 15, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.5,<8.0.0)

     PyTest plugin for docker-based testing on database images

  :pypi:`pytest-astropy`
     *last release*: Sep 26, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=4.6

     Meta-package containing dependencies for testing

  :pypi:`pytest-astropy-header`
     *last release*: Sep 06, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest (>=4.6)

     pytest plugin to add diagnostic information to the header of the test output

  :pypi:`pytest-ast-transformer`
     *last release*: May 04, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest



  :pypi:`pytest_async`
     *last release*: Feb 26, 2020,
     *status*: N/A,
     *requires*: N/A

     pytest-async - Run your coroutine in event loop without decorator

  :pypi:`pytest-async-benchmark`
     *last release*: May 28, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.5

     pytest-async-benchmark: Modern pytest benchmarking for async code. 🚀

  :pypi:`pytest-async-generators`
     *last release*: Jul 05, 2023,
     *status*: N/A,
     *requires*: N/A

     Pytest fixtures for async generators

  :pypi:`pytest-asyncio`
     *last release*: May 26, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=8.4

     Pytest support for asyncio

  :pypi:`pytest-asyncio-concurrent`
     *last release*: Apr 09, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Pytest plugin to execute python async tests concurrently.

  :pypi:`pytest-asyncio-cooperative`
     *last release*: Jun 24, 2025,
     *status*: N/A,
     *requires*: N/A

     Run all your asynchronous tests cooperatively.

  :pypi:`pytest-asyncio-network-simulator`
     *last release*: Jul 31, 2018,
     *status*: 3 - Alpha,
     *requires*: pytest (<3.7.0,>=3.3.2)

     pytest-asyncio-network-simulator: Plugin for pytest for simulator the network in tests

  :pypi:`pytest-async-mongodb`
     *last release*: Oct 18, 2017,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.5.2)

     pytest plugin for async MongoDB

  :pypi:`pytest-async-sqlalchemy`
     *last release*: Oct 07, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0.0)

     Database testing fixtures using the SQLAlchemy asyncio API

  :pypi:`pytest-atf-allure`
     *last release*: Nov 29, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.4.2,<8.0.0)

     基于allure-pytest进行自定义

  :pypi:`pytest-atomic`
     *last release*: Nov 24, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     Skip rest of tests if previous test failed.

  :pypi:`pytest-atstack`
     *last release*: Jan 02, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A simple plugin to use with pytest

  :pypi:`pytest-attempt-summary`
     *last release*: Jan 04, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Enhanced Allure Attempt Summary for Playwright + Pytest

  :pypi:`pytest-attrib`
     *last release*: May 24, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin to select tests based on attributes similar to the nose-attrib plugin

  :pypi:`pytest-attributes`
     *last release*: Jun 24, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin that allows users to add attributes to their tests. These attributes can then be referenced by fixtures or the test itself.

  :pypi:`pytest-audioeval`
     *last release*: Mar 18, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0

     Pytest plugin for STT/TTS integration testing with httpx, metrics, and embedded audio samples.

  :pypi:`pytest-austin`
     *last release*: Oct 11, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     Austin plugin for pytest

  :pypi:`pytest-auto-api2-cli`
     *last release*: Mar 26, 2026,
     *status*: N/A,
     *requires*: pytest==8.4.1

     CLI for generating and running pytest-auto-api2 test cases.

  :pypi:`pytest-autocap`
     *last release*: May 15, 2022,
     *status*: N/A,
     *requires*: pytest (<7.2,>=7.1.2)

     automatically capture test & fixture stdout/stderr to files

  :pypi:`pytest-autochecklog`
     *last release*: Apr 25, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     automatically check condition and log all the checks

  :pypi:`pytest-autofixture`
     *last release*: Aug 01, 2024,
     *status*: N/A,
     *requires*: pytest>=8

     simplify pytest fixtures

  :pypi:`pytest-autofocus`
     *last release*: Dec 02, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Auto-focus plugin: run only @pytest.mark.focus tests when --auto-focus is set

  :pypi:`pytest-automation`
     *last release*: Apr 24, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     pytest plugin for building a test suite, using YAML files to extend pytest parameterize functionality.

  :pypi:`pytest-automock`
     *last release*: May 16, 2023,
     *status*: N/A,
     *requires*: pytest ; extra == 'dev'

     Pytest plugin for automatical mocks creation

  :pypi:`pytest-auto-parametrize`
     *last release*: Oct 02, 2016,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin: avoid repeating arguments in parametrize

  :pypi:`pytest-autoprofile`
     *last release*: Mar 13, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     \`line_profiler.autoprofile\`-ing your \`pytest\` test suite

  :pypi:`pytest-autotest`
     *last release*: Aug 25, 2021,
     *status*: N/A,
     *requires*: pytest

     This fixture provides a configured "driver" for Android Automated Testing, using uiautomator2.

  :pypi:`pytest-aviator`
     *last release*: Nov 04, 2022,
     *status*: 4 - Beta,
     *requires*: pytest

     Aviator's Flakybot pytest plugin that automatically reruns flaky tests.

  :pypi:`pytest-avoidance`
     *last release*: May 23, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Makes pytest skip tests that don not need rerunning

  :pypi:`pytest-awaiting-fix`
     *last release*: Aug 09, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A simple plugin to use with pytest for traceability across Jira and disabled automated tests

  :pypi:`pytest-aws`
     *last release*: Oct 04, 2017,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin for testing AWS resource configurations

  :pypi:`pytest-aws-apigateway`
     *last release*: May 24, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin for AWS ApiGateway

  :pypi:`pytest-aws-config`
     *last release*: May 28, 2021,
     *status*: N/A,
     *requires*: N/A

     Protect your AWS credentials in unit tests

  :pypi:`pytest-aws-fixtures`
     *last release*: Nov 11, 2025,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=8.0.0

     A series of fixtures to use in integration tests involving actual AWS services.

  :pypi:`pytest-aws-fixtures-293984`
     *last release*: Dec 04, 2025,
     *status*: 3 - Alpha,
     *requires*: N/A

     AWS configuration utilities for Python applications

  :pypi:`pytest-axe`
     *last release*: Nov 12, 2018,
     *status*: N/A,
     *requires*: pytest (>=3.0.0)

     pytest plugin for axe-selenium-python

  :pypi:`pytest-axe-playwright-snapshot`
     *last release*: Jul 25, 2023,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin that runs Axe-core on Playwright pages and takes snapshots of the results.

  :pypi:`pytest-azure`
     *last release*: Jan 18, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest utilities and mocks for Azure

  :pypi:`pytest-azure-devops`
     *last release*: Jul 16, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     Simplifies using azure devops parallel strategy (https://docs.microsoft.com/en-us/azure/devops/pipelines/test/parallel-testing-any-test-runner) with pytest.

  :pypi:`pytest-azurepipelines`
     *last release*: Oct 06, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.0.0)

     Formatting PyTest output for Azure Pipelines UI

  :pypi:`pytest-balance`
     *last release*: Apr 09, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8

     Intelligent test distribution for pytest based on actual execution times, not file count

  :pypi:`pytest-bandit`
     *last release*: Feb 23, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A bandit plugin for pytest

  :pypi:`pytest-bandit-xayon`
     *last release*: Oct 17, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A bandit plugin for pytest

  :pypi:`pytest-base-url`
     *last release*: Jan 31, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest plugin for URL based testing

  :pypi:`pytest-bashdoctest`
     *last release*: Oct 03, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin for testing bash command examples in markdown documentation

  :pypi:`pytest-batch-regression`
     *last release*: May 08, 2024,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     A pytest plugin to repeat the entire test suite in batches.

  :pypi:`pytest-bazel`
     *last release*: Oct 31, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     A pytest runner with bazel support

  :pypi:`pytest-bdd`
     *last release*: Dec 05, 2024,
     *status*: 6 - Mature,
     *requires*: pytest>=7.0.0

     BDD for pytest

  :pypi:`pytest-bdd-html`
     *last release*: Nov 22, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest (!=6.0.0,>=5.0)

     pytest plugin to display BDD info in HTML test report

  :pypi:`pytest-bdd-md-report`
     *last release*: Feb 07, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Markdown test report formatter for pytest-bdd with pytest-playwright screenshot support

  :pypi:`pytest-bdd-ng`
     *last release*: Nov 26, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=5.2

     BDD for pytest

  :pypi:`pytest-bdd-property`
     *last release*: Mar 12, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0

     Property-based testing plugin for pytest-bdd — express universal invariants in standard Gherkin, executed by Hypothesis

  :pypi:`pytest-bdd-report`
     *last release*: Dec 29, 2025,
     *status*: N/A,
     *requires*: pytest>=7.1.3

     A pytest-bdd plugin for generating useful and informative BDD test reports

  :pypi:`pytest-bdd-reporter`
     *last release*: Oct 14, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0.0

     Enterprise-grade BDD test reporting with interactive dashboards, suite management, and comprehensive email integration

  :pypi:`pytest-bdd-splinter`
     *last release*: Aug 12, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.0.0)

     Common steps for pytest bdd and splinter integration

  :pypi:`pytest-bdd-web`
     *last release*: Jan 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to use with pytest

  :pypi:`pytest-bdd-wrappers`
     *last release*: Feb 11, 2020,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A



  :pypi:`pytest-beacon`
     *last release*: May 11, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=9.0.0

     Highly customizable pytest reporting plugin combining AI-optimized CTRF reports and rich test metrics

  :pypi:`pytest-beakerlib`
     *last release*: Mar 17, 2017,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A pytest plugin that reports test results to the BeakerLib framework

  :pypi:`pytest-beartype`
     *last release*: Oct 31, 2024,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin to run your tests with beartype checking enabled.

  :pypi:`pytest-beartype-tests`
     *last release*: Apr 26, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8

     Pytest plugin that applies @beartype to every collected test function.

  :pypi:`pytest-bec-e2e`
     *last release*: Jun 05, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest

     BEC pytest plugin for end-to-end tests

  :pypi:`pytest-beds`
     *last release*: Jun 07, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Fixtures for testing Google Appengine (GAE) apps

  :pypi:`pytest-beehave`
     *last release*: May 20, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.3; extra == "dev"

     A pytest plugin that generates test stubs from Gherkin feature files, checks consistency, and displays BDD steps in pytest output

  :pypi:`pytest-beeprint`
     *last release*: Jul 04, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     use icdiff for better error messages in pytest assertions

  :pypi:`pytest-bench`
     *last release*: Jul 21, 2014,
     *status*: 3 - Alpha,
     *requires*: N/A

     Benchmark utility that plugs into pytest.

  :pypi:`pytest-benchmark`
     *last release*: Nov 09, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.1

     A \`\`pytest\`\` fixture for benchmarking code. It will group the tests into rounds that are calibrated to the chosen timer.

  :pypi:`pytest-better-datadir`
     *last release*: Mar 13, 2023,
     *status*: N/A,
     *requires*: N/A

     A small example package

  :pypi:`pytest-better-parametrize`
     *last release*: Mar 05, 2024,
     *status*: 4 - Beta,
     *requires*: pytest >=6.2.0

     Better description of parametrized test cases

  :pypi:`pytest-bg-process`
     *last release*: Jan 24, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Pytest plugin to initialize background process

  :pypi:`pytest-bigchaindb`
     *last release*: Jan 24, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     A BigchainDB plugin for pytest.

  :pypi:`pytest-bigquery-mock`
     *last release*: Dec 28, 2022,
     *status*: N/A,
     *requires*: pytest (>=5.0)

     Provides a mock fixture for python bigquery client

  :pypi:`pytest-bisect-tests`
     *last release*: Jun 09, 2024,
     *status*: N/A,
     *requires*: N/A

     Find tests leaking state and affecting other

  :pypi:`pytest-black`
     *last release*: Dec 15, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin to enable format checking with black

  :pypi:`pytest-black-multipy`
     *last release*: Jan 14, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (!=3.7.3,>=3.5) ; extra == 'testing'

     Allow '--black' on older Pythons

  :pypi:`pytest-black-ng`
     *last release*: Oct 20, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.0.0)

     A pytest plugin to enable format checking with black

  :pypi:`pytest-blame`
     *last release*: May 04, 2019,
     *status*: N/A,
     *requires*: pytest (>=4.4.0)

     A pytest plugin helps developers to debug by providing useful commits history.

  :pypi:`pytest-blender`
     *last release*: Apr 18, 2026,
     *status*: N/A,
     *requires*: pytest

     Blender Pytest plugin.

  :pypi:`pytest-blink1`
     *last release*: Jan 07, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest plugin to emit notifications via the Blink(1) RGB LED

  :pypi:`pytest-blockage`
     *last release*: Dec 21, 2021,
     *status*: N/A,
     *requires*: pytest

     Disable network requests during a test run.

  :pypi:`pytest-blocker`
     *last release*: Sep 07, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin to mark a test as blocker and skip all other tests

  :pypi:`pytest-b-logger`
     *last release*: Dec 16, 2025,
     *status*: N/A,
     *requires*: pytest

     BLogger is a Pytest plugin for enhanced test logging and generating convenient and lightweight reports.

  :pypi:`pytest-blue`
     *last release*: Sep 05, 2022,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin that adds a \`blue\` fixture for printing stuff in blue.

  :pypi:`pytest-bluezenv`
     *last release*: May 12, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8

     pytest BlueZ environment plugin

  :pypi:`pytest-board`
     *last release*: Jan 20, 2019,
     *status*: N/A,
     *requires*: N/A

     Local continuous test runner with pytest and watchdog.

  :pypi:`pytest_boardfarm3`
     *last release*: May 13, 2026,
     *status*: N/A,
     *requires*: pytest

     Integrate boardfarm as a pytest plugin.

  :pypi:`pytest-bods-v04-fixtures`
     *last release*: Apr 20, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin providing a parametrized fixture over the canonical BODS v0.4 fixtures pack

  :pypi:`pytest-boilerplate`
     *last release*: Sep 12, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=4.0.0

     The pytest plugin for your Django Boilerplate.

  :pypi:`pytest-bonsai`
     *last release*: Apr 08, 2025,
     *status*: N/A,
     *requires*: pytest>=6



  :pypi:`pytest-boost-xml`
     *last release*: Nov 30, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Plugin for pytest to generate boost xml reports

  :pypi:`pytest-bootstrap`
     *last release*: Mar 04, 2022,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-boto-mock`
     *last release*: Jan 20, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.2.0

     Thin-wrapper around the mock package for easier use with pytest

  :pypi:`pytest-bpdb`
     *last release*: Jan 19, 2015,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     A py.test plug-in to enable drop to bpdb debugger on test failure.

  :pypi:`pytest-bq`
     *last release*: May 08, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2

     BigQuery fixtures and fixture factories for Pytest.

  :pypi:`pytest-bravado`
     *last release*: Feb 15, 2022,
     *status*: N/A,
     *requires*: N/A

     Pytest-bravado automatically generates from OpenAPI specification client fixtures.

  :pypi:`pytest-breadcrumb`
     *last release*: Mar 09, 2026,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest>=8.0; extra == "dev"

     Self-healing test framework for Playwright. Your tests survive app changes.

  :pypi:`pytest-breakword`
     *last release*: Aug 04, 2021,
     *status*: N/A,
     *requires*: pytest (>=6.2.4,<7.0.0)

     Use breakword with pytest

  :pypi:`pytest-breed-adapter`
     *last release*: Nov 07, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to connect with breed-server

  :pypi:`pytest-briefcase`
     *last release*: Jun 14, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin for running tests on a Briefcase project.

  :pypi:`pytest-brightest`
     *last release*: Jul 15, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.4.1

     Bright ideas for improving your pytest experience

  :pypi:`pytest-broadcaster`
     *last release*: Mar 02, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin to broadcast pytest output to various destinations

  :pypi:`pytest-browser`
     *last release*: Dec 10, 2016,
     *status*: 3 - Alpha,
     *requires*: N/A

     A pytest plugin for console based browser test selection just after the collection phase

  :pypi:`pytest-browsermob-proxy`
     *last release*: Jun 11, 2013,
     *status*: 4 - Beta,
     *requires*: N/A

     BrowserMob proxy plugin for py.test.

  :pypi:`pytest_browserstack`
     *last release*: Jan 27, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Py.test plugin for BrowserStack

  :pypi:`pytest-browserstack-local`
     *last release*: Feb 09, 2018,
     *status*: N/A,
     *requires*: N/A

     \`\`py.test\`\` plugin to run \`\`BrowserStackLocal\`\` in background.

  :pypi:`pytest-budosystems`
     *last release*: May 07, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest

     Budo Systems is a martial arts school management system. This module is the Budo Systems Pytest Plugin.

  :pypi:`pytest-bug`
     *last release*: Dec 30, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.0

     Pytest plugin for marking tests as a bug

  :pypi:`pytest-bugtong-tag`
     *last release*: Jan 16, 2022,
     *status*: N/A,
     *requires*: N/A

     pytest-bugtong-tag is a plugin for pytest

  :pypi:`pytest-bugzilla`
     *last release*: May 05, 2010,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test bugzilla integration plugin

  :pypi:`pytest-bugzilla-notifier`
     *last release*: Jun 15, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.9.2)

     A plugin that allows you to execute create, update, and read information from BugZilla bugs

  :pypi:`pytest-buildkite`
     *last release*: Jul 13, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Plugin for pytest that automatically publishes coverage and pytest report annotations to Buildkite.

  :pypi:`pytest-builtin-types`
     *last release*: Nov 17, 2021,
     *status*: N/A,
     *requires*: pytest



  :pypi:`pytest-bwrap`
     *last release*: Feb 25, 2024,
     *status*: 3 - Alpha,
     *requires*: N/A

     Run your tests in Bubblewrap sandboxes

  :pypi:`pytest-cache`
     *last release*: Jun 04, 2013,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin with mechanisms for caching across test runs

  :pypi:`pytest-cache-assert`
     *last release*: Aug 14, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=6.0.0)

     Cache assertion data to simplify regression testing of complex serializable data

  :pypi:`pytest-cagoule`
     *last release*: Jan 01, 2020,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest plugin to only run tests affected by changes

  :pypi:`pytest-cairo`
     *last release*: Apr 17, 2022,
     *status*: N/A,
     *requires*: pytest

     Pytest support for cairo-lang and starknet

  :pypi:`pytest-call-checker`
     *last release*: Oct 16, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.1.3,<8.0.0)

     Small pytest utility to easily create test doubles

  :pypi:`pytest-camel-collect`
     *last release*: Aug 02, 2020,
     *status*: N/A,
     *requires*: pytest (>=2.9)

     Enable CamelCase-aware pytest class collection

  :pypi:`pytest-canonical-data`
     *last release*: May 08, 2020,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest (>=3.5.0)

     A plugin which allows to compare results with canonical results, based on previous runs

  :pypi:`pytest-canvas`
     *last release*: Jul 22, 2025,
     *status*: N/A,
     *requires*: pytest<9,>=8.4

     A minimal pytest plugin that streamlines testing for projects using the Canvas SDK.

  :pypi:`pytest-capquery`
     *last release*: Apr 04, 2026,
     *status*: N/A,
     *requires*: pytest

     A pytest fixture for high-precision SQL testing in SQLAlchemy.

  :pypi:`pytest-caprng`
     *last release*: May 02, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     A plugin that replays pRNG state on failure.

  :pypi:`pytest-capsqlalchemy`
     *last release*: Mar 19, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest plugin to allow capturing SQLAlchemy queries.

  :pypi:`pytest-capture-deprecatedwarnings`
     *last release*: Apr 30, 2019,
     *status*: N/A,
     *requires*: N/A

     pytest plugin to capture all deprecatedwarnings and put them in one file

  :pypi:`pytest-capture-warnings`
     *last release*: May 03, 2022,
     *status*: N/A,
     *requires*: pytest

     pytest plugin to capture all warnings and put them in one file of your choice

  :pypi:`pytest-case`
     *last release*: Nov 25, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.3

     A clean, modern, wrapper for pytest.mark.parametrize

  :pypi:`pytest-case-provider`
     *last release*: Dec 15, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8

     Advanced pytest parametrization plugin that generates test case instances from sync or async factories.

  :pypi:`pytest-cases`
     *last release*: Mar 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Separate test code from test cases in pytest.

  :pypi:`pytest-case-start-from`
     *last release*: Oct 28, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0.0

     A pytest plugin to start test execution from a specific test case

  :pypi:`pytest-casewise-package-install`
     *last release*: Oct 31, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.0.0

     A pytest plugin for test case-level dynamic dependency management

  :pypi:`pytest-cassandra`
     *last release*: Nov 04, 2017,
     *status*: 1 - Planning,
     *requires*: N/A

     Cassandra CCM Test Fixtures for pytest

  :pypi:`pytest-catchlog`
     *last release*: Jan 24, 2016,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.6)

     py.test plugin to catch log messages. This is a fork of pytest-capturelog.

  :pypi:`pytest-catch-server`
     *last release*: Dec 12, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin with server for catching HTTP requests.

  :pypi:`pytest-cdist`
     *last release*: Jan 08, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     A pytest plugin to split your test suite into multiple parts

  :pypi:`pytest-celery`
     *last release*: Mar 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin for Celery

  :pypi:`pytest-celery-py37`
     *last release*: May 23, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin for Celery (compatible with python 3.7)

  :pypi:`pytest-celery-utils`
     *last release*: Jan 28, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.1

     Pytest plugin for inspecting Celery task queues in Redis during tests

  :pypi:`pytest-cfg-fetcher`
     *last release*: Feb 26, 2024,
     *status*: N/A,
     *requires*: N/A

     Pass config options to your unit tests.

  :pypi:`pytest-chainmaker`
     *last release*: Oct 15, 2021,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for chainmaker

  :pypi:`pytest-chalice`
     *last release*: Jul 01, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     A set of py.test fixtures for AWS Chalice

  :pypi:`pytest-change-assert`
     *last release*: Oct 19, 2022,
     *status*: N/A,
     *requires*: N/A

     修改报错中文为英文

  :pypi:`pytest-changed`
     *last release*: May 28, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0

     Run pytest for tests related to staged Python files in pre-commit.

  :pypi:`pytest-change-demo`
     *last release*: Mar 02, 2022,
     *status*: N/A,
     *requires*: pytest

     turn . into √，turn F into x

  :pypi:`pytest-change-report`
     *last release*: Sep 14, 2020,
     *status*: N/A,
     *requires*: pytest

     turn . into √，turn F into x

  :pypi:`pytest-change-xds`
     *last release*: Apr 16, 2022,
     *status*: N/A,
     *requires*: pytest

     turn . into √，turn F into x

  :pypi:`pytest-chdir`
     *last release*: Jan 28, 2020,
     *status*: N/A,
     *requires*: pytest (>=5.0.0,<6.0.0)

     A pytest fixture for changing current working directory

  :pypi:`pytest-check`
     *last release*: Mar 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     A pytest plugin that allows multiple failures per test.

  :pypi:`pytest-checkdocs`
     *last release*: Dec 26, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest!=8.1.*,>=6; extra == "test"

     check the README when running tests

  :pypi:`pytest-checkers`
     *last release*: Dec 27, 2025,
     *status*: N/A,
     *requires*: pytest>=9.0.2

     Pytest Plugin for dry-run checks LSPs, Type Checkers, Linters, and Formatters during testing

  :pypi:`pytest-checkipdb`
     *last release*: Dec 04, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=2.9.2

     plugin to check if there are ipdb debugs left

  :pypi:`pytest-check-library`
     *last release*: Jul 17, 2022,
     *status*: N/A,
     *requires*: N/A

     check your missing library

  :pypi:`pytest-check-libs`
     *last release*: Jul 17, 2022,
     *status*: N/A,
     *requires*: N/A

     check your missing library

  :pypi:`pytest-check-links`
     *last release*: Jul 29, 2020,
     *status*: N/A,
     *requires*: pytest<9,>=7.0

     Check links in files

  :pypi:`pytest-checklist`
     *last release*: May 23, 2025,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to track and report unit/function coverage.

  :pypi:`pytest-check-mk`
     *last release*: Nov 19, 2015,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin to test Check_MK checks

  :pypi:`pytest-checkpoint`
     *last release*: Oct 04, 2025,
     *status*: N/A,
     *requires*: pytest>=8.0.0

     Restore a checkpoint in pytest

  :pypi:`pytest-ch-framework`
     *last release*: Apr 17, 2024,
     *status*: N/A,
     *requires*: pytest==8.0.1

     My pytest framework

  :pypi:`pytest-chic-report`
     *last release*: Nov 01, 2024,
     *status*: N/A,
     *requires*: pytest>=6.0

     Simple pytest plugin for generating and sending report to messengers.

  :pypi:`pytest-chinesereport`
     *last release*: Apr 16, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0



  :pypi:`pytest-choose`
     *last release*: Feb 04, 2024,
     *status*: N/A,
     *requires*: pytest >=7.0.0

     Provide the pytest with the ability to collect use cases based on rules in text files

  :pypi:`pytest-chronicle`
     *last release*: Dec 15, 2025,
     *status*: N/A,
     *requires*: pytest>=8.0; extra == "dev"

     Reusable pytest results ingestion tooling with database export and CLI helpers.

  :pypi:`pytest-chunks`
     *last release*: Jul 05, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.0.0)

     Run only a chunk of your test suite

  :pypi:`pytest_cid`
     *last release*: Sep 01, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >= 5.0, < 7.0

     Compare data structures containing matching CIDs of different versions and encoding

  :pypi:`pytest-circleci`
     *last release*: May 03, 2019,
     *status*: N/A,
     *requires*: N/A

     py.test plugin for CircleCI

  :pypi:`pytest-circleci-parallelized`
     *last release*: Oct 20, 2022,
     *status*: N/A,
     *requires*: N/A

     Parallelize pytest across CircleCI workers.

  :pypi:`pytest-circleci-parallelized-rjp`
     *last release*: Jun 21, 2022,
     *status*: N/A,
     *requires*: pytest

     Parallelize pytest across CircleCI workers.

  :pypi:`pytest-ckan`
     *last release*: Apr 28, 2020,
     *status*: 4 - Beta,
     *requires*: pytest

     Backport of CKAN 2.9 pytest plugin and fixtures to CAKN 2.8

  :pypi:`pytest-clab`
     *last release*: Mar 02, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.2

     A pytest plugin for managing containerlab topologies in tests.

  :pypi:`pytest-clang-tidy`
     *last release*: Mar 27, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin that runs clang-tidy static analysis on C/C++ source files

  :pypi:`pytest-clarity`
     *last release*: Jun 11, 2021,
     *status*: N/A,
     *requires*: N/A

     A plugin providing an alternative, colourful diff output for failing assertions.

  :pypi:`pytest-class-fixtures`
     *last release*: Nov 15, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.3

     Class as PyTest fixtures (and BDD steps)

  :pypi:`pytest-claude-agent-sdk`
     *last release*: Jan 19, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.0

     Use Claude Code in your pytests, or pytest your own Claude Code agents — or both

  :pypi:`pytest-cldf`
     *last release*: Nov 07, 2022,
     *status*: N/A,
     *requires*: pytest (>=3.6)

     Easy quality control for CLDF datasets using pytest

  :pypi:`pytest-clean-database`
     *last release*: Mar 14, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest<9,>=7.0

     A pytest plugin that cleans your database up after every test.

  :pypi:`pytest-cleanslate`
     *last release*: Apr 10, 2025,
     *status*: N/A,
     *requires*: pytest

     Collects and executes pytest tests separately

  :pypi:`pytest_cleanup`
     *last release*: Jan 28, 2020,
     *status*: N/A,
     *requires*: N/A

     Automated, comprehensive and well-organised pytest test cases.

  :pypi:`pytest-cleanuptotal`
     *last release*: Jul 22, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A cleanup plugin for pytest

  :pypi:`pytest-clerk`
     *last release*: Feb 04, 2026,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=8.0.0

     A set of pytest fixtures to help with integration testing with Clerk.

  :pypi:`pytest-clerk-mock`
     *last release*: Apr 01, 2026,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for mocking Clerk authentication

  :pypi:`pytest-cli2-ansible`
     *last release*: Mar 05, 2025,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-click`
     *last release*: Feb 11, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.0)

     Pytest plugin for Click

  :pypi:`pytest-clickhouse-mock`
     *last release*: May 29, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0

     Pytest fixtures that mock clickhouse-driver Client for unit tests.

  :pypi:`pytest-cli-fixtures`
     *last release*: Jul 28, 2022,
     *status*: N/A,
     *requires*: pytest (~=7.0)

     Automatically register fixtures for custom CLI arguments

  :pypi:`pytest-clld`
     *last release*: Oct 23, 2024,
     *status*: N/A,
     *requires*: pytest>=3.9



  :pypi:`pytest-cloud`
     *last release*: Oct 05, 2020,
     *status*: 6 - Mature,
     *requires*: N/A

     Distributed tests planner plugin for pytest testing framework.

  :pypi:`pytest-cloudflare-worker`
     *last release*: Mar 30, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0.0)

     pytest plugin for testing cloudflare workers

  :pypi:`pytest-cloudist`
     *last release*: Sep 02, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.1.2,<8.0.0)

     Distribute tests to cloud machines without fuss

  :pypi:`pytest-cloudreport`
     *last release*: May 04, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     pytest plugin for test analytics and flaky-test detection. Free local HTML reports out of the box, or upload to cloudreport.dev for cloud history and team dashboards.

  :pypi:`pytest-cmake`
     *last release*: Jan 03, 2026,
     *status*: N/A,
     *requires*: pytest<10,>=4

     Provide CMake module for Pytest

  :pypi:`pytest-cmake-presets`
     *last release*: Dec 26, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.2.0,<8.0.0)

     Execute CMake Presets via pytest

  :pypi:`pytest-cmdline-add-args`
     *last release*: Sep 01, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for custom argument handling and Allure reporting. This plugin allows you to add arguments before running a test.

  :pypi:`pytest-cobra`
     *last release*: Jun 29, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (<4.0.0,>=3.7.1)

     PyTest plugin for testing Smart Contracts for Ethereum blockchain.

  :pypi:`pytest-cocotb`
     *last release*: Nov 09, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin that enables using pytest as the regression manager for running cocotb tests.

  :pypi:`pytest-cocotb-cov`
     *last release*: Nov 09, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin for measuring HDL coverage.

  :pypi:`pytest-cocotb-fusesoc`
     *last release*: Jan 07, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin to integrate FuseSoC with Cocotb.

  :pypi:`pytest-cocotb-pyuvm`
     *last release*: Nov 09, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin that enables using pytest as the regression manager for running pyuvm tests.

  :pypi:`pytest-codeblock`
     *last release*: Apr 07, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest plugin to collect and test code blocks in reStructuredText and Markdown files.

  :pypi:`pytest_codeblocks`
     *last release*: Sep 17, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >= 7.0.0

     Test code blocks in your READMEs

  :pypi:`pytest-codecarbon`
     *last release*: Jun 15, 2022,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for measuring carbon emissions

  :pypi:`pytest-codecheckers`
     *last release*: Feb 13, 2010,
     *status*: N/A,
     *requires*: N/A

     pytest plugin to add source code sanity checks (pep8 and friends)

  :pypi:`pytest-codecov`
     *last release*: Mar 25, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=4.6.0

     Pytest plugin for uploading pytest-cov results to codecov.io

  :pypi:`pytest-codegen`
     *last release*: Aug 23, 2020,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     Automatically create pytest test signatures

  :pypi:`pytest-codeowners`
     *last release*: Mar 30, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0.0)

     Pytest plugin for selecting tests by GitHub CODEOWNERS.

  :pypi:`pytest-codestyle`
     *last release*: Mar 23, 2020,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin to run pycodestyle

  :pypi:`pytest-codspeed`
     *last release*: May 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.8

     Pytest plugin to create CodSpeed benchmarks

  :pypi:`pytest-collect-appoint-info`
     *last release*: Aug 03, 2023,
     *status*: N/A,
     *requires*: pytest

     set your encoding

  :pypi:`pytest-collect-formatter`
     *last release*: Mar 29, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Formatter for pytest collect output

  :pypi:`pytest-collect-formatter2`
     *last release*: May 31, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Formatter for pytest collect output

  :pypi:`pytest-collect-interface-info-plugin`
     *last release*: Sep 25, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     Get executed interface information in pytest interface automation framework

  :pypi:`pytest-collect-markers`
     *last release*: Jan 24, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A pytest plugin to collect and output test markers to JSON

  :pypi:`pytest-collector`
     *last release*: Aug 02, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.0,<8.0)

     Python package for collecting pytest.

  :pypi:`pytest-collect-pytest-interinfo`
     *last release*: Sep 26, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     A simple plugin to use with pytest

  :pypi:`pytest-collect-requirements`
     *last release*: May 19, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.1

     A pytest plugin to collect test requirements from requirements marker.

  :pypi:`pytest-colordots`
     *last release*: Oct 06, 2017,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Colorizes the progress indicators

  :pypi:`pytest-comfyui`
     *last release*: Jan 09, 2026,
     *status*: N/A,
     *requires*: N/A

     Integration testing framework for ComfyUI nodes and workflows.

  :pypi:`pytest-commander`
     *last release*: Aug 17, 2021,
     *status*: N/A,
     *requires*: pytest (<7.0.0,>=6.2.4)

     An interactive GUI test runner for PyTest

  :pypi:`pytest-common-subject`
     *last release*: Oct 22, 2025,
     *status*: N/A,
     *requires*: pytest<9,>=3.6

     pytest framework for testing different aspects of a common method

  :pypi:`pytest-compare`
     *last release*: Jun 22, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for comparing call arguments.

  :pypi:`pytest-concurrency`
     *last release*: Apr 02, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin for parallel test execution with configurable concurrency

  :pypi:`pytest-concurrent`
     *last release*: Jan 12, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     Concurrently execute test cases with multithread, multiprocess and gevent

  :pypi:`pytest-conductor`
     *last release*: Jul 30, 2025,
     *status*: N/A,
     *requires*: pytest<8.4; python_version == "3.8"

     Pytest plugin for coordinating the order in which marked tests run.

  :pypi:`pytest-config`
     *last release*: Nov 07, 2014,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Base configurations and utilities for developing    your Python project test suite with pytest.

  :pypi:`pytest-confiq`
     *last release*: May 25, 2026,
     *status*: 1 - Planning,
     *requires*: N/A

     pytest-confiq

  :pypi:`pytest-confluence-report`
     *last release*: Apr 17, 2022,
     *status*: N/A,
     *requires*: N/A

     Package stands for pytest plugin to upload results into Confluence page.

  :pypi:`pytest-console-scripts`
     *last release*: May 31, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.0.0)

     Pytest plugin for testing console scripts

  :pypi:`pytest-consul`
     *last release*: Nov 24, 2018,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest plugin with fixtures for testing consul aware apps

  :pypi:`pytest-container`
     *last release*: Jun 30, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.10

     Pytest fixtures for writing container based tests

  :pypi:`pytest-contextfixture`
     *last release*: Mar 12, 2013,
     *status*: 4 - Beta,
     *requires*: N/A

     Define pytest fixtures as context managers.

  :pypi:`pytest-contexts`
     *last release*: May 19, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     A plugin to run tests written with the Contexts framework using pytest

  :pypi:`pytest-continuous`
     *last release*: Apr 23, 2024,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin to run tests continuously until failure or interruption.

  :pypi:`pytest-conversational`
     *last release*: May 23, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0; extra == "dev"

     pytest plugin for multi-turn dialogue testing with a pluggable bot adapter. Rule-based, no LLM dependency.

  :pypi:`pytest-cookies`
     *last release*: Mar 22, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.9.0)

     The pytest plugin for your Cookiecutter templates. 🍪

  :pypi:`pytest-copie`
     *last release*: Sep 29, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     The pytest plugin for your copier templates 📒

  :pypi:`pytest-copier`
     *last release*: Dec 11, 2023,
     *status*: 4 - Beta,
     *requires*: pytest>=7.3.2

     A pytest plugin to help testing Copier templates

  :pypi:`pytest-couchdbkit`
     *last release*: Apr 17, 2012,
     *status*: N/A,
     *requires*: N/A

     py.test extension for per-test couchdb databases using couchdbkit

  :pypi:`pytest-count`
     *last release*: Jan 12, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     count erros and send email

  :pypi:`pytest-cov`
     *last release*: Mar 21, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     Pytest plugin for measuring coverage.

  :pypi:`pytest-cov-affected`
     *last release*: May 03, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     Run pytest and report coverage only for git-affected modules.

  :pypi:`pytest-cov-container`
     *last release*: May 16, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Pytest plugin to collect code coverage from applications running inside Docker containers

  :pypi:`pytest-cover`
     *last release*: Aug 01, 2015,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin for measuring coverage. Forked from \`pytest-cov\`.

  :pypi:`pytest-coverage`
     *last release*: Jun 17, 2015,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-coverage-context`
     *last release*: Jun 28, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     Coverage dynamic context support for PyTest, including sub-processes

  :pypi:`pytest-coverage-gate`
     *last release*: Apr 14, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A pre-commit hook that enforces a coverage quality gate using coverage.xml and a baseline file

  :pypi:`pytest-coverage-impact`
     *last release*: Jan 16, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Sensoria: High-fidelity coverage impact analysis for Python.

  :pypi:`pytest-coveragemarkers`
     *last release*: May 15, 2025,
     *status*: N/A,
     *requires*: pytest<8.0.0,>=7.1.2

     Using pytest markers to track functional coverage and filtering of tests

  :pypi:`pytest-cov-exclude`
     *last release*: Apr 29, 2016,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.8.0,<2.9.0); extra == 'dev'

     Pytest plugin for excluding tests based on coverage data

  :pypi:`pytest_covid`
     *last release*: Jun 24, 2020,
     *status*: N/A,
     *requires*: N/A

     Too many faillure, less tests.

  :pypi:`pytest-cpp`
     *last release*: Sep 18, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Use pytest's runner to discover and execute C++ tests

  :pypi:`pytest-cppcheck`
     *last release*: Mar 26, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin that runs cppcheck static analysis on C/C++ source files

  :pypi:`pytest-cpplint`
     *last release*: Mar 26, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin that runs cpplint style checking on C/C++ source files

  :pypi:`pytest-cqase`
     *last release*: Aug 22, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.2,<8.0.0)

     Custom qase pytest plugin

  :pypi:`pytest-cram`
     *last release*: Aug 08, 2020,
     *status*: N/A,
     *requires*: N/A

     Run cram tests with pytest.

  :pypi:`pytest-crap`
     *last release*: Dec 02, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     pytest plugin that calculates CRAP scores to guide test writing

  :pypi:`pytest-crate`
     *last release*: May 28, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=4.0)

     Manages CrateDB instances during your integration tests

  :pypi:`pytest-cratedb`
     *last release*: Jan 05, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10

     Manage CrateDB instances for integration tests

  :pypi:`pytest-cratedb-reporter`
     *last release*: Mar 11, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     A pytest plugin for reporting test results to CrateDB

  :pypi:`pytest-crayons`
     *last release*: Oct 14, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A pytest plugin for colorful print statements

  :pypi:`pytest-cream`
     *last release*: Oct 26, 2025,
     *status*: N/A,
     *requires*: pytest

     The cream of test execution - smooth pytest workflows with intelligent orchestration

  :pypi:`pytest-create`
     *last release*: Feb 15, 2023,
     *status*: 1 - Planning,
     *requires*: N/A

     pytest-create

  :pypi:`pytest-cricri`
     *last release*: Jan 27, 2018,
     *status*: N/A,
     *requires*: pytest

     A Cricri plugin for pytest.

  :pypi:`pytest-crontab`
     *last release*: Dec 09, 2019,
     *status*: N/A,
     *requires*: N/A

     add crontab task in crontab

  :pypi:`pytest-csv`
     *last release*: Apr 22, 2021,
     *status*: N/A,
     *requires*: pytest (>=6.0)

     CSV output for pytest.

  :pypi:`pytest-csv-params`
     *last release*: May 29, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest<9,>=8.3

     Pytest plugin for Test Case Parametrization with CSV files

  :pypi:`pytest-culprit`
     *last release*: May 15, 2025,
     *status*: N/A,
     *requires*: N/A

     Find the last Git commit where a pytest test started failing

  :pypi:`pytest-curio`
     *last release*: Oct 06, 2024,
     *status*: N/A,
     *requires*: pytest

     Pytest support for curio.

  :pypi:`pytest-curl-report`
     *last release*: Dec 11, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin to generate curl command line report

  :pypi:`pytest-custom-concurrency`
     *last release*: Feb 08, 2021,
     *status*: N/A,
     *requires*: N/A

     Custom grouping concurrence for pytest

  :pypi:`pytest-custom-exit-code`
     *last release*: Aug 07, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.0.2)

     Exit pytest test session with custom exit code in different scenarios

  :pypi:`pytest-custom-nodeid`
     *last release*: Mar 07, 2021,
     *status*: N/A,
     *requires*: N/A

     Custom grouping for pytest-xdist, rename test cases name and test cases nodeid, support allure report

  :pypi:`pytest-custom-outputs`
     *last release*: Jul 10, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin that allows users to create and use custom outputs instead of the standard Pass and Fail. Also allows users to retrieve test results in fixtures.

  :pypi:`pytest-custom-report`
     *last release*: Jan 30, 2019,
     *status*: N/A,
     *requires*: pytest

     Configure the symbols displayed for test outcomes

  :pypi:`pytest-custom-scheduling`
     *last release*: Mar 01, 2021,
     *status*: N/A,
     *requires*: N/A

     Custom grouping for pytest-xdist, rename test cases name and test cases nodeid, support allure report

  :pypi:`pytest-custom-timeout`
     *last release*: Jan 08, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0.0

     Use custom logic when a test times out. Based on pytest-timeout.

  :pypi:`pytest-cython`
     *last release*: Mar 11, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8

     A plugin for testing Cython extension modules.

  :pypi:`pytest-cython-collect`
     *last release*: Jun 17, 2022,
     *status*: N/A,
     *requires*: pytest



  :pypi:`pytest-dag`
     *last release*: Jun 02, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin that enforces test execution order via a dependency DAG

  :pypi:`pytest-darker`
     *last release*: Feb 25, 2024,
     *status*: N/A,
     *requires*: pytest <7,>=6.0.1

     A pytest plugin for checking of modified code using Darker

  :pypi:`pytest-dash`
     *last release*: Mar 18, 2019,
     *status*: N/A,
     *requires*: N/A

     pytest fixtures to run dash applications.

  :pypi:`pytest-dashboard`
     *last release*: Jun 02, 2025,
     *status*: N/A,
     *requires*: pytest<8.0.0,>=7.4.3



  :pypi:`pytest-data`
     *last release*: Nov 01, 2016,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Useful functions for managing data for pytest fixtures

  :pypi:`pytest-databases`
     *last release*: May 23, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     Reusable database fixtures for any and all databases.

  :pypi:`pytest-databricks`
     *last release*: Jul 29, 2020,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for remote Databricks notebooks testing

  :pypi:`pytest-datadir`
     *last release*: Jul 30, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     pytest plugin for test data directories and files

  :pypi:`pytest-datadir-mgr`
     *last release*: Apr 06, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7.1)

     Manager for test data: downloads, artifact caching, and a tmpdir context.

  :pypi:`pytest-datadir-ng`
     *last release*: Dec 25, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Fixtures for pytest allowing test functions/methods to easily retrieve test resources from the local filesystem.

  :pypi:`pytest-datadir-nng`
     *last release*: Nov 09, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7.0.0,<8.0.0)

     Fixtures for pytest allowing test functions/methods to easily retrieve test resources from the local filesystem.

  :pypi:`pytest-data-extractor`
     *last release*: Jul 19, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.0.1)

     A pytest plugin to extract relevant metadata about tests into an external file (currently only json support)

  :pypi:`pytest-datafaker`
     *last release*: May 30, 2026,
     *status*: 6 - Mature,
     *requires*: pytest<10.0.0,>=9.0.3

     Pytest plugin with Faker class and fixture

  :pypi:`pytest-data-file`
     *last release*: Dec 04, 2019,
     *status*: N/A,
     *requires*: N/A

     Fixture "data" and "case_data" for test from yaml file

  :pypi:`pytest-datafiles`
     *last release*: Jan 04, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.0

     py.test plugin to create a 'tmp_path' containing predefined files/directories.

  :pypi:`pytest-datafixtures`
     *last release*: May 15, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Data fixtures for pytest made simple.

  :pypi:`pytest-data-from-files`
     *last release*: Oct 13, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin to provide data from files loaded automatically

  :pypi:`pytest-dataguard`
     *last release*: Oct 08, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.2

     Data validation and integrity testing for your datasets using pytest.

  :pypi:`pytest-data-loader`
     *last release*: May 20, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=7.0.0

     Pytest plugin for loading test data for data-driven testing (DDT)

  :pypi:`pytest-dataplugin`
     *last release*: Sep 16, 2017,
     *status*: 1 - Planning,
     *requires*: N/A

     A pytest plugin for managing an archive of test data.

  :pypi:`pytest-datarecorder`
     *last release*: Jul 31, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A py.test plugin recording and comparing test output.

  :pypi:`pytest-dataset`
     *last release*: Sep 01, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Plugin for loading different datasets for pytest by prefix from json or yaml files

  :pypi:`pytest-data-suites`
     *last release*: Apr 06, 2024,
     *status*: N/A,
     *requires*: pytest<9.0,>=6.0

     Class-based pytest parametrization

  :pypi:`pytest-datatest`
     *last release*: Oct 15, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.3)

     A pytest plugin for test driven data-wrangling (this is the development version of datatest's pytest integration).

  :pypi:`pytest-db`
     *last release*: Nov 11, 2025,
     *status*: N/A,
     *requires*: pytest

     Session scope fixture "db" for mysql query or change

  :pypi:`pytest-dbfixtures`
     *last release*: Dec 07, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Databases fixtures plugin for py.test.

  :pypi:`pytest-db-plugin`
     *last release*: Nov 27, 2021,
     *status*: N/A,
     *requires*: pytest (>=5.0)



  :pypi:`pytest-dbt`
     *last release*: Jun 08, 2023,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest (>=7.0.0,<8.0.0)

     Unit test dbt models with standard python tooling

  :pypi:`pytest-dbt-adapter`
     *last release*: Nov 24, 2021,
     *status*: N/A,
     *requires*: pytest (<7,>=6)

     A pytest plugin for testing dbt adapter plugins

  :pypi:`pytest-dbt-conventions`
     *last release*: Mar 02, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.5,<7.0.0)

     A pytest plugin for linting a dbt project's conventions

  :pypi:`pytest-dbt-core`
     *last release*: Jun 04, 2024,
     *status*: N/A,
     *requires*: pytest>=6.2.5; extra == "test"

     Pytest extension for dbt.

  :pypi:`pytest-dbt-duckdb`
     *last release*: Apr 28, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3.4

     Fearless testing for dbt models, powered by DuckDB.

  :pypi:`pytest-dbt-postgres`
     *last release*: Sep 03, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.2

     Pytest tooling to unittest DBT & Postgres models

  :pypi:`pytest-dbus-notification`
     *last release*: Mar 05, 2014,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     D-BUS notifications for pytest results.

  :pypi:`pytest-dbx`
     *last release*: Nov 29, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.3,<8.0.0)

     Pytest plugin to run unit tests for dbx (Databricks CLI extensions) related code

  :pypi:`pytest-dc`
     *last release*: Aug 16, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=3.3

     Manages Docker containers during your integration tests

  :pypi:`pytest-deadfixtures`
     *last release*: Jan 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     A simple plugin to list unused fixtures in pytest

  :pypi:`pytest-deduplicate`
     *last release*: Aug 12, 2023,
     *status*: 4 - Beta,
     *requires*: pytest

     Identifies duplicate unit tests

  :pypi:`pytest-deepassert`
     *last release*: Nov 04, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     A pytest plugin for enhanced assertion reporting with detailed diffs

  :pypi:`pytest-deepcov`
     *last release*: Mar 30, 2021,
     *status*: N/A,
     *requires*: N/A

     deepcov

  :pypi:`pytest_defer`
     *last release*: Nov 13, 2024,
     *status*: N/A,
     *requires*: pytest>=8.3

     A 'defer' fixture for pytest

  :pypi:`pytest-delta`
     *last release*: Feb 12, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10.0.0,>=9.0.2

     Run only tests impacted by your code changes (delta-based selection) for pytest.

  :pypi:`pytest-demo-plugin`
     *last release*: May 15, 2021,
     *status*: N/A,
     *requires*: N/A

     pytest示例插件

  :pypi:`pytest-dependency`
     *last release*: Feb 15, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     Manage dependencies of tests

  :pypi:`pytest-depends`
     *last release*: Apr 05, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3)

     Tests that depend on other tests

  :pypi:`pytest-depends-on`
     *last release*: May 18, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.1

     A Python package for managing test dependencies in pytest.

  :pypi:`pytest-depper`
     *last release*: Oct 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Smart test selection based on AST-level code dependency analysis

  :pypi:`pytest-deprecate`
     *last release*: Jul 01, 2019,
     *status*: N/A,
     *requires*: N/A

     Mark tests as testing a deprecated feature with a warning note.

  :pypi:`pytest-deprecator`
     *last release*: Dec 02, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A simple plugin to use with pytest

  :pypi:`pytest-describe`
     *last release*: Dec 12, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=6

     Describe-style plugin for pytest

  :pypi:`pytest-describe-beautifully`
     *last release*: Jan 28, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Beautiful terminal and HTML output for pytest-describe.

  :pypi:`pytest-describe-it`
     *last release*: Jul 19, 2019,
     *status*: 4 - Beta,
     *requires*: pytest

     plugin for rich text descriptions

  :pypi:`pytest-deselect-if`
     *last release*: Dec 26, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin to deselect pytests tests rather than using skipif

  :pypi:`pytest-devant-cloud`
     *last release*: May 11, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     pytest plugin that streams runs, results, and step trees to Devant Cloud's /v1/runs API.

  :pypi:`pytest-devpi-server`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     DevPI server fixture for py.test

  :pypi:`pytest-devtools`
     *last release*: May 07, 2026,
     *status*: N/A,
     *requires*: pytest>=7

     Pytest plugin providing debug fixtures, ANSI-stripped capsys, whitespace-visible assertions, and terminal column management.

  :pypi:`pytest-dfm`
     *last release*: Nov 23, 2025,
     *status*: N/A,
     *requires*: pytest

     pytest-dfm provides a pytest integration for DV Flow Manager, a build system for silicon design

  :pypi:`pytest-dhos`
     *last release*: Sep 07, 2022,
     *status*: N/A,
     *requires*: N/A

     Common fixtures for pytest in DHOS services and libraries

  :pypi:`pytest-diamond`
     *last release*: Aug 31, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin for diamond

  :pypi:`pytest-dicom`
     *last release*: Dec 19, 2018,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest plugin to provide DICOM fixtures

  :pypi:`pytest-dictsdiff`
     *last release*: Jul 26, 2019,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-diff`
     *last release*: Mar 30, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to use with pytest

  :pypi:`pytest-diff-selector`
     *last release*: Feb 24, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.2) ; extra == 'all'

     Get tests affected by code changes (using git)

  :pypi:`pytest-difftest`
     *last release*: Feb 23, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Blazingly fast test selection for pytest - only run tests affected by your changes (Rust-powered)

  :pypi:`pytest-difido`
     *last release*: Oct 23, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.0.0)

     PyTest plugin for generating Difido reports

  :pypi:`pytest-directives`
     *last release*: Aug 11, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     Control your tests flow

  :pypi:`pytest-dir-equal`
     *last release*: Dec 11, 2023,
     *status*: 4 - Beta,
     *requires*: pytest>=7.3.2

     pytest-dir-equals is a pytest plugin providing helpers to assert directories equality allowing golden testing

  :pypi:`pytest-dirty`
     *last release*: Jun 08, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.2; extra == "dev"

     Static import analysis for thrifty testing.

  :pypi:`pytest-disable`
     *last release*: Sep 10, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin to disable a test and skip it from testrun

  :pypi:`pytest-disable-plugin`
     *last release*: Feb 28, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Disable plugins per test

  :pypi:`pytest-discord`
     *last release*: May 11, 2024,
     *status*: 4 - Beta,
     *requires*: pytest!=6.0.0,<9,>=3.3.2

     A pytest plugin to notify test results to a Discord channel.

  :pypi:`pytest-discover`
     *last release*: Mar 26, 2024,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin to record discovered tests in a file

  :pypi:`pytest-ditto`
     *last release*: Mar 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.5.0

     Snapshot testing pytest plugin with minimal ceremony and flexible recorders.

  :pypi:`pytest-ditto-pandas`
     *last release*: Mar 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.5.0

     pytest-ditto plugin for pandas DataFrame snapshots.

  :pypi:`pytest-ditto-pyarrow`
     *last release*: Mar 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.5.0

     pytest-ditto plugin for pyarrow table snapshots.

  :pypi:`pytest-django`
     *last release*: Feb 14, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     A Django plugin for pytest.

  :pypi:`pytest-django-ahead`
     *last release*: Oct 27, 2016,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.9)

     A Django plugin for pytest.

  :pypi:`pytest-djangoapp`
     *last release*: Apr 25, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Nice pytest plugin to help you with Django pluggable application testing.

  :pypi:`pytest-django-asyncio`
     *last release*: Mar 26, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0

     Temporary pytest plugin backport for async Django DB fixture handling.

  :pypi:`pytest-django-cache-xdist`
     *last release*: May 12, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     A djangocachexdist plugin for pytest

  :pypi:`pytest-django-casperjs`
     *last release*: Mar 15, 2015,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     Integrate CasperJS with your django tests as a pytest fixture.

  :pypi:`pytest-django-class`
     *last release*: Aug 08, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin for running django in class-scoped fixtures

  :pypi:`pytest-django-docker-pg`
     *last release*: Jun 13, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest<9.0.0,>=7.0.0



  :pypi:`pytest-django-dotenv`
     *last release*: Nov 26, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.6.0)

     Pytest plugin used to setup environment variables with django-dotenv

  :pypi:`pytest-django-factories`
     *last release*: Nov 12, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     Factories for your Django models that can be used as Pytest fixtures.

  :pypi:`pytest-django-filefield`
     *last release*: May 09, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest >= 5.2

     Replaces FileField.storage with something you can patch globally.

  :pypi:`pytest-django-gcir`
     *last release*: Mar 06, 2018,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A Django plugin for pytest.

  :pypi:`pytest-django-haystack`
     *last release*: Sep 03, 2017,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.3.4)

     Cleanup your Haystack indexes between tests

  :pypi:`pytest-django-ifactory`
     *last release*: Apr 30, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A model instance factory for pytest-django

  :pypi:`pytest-django-lite`
     *last release*: Jan 30, 2014,
     *status*: N/A,
     *requires*: N/A

     The bare minimum to integrate py.test with Django.

  :pypi:`pytest-django-liveserver-ssl`
     *last release*: Jan 09, 2025,
     *status*: 3 - Alpha,
     *requires*: N/A



  :pypi:`pytest-django-model`
     *last release*: Feb 14, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     A Simple Way to Test your Django Models

  :pypi:`pytest-django-ordering`
     *last release*: Jul 25, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.3.0)

     A pytest plugin for preserving the order in which Django runs tests.

  :pypi:`pytest-django-queries`
     *last release*: Mar 01, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.2.0

     Generate performance reports from your django database performance tests.

  :pypi:`pytest-djangorestframework`
     *last release*: Aug 11, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     A djangorestframework plugin for pytest

  :pypi:`pytest-django-rq`
     *last release*: Apr 13, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin to help writing unit test for django-rq

  :pypi:`pytest-django-sqlcounts`
     *last release*: Jun 16, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin for reporting the number of SQLs executed per django testcase.

  :pypi:`pytest-django-testing-postgresql`
     *last release*: Jan 31, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Use a temporary PostgreSQL database with pytest-django

  :pypi:`pytest-doc`
     *last release*: Jun 28, 2015,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A documentation plugin for py.test.

  :pypi:`pytest-docfiles`
     *last release*: Dec 22, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.7.0)

     pytest plugin to test codeblocks in your documentation.

  :pypi:`pytest-docgen`
     *last release*: Apr 17, 2020,
     *status*: N/A,
     *requires*: N/A

     An RST Documentation Generator for pytest-based test suites

  :pypi:`pytest-docker`
     *last release*: Nov 12, 2025,
     *status*: N/A,
     *requires*: pytest<10.0,>=4.0

     Simple pytest fixtures for Docker and Docker Compose based tests

  :pypi:`pytest-docker-apache-fixtures`
     *last release*: Aug 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with apache2 (httpd).

  :pypi:`pytest-docker-butla`
     *last release*: Jun 16, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A



  :pypi:`pytest-dockerc`
     *last release*: Oct 09, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.0)

     Run, manage and stop Docker Compose project from Docker API

  :pypi:`pytest-docker-compose`
     *last release*: Jan 26, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.3)

     Manages Docker containers during your integration tests

  :pypi:`pytest-docker-compose-v2`
     *last release*: Dec 17, 2025,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=7.2.2

     Manages Docker containers during your integration tests

  :pypi:`pytest-docker-db`
     *last release*: Mar 20, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.1.1)

     A plugin to use docker databases for pytests

  :pypi:`pytest-docker-fixtures`
     *last release*: May 07, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest docker fixtures

  :pypi:`pytest-docker-git-fixtures`
     *last release*: Aug 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with git scm.

  :pypi:`pytest-docker-haproxy-fixtures`
     *last release*: Aug 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with haproxy.

  :pypi:`pytest-docker-pexpect`
     *last release*: Jan 14, 2019,
     *status*: N/A,
     *requires*: pytest

     pytest plugin for writing functional tests with pexpect and docker

  :pypi:`pytest-docker-postgresql`
     *last release*: Sep 24, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to use with pytest

  :pypi:`pytest-docker-py`
     *last release*: Nov 27, 2018,
     *status*: N/A,
     *requires*: pytest (==4.0.0)

     Easy to use, simple to extend, pytest plugin that minimally leverages docker-py.

  :pypi:`pytest-docker-registry-fixtures`
     *last release*: Aug 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with docker registries.

  :pypi:`pytest-docker-service`
     *last release*: Jan 03, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest (>=7.1.3)

     pytest plugin to start docker container

  :pypi:`pytest-docker-squid-fixtures`
     *last release*: Aug 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with squid.

  :pypi:`pytest-docker-tools`
     *last release*: Mar 16, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0.1

     Docker integration tests for pytest

  :pypi:`pytest-docs`
     *last release*: Nov 11, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Documentation tool for pytest

  :pypi:`pytest-docstyle`
     *last release*: Mar 23, 2020,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin to run pydocstyle

  :pypi:`pytest-doctest-custom`
     *last release*: Jul 25, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     A py.test plugin for customizing string representations of doctest results.

  :pypi:`pytest-doctest-ellipsis-markers`
     *last release*: Jan 12, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     Setup additional values for ELLIPSIS_MARKER for doctests

  :pypi:`pytest-doctest-import`
     *last release*: Nov 13, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.3.0)

     A simple pytest plugin to import names and add them to the doctest namespace.

  :pypi:`pytest-doctest-mkdocstrings`
     *last release*: Mar 02, 2024,
     *status*: N/A,
     *requires*: pytest

     Run pytest --doctest-modules with markdown docstrings in code blocks (\`\`\`)

  :pypi:`pytest-doctest-only`
     *last release*: Jul 30, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3.0

     A plugin to run only doctest

  :pypi:`pytest-doctestplus`
     *last release*: Jan 26, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     Pytest plugin with advanced doctest features.

  :pypi:`pytest-doctor`
     *last release*: Mar 22, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     A CLI tool that diagnoses weak or broken pytest suites and provides a 0-100 health score with actionable recommendations

  :pypi:`pytest-documentary`
     *last release*: Jul 11, 2024,
     *status*: N/A,
     *requires*: pytest

     A simple pytest plugin to generate test documentation

  :pypi:`pytest-dogu-report`
     *last release*: Jul 07, 2023,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for dogu report

  :pypi:`pytest-dogu-sdk`
     *last release*: Dec 14, 2023,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for the Dogu

  :pypi:`pytest-dolphin`
     *last release*: Nov 30, 2016,
     *status*: 4 - Beta,
     *requires*: pytest (==3.0.4)

     Some extra stuff that we use ininternally

  :pypi:`pytest-donde`
     *last release*: Oct 01, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=7.3.1

     record pytest session characteristics per test item (coverage and duration) into a persistent file and use them in your own plugin or script.

  :pypi:`pytest-doorstop`
     *last release*: Jun 09, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin for adding test results into doorstop items.

  :pypi:`pytest-dotenv`
     *last release*: Jun 16, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=5.0.0)

     A py.test plugin that parses environment files before running tests

  :pypi:`pytest-dotenv-modern`
     *last release*: Sep 27, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0.0

     A modern pytest plugin that loads environment variables from dotenv files

  :pypi:`pytest-dot-only-pkcopley`
     *last release*: Oct 27, 2023,
     *status*: N/A,
     *requires*: N/A

     A Pytest marker for only running a single test

  :pypi:`pytest-dparam`
     *last release*: Aug 27, 2024,
     *status*: 6 - Mature,
     *requires*: pytest

     A more readable alternative to @pytest.mark.parametrize.

  :pypi:`pytest-dpg`
     *last release*: Aug 13, 2024,
     *status*: N/A,
     *requires*: N/A

     pytest-dpg is a pytest plugin for testing Dear PyGui (DPG) applications

  :pypi:`pytest-draw`
     *last release*: Mar 21, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin for randomly selecting a specific number of tests

  :pypi:`pytest-drf`
     *last release*: Jul 12, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.7)

     A Django REST framework plugin for pytest.

  :pypi:`pytest-drift`
     *last release*: May 09, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin for regression testing via branch comparison

  :pypi:`pytest-drill-sergeant`
     *last release*: Feb 20, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin that enforces test quality standards through automatic marker detection and AAA structure validation

  :pypi:`pytest-drivings`
     *last release*: Jan 13, 2021,
     *status*: N/A,
     *requires*: N/A

     Tool to allow webdriver automation to be ran locally or remotely

  :pypi:`pytest-drop-dup-tests`
     *last release*: Mar 04, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=7

     A Pytest plugin to drop duplicated tests during collection

  :pypi:`pytest-dryci`
     *last release*: Sep 27, 2024,
     *status*: 4 - Beta,
     *requires*: N/A

     Test caching plugin for pytest

  :pypi:`pytest-dryrun`
     *last release*: May 26, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=7.40

     A Pytest plugin to ignore tests during collection without reporting them in the test summary.

  :pypi:`pytest-dsl`
     *last release*: Jun 01, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A DSL testing framework based on pytest

  :pypi:`pytest-dsl-ssh`
     *last release*: Jul 25, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     SSH/SFTP关键字插件，为pytest-dsl提供SSH和SFTP操作能力

  :pypi:`pytest-dsl-ui`
     *last release*: Jun 05, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0; extra == "dev"

     Playwright-based UI automation keywords for pytest-dsl framework

  :pypi:`pytest-duckdb`
     *last release*: May 10, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     pytest plugin for SQL pipeline testing with DuckDB — load fixtures, run queries, snapshot results

  :pypi:`pytest-dummynet`
     *last release*: Dec 15, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A py.test plugin providing access to a dummynet.

  :pypi:`pytest-dump2json`
     *last release*: Jun 29, 2015,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for dumping test results to json.

  :pypi:`pytest-duration-insights`
     *last release*: Jul 15, 2024,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-durations`
     *last release*: Mar 13, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=4.6

     Pytest plugin reporting fixtures and test functions execution time.

  :pypi:`pytest-dynamic-parameterize`
     *last release*: May 27, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.1

     A pytest plugin to dynamically parameterize tests based on external data sources.

  :pypi:`pytest-dynamicrerun`
     *last release*: Aug 15, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin to rerun tests dynamically based off of test outcome and output.

  :pypi:`pytest-dynamodb`
     *last release*: Mar 13, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4.0

     DynamoDB fixtures for pytest

  :pypi:`pytest-easy-addoption`
     *last release*: Jan 22, 2020,
     *status*: N/A,
     *requires*: N/A

     pytest-easy-addoption: Easy way to work with pytest addoption

  :pypi:`pytest-easyMPI`
     *last release*: Oct 21, 2020,
     *status*: N/A,
     *requires*: N/A

     Package that supports mpi tests in pytest

  :pypi:`pytest-easyread`
     *last release*: Nov 17, 2017,
     *status*: N/A,
     *requires*: N/A

     pytest plugin that makes terminal printouts of the reports easier to read

  :pypi:`pytest-easy-server`
     *last release*: May 01, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (<5.0.0,>=4.3.1) ; python_version < "3.5"

     Pytest plugin for easy testing against servers

  :pypi:`pytest-ebics-sandbox`
     *last release*: Aug 15, 2022,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for testing against an EBICS sandbox server. Requires docker.

  :pypi:`pytest-ec2`
     *last release*: Oct 22, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest execution on EC2 instance

  :pypi:`pytest-echo`
     *last release*: Apr 27, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.3.3

     pytest plugin that allows to dump environment variables, package version and generic attributes

  :pypi:`pytest-edit`
     *last release*: Nov 17, 2024,
     *status*: N/A,
     *requires*: pytest

     Edit the source code of a failed test with \`pytest --edit\`.

  :pypi:`pytest-egg`
     *last release*: Apr 17, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin that prints egg ascii art at the end of a test run.

  :pypi:`pytest-ekstazi`
     *last release*: Sep 10, 2022,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin to select test using Ekstazi algorithm

  :pypi:`pytest-elastic-reporter`
     *last release*: Mar 13, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0



  :pypi:`pytest-elasticsearch`
     *last release*: Feb 16, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4.0

     Elasticsearch fixtures and fixture factories for Pytest.

  :pypi:`pytest-elasticsearch-test`
     *last release*: Apr 20, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     Elasticsearch fixtures and fixture factories for Pytest.

  :pypi:`pytest-elegant`
     *last release*: Apr 13, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin that provides elegant, beautiful test output

  :pypi:`pytest-elements`
     *last release*: Jan 13, 2021,
     *status*: N/A,
     *requires*: pytest (>=5.4,<6.0)

     Tool to help automate user interfaces

  :pypi:`pytest-eliot`
     *last release*: Aug 31, 2022,
     *status*: 1 - Planning,
     *requires*: pytest (>=5.4.0)

     An eliot plugin for pytest.

  :pypi:`pytest-elk-reporter`
     *last release*: Jul 25, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     A simple plugin to use with pytest

  :pypi:`pytest-email`
     *last release*: Jul 08, 2020,
     *status*: N/A,
     *requires*: pytest

     Send execution result email

  :pypi:`pytest-embedded`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     A pytest plugin that designed for embedded testing.

  :pypi:`pytest-embedded-arduino`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with Arduino.

  :pypi:`pytest-embedded-arduino-cli`
     *last release*: May 20, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     A pytest plugin to test Arduino projects using pytest-embedded and arduino-cli

  :pypi:`pytest-embedded-idf`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with ESP-IDF.

  :pypi:`pytest-embedded-jtag`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with JTAG.

  :pypi:`pytest-embedded-nuttx`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with NuttX.

  :pypi:`pytest-embedded-qemu`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with QEMU.

  :pypi:`pytest-embedded-serial`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with Serial.

  :pypi:`pytest-embedded-serial-esp`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with Espressif target boards.

  :pypi:`pytest-embedded-wokwi`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Make pytest-embedded plugin work with the Wokwi CLI.

  :pypi:`pytest-embrace`
     *last release*: Mar 25, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.0,<8.0)

     💝  Dataclasses-as-tests. Describe the runtime once and multiply coverage with no boilerplate.

  :pypi:`pytest-emoji`
     *last release*: Feb 19, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.2.1)

     A pytest plugin that adds emojis to your test result report

  :pypi:`pytest-emoji-output`
     *last release*: Apr 09, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (==7.0.1)

     Pytest plugin to represent test output with emoji support

  :pypi:`pytest-enabler`
     *last release*: May 16, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest!=8.1.*,>=6; extra == "test"

     Enable installed pytest plugins

  :pypi:`pytest-encode`
     *last release*: Nov 06, 2021,
     *status*: N/A,
     *requires*: N/A

     set your encoding and logger

  :pypi:`pytest-encode-kane`
     *last release*: Nov 16, 2021,
     *status*: N/A,
     *requires*: pytest

     set your encoding and logger

  :pypi:`pytest-encoding`
     *last release*: Aug 11, 2023,
     *status*: N/A,
     *requires*: pytest

     set your encoding and logger

  :pypi:`pytest_energy_reporter`
     *last release*: Mar 28, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest<9.0.0,>=8.1.1

     An energy estimation reporter for pytest

  :pypi:`pytest-enhanced-reports`
     *last release*: Dec 15, 2022,
     *status*: N/A,
     *requires*: N/A

     Enhanced test reports for pytest

  :pypi:`pytest-enhancements`
     *last release*: Oct 30, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     Improvements for pytest (rejected upstream)

  :pypi:`pytest-env`
     *last release*: Mar 12, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.2

     pytest plugin that allows you to add environment variables.

  :pypi:`pytest-envfiles`
     *last release*: Oct 08, 2015,
     *status*: 3 - Alpha,
     *requires*: N/A

     A py.test plugin that parses environment files before running tests

  :pypi:`pytest-env-info`
     *last release*: Nov 25, 2017,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     Push information about the running pytest into envvars

  :pypi:`pytest-environment`
     *last release*: Mar 17, 2024,
     *status*: 1 - Planning,
     *requires*: N/A

     Pytest Environment

  :pypi:`pytest-envraw`
     *last release*: Aug 27, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.6.0)

     py.test plugin that allows you to add environment variables.

  :pypi:`pytest-envvars`
     *last release*: Jun 13, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.0.0)

     Pytest plugin to validate use of envvars on your tests

  :pypi:`pytest-envx`
     *last release*: Jun 28, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.4.1

     Pytest plugin for managing environment variables with interpolation and .env file support.

  :pypi:`pytest-env-yaml`
     *last release*: Apr 02, 2019,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-ephemeral-container`
     *last release*: Apr 14, 2026,
     *status*: N/A,
     *requires*: pytest

     Spawn epehemeral containers in pytest

  :pypi:`pytest-eradicate`
     *last release*: Sep 08, 2020,
     *status*: N/A,
     *requires*: pytest (>=2.4.2)

     pytest plugin to check for commented out code

  :pypi:`pytest_erp`
     *last release*: Jan 13, 2015,
     *status*: N/A,
     *requires*: N/A

     py.test plugin to send test info to report portal dynamically

  :pypi:`pytest-error-for-skips`
     *last release*: Dec 19, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.6)

     Pytest plugin to treat skipped tests a test failure

  :pypi:`pytest-errxfail`
     *last release*: Jan 06, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     pytest plugin to mark a test as xfailed if it fails with the specified error message in the captured output

  :pypi:`pytest-essentials`
     *last release*: May 19, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     A Pytest plugin providing essential utilities like soft assertions.

  :pypi:`pytest-eth`
     *last release*: Aug 14, 2020,
     *status*: 1 - Planning,
     *requires*: N/A

     PyTest plugin for testing Smart Contracts for Ethereum Virtual Machine (EVM).

  :pypi:`pytest-ethereum`
     *last release*: Jun 24, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (==3.3.2); extra == 'dev'

     pytest-ethereum: Pytest library for ethereum projects.

  :pypi:`pytest-eucalyptus`
     *last release*: Jun 28, 2022,
     *status*: N/A,
     *requires*: pytest (>=4.2.0)

     Pytest Plugin for BDD

  :pypi:`pytest-eval`
     *last release*: Feb 11, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     LLM testing for humans.

  :pypi:`pytest-evals`
     *last release*: Feb 02, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A pytest plugin for running and analyzing LLM evaluation tests

  :pypi:`pytest-eventlet`
     *last release*: Oct 04, 2021,
     *status*: N/A,
     *requires*: pytest ; extra == 'dev'

     Applies eventlet monkey-patch as a pytest plugin.

  :pypi:`pytest-everyfunc`
     *last release*: Apr 30, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     A pytest plugin to detect completely untested functions using coverage

  :pypi:`pytest_evm`
     *last release*: Sep 23, 2024,
     *status*: 4 - Beta,
     *requires*: pytest<9.0.0,>=8.1.1

     The testing package containing tools to test Web3-based projects

  :pypi:`pytest_exact_fixtures`
     *last release*: Feb 04, 2019,
     *status*: N/A,
     *requires*: N/A

     Parse queries in Lucene and Elasticsearch syntaxes

  :pypi:`pytest-examples`
     *last release*: May 06, 2025,
     *status*: N/A,
     *requires*: pytest>=7

     Pytest plugin for testing examples in docstrings and markdown files.

  :pypi:`pytest-exasol-backend`
     *last release*: May 05, 2026,
     *status*: N/A,
     *requires*: pytest<10,>=7



  :pypi:`pytest-exasol-extension`
     *last release*: May 05, 2026,
     *status*: N/A,
     *requires*: pytest<10,>=7



  :pypi:`pytest-exasol-itde`
     *last release*: Nov 22, 2024,
     *status*: N/A,
     *requires*: pytest<9,>=7



  :pypi:`pytest-exasol-saas`
     *last release*: Nov 22, 2024,
     *status*: N/A,
     *requires*: pytest<9,>=7



  :pypi:`pytest-exasol-slc`
     *last release*: May 05, 2026,
     *status*: N/A,
     *requires*: pytest<10,>=7



  :pypi:`pytest-excel`
     *last release*: Jul 22, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest plugin for generating excel reports

  :pypi:`pytest-exceptional`
     *last release*: Mar 16, 2017,
     *status*: 4 - Beta,
     *requires*: N/A

     Better exceptions

  :pypi:`pytest-exception-script`
     *last release*: Aug 04, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest

     Walk your code through exception script to check it's resiliency to failures.

  :pypi:`pytest-executable`
     *last release*: Oct 07, 2023,
     *status*: N/A,
     *requires*: pytest <8,>=5

     pytest plugin for testing executables

  :pypi:`pytest-execution-timer`
     *last release*: Dec 24, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     A timer for the phases of Pytest's execution.

  :pypi:`pytest-exit-code`
     *last release*: May 06, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A pytest plugin that overrides the built-in exit codes to retain more information about the test results.

  :pypi:`pytest-exit-status`
     *last release*: Jan 25, 2025,
     *status*: N/A,
     *requires*: pytest>=8.0.0

     Enhance.

  :pypi:`pytest-expect`
     *last release*: Apr 21, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to store test expectations and mark tests based on them

  :pypi:`pytest-expectdir`
     *last release*: Mar 19, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.0)

     A pytest plugin to provide initial/expected directories, and check a test transforms the initial directory to the expected one

  :pypi:`pytest-expected`
     *last release*: Feb 26, 2025,
     *status*: N/A,
     *requires*: pytest

     Record and play back your expectations

  :pypi:`pytest-expecter`
     *last release*: Sep 18, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Better testing with expecter and pytest.

  :pypi:`pytest-expectr`
     *last release*: Oct 05, 2018,
     *status*: N/A,
     *requires*: pytest (>=2.4.2)

     This plugin is used to expect multiple assert using pytest framework.

  :pypi:`pytest-expect-test`
     *last release*: Apr 10, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A fixture to support expect tests in pytest

  :pypi:`pytest-experiments`
     *last release*: Dec 13, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.5,<7.0.0)

     A pytest plugin to help developers of research-oriented software projects keep track of the results of their numerical experiments.

  :pypi:`pytest-explicit`
     *last release*: Jun 15, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A Pytest plugin to ignore certain marked tests by default

  :pypi:`pytest-exploratory`
     *last release*: Sep 18, 2024,
     *status*: N/A,
     *requires*: pytest>=6.2

     Interactive console for pytest.

  :pypi:`pytest-explorer`
     *last release*: Aug 01, 2023,
     *status*: N/A,
     *requires*: N/A

     terminal ui for exploring and running tests

  :pypi:`pytest-ext`
     *last release*: Mar 31, 2024,
     *status*: N/A,
     *requires*: pytest>=5.3

     pytest plugin for automation test

  :pypi:`pytest-extended-mock`
     *last release*: Mar 12, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.5

     a pytest extension for easy mock setup

  :pypi:`pytest-extensions`
     *last release*: Aug 17, 2022,
     *status*: 4 - Beta,
     *requires*: pytest ; extra == 'testing'

     A collection of helpers for pytest to ease testing

  :pypi:`pytest-external-blockers`
     *last release*: Oct 05, 2021,
     *status*: N/A,
     *requires*: pytest

     a special outcome for tests that are blocked for external reasons

  :pypi:`pytest_extra`
     *last release*: Aug 14, 2014,
     *status*: N/A,
     *requires*: N/A

     Some helpers for writing tests with pytest.

  :pypi:`pytest-extra-durations`
     *last release*: Apr 21, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin to get durations on a per-function basis and per module basis.

  :pypi:`pytest-extra-markers`
     *last release*: Mar 05, 2023,
     *status*: 4 - Beta,
     *requires*: pytest

     Additional pytest markers to dynamically enable/disable tests viia CLI flags

  :pypi:`pytest-f3ts`
     *last release*: Mar 09, 2026,
     *status*: N/A,
     *requires*: pytest<8.0.0,>=7.2.1

     Pytest Plugin for communicating test results and information to a FixturFab Test Runner GUI

  :pypi:`pytest-fabric`
     *last release*: Sep 12, 2018,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Provides test utilities to run fabric task tests by using docker containers

  :pypi:`pytest-factory`
     *last release*: Sep 06, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest (>4.3)

     Use factories for test setup with py.test

  :pypi:`pytest-factoryboy`
     *last release*: Jul 01, 2025,
     *status*: 6 - Mature,
     *requires*: pytest>=7.0

     Factory Boy support for pytest.

  :pypi:`pytest-factoryboy-fixtures`
     *last release*: Jun 25, 2020,
     *status*: N/A,
     *requires*: N/A

     Generates pytest fixtures that allow the use of type hinting

  :pypi:`pytest-factoryboy-state`
     *last release*: Mar 22, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.0)

     Simple factoryboy random state management

  :pypi:`pytest-fahhh`
     *last release*: Apr 16, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     A pytest plugin that plays the fahhh meme sound when a test fails.

  :pypi:`pytest-failed-screen-record`
     *last release*: Jan 05, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.1.2d,<8.0.0)

     Create a video of the screen when pytest fails

  :pypi:`pytest-failed-screenshot`
     *last release*: Apr 21, 2021,
     *status*: N/A,
     *requires*: N/A

     Test case fails,take a screenshot,save it,attach it to the allure

  :pypi:`pytest-failed-to-verify`
     *last release*: Aug 08, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.1.0)

     A pytest plugin that helps better distinguishing real test failures from setup flakiness.

  :pypi:`pytest-fail-slow`
     *last release*: Jun 01, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0

     Fail tests that take too long to run

  :pypi:`pytest-failure-tracker`
     *last release*: Jul 17, 2024,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     A pytest plugin for tracking test failures over multiple runs

  :pypi:`pytest-fakellm`
     *last release*: May 21, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Pytest fixtures for the fakellm mock OpenAI/Anthropic server — spin up, reset, and assert with zero boilerplate.

  :pypi:`pytest-faker`
     *last release*: Dec 19, 2016,
     *status*: 6 - Mature,
     *requires*: N/A

     Faker integration with the pytest framework.

  :pypi:`pytest-falcon`
     *last release*: Sep 07, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest helpers for Falcon.

  :pypi:`pytest-fantasy`
     *last release*: Mar 14, 2019,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for Flask Fantasy Framework

  :pypi:`pytest-fastapi`
     *last release*: Dec 27, 2020,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-fastapi-deps`
     *last release*: Jul 20, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A fixture which allows easy replacement of fastapi dependencies for testing

  :pypi:`pytest-fastcollect`
     *last release*: Nov 19, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A high-performance pytest plugin that replaces test collection with a Rust-based implementation

  :pypi:`pytest-fastest`
     *last release*: Oct 04, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.4)

     Use SCM and coverage to run only needed tests

  :pypi:`pytest-fast-first`
     *last release*: Jan 19, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin that runs fast tests first

  :pypi:`pytest-fastprom`
     *last release*: May 22, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Isolated Prometheus metrics assertions for FastAPI tests

  :pypi:`pytest-faulthandler`
     *last release*: Jul 04, 2019,
     *status*: 6 - Mature,
     *requires*: pytest (>=5.0)

     py.test plugin that activates the fault handler module for tests (dummy package)

  :pypi:`pytest-fauna`
     *last release*: Jan 03, 2025,
     *status*: N/A,
     *requires*: N/A

     A collection of helpful test fixtures for Fauna DB.

  :pypi:`pytest-fauxfactory`
     *last release*: Dec 06, 2017,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.2)

     Integration of fauxfactory into pytest.

  :pypi:`pytest-figleaf`
     *last release*: Jan 18, 2010,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     py.test figleaf coverage plugin

  :pypi:`pytest-file`
     *last release*: Mar 18, 2024,
     *status*: 1 - Planning,
     *requires*: N/A

     Pytest File

  :pypi:`pytest-filecov`
     *last release*: Jun 27, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     A pytest plugin to detect unused files

  :pypi:`pytest-filedata`
     *last release*: Apr 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     easily load test data from files

  :pypi:`pytest-filemarker`
     *last release*: Dec 01, 2020,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin that runs marked tests when files change.

  :pypi:`pytest-file-watcher`
     *last release*: Mar 23, 2023,
     *status*: N/A,
     *requires*: pytest

     Pytest-File-Watcher is a CLI tool that watches for changes in your code and runs pytest on the changed files.

  :pypi:`pytest-filter-case`
     *last release*: Nov 05, 2020,
     *status*: N/A,
     *requires*: N/A

     run test cases filter by mark

  :pypi:`pytest-filterfixtures`
     *last release*: Jan 09, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.2

     pytest plugin to execute or ignore tests based on fixtures

  :pypi:`pytest-filter-subpackage`
     *last release*: Mar 04, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=4.6

     Pytest plugin for filtering based on sub-packages

  :pypi:`pytest-find-dependencies`
     *last release*: Jul 16, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.4

     A pytest plugin to find dependencies between tests

  :pypi:`pytest-finer-verdicts`
     *last release*: Jun 18, 2020,
     *status*: N/A,
     *requires*: pytest (>=5.4.3)

     A pytest plugin to treat non-assertion failures as test errors.

  :pypi:`pytest-firefox`
     *last release*: Feb 28, 2025,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-firestore`
     *last release*: Mar 10, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A Pytest fixture for managing Google Cloud Firestore emulator

  :pypi:`pytest-fixedpoint`
     *last release*: Mar 12, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin for recording and replaying deterministic function calls

  :pypi:`pytest-fixkit`
     *last release*: May 12, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A set of useful pytest fixtures that I use everyday.

  :pypi:`pytest-fixture-cache`
     *last release*: Jan 25, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Smart fixture caching for pytest with SQLite storage

  :pypi:`pytest-fixturecheck`
     *last release*: Jun 02, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.0.0

     A pytest plugin to check fixture validity before test execution

  :pypi:`pytest-fixture-classes`
     *last release*: Oct 12, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Fixtures as classes that work well with dependency injection, autocompletetion, type checkers, and language servers

  :pypi:`pytest-fixture-collect`
     *last release*: Jul 25, 2025,
     *status*: N/A,
     *requires*: pytest; extra == "test"

     A utility to collect pytest fixture file paths.

  :pypi:`pytest-fixturecollection`
     *last release*: Feb 22, 2024,
     *status*: 4 - Beta,
     *requires*: pytest >=3.5.0

     A pytest plugin to collect tests based on fixtures being used by tests

  :pypi:`pytest-fixture-config`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Fixture configuration utils for py.test

  :pypi:`pytest-fixture-forms`
     *last release*: Dec 06, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=7.0.0

     A pytest plugin for creating fixtures that holds different forms between tests.

  :pypi:`pytest-fixture-maker`
     *last release*: Sep 21, 2021,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to load fixtures from YAML files

  :pypi:`pytest-fixture-marker`
     *last release*: Oct 11, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A pytest plugin to add markers based on fixtures used.

  :pypi:`pytest-fixture-order`
     *last release*: Oct 22, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.0

     pytest plugin to control fixture evaluation order

  :pypi:`pytest-fixture-ref`
     *last release*: Nov 17, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Lets users reference fixtures without name matching magic.

  :pypi:`pytest-fixture-remover`
     *last release*: Feb 14, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A LibCST codemod to remove pytest fixtures applied via the usefixtures decorator, as well as its parametrizations.

  :pypi:`pytest-fixture-rtttg`
     *last release*: Feb 23, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.0.1,<8.0.0)

     Warn or fail on fixture name clash

  :pypi:`pytest-fixtures`
     *last release*: May 01, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Common fixtures for pytest

  :pypi:`pytest-fixtures-fixtures`
     *last release*: Nov 06, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.4.1

     Handy fixtues to access your fixtures from your _pytest tests.

  :pypi:`pytest-fixture-timing`
     *last release*: Dec 11, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0

     Tiny plugin to report total duration per fixture

  :pypi:`pytest-fixture-tools`
     *last release*: Apr 30, 2025,
     *status*: 6 - Mature,
     *requires*: pytest

     Plugin for pytest which provides tools for fixtures

  :pypi:`pytest-fixture-typecheck`
     *last release*: Aug 24, 2021,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin to assert type annotations at runtime.

  :pypi:`pytest-fkit`
     *last release*: Apr 21, 2026,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     A pytest plugin that prevents crashes from killing your test suite

  :pypi:`pytest-flake8`
     *last release*: Nov 09, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     pytest plugin to check FLAKE8 requirements

  :pypi:`pytest-flake8-path`
     *last release*: Sep 09, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A pytest fixture for testing flake8 plugins.

  :pypi:`pytest-flake8-v2`
     *last release*: Mar 01, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7.0)

     pytest plugin to check FLAKE8 requirements

  :pypi:`pytest-flake-detection`
     *last release*: Nov 29, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Continuously runs your tests to detect flaky tests

  :pypi:`pytest-flakefighters`
     *last release*: Mar 05, 2026,
     *status*: N/A,
     *requires*: pytest>=6.2.0

     Pytest plugin implementing flaky test failure detection and classification.

  :pypi:`pytest-flakefinder`
     *last release*: Oct 26, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.7.1)

     Runs tests multiple times to expose flakiness.

  :pypi:`pytest-flakehunter`
     *last release*: Apr 07, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Re-run tests N times, visualize failure heatmaps, and get AI root cause hypotheses

  :pypi:`pytest-flakemark`
     *last release*: May 01, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Differential execution tracer that finds the exact file, line, and root cause of any flaky test.

  :pypi:`pytest-flakes`
     *last release*: Dec 02, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5)

     pytest plugin to check source code with pyflakes

  :pypi:`pytest-flakiness`
     *last release*: May 15, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.2

     Pytest reporter for Flakiness.io

  :pypi:`pytest-flaptastic`
     *last release*: Mar 17, 2019,
     *status*: N/A,
     *requires*: N/A

     Flaptastic py.test plugin

  :pypi:`pytest-flask`
     *last release*: Oct 23, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=5.2

     A set of py.test fixtures to test Flask applications.

  :pypi:`pytest-flask-ligand`
     *last release*: May 14, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.3



  :pypi:`pytest-flask-sqlalchemy`
     *last release*: Apr 30, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.2.1)

     A pytest plugin for preserving test isolation in Flask-SQlAlchemy using database transactions.

  :pypi:`pytest-flask-sqlalchemy-transactions`
     *last release*: Aug 02, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.2.1)

     Run tests in transactions using pytest, Flask, and SQLalchemy.

  :pypi:`pytest-flexreport`
     *last release*: Apr 15, 2023,
     *status*: 4 - Beta,
     *requires*: pytest



  :pypi:`pytest-fluent`
     *last release*: Aug 14, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin in order to provide logs via fluentd

  :pypi:`pytest-fluentbit`
     *last release*: Jun 16, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.0.0)

     A pytest plugin in order to provide logs via fluentbit

  :pypi:`pytest-fly`
     *last release*: Jun 06, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest runner and observer

  :pypi:`pytest-flyte`
     *last release*: May 03, 2021,
     *status*: N/A,
     *requires*: pytest

     Pytest fixtures for simplifying Flyte integration testing

  :pypi:`pytest-fmu-filter`
     *last release*: Jun 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin to filter fmus

  :pypi:`pytest-focus`
     *last release*: May 04, 2019,
     *status*: 4 - Beta,
     *requires*: pytest

     A pytest plugin that alerts user of failed test cases with screen notifications

  :pypi:`pytest-forbid`
     *last release*: Mar 07, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.2,<8.0.0)



  :pypi:`pytest-forcefail`
     *last release*: May 15, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to make the test failing regardless of pytest.mark.xfail

  :pypi:`pytest-forger`
     *last release*: Mar 09, 2026,
     *status*: N/A,
     *requires*: pytest>=7.4.0

     Automatic test scaffolding and mock generation for Python

  :pypi:`pytest-forward-compatability`
     *last release*: Sep 06, 2020,
     *status*: N/A,
     *requires*: N/A

     A name to avoid typosquating pytest-foward-compatibility

  :pypi:`pytest-forward-compatibility`
     *last release*: Sep 29, 2020,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin to shim pytest commandline options for fowards compatibility

  :pypi:`pytest-frappe`
     *last release*: Jul 30, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Pytest Frappe Plugin - A set of pytest fixtures to test Frappe applications

  :pypi:`pytest-freethreaded`
     *last release*: Oct 03, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest plugin for running parallel tests

  :pypi:`pytest-freeze`
     *last release*: Jan 27, 2026,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to simplify writing freeze tests.

  :pypi:`pytest-freezeblaster`
     *last release*: Oct 13, 2025,
     *status*: N/A,
     *requires*: pytest>=6.2.5

     Wrap tests with fixtures in freeze_time

  :pypi:`pytest-freezegun`
     *last release*: Jul 19, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.0.0)

     Wrap tests with fixtures in freeze_time

  :pypi:`pytest-freezer`
     *last release*: Dec 12, 2024,
     *status*: N/A,
     *requires*: pytest>=3.6

     Pytest plugin providing a fixture interface for spulec/freezegun

  :pypi:`pytest-freeze-reqs`
     *last release*: Apr 29, 2021,
     *status*: N/A,
     *requires*: N/A

     Check if requirement files are frozen

  :pypi:`pytest-frozen-uuids`
     *last release*: Apr 17, 2022,
     *status*: N/A,
     *requires*: pytest (>=3.0)

     Deterministically frozen UUID's for your tests

  :pypi:`pytest-fsd`
     *last release*: May 13, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     Feature-Sliced Design (FSD) architecture validation plugin for pytest

  :pypi:`pytest_ftpserver`
     *last release*: Feb 10, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A PyTest plugin which provides an FTP fixture for your tests

  :pypi:`pytest-func-cov`
     *last release*: Apr 15, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=5)

     Pytest plugin for measuring function coverage

  :pypi:`pytest-funcnodes`
     *last release*: Dec 21, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Testing plugin for funcnodes

  :pypi:`pytest-funparam`
     *last release*: Dec 02, 2021,
     *status*: 4 - Beta,
     *requires*: pytest >=4.6.0

     An alternative way to parametrize test cases.

  :pypi:`pytest-fusesoc`
     *last release*: May 31, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin to run FuseSoC simulation targets.

  :pypi:`pytest-fv`
     *last release*: Jun 06, 2025,
     *status*: N/A,
     *requires*: pytest

     pytest extensions to support running functional-verification jobs

  :pypi:`pytest-fxa`
     *last release*: Aug 28, 2018,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for Firefox Accounts

  :pypi:`pytest-fxa-mte`
     *last release*: May 21, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin for Firefox Accounts

  :pypi:`pytest-fxtest`
     *last release*: Oct 27, 2020,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-fzf`
     *last release*: Jan 06, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0.0

     fzf-based test selector for pytest

  :pypi:`pytest_gae`
     *last release*: Aug 03, 2016,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin for apps written with Google's AppEngine

  :pypi:`pytest-gak`
     *last release*: Apr 10, 2025,
     *status*: N/A,
     *requires*: N/A

     A Pytest plugin and command line tool for interactive testing with Pytest

  :pypi:`pytest-gather-fixtures`
     *last release*: Aug 18, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     set up asynchronous pytest fixtures concurrently

  :pypi:`pytest-gc`
     *last release*: Feb 01, 2018,
     *status*: N/A,
     *requires*: N/A

     The garbage collector plugin for py.test

  :pypi:`pytest-gcov`
     *last release*: Feb 01, 2018,
     *status*: 3 - Alpha,
     *requires*: N/A

     Uses gcov to measure test coverage of a C library

  :pypi:`pytest-gcppubsub`
     *last release*: Mar 10, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A Pytest fixture for managing Google Cloud Platform PubSub emulator

  :pypi:`pytest-gcpsecretmanager`
     *last release*: Feb 18, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A PyTest plugin for mocking GCP's Secret Manager

  :pypi:`pytest-gcs`
     *last release*: Jan 24, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2

     GCS fixtures and fixture factories for Pytest.

  :pypi:`pytest-gee`
     *last release*: Oct 16, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     The Python plugin for your GEE based packages.

  :pypi:`pytest-gevent`
     *last release*: Feb 25, 2020,
     *status*: N/A,
     *requires*: pytest

     Ensure that gevent is properly patched when invoking pytest

  :pypi:`pytest-gherkin`
     *last release*: Jul 27, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=5.0.0)

     A flexible framework for executing BDD gherkin tests

  :pypi:`pytest-gh-log-group`
     *last release*: Jan 11, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest plugin for gh actions

  :pypi:`pytest-ghostinspector`
     *last release*: May 17, 2016,
     *status*: 3 - Alpha,
     *requires*: N/A

     For finding/executing Ghost Inspector tests

  :pypi:`pytest-girder`
     *last release*: Jun 02, 2026,
     *status*: N/A,
     *requires*: pytest>=3.6

     A set of pytest fixtures for testing Girder applications.

  :pypi:`pytest-git`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Git repository fixture for py.test

  :pypi:`pytest-gitconfig`
     *last release*: Dec 28, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.1.2

     Provide a Git config sandbox for testing

  :pypi:`pytest-gitcov`
     *last release*: Jan 11, 2020,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     Pytest plugin for reporting on coverage of the last git commit.

  :pypi:`pytest-git-diff`
     *last release*: Apr 02, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin that allows the user to select the tests affected by a range of git commits

  :pypi:`pytest-git-fixtures`
     *last release*: Mar 11, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with git.

  :pypi:`pytest-github`
     *last release*: Mar 07, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Plugin for py.test that associates tests with github issues using a marker.

  :pypi:`pytest-github-actions-annotate-failures`
     *last release*: Mar 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest plugin to annotate failed tests with a workflow command for GitHub Actions

  :pypi:`pytest-github-report`
     *last release*: Jun 03, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Generate a GitHub report using pytest in GitHub Workflows

  :pypi:`pytest-gitignore`
     *last release*: Jul 17, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to ignore the same files as git

  :pypi:`pytest-gitlab`
     *last release*: Oct 16, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest Plugin for Gitlab

  :pypi:`pytest-gitlabci-parallelized`
     *last release*: Mar 08, 2023,
     *status*: N/A,
     *requires*: N/A

     Parallelize pytest across GitLab CI workers.

  :pypi:`pytest-gitlab-code-quality`
     *last release*: Apr 27, 2026,
     *status*: N/A,
     *requires*: pytest>=5.0.0

     Collects warnings while testing and generates a GitLab Code Quality Report.

  :pypi:`pytest-gitlab-fold`
     *last release*: Dec 31, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=2.6.0

     Folds output sections in GitLab CI build log

  :pypi:`pytest-gitscope`
     *last release*: Sep 24, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     A pragmatic pytest plugin that runs only the tests that matter, and ship faster

  :pypi:`pytest-git-selector`
     *last release*: Nov 17, 2022,
     *status*: N/A,
     *requires*: N/A

     Utility to select tests that have had its dependencies modified (as identified by git diff)

  :pypi:`pytest-glamor-allure`
     *last release*: Jan 30, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<=9.0.2

     Extends allure-pytest functionality

  :pypi:`pytest-glaze`
     *last release*: May 20, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     A thin, transparent coat that makes your test output shine.

  :pypi:`pytest-glow-report`
     *last release*: Dec 08, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0; extra == "dev"

     Beautiful, glowing HTML test reports for PyTest and unittest.

  :pypi:`pytest-gnupg-fixtures`
     *last release*: Mar 04, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixtures for testing with gnupg.

  :pypi:`pytest-golden`
     *last release*: Jan 06, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.1.2

     Plugin for pytest that offloads expected outputs to data files

  :pypi:`pytest-goldie`
     *last release*: May 23, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A plugin to support golden tests with pytest.

  :pypi:`pytest-google-chat`
     *last release*: Mar 27, 2022,
     *status*: 4 - Beta,
     *requires*: pytest

     Notify google chat channel for test results

  :pypi:`pytest-google-cloud-storage`
     *last release*: Sep 11, 2025,
     *status*: N/A,
     *requires*: pytest>=8.0.0

     Pytest custom features, e.g. fixtures and various tests. Aimed to emulate Google Cloud Storage service

  :pypi:`pytest-grader`
     *last release*: Aug 25, 2025,
     *status*: N/A,
     *requires*: pytest>=8

     Pytest extension for scoring programming assignments.

  :pypi:`pytest-gradescope`
     *last release*: Apr 29, 2025,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for Gradescope integration

  :pypi:`pytest-graphql-schema`
     *last release*: Oct 18, 2019,
     *status*: N/A,
     *requires*: N/A

     Get graphql schema as fixture for pytest

  :pypi:`pytest-greendots`
     *last release*: Feb 08, 2014,
     *status*: 3 - Alpha,
     *requires*: N/A

     Green progress dots

  :pypi:`pytest-greener`
     *last release*: Dec 24, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.3

     Pytest plugin for Greener

  :pypi:`pytest-green-light`
     *last release*: Nov 03, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Pytest plugin that gives SQLAlchemy async engines the green light - automatically fixes MissingGreenlet errors

  :pypi:`pytest-greet`
     *last release*: Oct 21, 2025,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-gremlins`
     *last release*: Apr 03, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Fast-first mutation testing for pytest. Let the gremlins loose, see which ones survive.

  :pypi:`pytest-group-by-class`
     *last release*: Jun 27, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.5)

     A Pytest plugin for running a subset of your tests by splitting them in to groups of classes.

  :pypi:`pytest-growl`
     *last release*: Jan 13, 2014,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Growl notifications for pytest results.

  :pypi:`pytest-grpc`
     *last release*: May 01, 2020,
     *status*: N/A,
     *requires*: pytest (>=3.6.0)

     pytest plugin for grpc

  :pypi:`pytest-grpc-aio`
     *last release*: Oct 28, 2025,
     *status*: N/A,
     *requires*: pytest>=3.6.0

     pytest plugin for grpc.aio

  :pypi:`pytest-grunnur`
     *last release*: Jul 26, 2024,
     *status*: N/A,
     *requires*: pytest>=6

     Py.Test plugin for Grunnur-based packages.

  :pypi:`pytest_gui_status`
     *last release*: Jan 23, 2016,
     *status*: N/A,
     *requires*: pytest

     Show pytest status in gui

  :pypi:`pytest-hammer`
     *last release*: Mar 27, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     tools such as db tools of pytest

  :pypi:`pytest-hammertime`
     *last release*: Jul 28, 2018,
     *status*: N/A,
     *requires*: pytest

     Display "🔨 " instead of "." for passed pytest tests.

  :pypi:`pytest-hardware-test-report`
     *last release*: Apr 01, 2024,
     *status*: 4 - Beta,
     *requires*: pytest<9.0.0,>=8.0.0

     A simple plugin to use with pytest

  :pypi:`pytest-harmony`
     *last release*: Jan 17, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.1,<8.0.0)

     Chain tests and data with pytest

  :pypi:`pytest-harvest`
     *last release*: Mar 16, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Store data created during your pytest tests execution, and retrieve it at the end of the session, e.g. for applicative benchmarking purposes.

  :pypi:`pytest-hbtn`
     *last release*: May 19, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     Shared pytest fixtures for hbtn-portal task grading

  :pypi:`pytest-helm`
     *last release*: Feb 21, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0.0

     Simple, ergonomic Helm manifest fixtures for pytest.

  :pypi:`pytest-helm-charts`
     *last release*: Dec 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest<9,>=8.0.0

     A plugin to provide different types and configs of Kubernetes clusters that can be used for testing.

  :pypi:`pytest-helm-templates`
     *last release*: Aug 07, 2024,
     *status*: N/A,
     *requires*: pytest~=7.4.0; extra == "dev"

     Pytest fixtures for unit testing the output of helm templates

  :pypi:`pytest-helper`
     *last release*: May 31, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Functions to help in using the pytest testing framework

  :pypi:`pytest-helpers`
     *last release*: May 17, 2020,
     *status*: N/A,
     *requires*: pytest

     pytest helpers

  :pypi:`pytest-helpers-namespace`
     *last release*: Dec 29, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=6.0.0)

     Pytest Helpers Namespace Plugin

  :pypi:`pytest-henry`
     *last release*: Aug 29, 2023,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-hidecaptured`
     *last release*: May 04, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.8.5)

     Hide captured output

  :pypi:`pytest-himark`
     *last release*: Jun 05, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     This plugin aims to create markers automatically based on a json configuration.

  :pypi:`pytest-historic`
     *last release*: Apr 08, 2020,
     *status*: N/A,
     *requires*: pytest

     Custom report to display pytest historical execution records

  :pypi:`pytest-historic-hook`
     *last release*: Apr 08, 2020,
     *status*: N/A,
     *requires*: pytest

     Custom listener to store execution results into MYSQL DB, which is used for pytest-historic report

  :pypi:`pytest-history`
     *last release*: Jan 14, 2024,
     *status*: N/A,
     *requires*: pytest (>=7.4.3,<8.0.0)

     Pytest plugin to keep a history of your pytest runs

  :pypi:`pytest-home`
     *last release*: Jul 28, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Home directory fixtures

  :pypi:`pytest-homeassistant`
     *last release*: Aug 12, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin for use with homeassistant custom components.

  :pypi:`pytest-homeassistant-custom-component`
     *last release*: Jun 06, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest==9.0.3

     Experimental package to automatically extract test plugins for Home Assistant custom components

  :pypi:`pytest-homeassistant-custom-component-framework`
     *last release*: Jun 06, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest==9.0.3

     Experimental package to automatically extract test plugins for Home Assistant custom components

  :pypi:`pytest-Honda-report`
     *last release*: Apr 11, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Enterprise-grade pytest HTML report plugin with Chinese UI, API details, and historical trends

  :pypi:`pytest-honey`
     *last release*: Jan 07, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to use with pytest

  :pypi:`pytest-honors`
     *last release*: Mar 06, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     Report on tests that honor constraints, and guard against regressions

  :pypi:`pytest-hot-reloading`
     *last release*: Sep 23, 2024,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-hot-test`
     *last release*: Dec 10, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A plugin that tracks test changes

  :pypi:`pytest-houdini`
     *last release*: May 27, 2026,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=9.0.3

     pytest plugin for testing code in Houdini

  :pypi:`pytest-hoverfly`
     *last release*: Jan 30, 2023,
     *status*: N/A,
     *requires*: pytest (>=5.0)

     Simplify working with Hoverfly from pytest

  :pypi:`pytest-hoverfly-wrapper`
     *last release*: Feb 27, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.7.0)

     Integrates the Hoverfly HTTP proxy into Pytest

  :pypi:`pytest-hpfeeds`
     *last release*: Feb 28, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.4,<7.0.0)

     Helpers for testing hpfeeds in your python project

  :pypi:`pytest-html`
     *last release*: Jan 19, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     pytest plugin for generating HTML reports

  :pypi:`pytest-html5`
     *last release*: Dec 18, 2025,
     *status*: N/A,
     *requires*: N/A

     the best report for pytest

  :pypi:`pytest-html-cn`
     *last release*: Aug 19, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest!=6.0.0,>=5.0

     pytest plugin for generating HTML reports

  :pypi:`pytest-html-dashboard`
     *last release*: Nov 24, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Beautiful dashboard-style HTML reports for pytest with charts, error analysis, and visual insights

  :pypi:`pytest-html-lee`
     *last release*: Jun 30, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.0)

     optimized pytest plugin for generating HTML reports

  :pypi:`pytest-html-merger`
     *last release*: Jul 12, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest HTML reports merging utility

  :pypi:`pytest-html-nova-act`
     *last release*: Mar 30, 2026,
     *status*: N/A,
     *requires*: N/A

     A Pytest Plugin for Amazon Nova Act Python SDK.

  :pypi:`pytest-html-object-storage`
     *last release*: Jan 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest report plugin for send HTML report on object-storage

  :pypi:`pytest-html-plus`
     *last release*: May 07, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Generate Actionable, automatic screenshots, unified Mobile friendly Pytest HTML report in less than 3 seconds — no hooks, merge plugins, no config, xdist-ready.

  :pypi:`pytest-html-profiling`
     *last release*: Feb 11, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.0)

     Pytest plugin for generating HTML reports with per-test profiling and optionally call graph visualizations. Based on pytest-html by Dave Hunt.

  :pypi:`pytest-html-report`
     *last release*: Jun 24, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0

     Enhanced HTML reporting for pytest with categories, specifications, and detailed logging

  :pypi:`pytest-html-report-builder`
     *last release*: Apr 22, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     A pytest plugin that generates self-contained HTML automation reports with visual charts.

  :pypi:`pytest-html-reporter`
     *last release*: Feb 13, 2022,
     *status*: N/A,
     *requires*: N/A

     Generates a static html report based on pytest framework

  :pypi:`pytest-html-report-merger`
     *last release*: May 22, 2024,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-html-thread`
     *last release*: Dec 29, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for generating HTML reports

  :pypi:`pytest-htmlx`
     *last release*: Sep 09, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     Custom HTML report plugin for Pytest with charts and tables

  :pypi:`pytest-http`
     *last release*: Aug 22, 2024,
     *status*: N/A,
     *requires*: pytest

     Fixture "http" for http requests

  :pypi:`pytest-httpbin`
     *last release*: Sep 18, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest; extra == "test"

     Easily test your HTTP library against a local copy of httpbin

  :pypi:`pytest-httpchain`
     *last release*: Jun 04, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for HTTP testing using JSON files

  :pypi:`pytest-httpchain-core`
     *last release*: Jun 04, 2026,
     *status*: N/A,
     *requires*: N/A

     Shared base types for pytest-httpchain

  :pypi:`pytest-httpchain-jsonref`
     *last release*: Jun 04, 2026,
     *status*: N/A,
     *requires*: N/A

     JSON reference ($ref) support for pytest-httpchain

  :pypi:`pytest-httpchain-mcp`
     *last release*: Apr 02, 2026,
     *status*: N/A,
     *requires*: N/A

     MCP server for pytest-httpchain

  :pypi:`pytest-httpchain-models`
     *last release*: Jun 04, 2026,
     *status*: N/A,
     *requires*: N/A

     Pydantic models for pytest-httpchain

  :pypi:`pytest-httpchain-templates`
     *last release*: Jun 04, 2026,
     *status*: N/A,
     *requires*: N/A

     Templating support for pytest-httpchain

  :pypi:`pytest-httpchain-userfunc`
     *last release*: Jun 04, 2026,
     *status*: N/A,
     *requires*: N/A

     User functions support for pytest-httpchain

  :pypi:`pytest-httpdbg`
     *last release*: Mar 29, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin to record HTTP(S) requests with stack trace.

  :pypi:`pytest-http-mocker`
     *last release*: Oct 20, 2019,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for http mocking (via https://github.com/vilus/mocker)

  :pypi:`pytest-httpretty`
     *last release*: Feb 16, 2014,
     *status*: 3 - Alpha,
     *requires*: N/A

     A thin wrapper of HTTPretty for pytest

  :pypi:`pytest_httpserver`
     *last release*: Feb 14, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest-httpserver is a httpserver for pytest

  :pypi:`pytest-httptesting`
     *last release*: Dec 19, 2024,
     *status*: N/A,
     *requires*: pytest>=8.2.0

     http_testing framework on top of pytest

  :pypi:`pytest-httpx`
     *last release*: Apr 09, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest==9.*

     Send responses to httpx.

  :pypi:`pytest-httpx2`
     *last release*: May 20, 2026,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for mocking out httpx2 using respx.

  :pypi:`pytest-httpx-blockage`
     *last release*: Feb 16, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.1)

     Disable httpx requests during a test run

  :pypi:`pytest-httpx-recorder`
     *last release*: Jan 04, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Recorder feature based on pytest_httpx, like recorder feature in responses.

  :pypi:`pytest-hue`
     *last release*: May 09, 2019,
     *status*: N/A,
     *requires*: N/A

     Visualise PyTest status via your Phillips Hue lights

  :pypi:`pytest-human`
     *last release*: Jan 25, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8

     A beautiful nested pytest HTML test report

  :pypi:`pytest-hy`
     *last release*: Feb 11, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin for discovering and running Hy test files

  :pypi:`pytest-hylang`
     *last release*: Mar 28, 2021,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin to allow running tests written in hylang

  :pypi:`pytest-hypo-25`
     *last release*: Jan 12, 2020,
     *status*: 3 - Alpha,
     *requires*: N/A

     help hypo module for pytest

  :pypi:`pytest-hypothesis`
     *last release*: Feb 09, 2026,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-iam`
     *last release*: Nov 02, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A fully functional OAUTH2 / OpenID Connect (OIDC) / SCIM server to be used in your testsuite

  :pypi:`pytest-ibutsu`
     *last release*: Feb 23, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     A plugin to sent pytest results to an Ibutsu server

  :pypi:`pytest-icdiff`
     *last release*: Dec 05, 2023,
     *status*: 4 - Beta,
     *requires*: pytest

     use icdiff for better error messages in pytest assertions

  :pypi:`pytest-idapro`
     *last release*: Nov 03, 2018,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for idapython. Allows a pytest setup to run tests outside and inside IDA in an automated manner by runnig pytest inside IDA and by mocking idapython api

  :pypi:`pytest-idem`
     *last release*: Dec 13, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A pytest plugin to help with testing idem projects

  :pypi:`pytest-idempotent`
     *last release*: Jul 25, 2022,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for testing function idempotence.

  :pypi:`pytest-ignore-flaky`
     *last release*: Apr 20, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0

     ignore failures from flaky tests (pytest plugin)

  :pypi:`pytest-ignore-test-results`
     *last release*: Feb 03, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     A pytest plugin to ignore test results.

  :pypi:`pytest-image-diff`
     *last release*: Dec 31, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest



  :pypi:`pytest-image-snapshot`
     *last release*: Jun 02, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     A pytest plugin for image snapshot management and comparison.

  :pypi:`pytest-impacted`
     *last release*: May 19, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0.0

     A pytest plugin that selectively runs tests impacted by code changes via git introspection, AST parsing, and dependency graph analysis.

  :pypi:`pytest-impacted-rs`
     *last release*: May 19, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     Rust-accelerated import parsing for pytest-impacted (ruff parser + rayon parallelism).

  :pypi:`pytest-imply`
     *last release*: Mar 21, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Pytest plugin for test implication — skip tests implied by stronger ones

  :pypi:`pytest-import-check`
     *last release*: Jul 19, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.1

     pytest plugin to check whether Python modules can be imported

  :pypi:`pytest-incremental`
     *last release*: Apr 24, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     an incremental test runner (pytest plugin)

  :pypi:`pytest-in-docker`
     *last release*: Feb 09, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=9.0.2

     Seamlessly run pytest tests inside docker containers

  :pypi:`pytest-infinity`
     *last release*: Jun 09, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.0.0



  :pypi:`pytest-influx`
     *last release*: Oct 16, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.3

     Pytest plugin for managing your influx instance between test runs

  :pypi:`pytest-influxdb`
     *last release*: Apr 20, 2021,
     *status*: N/A,
     *requires*: N/A

     Plugin for influxdb and pytest integration.

  :pypi:`pytest-info-collector`
     *last release*: May 26, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin to collect information from tests

  :pypi:`pytest-info-plugin`
     *last release*: Sep 14, 2023,
     *status*: N/A,
     *requires*: N/A

     Get executed interface information in pytest interface automation framework

  :pypi:`pytest-informative-node`
     *last release*: Apr 25, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     display more node ininformation.

  :pypi:`pytest-infrahouse`
     *last release*: Mar 17, 2026,
     *status*: 4 - Beta,
     *requires*: pytest~=9.0

     A set of fixtures to use with pytest

  :pypi:`pytest-infrastructure`
     *last release*: Apr 12, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest stack validation prior to testing executing

  :pypi:`pytest-ini`
     *last release*: Apr 26, 2022,
     *status*: N/A,
     *requires*: N/A

     Reuse pytest.ini to store env variables

  :pypi:`pytest-initry`
     *last release*: Apr 30, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.1.1

     Plugin for sending automation test data from Pytest to the initry

  :pypi:`pytest-inject`
     *last release*: Nov 25, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     A pytest plugin that allows you to inject arguments into fixtures and parametrized tests using pytest command-line options.

  :pypi:`pytest-inline`
     *last release*: Oct 24, 2024,
     *status*: 4 - Beta,
     *requires*: pytest<9.0,>=7.0

     A pytest plugin for writing inline tests

  :pypi:`pytest-inline-snapshot`
     *last release*: Nov 09, 2025,
     *status*: N/A,
     *requires*: N/A

     inline-snapshot is the package you are looking for

  :pypi:`pytest-inline-tdd`
     *last release*: Mar 09, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<9.0,>=7.0

     A pytest plugin for writing inline tests

  :pypi:`pytest-inmanta`
     *last release*: Nov 18, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A py.test plugin providing fixtures to simplify inmanta modules testing.

  :pypi:`pytest-inmanta-extensions`
     *last release*: Jun 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Inmanta tests package

  :pypi:`pytest-inmanta-lsm`
     *last release*: Apr 29, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Common fixtures used in inmanta LSM related modules

  :pypi:`pytest-inmanta-srlinux`
     *last release*: Apr 22, 2025,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest library to facilitate end to end testing of inmanta projects

  :pypi:`pytest-inmanta-yang`
     *last release*: Oct 28, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     Common fixtures used in inmanta yang related modules

  :pypi:`pytest-Inomaly`
     *last release*: Feb 13, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     A simple image diff plugin for pytest

  :pypi:`pytest-in-robotframework`
     *last release*: Nov 23, 2024,
     *status*: N/A,
     *requires*: pytest

     The extension enables easy execution of pytest tests within the Robot Framework environment.

  :pypi:`pytest-insper`
     *last release*: Mar 21, 2024,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for courses at Insper

  :pypi:`pytest-insta`
     *last release*: Nov 22, 2025,
     *status*: N/A,
     *requires*: pytest>=9.0.0

     A practical snapshot testing plugin for pytest

  :pypi:`pytest-instafail`
     *last release*: Mar 31, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=5)

     pytest plugin to show failures instantly

  :pypi:`pytest-instrument`
     *last release*: Apr 05, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.1.0)

     pytest plugin to instrument tests

  :pypi:`pytest-insubprocess`
     *last release*: Dec 08, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.4

     A pytest plugin to execute test cases in a subprocess

  :pypi:`pytest-integration`
     *last release*: Nov 17, 2022,
     *status*: N/A,
     *requires*: N/A

     Organizing pytests by integration or not

  :pypi:`pytest-integration-mark`
     *last release*: May 22, 2023,
     *status*: N/A,
     *requires*: pytest (>=5.2)

     Automatic integration test marking and excluding plugin for pytest

  :pypi:`pytest-intent`
     *last release*: Dec 17, 2025,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=9.0.0

     A pytest plugin for tracking requirement coverage.

  :pypi:`pytest-interactive`
     *last release*: Nov 30, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     A pytest plugin for console based interactive test selection just after the collection phase

  :pypi:`pytest-intercept-remote`
     *last release*: May 24, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.6)

     Pytest plugin for intercepting outgoing connection requests during pytest run.

  :pypi:`pytest-interface-tester`
     *last release*: Feb 11, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest plugin for checking charm relation interface protocol compliance.

  :pypi:`pytest-invenio`
     *last release*: Mar 16, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<9.0.0,>=6

     Pytest fixtures for Invenio.

  :pypi:`pytest-involve`
     *last release*: Feb 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Run tests covering a specific file or changeset

  :pypi:`pytest-iovis`
     *last release*: Nov 06, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.1.0

     A Pytest plugin to enable Jupyter Notebook testing with Papermill

  :pypi:`pytest-ipdb`
     *last release*: Mar 20, 2013,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     A py.test plug-in to enable drop to ipdb debugger on test failure.

  :pypi:`pytest-ipso`
     *last release*: Mar 24, 2026,
     *status*: N/A,
     *requires*: pytest

     pytest plugin for running ipso notebook cell tests

  :pypi:`pytest-ipynb`
     *last release*: Jan 29, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A

     THIS PROJECT IS ABANDONED

  :pypi:`pytest-ipynb2`
     *last release*: Mar 09, 2025,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin to run tests in Jupyter Notebooks

  :pypi:`pytest-ipywidgets`
     *last release*: May 14, 2026,
     *status*: N/A,
     *requires*: pytest



  :pypi:`pytest-isolate`
     *last release*: Jun 01, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     Run pytest tests in isolated subprocesses

  :pypi:`pytest-isolated`
     *last release*: Mar 04, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Run marked pytest tests in grouped subprocesses (cross-platform).

  :pypi:`pytest-isolate-mpi`
     *last release*: Feb 24, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=5

     pytest-isolate-mpi allows for MPI-parallel tests being executed in a segfault and MPI_Abort safe manner

  :pypi:`pytest-isort`
     *last release*: Mar 05, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.0)

     py.test plugin to check import ordering using isort

  :pypi:`pytest-issues`
     *last release*: May 29, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8

     Decorators for pytest tests that should issue exceptions or warnings

  :pypi:`pytest-it`
     *last release*: Jan 29, 2024,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest plugin to display test reports as a plaintext spec, inspired by Rspec: https://github.com/mattduck/pytest-it.

  :pypi:`pytest-item-dict`
     *last release*: May 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.3.0

     Get a hierarchical dict of session.items

  :pypi:`pytest-iterassert`
     *last release*: May 11, 2020,
     *status*: 3 - Alpha,
     *requires*: N/A

     Nicer list and iterable assertion messages for pytest

  :pypi:`pytest-iteration`
     *last release*: Aug 22, 2024,
     *status*: N/A,
     *requires*: pytest

     Add iteration mark for tests

  :pypi:`pytest-iters`
     *last release*: May 09, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     A contextmanager pytest fixture for handling multiple mock iters

  :pypi:`pytest_jar_yuan`
     *last release*: Dec 12, 2022,
     *status*: N/A,
     *requires*: N/A

     A allure and pytest used package

  :pypi:`pytest-jasmine`
     *last release*: Nov 04, 2017,
     *status*: 1 - Planning,
     *requires*: N/A

     Run jasmine tests from your pytest test suite

  :pypi:`pytest-jax-bench`
     *last release*: Apr 06, 2026,
     *status*: N/A,
     *requires*: pytest>=7

     Pytest plugin to profile jitted JAX functions (compile time, runtime, memory).

  :pypi:`pytest-jelastic`
     *last release*: Nov 16, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.2.0,<8.0.0)

     Pytest plugin defining the necessary command-line options to pass to pytests testing a Jelastic environment.

  :pypi:`pytest-jest`
     *last release*: May 22, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.3.2)

     A custom jest-pytest oriented Pytest reporter

  :pypi:`pytest-jinja`
     *last release*: Oct 04, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest (>=6.2.5,<7.0.0)

     A plugin to generate customizable jinja-based HTML reports in pytest

  :pypi:`pytest-jinja-check`
     *last release*: Mar 14, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Pytest plugin to lint Jinja2 templates in FastAPI applications

  :pypi:`pytest-jira`
     *last release*: Mar 19, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=2.2.4

     py.test JIRA integration plugin, using markers

  :pypi:`pytest-jira-xfail`
     *last release*: Jul 09, 2024,
     *status*: N/A,
     *requires*: pytest>=7.2.0

     Plugin skips (xfail) tests if unresolved Jira issue(s) linked

  :pypi:`pytest-jira-xray`
     *last release*: Apr 24, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.4

     pytest plugin to integrate tests with JIRA XRAY

  :pypi:`pytest-job-selection`
     *last release*: Jan 30, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin for load balancing test suites

  :pypi:`pytest-jobserver`
     *last release*: Feb 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Limit parallel tests with posix jobserver.

  :pypi:`pytest-joke`
     *last release*: Oct 08, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.2.1)

     Test failures are better served with humor.

  :pypi:`pytest-jscov`
     *last release*: Apr 04, 2026,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for JavaScript coverage via Playwright CDP

  :pypi:`pytest-json`
     *last release*: Jan 18, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Generate JSON test reports

  :pypi:`pytest-json-ctrf`
     *last release*: Apr 30, 2026,
     *status*: N/A,
     *requires*: pytest>6.0.0

     Pytest plugin to generate json report in CTRF (Common Test Report Format)

  :pypi:`pytest-json-fixtures`
     *last release*: Mar 14, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     JSON output for the --fixtures flag

  :pypi:`pytest-jsonlint`
     *last release*: Aug 04, 2016,
     *status*: N/A,
     *requires*: N/A

     UNKNOWN

  :pypi:`pytest-json-report`
     *last release*: Mar 15, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.8.0)

     A pytest plugin to report test results as JSON files

  :pypi:`pytest-json-report-wip`
     *last release*: Jul 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest >=3.8.0

     A pytest plugin to report test results as JSON files

  :pypi:`pytest-jsonschema`
     *last release*: Nov 07, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.0

     A pytest plugin to perform JSONSchema validations

  :pypi:`pytest-jsonschema-snapshot`
     *last release*: Mar 29, 2026,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for automatic JSON Schema generation and validation from examples

  :pypi:`pytest-jtr`
     *last release*: Jul 21, 2024,
     *status*: N/A,
     *requires*: pytest<8.0.0,>=7.1.2

     pytest plugin supporting json test report output

  :pypi:`pytest-jubilant`
     *last release*: Apr 07, 2026,
     *status*: N/A,
     *requires*: pytest>=8.3.5

     Add your description here

  :pypi:`pytest-junit-logging`
     *last release*: Nov 27, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0

     A pytest plugin for embedding log output into JUnit XML reports

  :pypi:`pytest-junit-xray-xml`
     *last release*: Jan 01, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     Export test results in an augmented JUnit format for usage with Xray ()

  :pypi:`pytest-jupyter`
     *last release*: Oct 16, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     A pytest plugin for testing Jupyter libraries and extensions.

  :pypi:`pytest-jupyter-deploy`
     *last release*: May 27, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.3.5

     Pytest plugin for E2E testing of jupyter-deploy templates

  :pypi:`pytest-jupyterhub`
     *last release*: Apr 25, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A reusable JupyterHub pytest plugin

  :pypi:`pytest-just`
     *last release*: Mar 22, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0.0

     A pytest plugin for testing justfile recipes

  :pypi:`pytest-jux`
     *last release*: Jan 08, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.4

     A pytest plugin for signing and publishing JUnit XML test reports to the Jux REST API

  :pypi:`pytest-k8s`
     *last release*: Jul 07, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.1

     Kubernetes-based testing for pytest

  :pypi:`pytest-kafka`
     *last release*: Aug 14, 2024,
     *status*: N/A,
     *requires*: pytest

     Zookeeper, Kafka server, and Kafka consumer fixtures for Pytest

  :pypi:`pytest-kafka-broker`
     *last release*: Apr 03, 2026,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to run a single-broker Kafka cluster

  :pypi:`pytest-kafka-contract`
     *last release*: May 10, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0.0

     A pytest plugin and CLI for validating Kafka JSON and Avro messages against contracts.

  :pypi:`pytest-kafkavents`
     *last release*: Sep 08, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     A plugin to send pytest events to Kafka

  :pypi:`pytest-kairos`
     *last release*: Aug 08, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=5.0.0

     Pytest plugin with random number generation, reproducibility, and test repetition

  :pypi:`pytest-kasima`
     *last release*: Jan 26, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7.2.1,<8.0.0)

     Display horizontal lines above and below the captured standard output for easy viewing.

  :pypi:`pytest-kedge`
     *last release*: Jan 10, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Agent-friendly structured test data collector for pytest

  :pypi:`pytest-keep-together`
     *last release*: Dec 07, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin to customize test ordering by running all 'related' tests together

  :pypi:`pytest-kexi`
     *last release*: Apr 29, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.2,<8.0.0)



  :pypi:`pytest-keyring`
     *last release*: Apr 10, 2026,
     *status*: N/A,
     *requires*: pytest>=8.0.2

     A Pytest plugin to access the system's keyring to provide credentials for tests

  :pypi:`pytest-kind`
     *last release*: Nov 30, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Kubernetes test support with KIND for pytest

  :pypi:`pytest-kivy`
     *last release*: Jul 06, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.6)

     Kivy GUI tests fixtures using pytest

  :pypi:`pytest-knows`
     *last release*: Aug 22, 2014,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin that can automaticly skip test case based on dependence info calculated by trace

  :pypi:`pytest-konira`
     *last release*: Oct 09, 2011,
     *status*: N/A,
     *requires*: N/A

     Run Konira DSL tests with py.test

  :pypi:`pytest-kookit`
     *last release*: Sep 10, 2024,
     *status*: N/A,
     *requires*: N/A

     Your simple but kooky integration testing with pytest

  :pypi:`pytest-koopmans`
     *last release*: Nov 21, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A plugin for testing the koopmans package

  :pypi:`pytest-krtech-common`
     *last release*: Nov 28, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest krtech common library

  :pypi:`pytest-kubernetes`
     *last release*: Apr 14, 2026,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=9.0.0

     A lightweight pytest plugin for managing local Kubernetes clusters (minikube, k3d, kind)

  :pypi:`pytest_kustomize`
     *last release*: Dec 08, 2025,
     *status*: N/A,
     *requires*: N/A

     Parse and validate kustomize output

  :pypi:`pytest-kuunda`
     *last release*: Feb 25, 2024,
     *status*: 4 - Beta,
     *requires*: pytest >=6.2.0

     pytest plugin to help with test data setup for PySpark tests

  :pypi:`pytest-kwparametrize`
     *last release*: Jan 22, 2021,
     *status*: N/A,
     *requires*: pytest (>=6)

     Alternate syntax for @pytest.mark.parametrize with test cases as dictionaries and default value fallbacks

  :pypi:`pytest-lambda`
     *last release*: May 27, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest<9,>=3.6

     Define pytest fixtures with lambda functions.

  :pypi:`pytest-lamp`
     *last release*: Jan 06, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A



  :pypi:`pytest-langchain`
     *last release*: Feb 26, 2023,
     *status*: N/A,
     *requires*: pytest

     Pytest-style test runner for langchain agents

  :pypi:`pytest-language-server`
     *last release*: Jun 04, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     A blazingly fast Language Server Protocol implementation for pytest

  :pypi:`pytest-lark`
     *last release*: Nov 05, 2023,
     *status*: N/A,
     *requires*: N/A

     Create fancy and clear HTML test reports.

  :pypi:`pytest-latin-hypercube`
     *last release*: Jun 26, 2025,
     *status*: N/A,
     *requires*: pytest

     Implementation of Latin Hypercube Sampling for pytest.

  :pypi:`pytest-launchable`
     *last release*: Apr 05, 2023,
     *status*: N/A,
     *requires*: pytest (>=4.2.0)

     Launchable Pytest Plugin

  :pypi:`pytest-layab`
     *last release*: Oct 05, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest fixtures for layab.

  :pypi:`pytest-lazy-fixture`
     *last release*: Feb 01, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.2.5)

     It helps to use fixtures in pytest.mark.parametrize

  :pypi:`pytest-lazy-fixtures`
     *last release*: Sep 16, 2025,
     *status*: N/A,
     *requires*: pytest>=7

     Allows you to use fixtures in @pytest.mark.parametrize.

  :pypi:`pytest-ldap`
     *last release*: Aug 18, 2020,
     *status*: N/A,
     *requires*: pytest

     python-ldap fixtures for pytest

  :pypi:`pytest-leak-finder`
     *last release*: Dec 19, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     Find the test that's leaking before the one that fails

  :pypi:`pytest-leaks`
     *last release*: Nov 27, 2019,
     *status*: 1 - Planning,
     *requires*: N/A

     A pytest plugin to trace resource leaks.

  :pypi:`pytest-leaping`
     *last release*: Mar 27, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A simple plugin to use with pytest

  :pypi:`pytest-leela`
     *last release*: Apr 27, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Type-aware mutation testing for Python — fast, opinionated, pytest-native

  :pypi:`pytest-leo-interface`
     *last release*: Mar 19, 2025,
     *status*: N/A,
     *requires*: N/A

     Pytest extension tool for leo projects.

  :pypi:`pytest-level`
     *last release*: Oct 21, 2019,
     *status*: N/A,
     *requires*: pytest

     Select tests of a given level or lower

  :pypi:`pytest-lf-skip`
     *last release*: Feb 27, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3.5

     A pytest plugin which makes \`--last-failed\` skip instead of deselect tests.

  :pypi:`pytest-libfaketime`
     *last release*: Apr 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=3.0.0

     A python-libfaketime plugin for pytest

  :pypi:`pytest-libiio`
     *last release*: Jun 06, 2026,
     *status*: N/A,
     *requires*: pytest>=3.5.0

     A pytest plugin for testing libiio based devices

  :pypi:`pytest-libnotify`
     *last release*: Apr 02, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin that shows notifications about the test run

  :pypi:`pytest-ligo`
     *last release*: Jan 16, 2020,
     *status*: 4 - Beta,
     *requires*: N/A



  :pypi:`pytest-lineno`
     *last release*: Dec 04, 2020,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin to show the line numbers of test functions

  :pypi:`pytest-line-profiler`
     *last release*: Aug 10, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=3.5.0

     Profile code executed by pytest

  :pypi:`pytest-line-profiler-apn`
     *last release*: Dec 05, 2022,
     *status*: N/A,
     *requires*: pytest (>=3.5.0)

     Profile code executed by pytest

  :pypi:`pytest-line-runner`
     *last release*: Feb 08, 2026,
     *status*: N/A,
     *requires*: N/A

     Run pytest tests by line number instead of exact test name

  :pypi:`pytest-lisa`
     *last release*: Jan 21, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=6.1.2,<7.0.0)

     Pytest plugin for organizing tests.

  :pypi:`pytest-listener`
     *last release*: Nov 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A simple network listener

  :pypi:`pytest-litf`
     *last release*: Jan 18, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     A pytest plugin that stream output in LITF format

  :pypi:`pytest-litter`
     *last release*: Nov 23, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=6.1

     Pytest plugin which verifies that tests do not modify file trees.

  :pypi:`pytest-live`
     *last release*: Mar 08, 2020,
     *status*: N/A,
     *requires*: pytest

     Live results for pytest

  :pypi:`pytest-liveview`
     *last release*: Mar 09, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin that shows a real-time test dashboard in a local web server

  :pypi:`pytest-llm`
     *last release*: Oct 03, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     pytest-llm: A pytest plugin for testing LLM outputs with success rate thresholds.

  :pypi:`pytest-llm-agent`
     *last release*: Dec 16, 2025,
     *status*: N/A,
     *requires*: pytest>=9.0.2

     LLM Agent for working with pytest

  :pypi:`pytest-llm-assert`
     *last release*: Mar 31, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=9.0

     Simple LLM-powered assertions for any pytest test

  :pypi:`pytest-llmeval`
     *last release*: Mar 19, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A pytest plugin to evaluate/benchmark LLM prompts

  :pypi:`pytest-llm-report`
     *last release*: Jan 21, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Human-friendly pytest test reports with optional LLM annotations

  :pypi:`pytest-llm-rubric`
     *last release*: Apr 07, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.2

     A pytest plugin for rubric-based LLM-as-judge testing with auto-discovery and preflight

  :pypi:`pytest-llmtest`
     *last release*: Mar 08, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0; extra == "dev"

     The pytest for LLMs — fast, Pydantic-based assertions for AI applications

  :pypi:`pytest-lobster`
     *last release*: Jul 26, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest to generate lobster tracing files

  :pypi:`pytest-local-badge`
     *last release*: May 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4

     Pytest plugin that writes self-hosted SVG status and coverage badges to your repo — no third-party shield service required.

  :pypi:`pytest-localftpserver`
     *last release*: Nov 16, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A PyTest plugin which provides an FTP fixture for your tests

  :pypi:`pytest-localserver`
     *last release*: Nov 24, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin to test server connections locally.

  :pypi:`pytest-localstack`
     *last release*: Jun 07, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0.0,<7.0.0)

     Pytest plugin for AWS integration tests

  :pypi:`pytest-lock`
     *last release*: Feb 03, 2024,
     *status*: N/A,
     *requires*: pytest (>=7.4.3,<8.0.0)

     pytest-lock is a pytest plugin that allows you to "lock" the results of unit tests, storing them in a local cache. This is particularly useful for tests that are resource-intensive or don't need to be run every time. When the tests are run subsequently, pytest-lock will compare the current results with the locked results and issue a warning if there are any discrepancies.

  :pypi:`pytest-lockable`
     *last release*: Sep 08, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     lockable resource plugin for pytest

  :pypi:`pytest-locker`
     *last release*: Dec 20, 2024,
     *status*: N/A,
     *requires*: pytest>=5.4

     Used to lock object during testing. Essentially changing assertions from being hard coded to asserting that nothing changed

  :pypi:`pytest-loco`
     *last release*: Mar 08, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest<10.0.0,>=9.0.2

     Another one YAML-based DSL for testing

  :pypi:`pytest-loco-allure`
     *last release*: Mar 08, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     Allure support for pytest-loco

  :pypi:`pytest-loco-http`
     *last release*: Feb 25, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     HTTP support for pytest-loco

  :pypi:`pytest-loco-json`
     *last release*: Feb 25, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     JSON support for pytest-loco

  :pypi:`pytest-log`
     *last release*: Aug 15, 2021,
     *status*: N/A,
     *requires*: pytest (>=3.8)

     print log

  :pypi:`pytest-logbook`
     *last release*: Nov 23, 2015,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.8)

     py.test plugin to capture logbook log messages

  :pypi:`pytest-logdog`
     *last release*: Jun 15, 2021,
     *status*: 1 - Planning,
     *requires*: pytest (>=6.2.0)

     Pytest plugin to test logging

  :pypi:`pytest-logfest`
     *last release*: Jul 21, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Pytest plugin providing three logger fixtures with basic or full writing to log files

  :pypi:`pytest-log-filter`
     *last release*: Nov 13, 2025,
     *status*: N/A,
     *requires*: pytest

     Ignore some loggers' log for pytest

  :pypi:`pytest-logger`
     *last release*: Mar 10, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.2)

     Plugin configuring handlers for loggers from Python logging module.

  :pypi:`pytest-logger-db`
     *last release*: Sep 14, 2025,
     *status*: N/A,
     *requires*: N/A

     Add your description here

  :pypi:`pytest-logging`
     *last release*: Nov 04, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     Configures logging and allows tweaking the log level with a py.test flag

  :pypi:`pytest-logging-end-to-end-test-tool`
     *last release*: Sep 23, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.2,<8.0.0)



  :pypi:`pytest-logging-strict`
     *last release*: May 20, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest fixture logging configured from packaged YAML

  :pypi:`pytest-logikal`
     *last release*: May 29, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest==9.0.3

     Common testing environment

  :pypi:`pytest-log-report`
     *last release*: Dec 26, 2019,
     *status*: N/A,
     *requires*: N/A

     Package for creating a pytest test run reprot

  :pypi:`pytest-logscanner`
     *last release*: Sep 30, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=8.2.2

     Pytest plugin for logscanner (A logger for python logging outputting to easily viewable (and filterable) html files. Good for people not grep savey, and color higlighting and quickly changing filters might even bye useful for commandline wizards.)

  :pypi:`pytest-loguru`
     *last release*: May 16, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest Loguru

  :pypi:`pytest-loop`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest plugin for looping tests

  :pypi:`pytest-lsp`
     *last release*: Oct 25, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0

     A pytest plugin for end-to-end testing of language servers

  :pypi:`pytest-lw-realtime-result`
     *last release*: Mar 13, 2025,
     *status*: N/A,
     *requires*: pytest>=3.5.0

     Pytest plugin to generate realtime test results to a file

  :pypi:`pytest-manifest`
     *last release*: Apr 07, 2025,
     *status*: N/A,
     *requires*: pytest

     PyTest plugin for recording and asserting against a manifest file

  :pypi:`pytest-manual-marker`
     *last release*: Aug 04, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest>=7

     pytest marker for marking manual tests

  :pypi:`pytest-mark-ac`
     *last release*: Mar 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=8.4

     Provides a marker to reference acceptance criteria from PyTest tests through annotations

  :pypi:`pytest-mark-count`
     *last release*: Nov 13, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0.0

     Get a count of the number of tests marked, unmarked, and unique tests if tests have multiple markers

  :pypi:`pytest-markdir`
     *last release*: Feb 01, 2026,
     *status*: N/A,
     *requires*: pytest<10,>=8.0



  :pypi:`pytest-markdoctest`
     *last release*: Jul 22, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=6)

     A pytest plugin to doctest your markdown files

  :pypi:`pytest-markdown`
     *last release*: Jan 15, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0.1,<7.0.0)

     Test your markdown docs with pytest

  :pypi:`pytest-markdown-console`
     *last release*: May 31, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     A pytest extension to test console code blocks in markdown files.

  :pypi:`pytest-markdown-docs`
     *last release*: Mar 23, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Run markdown code fences through pytest

  :pypi:`pytest-markdown-report`
     *last release*: Jan 10, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Token-efficient markdown test reports for LLM-based TDD agents

  :pypi:`pytest-markdown-summary`
     *last release*: Apr 30, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest<10,>=7

     A Pytest plugin for generating reports in Markdown format.

  :pypi:`pytest-marker-bugzilla`
     *last release*: Apr 02, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=2.2.4

     py.test bugzilla integration plugin, using markers

  :pypi:`pytest-markers-presence`
     *last release*: Oct 30, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.0

     A simple plugin to detect missed pytest tags and markers"

  :pypi:`pytest-mark-filter`
     *last release*: May 11, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.0

     Filter pytest marks by name using match kw

  :pypi:`pytest-markfiltration`
     *last release*: Nov 08, 2011,
     *status*: 3 - Alpha,
     *requires*: N/A

     UNKNOWN

  :pypi:`pytest-mark-integration`
     *last release*: Jan 13, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Pytest plugin for automatic integration test marking and management

  :pypi:`pytest-mark-manage`
     *last release*: Aug 15, 2024,
     *status*: N/A,
     *requires*: pytest

     用例标签化管理

  :pypi:`pytest-mark-no-py3`
     *last release*: May 17, 2019,
     *status*: N/A,
     *requires*: pytest

     pytest plugin and bowler codemod to help migrate tests to Python 3

  :pypi:`pytest-marks`
     *last release*: Nov 23, 2012,
     *status*: 3 - Alpha,
     *requires*: N/A

     UNKNOWN

  :pypi:`pytest-mask-secrets`
     *last release*: Dec 17, 2025,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to hide sensitive data in test reports

  :pypi:`pytest-matcher`
     *last release*: Aug 07, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Easy way to match captured \`pytest\` output against expectations stored in files

  :pypi:`pytest-matchers`
     *last release*: Dec 19, 2025,
     *status*: N/A,
     *requires*: pytest<10.0,>=7.0

     Matchers for pytest

  :pypi:`pytest-match-skip`
     *last release*: May 15, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.4.1)

     Skip matching marks. Matches partial marks using wildcards.

  :pypi:`pytest-mat-report`
     *last release*: Jan 20, 2021,
     *status*: N/A,
     *requires*: N/A

     this is report

  :pypi:`pytest-matrix`
     *last release*: Jun 24, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=5.4.3,<6.0.0)

     Provide tools for generating tests from combinations of fixtures.

  :pypi:`pytest-maxcov`
     *last release*: Sep 24, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.4.0,<8.0.0)

     Compute the maximum coverage available through pytest with the minimum execution time cost

  :pypi:`pytest-max-warnings`
     *last release*: Oct 23, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3.3

     A Pytest plugin to exit non-zero exit code when the configured maximum warnings has been exceeded.

  :pypi:`pytest-maybe-context`
     *last release*: Apr 16, 2023,
     *status*: N/A,
     *requires*: pytest (>=7,<8)

     Simplify tests with warning and exception cases.

  :pypi:`pytest-maybe-raises`
     *last release*: May 27, 2022,
     *status*: N/A,
     *requires*: pytest ; extra == 'dev'

     Pytest fixture for optional exception testing.

  :pypi:`pytest-mccabe`
     *last release*: Jul 22, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest (>=5.4.0)

     pytest plugin to run the mccabe code complexity checker.

  :pypi:`pytest-mcp`
     *last release*: Jul 07, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.0

     Pytest-style framework for evaluating Model Context Protocol (MCP) servers.

  :pypi:`pytest-mcp-assert`
     *last release*: Jun 04, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     pytest plugin for mcp-assert: run MCP server assertions as pytest test items

  :pypi:`pytest-mcp-plugin`
     *last release*: May 05, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     pytest for MCP servers — the testing framework for the Model Context Protocol

  :pypi:`pytest-mcp-tools`
     *last release*: Apr 25, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0; extra == "test"

     \`pytest --mcp-tools\` an opinionated black box tester to call a live MCP server and test it live against its own contracts

  :pypi:`pytest-md`
     *last release*: Jul 11, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=4.2.1)

     Plugin for generating Markdown reports for pytest results

  :pypi:`pytest-md-report`
     *last release*: May 04, 2026,
     *status*: 4 - Beta,
     *requires*: pytest!=6.0.0,<10,>=3.3.2

     A pytest plugin to generate test outcomes reports with markdown table format.

  :pypi:`pytest-meilisearch`
     *last release*: Oct 08, 2024,
     *status*: N/A,
     *requires*: pytest>=7.4.3

     Pytest helpers for testing projects using Meilisearch

  :pypi:`pytest-memlog`
     *last release*: May 03, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.3.0,<8.0.0)

     Log memory usage during tests

  :pypi:`pytest-memprof`
     *last release*: Mar 29, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     Estimates memory consumption of test functions

  :pypi:`pytest-memray`
     *last release*: Aug 18, 2025,
     *status*: N/A,
     *requires*: pytest>=7.2

     A simple plugin to use with pytest

  :pypi:`pytest-menu`
     *last release*: Oct 04, 2017,
     *status*: 3 - Alpha,
     *requires*: pytest (>=2.4.2)

     A pytest plugin for console based interactive test selection just after the collection phase

  :pypi:`pytest-mercurial`
     *last release*: Nov 21, 2020,
     *status*: 1 - Planning,
     *requires*: N/A

     pytest plugin to write integration tests for projects using Mercurial Python internals

  :pypi:`pytest-mergify`
     *last release*: May 27, 2026,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     Pytest plugin for Mergify

  :pypi:`pytest-mesh`
     *last release*: Aug 05, 2022,
     *status*: N/A,
     *requires*: pytest (==7.1.2)

     pytest_mesh插件

  :pypi:`pytest-message`
     *last release*: Aug 04, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.5)

     Pytest plugin for sending report message of marked tests execution

  :pypi:`pytest-messenger`
     *last release*: Nov 24, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest to Slack reporting plugin

  :pypi:`pytest-metadata`
     *last release*: Feb 12, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest plugin for test session metadata

  :pypi:`pytest-metaexport`
     *last release*: Jun 24, 2025,
     *status*: N/A,
     *requires*: pytest>=7.1.0

     Pytest plugin for exporting custom test metadata to JSON.

  :pypi:`pytest-metrics`
     *last release*: Apr 04, 2020,
     *status*: N/A,
     *requires*: pytest

     Custom metrics report for pytest

  :pypi:`pytest-mfd-config`
     *last release*: May 19, 2026,
     *status*: N/A,
     *requires*: pytest<9,>=7.2.1

     Pytest Plugin that handles test and topology configs and all their belongings like helper fixtures.

  :pypi:`pytest-mfd-logging`
     *last release*: Nov 14, 2025,
     *status*: N/A,
     *requires*: pytest<9,>=7.2.1

     Module for handling PyTest logging.

  :pypi:`pytest-mg`
     *last release*: May 11, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0

     A tiny plugin for pytest which runs MongoDB in Docker

  :pypi:`pytest-mh`
     *last release*: Oct 16, 2025,
     *status*: N/A,
     *requires*: pytest

     Pytest multihost plugin

  :pypi:`pytest-mimesis`
     *last release*: Mar 21, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.2)

     Mimesis integration with the pytest test runner

  :pypi:`pytest-mimic`
     *last release*: Apr 24, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Easily record function calls while testing

  :pypi:`pytest-minecraft`
     *last release*: Apr 06, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.0.1)

     A pytest plugin for running tests against Minecraft releases

  :pypi:`pytest-mini`
     *last release*: Feb 06, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.0,<8.0.0)

     A plugin to test mp

  :pypi:`pytest-minio-mock`
     *last release*: Aug 06, 2025,
     *status*: N/A,
     *requires*: pytest>=5.0.0

     A pytest plugin for mocking Minio S3 interactions

  :pypi:`pytest-mirror`
     *last release*: Jul 30, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     A pluggy-based pytest plugin and CLI tool for ensuring your test suite mirrors your source code structure

  :pypi:`pytest-missing-fixtures`
     *last release*: Oct 14, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Pytest plugin that creates missing fixtures

  :pypi:`pytest-missing-modules`
     *last release*: Nov 17, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.2

     Pytest plugin to easily fake missing modules

  :pypi:`pytest-mitmproxy`
     *last release*: May 09, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     pytest plugin for mitmproxy tests

  :pypi:`pytest-mitmproxy-plugin`
     *last release*: Apr 10, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.2.0

     Use MITM Proxy in autotests with full control from code

  :pypi:`pytest-ml`
     *last release*: May 04, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     Test your machine learning!

  :pypi:`pytest-mocha`
     *last release*: Apr 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=5.4.0)

     pytest plugin to display test execution output like a mochajs

  :pypi:`pytest-mock`
     *last release*: Sep 16, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.5

     Thin-wrapper around the mock package for easier use with pytest

  :pypi:`pytest-mock-api`
     *last release*: Feb 13, 2019,
     *status*: 1 - Planning,
     *requires*: pytest (>=4.0.0)

     A mock API server with configurable routes and responses available as a fixture.

  :pypi:`pytest-mock-generator`
     *last release*: May 16, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A pytest fixture wrapper for https://pypi.org/project/mock-generator

  :pypi:`pytest-mock-helper`
     *last release*: Jan 24, 2018,
     *status*: N/A,
     *requires*: pytest

     Help you mock HTTP call and generate mock code

  :pypi:`pytest-mockito`
     *last release*: Feb 10, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6

     Base fixtures for mockito

  :pypi:`pytest-mockllm`
     *last release*: Dec 22, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     🚀 Zero-config pytest plugin for mocking LLM APIs - OpenAI, Anthropic, Gemini, LangChain & more

  :pypi:`pytest-mockredis`
     *last release*: Jan 02, 2018,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     An in-memory mock of a Redis server that runs in a separate thread. This is to be used for unit-tests that require a Redis database.

  :pypi:`pytest-mock-resources`
     *last release*: Sep 17, 2025,
     *status*: N/A,
     *requires*: pytest>=1.0

     A pytest plugin for easily instantiating reproducible mock resources.

  :pypi:`pytest-mock-server`
     *last release*: Jan 09, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Mock server plugin for pytest

  :pypi:`pytest-mockservers`
     *last release*: Mar 31, 2020,
     *status*: N/A,
     *requires*: pytest (>=4.3.0)

     A set of fixtures to test your requests to HTTP/UDP servers

  :pypi:`pytest-mocktcp`
     *last release*: Oct 11, 2022,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin for testing TCP clients

  :pypi:`pytest-mock-unity-catalog`
     *last release*: Mar 12, 2026,
     *status*: N/A,
     *requires*: pytest

     Unity Catalog pyspark fixtures

  :pypi:`pytest-modalt`
     *last release*: Feb 27, 2024,
     *status*: 4 - Beta,
     *requires*: pytest >=6.2.0

     Massively distributed pytest runs using modal.com

  :pypi:`pytest-model-lib`
     *last release*: Feb 22, 2026,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for model-lib

  :pypi:`pytest-modern`
     *last release*: Aug 19, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8

     A more modern pytest

  :pypi:`pytest-modified-env`
     *last release*: Jan 29, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest plugin to fail a test if it leaves modified \`os.environ\` afterwards.

  :pypi:`pytest-modifyjunit`
     *last release*: Jan 10, 2019,
     *status*: N/A,
     *requires*: N/A

     Utility for adding additional properties to junit xml for IDM QE

  :pypi:`pytest-molecule`
     *last release*: Mar 29, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7.0.0)

     PyTest Molecule Plugin :: discover and run molecule tests

  :pypi:`pytest-molecule-JC`
     *last release*: Jul 18, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7.0.0)

     PyTest Molecule Plugin :: discover and run molecule tests

  :pypi:`pytest-mongo`
     *last release*: Feb 04, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4

     MongoDB process and client fixtures plugin for Pytest.

  :pypi:`pytest-mongodb`
     *last release*: May 16, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for MongoDB fixtures

  :pypi:`pytest-mongodb-nono`
     *last release*: Jan 07, 2025,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for MongoDB

  :pypi:`pytest-mongodb-ry`
     *last release*: Sep 25, 2025,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for MongoDB

  :pypi:`pytest-mongo-docker`
     *last release*: May 14, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0

     A tiny plugin for pytest which runs MongoDB in Docker

  :pypi:`pytest-monitor`
     *last release*: Jun 25, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin for analyzing resource usage.

  :pypi:`pytest-monkeyplus`
     *last release*: Sep 18, 2012,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest's monkeypatch subclass with extra functionalities

  :pypi:`pytest-monkeytype`
     *last release*: Jul 29, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest-monkeytype: Generate Monkeytype annotations from your pytest tests.

  :pypi:`pytest-moto`
     *last release*: Aug 28, 2015,
     *status*: 1 - Planning,
     *requires*: N/A

     Fixtures for integration tests of AWS services,uses moto mocking library.

  :pypi:`pytest-moto-fixtures`
     *last release*: Nov 17, 2025,
     *status*: 1 - Planning,
     *requires*: pytest<9.1,>=8.3; extra == "pytest"

     Fixtures for testing code that interacts with AWS

  :pypi:`pytest-motor`
     *last release*: Jul 21, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin for motor, the non-blocking MongoDB driver.

  :pypi:`pytest-mp`
     *last release*: May 23, 2018,
     *status*: 4 - Beta,
     *requires*: pytest

     A test batcher for multiprocessed Pytest runs

  :pypi:`pytest-mpi`
     *last release*: Jan 08, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest plugin to collect information from tests

  :pypi:`pytest-mpiexec`
     *last release*: Jul 29, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest plugin for running individual tests with mpiexec

  :pypi:`pytest-mpi-tmweigand`
     *last release*: Dec 27, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     forked pytest plugin to collect information from tests

  :pypi:`pytest-mpl`
     *last release*: Mar 25, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.5

     pytest plugin to help with testing figures output from Matplotlib

  :pypi:`pytest-mpl-oggm`
     *last release*: Mar 09, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.5

     pytest plugin to help with testing figures output from Matplotlib - OGGM fork

  :pypi:`pytest-mproc`
     *last release*: Mar 27, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6

     low-startup-overhead, scalable, distributed-testing pytest plugin

  :pypi:`pytest-mqtt`
     *last release*: Jan 28, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10; extra == "test"

     pytest-mqtt supports testing systems based on MQTT

  :pypi:`pytest-mrt`
     *last release*: Jun 06, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     Catch database migration rollback failures before they reach production

  :pypi:`pytest-multihost`
     *last release*: Apr 07, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     Utility for writing multi-host tests for pytest

  :pypi:`pytest-multilog`
     *last release*: Dec 28, 2025,
     *status*: N/A,
     *requires*: pytest

     Multi-process logs handling and other helpers for pytest

  :pypi:`pytest-multithreading`
     *last release*: Aug 05, 2024,
     *status*: N/A,
     *requires*: N/A

     a pytest plugin for th and concurrent testing

  :pypi:`pytest-multithreading-allure`
     *last release*: Nov 25, 2022,
     *status*: N/A,
     *requires*: N/A

     pytest_multithreading_allure

  :pypi:`pytest-mutagen`
     *last release*: Jul 24, 2020,
     *status*: N/A,
     *requires*: pytest (>=5.4)

     Add the mutation testing feature to pytest

  :pypi:`pytest-my-cool-lib`
     *last release*: Nov 02, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.1.3,<8.0.0)



  :pypi:`pytest-my-plugin`
     *last release*: Jan 27, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0

     A pytest plugin that does awesome things

  :pypi:`pytest-mypy`
     *last release*: Apr 02, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     A Pytest Plugin for Mypy

  :pypi:`pytest-mypyd`
     *last release*: Aug 20, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (<4.7,>=2.8) ; python_version < "3.5"

     Mypy static type checker plugin for Pytest

  :pypi:`pytest-mypy-plugins`
     *last release*: May 14, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest plugin for writing tests for mypy plugins

  :pypi:`pytest-mypy-plugins-shim`
     *last release*: Feb 14, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     Substitute for "pytest-mypy-plugins" for Python implementations which aren't supported by mypy.

  :pypi:`pytest-mypy-runner`
     *last release*: Apr 23, 2024,
     *status*: N/A,
     *requires*: pytest>=8.0

     Run the mypy static type checker as a pytest test case

  :pypi:`pytest-mypy-testing`
     *last release*: Jan 26, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     Pytest plugin to check mypy output

  :pypi:`pytest-mysql`
     *last release*: Apr 12, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4

     MySQL process and client fixtures for pytest

  :pypi:`pytest-nb`
     *last release*: Jul 26, 2025,
     *status*: N/A,
     *requires*: pytest==8.4.1

     Seedable Jupyter Notebook testing tool

  :pypi:`pytest-nb-as-test`
     *last release*: Feb 25, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<9.1.0,>=7.0.0; python_version < "3.14"

     Use notebooks as pytests. Keep your notebooks working.

  :pypi:`pytest-nbgrader`
     *last release*: Mar 31, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8

     Pytest plugin for using with nbgrader and generating test cases.

  :pypi:`pytest-ndb`
     *last release*: Apr 28, 2024,
     *status*: N/A,
     *requires*: pytest

     pytest notebook debugger

  :pypi:`pytest-needle`
     *last release*: Dec 10, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (<5.0.0,>=3.0.0)

     pytest plugin for visual testing websites using selenium

  :pypi:`pytest-neo`
     *last release*: Jan 08, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest (>=6.2.0)

     pytest-neo is a plugin for pytest that shows tests like screen of Matrix.

  :pypi:`pytest-neon`
     *last release*: Feb 05, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Pytest plugin for Neon database branch isolation in tests

  :pypi:`pytest-neos`
     *last release*: Sep 10, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest<8.0,>=7.2; extra == "dev"

     Pytest plugin for neos

  :pypi:`pytest-netconf`
     *last release*: Nov 03, 2025,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin that provides a mock NETCONF (RFC6241/RFC6242) server for local testing.

  :pypi:`pytest-netdut`
     *last release*: Oct 09, 2025,
     *status*: N/A,
     *requires*: pytest>=3.5.0

     "Automated software testing for switches using pytest"

  :pypi:`pytest-network`
     *last release*: May 07, 2020,
     *status*: N/A,
     *requires*: N/A

     A simple plugin to disable network on socket level.

  :pypi:`pytest-network-endpoints`
     *last release*: Mar 06, 2022,
     *status*: N/A,
     *requires*: pytest

     Network endpoints plugin for pytest

  :pypi:`pytest-never-sleep`
     *last release*: May 05, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.5.1)

     pytest plugin helps to avoid adding tests without mock \`time.sleep\`

  :pypi:`pytest-nginx`
     *last release*: May 03, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.0.0

     nginx fixture for pytest

  :pypi:`pytest-nginx-iplweb`
     *last release*: Mar 01, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     nginx fixture for pytest - iplweb temporary fork

  :pypi:`pytest-ngrok`
     *last release*: Jan 20, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest



  :pypi:`pytest-ngsfixtures`
     *last release*: Sep 06, 2019,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest (>=5.0.0)

     pytest ngs fixtures

  :pypi:`pytest-nhsd-apim`
     *last release*: Jun 03, 2026,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=8.2.0

     Pytest plugin accessing NHSDigital's APIM proxies

  :pypi:`pytest-nice`
     *last release*: May 04, 2019,
     *status*: 4 - Beta,
     *requires*: pytest

     A pytest plugin that alerts user of failed test cases with screen notifications

  :pypi:`pytest-nice-parametrize`
     *last release*: Apr 17, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A small snippet for nicer PyTest's Parametrize

  :pypi:`pytest_nlcov`
     *last release*: Aug 05, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to get the coverage of the new lines (based on git diff) only

  :pypi:`pytest-nocustom`
     *last release*: Aug 05, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Run all tests without custom markers

  :pypi:`pytest-node-dependency`
     *last release*: Apr 10, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for controlling execution flow

  :pypi:`pytest-nodev`
     *last release*: Jul 21, 2016,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.8.1)

     Test-driven source code search for Python.

  :pypi:`pytest-nogarbage`
     *last release*: Feb 24, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=4.6.0

     Ensure a test produces no garbage

  :pypi:`pytest-no-problem`
     *last release*: Jan 11, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin to tell you when there's no problem

  :pypi:`pytest-nose-attrib`
     *last release*: Aug 13, 2023,
     *status*: N/A,
     *requires*: N/A

     pytest plugin to use nose @attrib marks decorators and pick tests based on attributes and partially uses nose-attrib plugin approach

  :pypi:`pytest_notebook`
     *last release*: Nov 28, 2023,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     A pytest plugin for testing Jupyter Notebooks.

  :pypi:`pytest-notebook-policy`
     *last release*: May 30, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0

     Pytest plugin for notebook policy and quality checks

  :pypi:`pytest-notice`
     *last release*: Nov 05, 2020,
     *status*: N/A,
     *requires*: N/A

     Send pytest execution result email

  :pypi:`pytest-notification`
     *last release*: Jun 19, 2020,
     *status*: N/A,
     *requires*: pytest (>=4)

     A pytest plugin for sending a desktop notification and playing a sound upon completion of tests

  :pypi:`pytest-notifier`
     *last release*: Jun 12, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin to notify test result

  :pypi:`pytest-notifier-plugin`
     *last release*: Dec 22, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin для отправки нотификаций в различные каналы связи о статуе прохождения тестов.

  :pypi:`pytest_notify`
     *last release*: Jul 05, 2017,
     *status*: N/A,
     *requires*: pytest>=3.0.0

     Get notifications when your tests ends

  :pypi:`pytest-notimplemented`
     *last release*: Aug 27, 2019,
     *status*: N/A,
     *requires*: pytest (>=5.1,<6.0)

     Pytest markers for not implemented features and tests.

  :pypi:`pytest-notion`
     *last release*: Aug 07, 2019,
     *status*: N/A,
     *requires*: N/A

     A PyTest Reporter to send test runs to Notion.so

  :pypi:`pytest-nunit`
     *last release*: Feb 26, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A pytest plugin for generating NUnit3 test result XML output

  :pypi:`pytest-oar`
     *last release*: May 12, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0.1

     PyTest plugin for the OAR testing framework

  :pypi:`pytest-oarepo`
     *last release*: Jun 06, 2026,
     *status*: N/A,
     *requires*: pytest>=7.1.2; extra == "dev"



  :pypi:`pytest-object-getter`
     *last release*: Jul 31, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Import any object from a 3rd party module while mocking its namespace on demand.

  :pypi:`pytest-ochrus`
     *last release*: Feb 21, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest results data-base and HTML reporter

  :pypi:`pytest-odc`
     *last release*: Aug 04, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin for simplifying ODC database tests

  :pypi:`pytest-odoo`
     *last release*: May 20, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8

     py.test plugin to run Odoo tests

  :pypi:`pytest-odoo-fixtures`
     *last release*: Jun 25, 2019,
     *status*: N/A,
     *requires*: N/A

     Project description

  :pypi:`pytest-oduit`
     *last release*: May 12, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8

     py.test plugin to run Odoo tests

  :pypi:`pytest-oerp`
     *last release*: Feb 28, 2012,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin to test OpenERP modules

  :pypi:`pytest-offline`
     *last release*: Mar 09, 2023,
     *status*: 1 - Planning,
     *requires*: pytest (>=7.0.0,<8.0.0)



  :pypi:`pytest-ogsm-plugin`
     *last release*: May 16, 2023,
     *status*: N/A,
     *requires*: N/A

     针对特定项目定制化插件，优化了pytest报告展示方式,并添加了项目所需特定参数

  :pypi:`pytest-ok`
     *last release*: Apr 01, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     The ultimate pytest output plugin

  :pypi:`pytest-once`
     *last release*: Oct 10, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.4.0

     xdist-safe 'run once' fixture decorator for pytest (setup/teardown across workers)

  :pypi:`pytest-only`
     *last release*: May 27, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest<9,>=3.6.0

     Use @pytest.mark.only to run a single test

  :pypi:`pytest-only-markers`
     *last release*: Mar 17, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.1

     A pytest plugin that isolates test execution to only tests decorated with ONLY\* markers, stripping all other markers from matching items.

  :pypi:`pytest-oof`
     *last release*: Dec 11, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     A Pytest plugin providing structured, programmatic access to a test run's results

  :pypi:`pytest-oot`
     *last release*: Sep 18, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Run object-oriented tests in a simple format

  :pypi:`pytest-openapi`
     *last release*: Apr 21, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     \`pytest --openapi\` - an opinionated, lightweight black-box contract tester against a live API using its OpenAPI specification as the source of truth

  :pypi:`pytest-openfeature`
     *last release*: Apr 28, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0

     Drive pytest configuration from an OpenFeature provider.

  :pypi:`pytest-openfiles`
     *last release*: Jun 05, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest>=4.6

     Pytest plugin for detecting inadvertent open file handles

  :pypi:`pytest-open-html`
     *last release*: Mar 31, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0

     Auto-open HTML reports after pytest runs

  :pypi:`pytest-opentelemetry`
     *last release*: Apr 25, 2025,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin for instrumenting test runs via OpenTelemetry

  :pypi:`pytest-opentmi`
     *last release*: Feb 09, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=5.0

     pytest plugin for publish results to opentmi

  :pypi:`pytest-operator`
     *last release*: Sep 28, 2022,
     *status*: N/A,
     *requires*: pytest

     Fixtures for Charmed Operators

  :pypi:`pytest-optional`
     *last release*: Oct 07, 2015,
     *status*: N/A,
     *requires*: N/A

     include/exclude values of fixtures in pytest

  :pypi:`pytest-optional-tests`
     *last release*: Jul 21, 2025,
     *status*: 4 - Beta,
     *requires*: pytest; extra == "dev"

     Easy declaration of optional tests (i.e., that are not run by default)

  :pypi:`pytest-orchestration`
     *last release*: Jul 18, 2019,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for orchestrating tests

  :pypi:`pytest-order`
     *last release*: Apr 26, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.4; python_version < "3.14"

     pytest plugin to run tests in a specific order

  :pypi:`pytest-ordered`
     *last release*: Nov 09, 2025,
     *status*: N/A,
     *requires*: pytest>=6.2.0

     Declare the order in which tests should run in your pytest.ini

  :pypi:`pytest-ordering`
     *last release*: Nov 14, 2018,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin to run your tests in a specific order

  :pypi:`pytest-order-modify`
     *last release*: Nov 04, 2022,
     *status*: N/A,
     *requires*: N/A

     新增run_marker 来自定义用例的执行顺序

  :pypi:`pytest-osxnotify`
     *last release*: May 15, 2015,
     *status*: N/A,
     *requires*: N/A

     OS X notifications for py.test results.

  :pypi:`pytest-ot`
     *last release*: Mar 21, 2024,
     *status*: N/A,
     *requires*: pytest; extra == "dev"

     A pytest plugin for instrumenting test runs via OpenTelemetry

  :pypi:`pytest-otel`
     *last release*: Apr 29, 2026,
     *status*: N/A,
     *requires*: pytest==9.0.3

     OpenTelemetry plugin for Pytest

  :pypi:`pytest-otelmark`
     *last release*: Sep 14, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.3.5

     Pytest plugin for otelmark.

  :pypi:`pytest-override-env-var`
     *last release*: Feb 25, 2023,
     *status*: N/A,
     *requires*: N/A

     Pytest mark to override a value of an environment variable.

  :pypi:`pytest-owner`
     *last release*: Aug 19, 2024,
     *status*: N/A,
     *requires*: pytest

     Add owner mark for tests

  :pypi:`pytest-pact`
     *last release*: Jan 07, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     A simple plugin to use with pytest

  :pypi:`pytest-pagerduty`
     *last release*: Mar 22, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=7.4.0

     Pytest plugin for PagerDuty integration via automation testing.

  :pypi:`pytest-pahrametahrize`
     *last release*: Nov 24, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0,<7.0)

     Parametrize your tests with a Boston accent.

  :pypi:`pytest-paia-blockly`
     *last release*: Mar 19, 2026,
     *status*: N/A,
     *requires*: pytest>=8.0

     pytest plugin for PAIA Blockly: verify get_solution() against test cases

  :pypi:`pytest-paraflow`
     *last release*: Feb 26, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=9.0.0

     Deterministic pytest test sharding across CI machines

  :pypi:`pytest-parallel`
     *last release*: Oct 10, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0.0)

     a pytest plugin for parallel and concurrent testing

  :pypi:`pytest-parallel-39`
     *last release*: Jul 12, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0.0)

     a pytest plugin for parallel and concurrent testing

  :pypi:`pytest-parallelize-tests`
     *last release*: Jan 27, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin that parallelizes test execution across multiple hosts

  :pypi:`pytest-param`
     *last release*: Sep 11, 2016,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.6.0)

     pytest plugin to test all, first, last or random params

  :pypi:`pytest-parametrization`
     *last release*: May 22, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Simpler PyTest parametrization

  :pypi:`pytest-parametrization-annotation`
     *last release*: Dec 10, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     A pytest library for parametrizing tests using type hints.

  :pypi:`pytest-parametrize`
     *last release*: Apr 03, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10.0,>=8.3

     pytest decorator for parametrizing test cases in a dict-way

  :pypi:`pytest-parametrize-cases`
     *last release*: Mar 13, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.1.2)

     A more user-friendly way to write parametrized tests.

  :pypi:`pytest-parametrized`
     *last release*: Dec 21, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest decorator for parametrizing tests with default iterables.

  :pypi:`pytest-parametrize-suite`
     *last release*: Jan 19, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A simple pytest extension for creating a named test suite.

  :pypi:`pytest_param_files`
     *last release*: Jul 29, 2023,
     *status*: N/A,
     *requires*: pytest

     Create pytest parametrize decorators from external files.

  :pypi:`pytest-params`
     *last release*: Mar 14, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     Simplified pytest test case parameters.

  :pypi:`pytest-param-scope`
     *last release*: Oct 18, 2023,
     *status*: N/A,
     *requires*: pytest

     pytest parametrize scope fixture workaround

  :pypi:`pytest-parawtf`
     *last release*: Dec 03, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.6.0)

     Finally spell paramete?ri[sz]e correctly

  :pypi:`pytest-park`
     *last release*: Mar 20, 2026,
     *status*: N/A,
     *requires*: N/A

     Organise and analyse your pytest benchmarks

  :pypi:`pytest-pass`
     *last release*: Dec 04, 2019,
     *status*: N/A,
     *requires*: N/A

     Check out https://github.com/elilutsky/pytest-pass

  :pypi:`pytest-passrunner`
     *last release*: Feb 10, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.6.0)

     Pytest plugin providing the 'run_on_pass' marker

  :pypi:`pytest-pastebin`
     *last release*: May 10, 2026,
     *status*: 6 - Mature,
     *requires*: pytest>=7

     Submit pytest failure or test session information to a pastebin service

  :pypi:`pytest-paste-config`
     *last release*: Sep 18, 2013,
     *status*: 3 - Alpha,
     *requires*: N/A

     Allow setting the path to a paste config file

  :pypi:`pytest-patch`
     *last release*: Apr 29, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest (>=7.0.0)

     An automagic \`patch\` fixture that can patch objects directly or by name.

  :pypi:`pytest-patches`
     *last release*: May 09, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     A contextmanager pytest fixture for handling multiple mock patches

  :pypi:`pytest-patterns`
     *last release*: Oct 22, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6

     pytest plugin to make testing complicated long string output easy to write and easy to debug

  :pypi:`pytest-pdb`
     *last release*: Jul 31, 2018,
     *status*: N/A,
     *requires*: N/A

     pytest plugin which adds pdb helper commands related to pytest.

  :pypi:`pytest-peach`
     *last release*: Apr 12, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.8.7)

     pytest plugin for fuzzing with Peach API Security

  :pypi:`pytest-pep257`
     *last release*: Jul 09, 2016,
     *status*: N/A,
     *requires*: N/A

     py.test plugin for pep257

  :pypi:`pytest-pep723`
     *last release*: Apr 06, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7

     Pytest plugin to verify PEP 723 inline script metadata covers all imports.

  :pypi:`pytest-pep8`
     *last release*: Apr 27, 2014,
     *status*: N/A,
     *requires*: N/A

     pytest plugin to check PEP8 requirements

  :pypi:`pytest-percent`
     *last release*: May 21, 2020,
     *status*: N/A,
     *requires*: pytest (>=5.2.0)

     Change the exit code of pytest test sessions when a required percent of tests pass.

  :pypi:`pytest-percents`
     *last release*: Mar 16, 2024,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-perf`
     *last release*: May 20, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest!=8.1.*,>=6; extra == "testing"

     Run performance tests against the mainline code.

  :pypi:`pytest-performance`
     *last release*: Sep 11, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.7.0)

     A simple plugin to ensure the execution of critical sections of code has not been impacted

  :pypi:`pytest-performancetotal`
     *last release*: Mar 24, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A performance plugin for pytest

  :pypi:`pytest-persistence`
     *last release*: Aug 21, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest tool for persistent objects

  :pypi:`pytest-pexpect`
     *last release*: Sep 10, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Pytest pexpect plugin.

  :pypi:`pytest_pg`
     *last release*: Jun 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0

     A tiny plugin for pytest which runs PostgreSQL in Docker

  :pypi:`pytest-pgsql`
     *last release*: May 13, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.0.0)

     Pytest plugins and helpers for tests using a Postgres database.

  :pypi:`pytest-pgtap`
     *last release*: May 29, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest plugin for running pgTAP tests

  :pypi:`pytest-phmdoctest`
     *last release*: Apr 15, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=5.4.3)

     pytest plugin to test Python examples in Markdown using phmdoctest.

  :pypi:`pytest-phoenix-interface`
     *last release*: Mar 19, 2025,
     *status*: N/A,
     *requires*: N/A

     Pytest extension tool for phoenix projects.

  :pypi:`pytest-picked`
     *last release*: Nov 06, 2024,
     *status*: N/A,
     *requires*: pytest>=3.7.0

     Run the tests related to the changed files

  :pypi:`pytest-pickle-cache`
     *last release*: Feb 06, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=9

     A pytest plugin for caching test results using pickle.

  :pypi:`pytest-pigeonhole`
     *last release*: Jun 25, 2018,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.4)



  :pypi:`pytest-pikachu`
     *last release*: Aug 05, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Show surprise when tests are passing

  :pypi:`pytest-pilot`
     *last release*: Dec 17, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Slice in your test base thanks to powerful markers.

  :pypi:`pytest-pingguo-pytest-plugin`
     *last release*: Oct 26, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     pingguo test

  :pypi:`pytest-pings`
     *last release*: Jun 29, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=5.0.0)

     🦊 The pytest plugin for Firefox Telemetry 📊

  :pypi:`pytest-pinned`
     *last release*: Sep 17, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple pytest plugin for pinning tests

  :pypi:`pytest-pinpoint`
     *last release*: Sep 25, 2020,
     *status*: N/A,
     *requires*: pytest (>=4.4.0)

     A pytest plugin which runs SBFL algorithms to detect faults.

  :pypi:`pytest-pipeline`
     *last release*: Jan 24, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest plugin for functional testing of data analysispipelines

  :pypi:`pytest-pitch`
     *last release*: Nov 02, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=7.3.1

     runs tests in an order such that coverage increases as fast as possible

  :pypi:`pytest-platform-adapter`
     *last release*: Mar 23, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.5

     Pytest集成自动化平台插件

  :pypi:`pytest-platform-markers`
     *last release*: Sep 09, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.6.0)

     Markers for pytest to skip tests on specific platforms

  :pypi:`pytest-play`
     *last release*: Jun 12, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin that let you automate actions and assertions with test metrics reporting executing plain YAML files

  :pypi:`pytest-playbook`
     *last release*: Jan 21, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=6.1.2,<7.0.0)

     Pytest plugin for reading playbooks.

  :pypi:`pytest-playwright`
     *last release*: May 18, 2026,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=6.2.4

     A pytest wrapper with fixtures for Playwright to automate web browsers

  :pypi:`pytest-playwright-artifacts`
     *last release*: May 21, 2026,
     *status*: N/A,
     *requires*: N/A

     Capture screenshots, HTML, and console logs on Playwright test failures

  :pypi:`pytest_playwright_async`
     *last release*: Sep 28, 2024,
     *status*: N/A,
     *requires*: N/A

     ASYNC Pytest plugin for Playwright

  :pypi:`pytest-playwright-asyncio`
     *last release*: May 18, 2026,
     *status*: N/A,
     *requires*: pytest<10.0.0,>=6.2.4

     A pytest wrapper with async fixtures for Playwright to automate web browsers

  :pypi:`pytest-playwright-axe`
     *last release*: Jun 05, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     An axe-core integration for accessibility testing using Playwright Python.

  :pypi:`pytest-playwright-enhanced`
     *last release*: Mar 24, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.0.0

     A pytest plugin for playwright python

  :pypi:`pytest-playwright-json`
     *last release*: Jan 06, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Generate Playwright-compatible JSON reports from pytest-playwright test runs

  :pypi:`pytest-playwrights`
     *last release*: Dec 02, 2021,
     *status*: N/A,
     *requires*: N/A

     A pytest wrapper with fixtures for Playwright to automate web browsers

  :pypi:`pytest-playwright-snapshot`
     *last release*: Aug 19, 2021,
     *status*: N/A,
     *requires*: N/A

     A pytest wrapper for snapshot testing with playwright

  :pypi:`pytest-playwright-visual`
     *last release*: Apr 28, 2022,
     *status*: N/A,
     *requires*: N/A

     A pytest fixture for visual testing with Playwright

  :pypi:`pytest-playwright-visual-snapshot`
     *last release*: Feb 05, 2026,
     *status*: N/A,
     *requires*: N/A

     Easy pytest visual regression testing using playwright

  :pypi:`pytest-pl-grader`
     *last release*: Nov 12, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin for autograding Python code. Designed for use with the PrairieLearn platform.

  :pypi:`pytest-plone`
     *last release*: May 18, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.4.0

     Pytest plugin to test Plone addons

  :pypi:`pytest-plt`
     *last release*: Jan 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Fixtures for quickly making Matplotlib plots in tests

  :pypi:`pytest-plugin-helpers`
     *last release*: Nov 23, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A plugin to help developing and testing other plugins

  :pypi:`pytest-plugins`
     *last release*: May 18, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.1

     A Python package for managing pytest plugins.

  :pypi:`pytest-plugin-utils`
     *last release*: May 04, 2026,
     *status*: N/A,
     *requires*: N/A

     Reusable configuration and artifact utilities for building pytest plugins

  :pypi:`pytest-plus`
     *last release*: Feb 02, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.4.2

     PyTest Plus Plugin :: extends pytest functionality

  :pypi:`pytest-pmisc`
     *last release*: Mar 21, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A



  :pypi:`pytest-podman`
     *last release*: Feb 03, 2026,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for Podman integration

  :pypi:`pytest-pogo`
     *last release*: Jan 20, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7

     Pytest plugin for pogo-migrate

  :pypi:`pytest-pointers`
     *last release*: Dec 26, 2022,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to define functions you test with special marks for better navigation and reports

  :pypi:`pytest-pokie`
     *last release*: Oct 19, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pokie plugin for pytest

  :pypi:`pytest-polarion-cfme`
     *last release*: Nov 13, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin for collecting test cases and recording test results

  :pypi:`pytest-polarion-collect`
     *last release*: Jun 18, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest plugin for collecting polarion test cases data

  :pypi:`pytest-polaroid`
     *last release*: Apr 23, 2026,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for snapshot testing.

  :pypi:`pytest-polecat`
     *last release*: Aug 12, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     Provides Polecat pytest fixtures

  :pypi:`pytest-polymeric-report`
     *last release*: Feb 24, 2026,
     *status*: N/A,
     *requires*: N/A

     A polymeric test report plugin for pytest

  :pypi:`pytest-ponyorm`
     *last release*: Oct 31, 2018,
     *status*: N/A,
     *requires*: pytest (>=3.1.1)

     PonyORM in Pytest

  :pypi:`pytest-poo`
     *last release*: Mar 25, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.3.4)

     Visualize your crappy tests

  :pypi:`pytest-poo-fail`
     *last release*: Feb 12, 2015,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Visualize your failed tests with poo

  :pypi:`pytest-pook`
     *last release*: Feb 15, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest plugin for pook

  :pypi:`pytest-pop`
     *last release*: May 09, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A pytest plugin to help with testing pop projects

  :pypi:`pytest-porcochu`
     *last release*: Nov 28, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Show surprise when tests are passing

  :pypi:`pytest-portion`
     *last release*: Mar 04, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     Select a portion of the collected tests

  :pypi:`pytest-postgres`
     *last release*: Mar 22, 2020,
     *status*: N/A,
     *requires*: pytest

     Run PostgreSQL in Docker container in Pytest.

  :pypi:`pytest-postgresql`
     *last release*: May 15, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.2

     Postgresql fixtures and fixture factories for Pytest.

  :pypi:`pytest-power`
     *last release*: Dec 31, 2020,
     *status*: N/A,
     *requires*: pytest (>=5.4)

     pytest plugin with powerful fixtures

  :pypi:`pytest-powerpack`
     *last release*: Jan 04, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.1.1

     A plugin containing extra batteries for pytest

  :pypi:`pytest-prairielearn-grader`
     *last release*: May 21, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin for autograding Python code. Designed for use with the PrairieLearn platform.

  :pypi:`pytest-prefer-nested-dup-tests`
     *last release*: Apr 27, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.1.1,<8.0.0)

     A Pytest plugin to drop duplicated tests during collection, but will prefer keeping nested packages.

  :pypi:`pytest-pretty`
     *last release*: Jun 04, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     pytest plugin for printing summary data as I want it

  :pypi:`pytest-pretty-terminal`
     *last release*: Jan 31, 2022,
     *status*: N/A,
     *requires*: pytest (>=3.4.1)

     pytest plugin for generating prettier terminal output

  :pypi:`pytest-pride`
     *last release*: Apr 02, 2016,
     *status*: 3 - Alpha,
     *requires*: N/A

     Minitest-style test colors

  :pypi:`pytest-print`
     *last release*: Feb 11, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.2

     pytest-print adds the printer fixture you can use to print messages to the user (directly to the pytest runner, not stdout)

  :pypi:`pytest-priority`
     *last release*: Aug 19, 2024,
     *status*: N/A,
     *requires*: pytest

     pytest plugin for add priority for tests

  :pypi:`pytest-proceed`
     *last release*: Oct 01, 2024,
     *status*: N/A,
     *requires*: pytest



  :pypi:`pytest-profiles`
     *last release*: Dec 09, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.7.0)

     pytest plugin for configuration profiles

  :pypi:`pytest-profiling`
     *last release*: Nov 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Profiling plugin for py.test

  :pypi:`pytest-progress`
     *last release*: Nov 11, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0

     pytest plugin for instant test progress status

  :pypi:`pytest-prometheus`
     *last release*: Oct 03, 2017,
     *status*: N/A,
     *requires*: N/A

     Report test pass / failures to a Prometheus PushGateway

  :pypi:`pytest-prometheus-pushgateway`
     *last release*: Sep 27, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest report plugin for Zulip

  :pypi:`pytest-prometheus-pushgw`
     *last release*: May 19, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     Pytest plugin to export test metrics to Prometheus Pushgateway

  :pypi:`pytest-prompts`
     *last release*: Apr 23, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0

     pytest for LLM prompts — tests, regressions, CI.

  :pypi:`pytest-proofy`
     *last release*: Nov 13, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Pytest plugin for Proofy test reporting

  :pypi:`pytest-prosper`
     *last release*: Sep 24, 2018,
     *status*: N/A,
     *requires*: N/A

     Test helpers for Prosper projects

  :pypi:`pytest-prysk`
     *last release*: Dec 10, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.3.2

     Pytest plugin for prysk

  :pypi:`pytest-pspec`
     *last release*: Jun 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.0.0)

     A rspec format reporter for Python ptest

  :pypi:`pytest-psqlgraph`
     *last release*: Oct 19, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0)

     pytest plugin for testing applications that use psqlgraph

  :pypi:`pytest-pt`
     *last release*: May 20, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest plugin to use \*.pt files as tests

  :pypi:`pytest-ptera`
     *last release*: Mar 01, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.4,<7.0.0)

     Use ptera probes in tests

  :pypi:`pytest-publish`
     *last release*: Jun 04, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.0.0



  :pypi:`pytest-pudb`
     *last release*: Oct 25, 2018,
     *status*: 3 - Alpha,
     *requires*: pytest (>=2.0)

     Pytest PuDB debugger integration

  :pypi:`pytest-pudb-resurrected`
     *last release*: Mar 12, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Pytest PuDB debugger integration

  :pypi:`pytest-pulse-report`
     *last release*: May 14, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A pytest reporter and dashboard for visualizing Playwright (pytest-playwright) test results — Python port of playwright-pulse

  :pypi:`pytest-pumpkin-spice`
     *last release*: Sep 18, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin that makes your test reporting pumpkin-spiced

  :pypi:`pytest-purkinje`
     *last release*: Oct 28, 2017,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     py.test plugin for purkinje test runner

  :pypi:`pytest-pusher`
     *last release*: Jan 06, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.6)

     pytest plugin for push report to minio

  :pypi:`pytest-pvcr`
     *last release*: Feb 25, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=3.5.0

     PyTest Process VCR

  :pypi:`pytest-pve-cloud`
     *last release*: Feb 27, 2026,
     *status*: N/A,
     *requires*: pytest==8.4.2



  :pypi:`pytest-pw-config-gen`
     *last release*: Mar 14, 2026,
     *status*: N/A,
     *requires*: pytest>=7.4; extra == "dev"

     Generate pytest-playwright configuration files (pytest.ini, pyproject.toml, conftest.py) via CLI

  :pypi:`pytest-py125`
     *last release*: Dec 03, 2022,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-pycharm`
     *last release*: Aug 13, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.3)

     Plugin for py.test to enter PyCharm debugger on uncaught exceptions

  :pypi:`pytest-pycodestyle`
     *last release*: Jul 20, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     pytest plugin to run pycodestyle

  :pypi:`pytest-pydantic-schema-sync`
     *last release*: Aug 29, 2024,
     *status*: N/A,
     *requires*: pytest>=6

     Pytest plugin to synchronise Pydantic model schemas with JSONSchema files

  :pypi:`pytest-pydev`
     *last release*: Nov 15, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     py.test plugin to connect to a remote debug server with PyDev or PyCharm.

  :pypi:`pytest-pydocstyle`
     *last release*: Oct 09, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     pytest plugin to run pydocstyle

  :pypi:`pytest-pyeval`
     *last release*: Apr 13, 2026,
     *status*: N/A,
     *requires*: pytest>=8.0

     pytest plugin integrating pydantic-evals

  :pypi:`pytest-pylembic`
     *last release*: Jul 22, 2025,
     *status*: 3 - Alpha,
     *requires*: N/A

     This package provides pytest plugin for validating Alembic migrations using the pylembic package.

  :pypi:`pytest-pylint`
     *last release*: Oct 06, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=7.0

     pytest plugin to check source code with pylint

  :pypi:`pytest-pylyzer`
     *last release*: Feb 15, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin for pylyzer

  :pypi:`pytest-pymysql-autorecord`
     *last release*: Sep 02, 2022,
     *status*: N/A,
     *requires*: N/A

     Record PyMySQL queries and mock with the stored data.

  :pypi:`pytest-pyodide`
     *last release*: Apr 27, 2026,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for testing applications that use Pyodide

  :pypi:`pytest-pypi`
     *last release*: Mar 04, 2018,
     *status*: 3 - Alpha,
     *requires*: N/A

     Easily test your HTTP library against a local copy of pypi

  :pypi:`pytest-pypom-navigation`
     *last release*: Feb 18, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.0.7)

     Core engine for cookiecutter-qa and pytest-play packages

  :pypi:`pytest-pyppeteer`
     *last release*: Apr 28, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.5,<7.0.0)

     A plugin to run pyppeteer in pytest

  :pypi:`pytest-pyq`
     *last release*: Mar 10, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest fixture "q" for pyq

  :pypi:`pytest-pyramid`
     *last release*: Sep 30, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest_pyramid - provides fixtures for testing pyramid applications with pytest test suite

  :pypi:`pytest-pyramid-server`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pyramid server fixture for py.test

  :pypi:`pytest-pyreport`
     *last release*: May 05, 2024,
     *status*: N/A,
     *requires*: pytest

     PyReport is a lightweight reporting plugin for Pytest that provides concise HTML report

  :pypi:`pytest-pyright`
     *last release*: Jan 26, 2024,
     *status*: 4 - Beta,
     *requires*: pytest >=7.0.0

     Pytest plugin for type checking code with Pyright

  :pypi:`pytest-pyspark-plugin`
     *last release*: Nov 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0.0

     Pytest pyspark plugin (p3)

  :pypi:`pytest-pyspark-utils`
     *last release*: May 20, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A simple plugin to use with pytest

  :pypi:`pytest-pyspec`
     *last release*: Nov 18, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=9

     The pytest-pyspec plugin transforms pytest output into a beautiful, readable format similar to RSpec. It provides semantic meaning to your tests by organizing them into descriptive hierarchies, using the prefixes \`Describe\`/\`Test\`, \`With\`/\`Without\`/\`When\`, and \`test\`/\`it\`, while allowing docstrings and decorators to override the descriptions.

  :pypi:`pytest-pystack`
     *last release*: Nov 16, 2024,
     *status*: N/A,
     *requires*: pytest>=3.5.0

     Plugin to run pystack after a timeout for a test suite.

  :pypi:`pytest-pytestdb`
     *last release*: Sep 14, 2025,
     *status*: N/A,
     *requires*: N/A

     Add your description here

  :pypi:`pytest-pytestrail`
     *last release*: Aug 27, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.8.0)

     Pytest plugin for interaction with TestRail

  :pypi:`pytest-pytestrail-internal`
     *last release*: Jun 12, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.8.0

     Pytest plugin for interaction with TestRail, Pytest plugin for TestRail (internal fork from: https://github.com/tolstislon/pytest-pytestrail with PR #25 fix)

  :pypi:`pytest-pythonhashseed`
     *last release*: Nov 16, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.0.0

     Pytest plugin to set PYTHONHASHSEED env var.

  :pypi:`pytest-pythonpath`
     *last release*: Feb 10, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (<7,>=2.5.2)

     pytest plugin for adding to the PYTHONPATH from command line or configs.

  :pypi:`pytest-python-test-engineer-sort`
     *last release*: May 13, 2024,
     *status*: N/A,
     *requires*: pytest>=6.2.0

     Sort plugin for Pytest

  :pypi:`pytest-pytorch`
     *last release*: May 25, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin for a better developer experience when working with the PyTorch test suite

  :pypi:`pytest-pyvenv`
     *last release*: Feb 27, 2024,
     *status*: N/A,
     *requires*: pytest ; extra == 'test'

     A package for create venv in tests

  :pypi:`pytest-pyvista`
     *last release*: Apr 13, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Pytest-pyvista package.

  :pypi:`pytest-qanova`
     *last release*: Sep 05, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin to collect test information

  :pypi:`pytest-qaseio`
     *last release*: Dec 10, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.2.2

     Pytest plugin for Qase.io integration

  :pypi:`pytest-qasync`
     *last release*: Jul 12, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=5.4.0)

     Pytest support for qasync.

  :pypi:`pytest-qatouch`
     *last release*: Feb 14, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.0)

     Pytest plugin for uploading test results to your QA Touch Testrun.

  :pypi:`pytest-qemu-pic32mk`
     *last release*: May 17, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     pytest plugin for QEMU-based functional tests targeting PIC32MK (MIPS32) firmware

  :pypi:`pytest-qfield`
     *last release*: Jun 05, 2026,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin for testing QField qml plugins

  :pypi:`pytest-qgis`
     *last release*: Apr 01, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0

     A pytest plugin for testing QGIS python plugins

  :pypi:`pytest-qml`
     *last release*: Dec 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.0.0)

     Run QML Tests with pytest

  :pypi:`pytest-qr`
     *last release*: Nov 25, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest plugin to generate test result QR codes

  :pypi:`pytest-qt`
     *last release*: Jul 01, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest support for PyQt and PySide applications

  :pypi:`pytest-qt-app`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     QT app fixture for py.test

  :pypi:`pytest-quantum`
     *last release*: Mar 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0

     A cross-framework pytest plugin for quantum program testing

  :pypi:`pytest-quarantine`
     *last release*: Nov 24, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.6)

     A plugin for pytest to manage expected test failures

  :pypi:`pytest-quickcheck`
     *last release*: Nov 05, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.0)

     pytest plugin to generate random data inspired by QuickCheck

  :pypi:`pytest_quickify`
     *last release*: Jun 14, 2019,
     *status*: N/A,
     *requires*: pytest

     Run test suites with pytest-quickify.

  :pypi:`pytest-rabbitmq`
     *last release*: Mar 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2

     RabbitMQ process and client fixtures for pytest

  :pypi:`pytest-race`
     *last release*: Jun 07, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Race conditions tester for pytest

  :pypi:`pytest-rage`
     *last release*: Oct 21, 2011,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin to implement PEP712

  :pypi:`pytest-rail`
     *last release*: May 02, 2022,
     *status*: N/A,
     *requires*: pytest (>=3.6)

     pytest plugin for creating TestRail runs and adding results

  :pypi:`pytest-railflow-testrail-reporter`
     *last release*: Jun 29, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Generate json reports along with specified metadata defined in test markers.

  :pypi:`pytest-raises`
     *last release*: Apr 23, 2020,
     *status*: N/A,
     *requires*: pytest (>=3.2.2)

     An implementation of pytest.raises as a pytest.mark fixture

  :pypi:`pytest-raisesregexp`
     *last release*: Dec 18, 2015,
     *status*: N/A,
     *requires*: N/A

     Simple pytest plugin to look for regex in Exceptions

  :pypi:`pytest-raisin`
     *last release*: Feb 06, 2022,
     *status*: N/A,
     *requires*: pytest

     Plugin enabling the use of exception instances with pytest.raises

  :pypi:`pytest-random`
     *last release*: Apr 28, 2013,
     *status*: 3 - Alpha,
     *requires*: N/A

     py.test plugin to randomize tests

  :pypi:`pytest-randomly`
     *last release*: Apr 20, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin to randomly order tests and control random.seed.

  :pypi:`pytest-randomness`
     *last release*: May 30, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest plugin about random seed management

  :pypi:`pytest-random-num`
     *last release*: Oct 19, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Randomise the order in which pytest tests are run with some control over the randomness

  :pypi:`pytest-random-order`
     *last release*: Jun 22, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Randomise the order in which pytest tests are run with some control over the randomness

  :pypi:`pytest-ranking`
     *last release*: Apr 08, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.4.3

     A Pytest plugin for faster fault detection via regression test prioritization

  :pypi:`pytest-rca-report`
     *last release*: Aug 04, 2025,
     *status*: N/A,
     *requires*: N/A

     Interactive RCA report generator for pytest runs, with AI-based analysis and visual dashboard

  :pypi:`pytest-readable`
     *last release*: Mar 23, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest<10.0,>=9.0

     Pytest plugin that renders readable test specifications and exports documentation

  :pypi:`pytest-readme`
     *last release*: Aug 01, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Test your README.md file

  :pypi:`pytest-reana`
     *last release*: May 12, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest fixtures for REANA.

  :pypi:`pytest-recap`
     *last release*: Jun 16, 2025,
     *status*: N/A,
     *requires*: pytest>=6.2.0

     Capture your test sessions. Recap the results.

  :pypi:`pytest-recorder`
     *last release*: Apr 13, 2026,
     *status*: N/A,
     *requires*: pytest>=8.4.1

     Pytest plugin, meant to facilitate unit tests writing for tools consumming Web APIs.

  :pypi:`pytest-recording`
     *last release*: May 08, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     A pytest plugin powered by VCR.py to record and replay HTTP traffic

  :pypi:`pytest-recordings`
     *last release*: Aug 13, 2020,
     *status*: N/A,
     *requires*: N/A

     Provides pytest plugins for reporting request/response traffic, screenshots, and more to ReportPortal

  :pypi:`pytest-record-video`
     *last release*: Oct 31, 2024,
     *status*: N/A,
     *requires*: N/A

     用例执行过程中录制视频

  :pypi:`pytest-redis`
     *last release*: Feb 28, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4.0

     Redis fixtures and fixture factories for Pytest.

  :pypi:`pytest-redislite`
     *last release*: Apr 22, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest plugin for testing code using Redis

  :pypi:`pytest-redmine`
     *last release*: Mar 19, 2018,
     *status*: 1 - Planning,
     *requires*: N/A

     Pytest plugin for redmine

  :pypi:`pytest-ref`
     *last release*: Nov 23, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A plugin to store reference files to ease regression testing

  :pypi:`pytest-reference-formatter`
     *last release*: Oct 01, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     Conveniently run pytest with a dot-formatted test reference.

  :pypi:`pytest-regex`
     *last release*: May 29, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Select pytest tests with regular expressions

  :pypi:`pytest-regex-dependency`
     *last release*: Jun 12, 2022,
     *status*: N/A,
     *requires*: pytest

     Management of Pytest dependencies via regex patterns

  :pypi:`pytest-regressions`
     *last release*: May 25, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.2.0

     Easy to use fixtures to write regression tests.

  :pypi:`pytest-regtest`
     *last release*: May 05, 2026,
     *status*: N/A,
     *requires*: pytest>7.2

     pytest plugin for snapshot regression testing

  :pypi:`pytest-relative-order`
     *last release*: May 17, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     a pytest plugin that sorts tests using "before" and "after" markers

  :pypi:`pytest-relative-path`
     *last release*: Nov 13, 2025,
     *status*: N/A,
     *requires*: pytest

     Handle relative path in pytest options or ini configs

  :pypi:`pytest-relaxed`
     *last release*: Mar 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     Relaxed test discovery/organization for pytest

  :pypi:`pytest_relay`
     *last release*: Jan 31, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin to relay test information and control from and to pytest

  :pypi:`pytest-relay-run`
     *last release*: Jan 31, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A pytest wrapper using for pytest-relay with pytest-relay-ws to control pytest executions.

  :pypi:`pytest_relay_ws`
     *last release*: Jan 31, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     An extension plugin to pytest-relay to relay pytest information via websockets

  :pypi:`pytest-remaster`
     *last release*: Apr 09, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7

     Pytest plugin for golden master (characterisation) testing with automatic expected file regeneration.

  :pypi:`pytest-remfiles`
     *last release*: Jul 01, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin to create a temporary directory with remote files

  :pypi:`pytest-remotedata`
     *last release*: Sep 26, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=4.6

     Pytest plugin for controlling remote data access.

  :pypi:`pytest-remote-response`
     *last release*: Apr 26, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.6)

     Pytest plugin for capturing and mocking connection requests.

  :pypi:`pytest-remove-stale-bytecode`
     *last release*: Nov 19, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     py.test plugin to remove stale byte code files.

  :pypi:`pytest-reorder`
     *last release*: May 31, 2018,
     *status*: 4 - Beta,
     *requires*: pytest

     Reorder tests depending on their paths and names.

  :pypi:`pytest-repeat`
     *last release*: Apr 07, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest plugin for repeating tests

  :pypi:`pytest-repeated`
     *last release*: Feb 24, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A pytest module for very basic statistical tests. Repeat test multiple times and pass if the underlying test passes a threshold.

  :pypi:`pytest_repeater`
     *last release*: Feb 09, 2018,
     *status*: 1 - Planning,
     *requires*: N/A

     py.test plugin for repeating single test multiple times.

  :pypi:`pytest-replay`
     *last release*: Dec 23, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Saves previous test runs and allow re-execute previous pytest runs to reproduce crashes or flaky tests

  :pypi:`pytest-repo-health`
     *last release*: Dec 09, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin to report on repository standards conformance

  :pypi:`pytest-report`
     *last release*: May 11, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     Creates json report that is compatible with atom.io's linter message format

  :pypi:`pytest-reporter`
     *last release*: Feb 28, 2024,
     *status*: 4 - Beta,
     *requires*: pytest

     Generate Pytest reports with templates

  :pypi:`pytest-reporter-html`
     *last release*: Apr 27, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0

     Pytest plugin that generates rich HTML test reports with step tracking, log capture, and interactive filtering

  :pypi:`pytest-reporter-html1`
     *last release*: Oct 10, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     A basic HTML report template for Pytest

  :pypi:`pytest-reporter-html-dots`
     *last release*: Apr 26, 2025,
     *status*: N/A,
     *requires*: N/A

     A basic HTML report for pytest using Jinja2 template engine.

  :pypi:`pytest-reporter-plus`
     *last release*: Jul 16, 2025,
     *status*: N/A,
     *requires*: N/A

     Lightweight enhanced HTML reporter for Pytest

  :pypi:`pytest-report-extras`
     *last release*: Dec 24, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.0

     Pytest plugin to enhance pytest-html and allure reports by adding comments, screenshots, webpage sources and attachments.

  :pypi:`pytest-reportinfra`
     *last release*: Aug 11, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest plugin for reportinfra

  :pypi:`pytest-reporting`
     *last release*: Oct 25, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A plugin to report summarized results in a table format

  :pypi:`pytest-reportlog`
     *last release*: Nov 11, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Replacement for the --resultlog option, focused in simplicity and extensibility

  :pypi:`pytest-report-me`
     *last release*: Dec 31, 2020,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin to generate report.

  :pypi:`pytest-report-parameters`
     *last release*: Jun 18, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest (>=2.4.2)

     pytest plugin for adding tests' parameters to junit report

  :pypi:`pytest-reportportal`
     *last release*: Jun 03, 2026,
     *status*: N/A,
     *requires*: N/A

     Agent for Reporting results of tests to the Report Portal

  :pypi:`pytest-report-stream`
     *last release*: Oct 22, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin which allows to stream test reports at runtime

  :pypi:`pytest-repo-structure`
     *last release*: Mar 18, 2024,
     *status*: 1 - Planning,
     *requires*: N/A

     Pytest Repo Structure

  :pypi:`pytest-req`
     *last release*: Apr 26, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4.2

     pytest requests plugin

  :pypi:`pytest-reqcov`
     *last release*: Jul 04, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.0

     A pytest plugin for requirement coverage tracking

  :pypi:`pytest-reqs`
     *last release*: May 12, 2019,
     *status*: N/A,
     *requires*: pytest (>=2.4.2)

     pytest plugin to check pinned requirements

  :pypi:`pytest-requests`
     *last release*: Jun 24, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to use with pytest

  :pypi:`pytest-requestselapsed`
     *last release*: Aug 14, 2022,
     *status*: N/A,
     *requires*: N/A

     collect and show http requests elapsed time

  :pypi:`pytest-requests-futures`
     *last release*: Jul 06, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest Plugin to Mock Requests Futures

  :pypi:`pytest-requirements`
     *last release*: Jun 05, 2026,
     *status*: N/A,
     *requires*: pytest

     pytest plugin for using custom markers to relate tests to requirements and usecases

  :pypi:`pytest-requires`
     *last release*: Dec 21, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin to elegantly skip tests with optional requirements

  :pypi:`pytest-reqyaml`
     *last release*: Aug 16, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.1

     This is a plugin where generate requests test cases from yaml.

  :pypi:`pytest-reraise`
     *last release*: Sep 20, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.6)

     Make multi-threaded pytest test cases fail when they should

  :pypi:`pytest-rerun`
     *last release*: Jul 08, 2019,
     *status*: N/A,
     *requires*: pytest (>=3.6)

     Re-run only changed files in specified branch

  :pypi:`pytest-rerun-all`
     *last release*: Jul 30, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Rerun testsuite for a certain time or iterations

  :pypi:`pytest-rerunclassfailures`
     *last release*: Apr 24, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.2

     pytest rerun class failures plugin

  :pypi:`pytest-rerunfailures`
     *last release*: May 22, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest!=8.2.2,>=8.1

     pytest plugin to re-run tests to eliminate flaky failures

  :pypi:`pytest-rerunfailures-all-logs`
     *last release*: Mar 07, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin to re-run tests to eliminate flaky failures

  :pypi:`pytest-reserial`
     *last release*: Dec 30, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     Pytest fixture for recording and replaying serial port traffic.

  :pypi:`pytest-resilient-circuits`
     *last release*: Apr 29, 2026,
     *status*: N/A,
     *requires*: pytest~=7.0

     Resilient Circuits fixtures for PyTest

  :pypi:`pytest-resource`
     *last release*: Nov 14, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     Load resource fixture plugin to use with pytest

  :pypi:`pytest-resource-path`
     *last release*: May 17, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.5.0

     Provides path for uniform access to test resources in isolated directory

  :pypi:`pytest-resource-usage`
     *last release*: Nov 06, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     Pytest plugin for reporting running time and peak memory usage

  :pypi:`pytest-respect`
     *last release*: Apr 08, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0.0

     Pytest plugin to load resource files relative to test code and to expect values to match them.

  :pypi:`pytest-responsemock`
     *last release*: Mar 10, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Simplified requests calls mocking for pytest

  :pypi:`pytest-responses`
     *last release*: Oct 11, 2022,
     *status*: N/A,
     *requires*: pytest (>=2.5)

     py.test integration for responses

  :pypi:`pytest-rest-api`
     *last release*: Aug 08, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.2,<8.0.0)



  :pypi:`pytest-restrict`
     *last release*: Feb 09, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin to restrict the test types allowed

  :pypi:`pytest-resttest`
     *last release*: May 26, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=9

     A REST API testing framework for Python, as plugin for pytest. Uses simple and readable YAML files for specifying test cases.

  :pypi:`pytest-result-log`
     *last release*: Jan 10, 2024,
     *status*: N/A,
     *requires*: pytest>=7.2.0

     A pytest plugin that records the start, end, and result information of each use case in a log file

  :pypi:`pytest-result-notify`
     *last release*: Apr 27, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.5

     Default template for PDM package

  :pypi:`pytest-results`
     *last release*: Oct 08, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     Easily spot regressions in your tests.

  :pypi:`pytest-result-sender`
     *last release*: Apr 20, 2023,
     *status*: N/A,
     *requires*: pytest>=7.3.1



  :pypi:`pytest-result-sender-fanrenbufan`
     *last release*: Mar 12, 2026,
     *status*: N/A,
     *requires*: pytest>=8.4.2

     Default template for PDM package

  :pypi:`pytest-result-sender-jms`
     *last release*: May 22, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.5

     Default template for PDM package

  :pypi:`pytest-result-sender-lj`
     *last release*: Dec 17, 2024,
     *status*: N/A,
     *requires*: pytest>=8.3.4

     Default template for PDM package

  :pypi:`pytest-result-sender-lyt`
     *last release*: Mar 14, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.5

     Default template for PDM package

  :pypi:`pytest-result-sender-misszhang`
     *last release*: Mar 21, 2025,
     *status*: N/A,
     *requires*: pytest>=8.3.5

     Default template for PDM package

  :pypi:`pytest-result-sender-r`
     *last release*: Dec 26, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.2

     Default template for PDM package

  :pypi:`pytest-resume`
     *last release*: Apr 22, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.0)

     A Pytest plugin to resuming from the last run test

  :pypi:`pytest-rethinkdb`
     *last release*: Jul 24, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     A RethinkDB plugin for pytest.

  :pypi:`pytest-retry`
     *last release*: Jan 19, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Adds the ability to retry flaky tests in CI environments

  :pypi:`pytest-retry-class`
     *last release*: Nov 24, 2024,
     *status*: N/A,
     *requires*: pytest>=5.3

     A pytest plugin to rerun entire class on failure

  :pypi:`pytest-reusable-testcases`
     *last release*: Apr 28, 2023,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-revealtype-injector`
     *last release*: Feb 03, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Pytest plugin for replacing reveal_type() calls inside test functions with static and runtime type checking result comparison, for confirming type annotation validity.

  :pypi:`pytest-reverse`
     *last release*: Sep 09, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest plugin to reverse test order.

  :pypi:`pytest-review`
     *last release*: Apr 12, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     A pytest plugin that reviews the quality of your tests

  :pypi:`pytest-rich`
     *last release*: Dec 12, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     Leverage rich for richer test session output

  :pypi:`pytest-richer`
     *last release*: Oct 27, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin providing a Rich based reporter.

  :pypi:`pytest-rich-reporter`
     *last release*: Feb 17, 2022,
     *status*: 1 - Planning,
     *requires*: pytest (>=5.0.0)

     A pytest plugin using Rich for beautiful test result formatting.

  :pypi:`pytest-richtrace`
     *last release*: Jun 20, 2023,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin that displays the names and information of the pytest hook functions as they are executed.

  :pypi:`pytest-ringo`
     *last release*: Sep 27, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin to test webapplications using the Ringo webframework

  :pypi:`pytest-rmsis`
     *last release*: Aug 10, 2022,
     *status*: N/A,
     *requires*: pytest (>=5.3.5)

     Sycronise pytest results to Jira RMsis

  :pypi:`pytest-rmysql`
     *last release*: Aug 17, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.1

     This is a plugin which is able to connet MySQL easyly.

  :pypi:`pytest-rng`
     *last release*: Aug 08, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Fixtures for seeding tests and making randomness reproducible

  :pypi:`pytest-roast`
     *last release*: Nov 09, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     pytest plugin for ROAST configuration override and fixtures

  :pypi:`pytest_robotframework`
     *last release*: Dec 22, 2025,
     *status*: N/A,
     *requires*: pytest<10,>=7

     a pytest plugin that can run both python and robotframework tests while generating robot reports for them

  :pypi:`pytest-rocketchat`
     *last release*: Apr 18, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest to Rocket.Chat reporting plugin

  :pypi:`pytest-rotest`
     *last release*: Sep 08, 2019,
     *status*: N/A,
     *requires*: pytest (>=3.5.0)

     Pytest integration with rotest

  :pypi:`pytest-route-coverage`
     *last release*: Apr 02, 2026,
     *status*: N/A,
     *requires*: pytest>=7.2.2

     pytest plugin to generate reports on routes coverage for web applications.

  :pypi:`pytest-routes`
     *last release*: Dec 01, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Property-based smoke testing for ASGI application routes

  :pypi:`pytest-rpc`
     *last release*: Feb 22, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (~=3.6)

     Extend py.test for RPC OpenStack testing.

  :pypi:`pytest-rs`
     *last release*: Jun 06, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     A fast, drop-in compatible pytest runner written in Rust

  :pypi:`pytest-r-snapshot`
     *last release*: Jan 02, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     A pytest plugin for snapshot testing against R code outputs

  :pypi:`pytest-rst`
     *last release*: Feb 22, 2026,
     *status*: N/A,
     *requires*: N/A

     Test code from RST documents with pytest

  :pypi:`pytest-rt`
     *last release*: May 05, 2022,
     *status*: N/A,
     *requires*: N/A

     pytest data collector plugin for Testgr

  :pypi:`pytest-rts`
     *last release*: May 17, 2021,
     *status*: N/A,
     *requires*: pytest

     Coverage-based regression test selection (RTS) plugin for pytest

  :pypi:`pytest-ruff`
     *last release*: Jun 19, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=5

     pytest plugin to check ruff requirements.

  :pypi:`pytest-run-changed`
     *last release*: Apr 02, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest

     Pytest plugin that runs changed tests only

  :pypi:`pytest-runfailed`
     *last release*: Mar 24, 2016,
     *status*: N/A,
     *requires*: N/A

     implement a --failed option for pytest

  :pypi:`pytest-run-parallel`
     *last release*: Jun 03, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A simple pytest plugin to run tests concurrently

  :pypi:`pytest-run-subprocess`
     *last release*: Nov 12, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest Plugin for running and testing subprocesses.

  :pypi:`pytest-runtime-types`
     *last release*: Feb 09, 2023,
     *status*: N/A,
     *requires*: pytest

     Checks type annotations on runtime while running tests.

  :pypi:`pytest-runtime-xfail`
     *last release*: Oct 10, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=5.0.0

     Call runtime_xfail() to mark running test as xfail.

  :pypi:`pytest-runtime-yoyo`
     *last release*: Jun 12, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.0)

     run case mark timeout

  :pypi:`pytest-rxdist`
     *last release*: Mar 17, 2026,
     *status*: 1 - Planning,
     *requires*: N/A

     Rust-accelerated next-generation execution engine for pytest (planned).

  :pypi:`pytest-saccharin`
     *last release*: Oct 31, 2022,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest-saccharin is a updated fork of pytest-sugar, a plugin for pytest that changes the default look and feel of pytest (e.g. progressbar, show tests that fail instantly).

  :pypi:`pytest-salt`
     *last release*: Jan 27, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest Salt Plugin

  :pypi:`pytest-salt-containers`
     *last release*: Nov 09, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     A Pytest plugin that builds and creates docker containers

  :pypi:`pytest-salt-factories`
     *last release*: Jul 08, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.4.0

     Pytest Salt Plugin

  :pypi:`pytest-salt-from-filenames`
     *last release*: Jan 29, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.1)

     Simple PyTest Plugin For Salt's Test Suite Specifically

  :pypi:`pytest-salt-runtests-bridge`
     *last release*: Dec 05, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=4.1)

     Simple PyTest Plugin For Salt's Test Suite Specifically

  :pypi:`pytest-sample-argvalues`
     *last release*: May 07, 2024,
     *status*: N/A,
     *requires*: pytest

     A utility function to help choose a random sample from your argvalues in pytest.

  :pypi:`pytest-sanic`
     *last release*: Oct 25, 2021,
     *status*: N/A,
     *requires*: pytest (>=5.2)

     a pytest plugin for Sanic

  :pypi:`pytest-sanitizer`
     *last release*: Mar 16, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.0.0

     A pytest plugin to sanitize output for LLMs (personal tool, no warranty or liability)

  :pypi:`pytest-sanity`
     *last release*: Dec 07, 2020,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-sa-pg`
     *last release*: May 14, 2019,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest_sauce`
     *last release*: Jul 14, 2014,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest_sauce provides sane and helpful methods worked    out in clearcode to run py.test tests with selenium/saucelabs

  :pypi:`pytest-sbase`
     *last release*: Jun 05, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A complete web automation framework for end-to-end testing.

  :pypi:`pytest-scenario`
     *last release*: Feb 06, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest plugin for test scenarios

  :pypi:`pytest-scenario-files`
     *last release*: May 18, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest<10,>=7.4

     A pytest plugin that generates unit test scenarios from data files.

  :pypi:`pytest-scenarios`
     *last release*: Jan 03, 2026,
     *status*: N/A,
     *requires*: N/A

     Add your description here

  :pypi:`pytest-schedule`
     *last release*: Oct 31, 2024,
     *status*: N/A,
     *requires*: N/A

     Automate and customize test scheduling effortlessly on local machines.

  :pypi:`pytest-schema`
     *last release*: Feb 16, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=3.5.0

     👍 Validate return values against a schema-like object in testing

  :pypi:`pytest-scim2-server`
     *last release*: Nov 14, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3.4

     SCIM2 server fixture for Pytest

  :pypi:`pytest-screenshot-on-failure`
     *last release*: Jul 21, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     Saves a screenshot when a test case from a pytest execution fails

  :pypi:`pytest-scrutinize`
     *last release*: Aug 19, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6

     Scrutinize your pytest test suites for slow fixtures, tests and more.

  :pypi:`pytest-securestore`
     *last release*: Nov 08, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     An encrypted password store for use within pytest cases

  :pypi:`pytest-select`
     *last release*: Jan 18, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0)

     A pytest plugin which allows to (de-)select tests from a file.

  :pypi:`pytest-selenium`
     *last release*: Feb 01, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0.0

     pytest plugin for Selenium

  :pypi:`pytest-selenium-auto`
     *last release*: Nov 07, 2023,
     *status*: N/A,
     *requires*: pytest >= 7.0.0

     pytest plugin to automatically capture screenshots upon selenium webdriver events

  :pypi:`pytest-seleniumbase`
     *last release*: Jun 05, 2026,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A complete web automation framework for end-to-end testing.

  :pypi:`pytest-selenium-driver`
     *last release*: Mar 07, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     A zero-boilerplate Selenium WebDriver fixture for pytest

  :pypi:`pytest-selenium-enhancer`
     *last release*: Apr 29, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for Selenium

  :pypi:`pytest-selenium-pdiff`
     *last release*: Apr 06, 2017,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     A pytest package implementing perceptualdiff for Selenium tests.

  :pypi:`pytest-selfie`
     *last release*: Dec 16, 2024,
     *status*: N/A,
     *requires*: pytest>=8.0.0

     A pytest plugin for selfie snapshot testing.

  :pypi:`pytest-semantic`
     *last release*: Nov 11, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     A pytest plugin for testing LLM outputs using semantic similarity matching

  :pypi:`pytest-semantic-assert`
     *last release*: Jan 09, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Pytest plugin for semantic LLM output assertions using embeddings. Test meaning, not strings.

  :pypi:`pytest-semantic-llm`
     *last release*: Mar 10, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Semantic assertions for pytest using LLMs

  :pypi:`pytest-semantix`
     *last release*: Apr 13, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     pytest plugin for semantic LLM output testing — validate meaning, not just shape.

  :pypi:`pytest-send-email`
     *last release*: Sep 02, 2024,
     *status*: N/A,
     *requires*: pytest

     Send pytest execution result email

  :pypi:`pytest-sentry`
     *last release*: Jul 01, 2025,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin to send testrun information to Sentry.io

  :pypi:`pytest-sequence-markers`
     *last release*: May 23, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin for sequencing markers for execution of tests

  :pypi:`pytest-server`
     *last release*: Sep 09, 2024,
     *status*: N/A,
     *requires*: N/A

     test server exec cmd

  :pypi:`pytest-server-fixtures`
     *last release*: Nov 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Extensible server fixtures for py.test

  :pypi:`pytest-serverless`
     *last release*: May 09, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Automatically mocks resources from serverless.yml in pytest using moto.

  :pypi:`pytest-servers`
     *last release*: Dec 21, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=6.2

     pytest servers

  :pypi:`pytest-service`
     *last release*: Aug 06, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0.0



  :pypi:`pytest-services`
     *last release*: Jul 16, 2025,
     *status*: 6 - Mature,
     *requires*: pytest

     Services plugin for pytest testing framework

  :pypi:`pytest-session2file`
     *last release*: Jan 26, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest

     pytest-session2file (aka: pytest-session_to_file for v0.1.0 - v0.1.2) is a py.test plugin for capturing and saving to file the stdout of py.test.

  :pypi:`pytest-session-fixture-globalize`
     *last release*: May 15, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to make session fixtures behave as if written in conftest, even if it is written in some modules

  :pypi:`pytest-session_to_file`
     *last release*: Oct 01, 2015,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest-session_to_file is a py.test plugin for capturing and saving to file the stdout of py.test.

  :pypi:`pytest-setupinfo`
     *last release*: Jan 23, 2023,
     *status*: N/A,
     *requires*: N/A

     Displaying setup info during pytest command run

  :pypi:`pytest-sftpserver`
     *last release*: Sep 16, 2019,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to locally test sftp server connections.

  :pypi:`pytest-shard`
     *last release*: Dec 11, 2020,
     *status*: 4 - Beta,
     *requires*: pytest



  :pypi:`pytest-shard-cloudc`
     *last release*: Apr 02, 2026,
     *status*: 4 - Beta,
     *requires*: pytest

     Shard tests to support parallelism across multiple machines.

  :pypi:`pytest-shard-fork`
     *last release*: Jun 13, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     Shard tests to support parallelism across multiple machines

  :pypi:`pytest-shared-session-scope`
     *last release*: Oct 31, 2025,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Pytest session-scoped fixture that works with xdist

  :pypi:`pytest-share-hdf`
     *last release*: Sep 21, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Plugin to save test data in HDF files and retrieve them for comparison

  :pypi:`pytest-sharkreport`
     *last release*: Jul 11, 2022,
     *status*: N/A,
     *requires*: pytest (>=3.5)

     this is pytest report plugin.

  :pypi:`pytest-shell`
     *last release*: Mar 27, 2022,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin to help with testing shell scripts / black box commands

  :pypi:`pytest-shell-utilities`
     *last release*: Oct 22, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.4.0

     Pytest plugin to simplify running shell commands against the system

  :pypi:`pytest-sheraf`
     *last release*: Feb 11, 2020,
     *status*: N/A,
     *requires*: pytest

     Versatile ZODB abstraction layer - pytest fixtures

  :pypi:`pytest-sherlock`
     *last release*: Aug 14, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=3.5.1

     pytest plugin help to find coupled tests

  :pypi:`pytest-shortcuts`
     *last release*: Oct 29, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Expand command-line shortcuts listed in pytest configuration

  :pypi:`pytest-shutil`
     *last release*: Nov 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A goodie-bag of unix shell and environment tools for py.test

  :pypi:`pytest-sigil`
     *last release*: Oct 21, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=7.0.0

     Proper fixture resource cleanup by handling signals

  :pypi:`pytest-simbind`
     *last release*: Mar 28, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Pytest plugin to operate with objects generated by Simbind tool.

  :pypi:`pytest-simplehttpserver`
     *last release*: Jun 24, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     Simple pytest fixture to spin up an HTTP server

  :pypi:`pytest-simple-plugin`
     *last release*: Nov 27, 2019,
     *status*: N/A,
     *requires*: N/A

     Simple pytest plugin

  :pypi:`pytest-simple-settings`
     *last release*: Nov 17, 2020,
     *status*: 4 - Beta,
     *requires*: pytest

     simple-settings plugin for pytest

  :pypi:`pytest-simplified`
     *last release*: Jan 19, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<9.0.0,>=8.3.5

     A PyTest plugin to simplify testing classes.

  :pypi:`pytest-single-file-logging`
     *last release*: May 05, 2016,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.8.1)

     Allow for multiple processes to log to a single file

  :pypi:`pytest-skill-engineering`
     *last release*: Apr 30, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=9.0

     The testing framework for skill engineering. Test tool descriptions, prompt templates, agent skills, and custom agents with real LLMs. AI analyzes results and tells you what to fix.

  :pypi:`pytest-skip`
     *last release*: Sep 12, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest

     A pytest plugin which allows to (de-)select or skip tests from a file.

  :pypi:`pytest-skip-markers`
     *last release*: Aug 09, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.1.0

     Pytest Salt Plugin

  :pypi:`pytest-skipper`
     *last release*: Mar 26, 2017,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0.6)

     A plugin that selects only tests with changes in execution path

  :pypi:`pytest-skippy`
     *last release*: Jan 27, 2018,
     *status*: 3 - Alpha,
     *requires*: pytest (>=2.3.4)

     Automatically skip tests that don't need to run!

  :pypi:`pytest-skip-slow`
     *last release*: May 27, 2026,
     *status*: N/A,
     *requires*: pytest>=6.2.0

     A pytest plugin to skip \`@pytest.mark.slow\` tests by default.

  :pypi:`pytest-skipuntil`
     *last release*: Nov 25, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=3.8.0

     A simple pytest plugin to skip flapping test with deadline

  :pypi:`pytest-slack`
     *last release*: Dec 15, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest to Slack reporting plugin

  :pypi:`pytest-slow`
     *last release*: Sep 28, 2021,
     *status*: N/A,
     *requires*: N/A

     A pytest plugin to skip \`@pytest.mark.slow\` tests by default.

  :pypi:`pytest-slowest-first`
     *last release*: Dec 11, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Sort tests by their last duration, slowest first

  :pypi:`pytest-slow-first`
     *last release*: Jan 30, 2024,
     *status*: 4 - Beta,
     *requires*: pytest >=3.5.0

     Prioritize running the slowest tests first.

  :pypi:`pytest-slow-last`
     *last release*: Mar 16, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.5.0

     Run tests in order of execution time (faster tests first)

  :pypi:`pytest-smartcollect`
     *last release*: Oct 04, 2018,
     *status*: N/A,
     *requires*: pytest (>=3.5.0)

     A plugin for collecting tests that touch changed code

  :pypi:`pytest-smartcov`
     *last release*: Sep 30, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     Smart coverage plugin for pytest.

  :pypi:`pytest-smart-debugger-backend`
     *last release*: Sep 17, 2025,
     *status*: N/A,
     *requires*: N/A

     Backend server for Pytest Smart Debugger

  :pypi:`pytest-smart-rerun`
     *last release*: Oct 12, 2025,
     *status*: 3 - Alpha,
     *requires*: N/A

     A Pytest plugin for intelligent retrying of flaky tests.

  :pypi:`pytest-smell`
     *last release*: Jun 26, 2022,
     *status*: N/A,
     *requires*: N/A

     Automated bad smell detection tool for Pytest

  :pypi:`pytest-smoke`
     *last release*: Nov 09, 2025,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=7.0.0

     Pytest plugin for smoke testing

  :pypi:`pytest-smtp`
     *last release*: Feb 20, 2021,
     *status*: N/A,
     *requires*: pytest

     Send email with pytest execution result

  :pypi:`pytest-smtp4dev`
     *last release*: Jun 27, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Plugin for smtp4dev API

  :pypi:`pytest-smtpd`
     *last release*: May 15, 2023,
     *status*: N/A,
     *requires*: pytest

     An SMTP server for testing built on aiosmtpd

  :pypi:`pytest-smtp-test-server`
     *last release*: Dec 03, 2023,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest (>=7.4.3,<8.0.0)

     pytest plugin for using \`smtp-test-server\` as a fixture

  :pypi:`pytest-snail`
     *last release*: Nov 04, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=5.0.1)

     Plugin for adding a marker to slow running tests. 🐌

  :pypi:`pytest-snap`
     *last release*: Aug 25, 2025,
     *status*: N/A,
     *requires*: pytest>=8.0.0

     A text-based snapshot testing library implemented as a pytest plugin

  :pypi:`pytest-snapcheck`
     *last release*: Sep 07, 2025,
     *status*: N/A,
     *requires*: pytest>=8.0

     Minimal deterministic test-run snapshot capture for pytest.

  :pypi:`pytest-snapci`
     *last release*: Nov 12, 2015,
     *status*: N/A,
     *requires*: N/A

     py.test plugin for Snap-CI

  :pypi:`pytest-snapmock`
     *last release*: Nov 15, 2024,
     *status*: N/A,
     *requires*: N/A

     Snapshots for your mocks.

  :pypi:`pytest-snapshot`
     *last release*: Apr 23, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.0.0)

     A plugin for snapshot testing with pytest.

  :pypi:`pytest-snapshot-with-message-generator`
     *last release*: Jul 25, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.0.0)

     A plugin for snapshot testing with pytest.

  :pypi:`pytest-snmpserver`
     *last release*: May 12, 2021,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-snob`
     *last release*: Jan 12, 2025,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin that only selects meaningful python tests to run.

  :pypi:`pytest-snowflake-bdd`
     *last release*: Jan 05, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.0)

     Setup test data and run tests on snowflake in BDD style!

  :pypi:`pytest-socket`
     *last release*: May 21, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Pytest Plugin to disable socket calls during tests

  :pypi:`pytest-sofaepione`
     *last release*: Aug 17, 2022,
     *status*: N/A,
     *requires*: N/A

     Test the installation of SOFA and the SofaEpione plugin.

  :pypi:`pytest-soft-assert`
     *last release*: Dec 07, 2025,
     *status*: N/A,
     *requires*: pytest>=8.4.0

     Pytest plugin for soft assertions.

  :pypi:`pytest-soft-assertions`
     *last release*: May 05, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest



  :pypi:`pytest-solidity`
     *last release*: Jan 15, 2022,
     *status*: 1 - Planning,
     *requires*: pytest (<7,>=6.0.1) ; extra == 'tests'

     A PyTest library plugin for Solidity language.

  :pypi:`pytest-solr`
     *last release*: May 11, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0.0)

     Solr process and client fixtures for py.test.

  :pypi:`pytest-sort`
     *last release*: Apr 04, 2026,
     *status*: N/A,
     *requires*: pytest>=7.4.0

     Tools for sorting test cases

  :pypi:`pytest-sorter`
     *last release*: Apr 20, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     A simple plugin to first execute tests that historically failed more

  :pypi:`pytest-sosu`
     *last release*: Aug 04, 2023,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest

     Unofficial PyTest plugin for Sauce Labs

  :pypi:`pytest-sourceorder`
     *last release*: Sep 01, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     Test-ordering plugin for pytest

  :pypi:`pytest-spark`
     *last release*: May 21, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin to run the tests with support of pyspark.

  :pypi:`pytest-spawner`
     *last release*: Jul 31, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to spawn process and communicate with them.

  :pypi:`pytest-spec`
     *last release*: May 17, 2026,
     *status*: N/A,
     *requires*: pytest; extra == "test"

     Library pytest-spec is a pytest plugin to display test execution output like a SPECIFICATION.

  :pypi:`pytest-spec2md`
     *last release*: Apr 10, 2024,
     *status*: N/A,
     *requires*: pytest>7.0

     Library pytest-spec2md is a pytest plugin to create a markdown specification while running pytest.

  :pypi:`pytest-speed`
     *last release*: Jan 22, 2023,
     *status*: 3 - Alpha,
     *requires*: pytest>=7

     Modern benchmarking library for python with pytest integration.

  :pypi:`pytest-sphinx`
     *last release*: Jan 21, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=8.1.1

     Doctest plugin for pytest with support for Sphinx-specific doctest-directives

  :pypi:`pytest-spiratest`
     *last release*: Feb 09, 2026,
     *status*: N/A,
     *requires*: pytest>=3.0.0

     Exports unit tests as test runs in Spira (SpiraTest/Team/Plan)

  :pypi:`pytest-splinter`
     *last release*: Sep 09, 2022,
     *status*: 6 - Mature,
     *requires*: pytest (>=3.0.0)

     Splinter plugin for pytest testing framework

  :pypi:`pytest-splinter4`
     *last release*: Feb 01, 2024,
     *status*: 6 - Mature,
     *requires*: pytest >=8.0.0

     Pytest plugin for the splinter automation library

  :pypi:`pytest-split`
     *last release*: Feb 03, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=5

     Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.

  :pypi:`pytest-split-ct`
     *last release*: Jan 23, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=5

     Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.

  :pypi:`pytest-split-ext`
     *last release*: Sep 23, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=5,<8)

     Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.

  :pypi:`pytest-splitio`
     *last release*: Sep 22, 2020,
     *status*: N/A,
     *requires*: pytest (<7,>=5.0)

     Split.io SDK integration for e2e tests

  :pypi:`pytest-split-ng`
     *last release*: Jan 05, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=5

     Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.

  :pypi:`pytest-split-tests`
     *last release*: Jul 30, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.5)

     A Pytest plugin for running a subset of your tests by splitting them in to equally sized groups. Forked from Mark Adams' original project pytest-test-groups.

  :pypi:`pytest-split-tests-tresorit`
     *last release*: Feb 22, 2021,
     *status*: 1 - Planning,
     *requires*: N/A



  :pypi:`pytest-split-v2`
     *last release*: Jan 14, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=5

     Pytest plugin which splits the test suite to equally sized sub suites based on test execution time.

  :pypi:`pytest-splunk-addon`
     *last release*: Apr 29, 2026,
     *status*: N/A,
     *requires*: pytest<8,>5.4.0

     A Dynamic test tool for Splunk Apps and Add-ons

  :pypi:`pytest-splunk-addon-ui-smartx`
     *last release*: Apr 23, 2026,
     *status*: N/A,
     *requires*: N/A

     Library to support testing Splunk Add-on UX

  :pypi:`pytest-splunk-env`
     *last release*: Oct 22, 2020,
     *status*: N/A,
     *requires*: pytest (>=6.1.1,<7.0.0)

     pytest fixtures for interaction with Splunk Enterprise and Splunk Cloud

  :pypi:`pytest-sqitch`
     *last release*: Apr 06, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     sqitch for pytest

  :pypi:`pytest-sqlalchemy`
     *last release*: Apr 19, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0

     pytest plugin with sqlalchemy related fixtures

  :pypi:`pytest-sqlalchemy-alembic`
     *last release*: Jun 05, 2026,
     *status*: N/A,
     *requires*: pytest>=8.4.0

     Pytest plugin to manage databases, sessions and migrations for sqlalchemy-based projects

  :pypi:`pytest-sqlalchemy-mock`
     *last release*: Aug 10, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     pytest sqlalchemy plugin for mock

  :pypi:`pytest-sqlalchemy-session`
     *last release*: May 19, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.0)

     A pytest plugin for preserving test isolation that use SQLAlchemy.

  :pypi:`pytest-sql-bigquery`
     *last release*: Dec 19, 2019,
     *status*: N/A,
     *requires*: pytest

     Yet another SQL-testing framework for BigQuery provided by pytest plugin

  :pypi:`pytest-sqlfluff`
     *last release*: Dec 21, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A pytest plugin to use sqlfluff to enable format checking of sql files.

  :pypi:`pytest-sqlguard`
     *last release*: Jun 06, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7

     Pytest fixture to record and check SQL Queries made by SQLAlchemy

  :pypi:`pytest-squadcast`
     *last release*: Feb 22, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest report plugin for Squadcast

  :pypi:`pytest-srcpaths`
     *last release*: Oct 15, 2021,
     *status*: N/A,
     *requires*: pytest>=6.2.0

     Add paths to sys.path

  :pypi:`pytest-ssh`
     *last release*: May 20, 2026,
     *status*: N/A,
     *requires*: pytest

     pytest plugin for ssh command run

  :pypi:`pytest-start-from`
     *last release*: Apr 11, 2016,
     *status*: N/A,
     *requires*: N/A

     Start pytest run from a given point

  :pypi:`pytest-static`
     *last release*: May 25, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest<8.0.0,>=7.4.3

     pytest-static

  :pypi:`pytest-stats`
     *last release*: Jul 18, 2024,
     *status*: N/A,
     *requires*: pytest>=8.0.0

     Collects tests metadata for future analysis, easy to extend for any data store

  :pypi:`pytest-statsd`
     *last release*: Nov 30, 2018,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.0.0)

     pytest plugin for reporting to graphite

  :pypi:`pytest-status`
     *last release*: Aug 22, 2024,
     *status*: N/A,
     *requires*: pytest

     Add status mark for tests

  :pypi:`pytest-stderr-db`
     *last release*: Sep 14, 2025,
     *status*: N/A,
     *requires*: N/A

     Add your description here

  :pypi:`pytest-stdout-db`
     *last release*: Sep 14, 2025,
     *status*: N/A,
     *requires*: N/A

     Add your description here

  :pypi:`pytest-stepfunctions`
     *last release*: May 08, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     A small description

  :pypi:`pytest-step-logger`
     *last release*: Mar 11, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Live Rich-rendered step trees in pytest terminal output

  :pypi:`pytest-steps`
     *last release*: Sep 23, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Create step-wise / incremental tests in pytest.

  :pypi:`pytest-stepthrough`
     *last release*: Aug 14, 2025,
     *status*: N/A,
     *requires*: N/A

     Pause and wait for Enter after each test with --step

  :pypi:`pytest-stepwise`
     *last release*: Dec 01, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     Run a test suite one failing test at a time.

  :pypi:`pytest-stf`
     *last release*: Sep 23, 2025,
     *status*: N/A,
     *requires*: pytest>=5.0

     pytest plugin for openSTF

  :pypi:`pytest-stochastic`
     *last release*: Feb 24, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     A pytest plugin for principled stochastic unit testing using concentration inequalities

  :pypi:`pytest-stochastics`
     *last release*: Dec 01, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.0.0

     pytest plugin that allows selectively running tests several times and accepting \*some\* failures.

  :pypi:`pytest-stogger`
     *last release*: Jun 02, 2026,
     *status*: N/A,
     *requires*: N/A

     AST-based convention checking helpers for pytest.

  :pypi:`pytest-stoq`
     *last release*: Feb 09, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     A plugin to pytest stoq

  :pypi:`pytest-storage`
     *last release*: Sep 12, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.4.2

     Pytest plugin to store test artifacts

  :pypi:`pytest-store`
     *last release*: Jul 30, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0.0

     Pytest plugin to store values from test runs

  :pypi:`pytest-streaming`
     *last release*: Jan 14, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.3.5

     Plugin for testing pubsub, pulsar, and kafka systems with pytest locally and in ci/cd

  :pypi:`pytest-stress`
     *last release*: Dec 07, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.6.0)

     A Pytest plugin that allows you to loop tests for a user defined amount of time.

  :pypi:`pytest-structlog`
     *last release*: Sep 10, 2025,
     *status*: N/A,
     *requires*: pytest

     Structured logging assertions

  :pypi:`pytest-structmpd`
     *last release*: Oct 17, 2018,
     *status*: N/A,
     *requires*: N/A

     provide structured temporary directory

  :pypi:`pytest-stub`
     *last release*: Apr 28, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Stub packages, modules and attributes.

  :pypi:`pytest-stubprocess`
     *last release*: Sep 17, 2018,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.5.0)

     Provide stub implementations for subprocesses in Python tests

  :pypi:`pytest-study`
     *last release*: Sep 26, 2017,
     *status*: 3 - Alpha,
     *requires*: pytest (>=2.0)

     A pytest plugin to organize long run tests (named studies) without interfering the regular tests

  :pypi:`pytest-subinterpreter`
     *last release*: Nov 25, 2023,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Run pytest in a subinterpreter

  :pypi:`pytest-subket`
     *last release*: Jul 31, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest Plugin to disable socket calls during tests

  :pypi:`pytest-subprocess`
     *last release*: May 10, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=4.0.0

     A plugin to fake subprocess for pytest

  :pypi:`pytest-subtesthack`
     *last release*: Jul 16, 2022,
     *status*: N/A,
     *requires*: N/A

     A hack to explicitly set up and tear down fixtures.

  :pypi:`pytest-subtests`
     *last release*: Oct 20, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.4

     unittest subTest() support and subtests fixture

  :pypi:`pytest-subunit`
     *last release*: Sep 17, 2023,
     *status*: N/A,
     *requires*: pytest (>=2.3)

     pytest-subunit is a plugin for py.test which outputs testsresult in subunit format.

  :pypi:`pytest-sugar`
     *last release*: Aug 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     pytest-sugar is a plugin for pytest that changes the default look and feel of pytest (e.g. progressbar, show tests that fail instantly).

  :pypi:`pytest-suitemanager`
     *last release*: Apr 28, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     A simple plugin to use with pytest

  :pypi:`pytest-suite-timeout`
     *last release*: Jan 26, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A pytest plugin for ensuring max suite time

  :pypi:`pytest-supercov`
     *last release*: Jul 02, 2023,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for measuring explicit test-file to source-file coverage

  :pypi:`pytest-svn`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     SVN repository fixture for py.test

  :pypi:`pytest-swag`
     *last release*: Apr 14, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Generate OpenAPI documentation from pytest tests

  :pypi:`pytest-swarm`
     *last release*: May 29, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Run parametrized test variants in parallel threads — with correct fixture lifecycle

  :pypi:`pytest-symbols`
     *last release*: Nov 20, 2017,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest-symbols is a pytest plugin that adds support for passing test environment symbols into pytest tests.

  :pypi:`pytest-system-statistics`
     *last release*: Feb 16, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=6.0.0)

     Pytest plugin to track and report system usage statistics

  :pypi:`pytest-system-test-plugin`
     *last release*: Feb 03, 2022,
     *status*: N/A,
     *requires*: N/A

     Pyst - Pytest System-Test Plugin

  :pypi:`pytest_tagging`
     *last release*: Nov 08, 2024,
     *status*: N/A,
     *requires*: pytest>=7.1.3

     a pytest plugin to tag tests

  :pypi:`pytest-takeltest`
     *last release*: Sep 07, 2024,
     *status*: N/A,
     *requires*: N/A

     Fixtures for ansible, testinfra and molecule

  :pypi:`pytest-talisker`
     *last release*: Nov 28, 2021,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-tally`
     *last release*: May 22, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.5)

     A Pytest plugin to generate realtime summary stats, and display them in-console using a text-based dashboard.

  :pypi:`pytest-tap`
     *last release*: Jan 30, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.0

     Test Anything Protocol (TAP) reporting plugin for pytest

  :pypi:`pytest-tape`
     *last release*: Mar 17, 2021,
     *status*: 4 - Beta,
     *requires*: N/A

     easy assertion with expected results saved to yaml files

  :pypi:`pytest-target`
     *last release*: Jan 21, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=6.1.2,<7.0.0)

     Pytest plugin for remote target orchestration.

  :pypi:`pytest-taskgraph`
     *last release*: Apr 09, 2025,
     *status*: N/A,
     *requires*: pytest

     Add your description here

  :pypi:`pytest-tblineinfo`
     *last release*: Dec 01, 2015,
     *status*: 3 - Alpha,
     *requires*: pytest (>=2.0)

     tblineinfo is a py.test plugin that insert the node id in the final py.test report when --tb=line option is used

  :pypi:`pytest-tcpclient`
     *last release*: Nov 16, 2022,
     *status*: N/A,
     *requires*: pytest (<8,>=7.1.3)

     A pytest plugin for testing TCP clients

  :pypi:`pytest-tdd`
     *last release*: Aug 18, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     run pytest on a python module

  :pypi:`pytest-teamcity-logblock`
     *last release*: May 15, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     py.test plugin to introduce block structure in teamcity build log, if output is not captured

  :pypi:`pytest-teardown`
     *last release*: Apr 15, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=7.4.1



  :pypi:`pytest-telegram`
     *last release*: Apr 25, 2024,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest to Telegram reporting plugin

  :pypi:`pytest-telegram-notifier`
     *last release*: Jun 27, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Telegram notification plugin for Pytest

  :pypi:`pytest-tempdir`
     *last release*: Oct 11, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.8.1)

     Predictable and repeatable tempdir support.

  :pypi:`pytest-terra-fixt`
     *last release*: Sep 15, 2022,
     *status*: N/A,
     *requires*: pytest (==6.2.5)

     Terraform and Terragrunt fixtures for pytest

  :pypi:`pytest-terraform`
     *last release*: May 21, 2024,
     *status*: N/A,
     *requires*: pytest>=6.0

     A pytest plugin for using terraform fixtures

  :pypi:`pytest-terraform-fixture`
     *last release*: Nov 14, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     generate terraform resources to use with pytest

  :pypi:`pytest-test-analyzer`
     *last release*: Jun 14, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     A powerful tool for analyzing pytest test files and generating detailed reports

  :pypi:`pytest-testbook`
     *last release*: May 29, 2026,
     *status*: N/A,
     *requires*: pytest>=5.4.0

     Enables pytest to execute your Jupyter Notebook as a test

  :pypi:`pytest-test-categories`
     *last release*: Mar 04, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.4.2

     A pytest plugin to enforce test timing constraints and size distributions.

  :pypi:`pytest-testconfig`
     *last release*: Jan 11, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Test configuration plugin for pytest.

  :pypi:`pytest-testcontainers`
     *last release*: May 08, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<9,>=7.4

     Named pytest fixtures and a maker convention on top of testcontainers-python.

  :pypi:`pytest-testcontainers-compose`
     *last release*: Feb 11, 2026,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin for Docker Compose

  :pypi:`pytest-testcontainers-django`
     *last release*: Jun 01, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<9,>=7.4

     Bridge between pytest-testcontainers and pytest-django: starts the DB container before Django imports settings.

  :pypi:`pytest-testdata`
     *last release*: Aug 30, 2024,
     *status*: N/A,
     *requires*: pytest

     Get and load testdata in pytest projects

  :pypi:`pytest-testdirectory`
     *last release*: May 02, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A py.test plugin providing temporary directories in unit tests.

  :pypi:`pytest-testdox`
     *last release*: Jul 22, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.6.0)

     A testdox format reporter for pytest

  :pypi:`pytest-test-grouping`
     *last release*: Feb 01, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.5)

     A Pytest plugin for running a subset of your tests by splitting them in to equally sized groups.

  :pypi:`pytest-test-groups`
     *last release*: May 08, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     A Pytest plugin for running a subset of your tests by splitting them in to equally sized groups.

  :pypi:`pytest-testinel`
     *last release*: May 26, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7

     Testinel’s pytest plugin captures structured test execution data directly from pytest and sends it to Testinel, where your test results become searchable, comparable, and actually useful.

  :pypi:`pytest-testinfra`
     *last release*: Mar 30, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6

     Test infrastructures

  :pypi:`pytest-testinfra-jpic`
     *last release*: Sep 21, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Test infrastructures

  :pypi:`pytest-testinfra-winrm-transport`
     *last release*: Sep 21, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Test infrastructures

  :pypi:`pytest-testit-parametrize`
     *last release*: Dec 04, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=8.3.3

     A pytest plugin for uploading parameterized tests parameters into TMS TestIT

  :pypi:`pytest-testlink-adaptor`
     *last release*: Dec 20, 2018,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.6)

     pytest reporting plugin for testlink

  :pypi:`pytest-testmon`
     *last release*: Dec 01, 2025,
     *status*: 4 - Beta,
     *requires*: pytest<10,>=5

     selects tests affected by changed files and methods

  :pypi:`pytest-testmon-dev`
     *last release*: Mar 30, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (<8,>=5)

     selects tests affected by changed files and methods

  :pypi:`pytest-testmon-oc`
     *last release*: Jun 01, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (<8,>=5)

     nOly selects tests affected by changed files and methods

  :pypi:`pytest-testmon-skip-libraries`
     *last release*: Mar 03, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (<8,>=5)

     selects tests affected by changed files and methods

  :pypi:`pytest-testobject`
     *last release*: Sep 24, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     Plugin to use TestObject Suites with Pytest

  :pypi:`pytest-test-observer`
     *last release*: May 23, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     A pytest plugin for observing test execution events.

  :pypi:`pytest-testpluggy`
     *last release*: Jan 07, 2022,
     *status*: N/A,
     *requires*: pytest

     set your encoding

  :pypi:`pytest-testrail`
     *last release*: Jan 25, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     A pytest plugin for creating TestRail runs and adding results

  :pypi:`pytest-testrail2`
     *last release*: Feb 10, 2023,
     *status*: N/A,
     *requires*: pytest (<8.0,>=7.2.0)

     A pytest plugin to upload results to TestRail.

  :pypi:`pytest-testrail-api`
     *last release*: Mar 17, 2025,
     *status*: N/A,
     *requires*: pytest

     TestRail Api Python Client

  :pypi:`pytest-testrail-api-client`
     *last release*: Dec 14, 2021,
     *status*: N/A,
     *requires*: pytest

     TestRail Api Python Client

  :pypi:`pytest-testrail-appetize`
     *last release*: Sep 29, 2021,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for creating TestRail runs and adding results

  :pypi:`pytest-testrail-client`
     *last release*: Sep 29, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest plugin for Testrail

  :pypi:`pytest-testrail-e2e`
     *last release*: Oct 11, 2021,
     *status*: N/A,
     *requires*: pytest (>=3.6)

     pytest plugin for creating TestRail runs and adding results

  :pypi:`pytest-testrail-integrator`
     *last release*: Aug 01, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.5)

     Pytest plugin for sending report to testrail system.

  :pypi:`pytest-testrail-ns`
     *last release*: Aug 12, 2022,
     *status*: N/A,
     *requires*: N/A

     pytest plugin for creating TestRail runs and adding results

  :pypi:`pytest-testrail-reporter`
     *last release*: Sep 10, 2018,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-testrail-results`
     *last release*: Mar 04, 2024,
     *status*: N/A,
     *requires*: pytest >=7.2.0

     A pytest plugin to upload results to TestRail.

  :pypi:`pytest-testreport`
     *last release*: Dec 01, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)



  :pypi:`pytest-testreport-new`
     *last release*: Oct 07, 2023,
     *status*: 4 - Beta,
     *requires*: pytest >=3.5.0



  :pypi:`pytest-testslide`
     *last release*: Jan 07, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (~=6.2)

     TestSlide fixture for pytest

  :pypi:`pytest-test-this`
     *last release*: Sep 15, 2019,
     *status*: 2 - Pre-Alpha,
     *requires*: pytest (>=2.3)

     Plugin for py.test to run relevant tests, based on naively checking if a test contains a reference to the symbol you supply

  :pypi:`pytest-test-tracer-for-pytest`
     *last release*: Jun 28, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin that allows coll test data for use on Test Tracer

  :pypi:`pytest-test-tracer-for-pytest-bdd`
     *last release*: Aug 20, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin that allows coll test data for use on Test Tracer

  :pypi:`pytest-test-utils`
     *last release*: Feb 08, 2024,
     *status*: N/A,
     *requires*: pytest >=3.9



  :pypi:`pytest-tesults`
     *last release*: Nov 12, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.5.0

     Tesults plugin for pytest

  :pypi:`pytest-texts-score`
     *last release*: Dec 17, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.4.2

     Texts content similarity scoring plugin

  :pypi:`pytest-textual-snapshot`
     *last release*: Jan 23, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.0.0

     Snapshot testing for Textual apps

  :pypi:`pytest-tezos`
     *last release*: Jan 16, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest-ligo

  :pypi:`pytest-tf`
     *last release*: May 29, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.2.1

     Test your OpenTofu and Terraform config using a PyTest plugin

  :pypi:`pytest-th2-bdd`
     *last release*: May 13, 2022,
     *status*: N/A,
     *requires*: N/A

     pytest_th2_bdd

  :pypi:`pytest-thawgun`
     *last release*: May 26, 2020,
     *status*: 3 - Alpha,
     *requires*: N/A

     Pytest plugin for time travel

  :pypi:`pytest-thread`
     *last release*: Jul 07, 2023,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-threadleak`
     *last release*: Jul 03, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     Detects thread leaks

  :pypi:`pytest-threadpool`
     *last release*: Mar 19, 2026,
     *status*: 4 - Beta,
     *requires*: pytest<=9.0.2,>=9.0.0

     Parallel test execution using threads — true parallelism on free-threaded Python, concurrent I/O on standard builds

  :pypi:`pytest-tick`
     *last release*: Aug 31, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=6.2.5,<7.0.0)

     Ticking on tests

  :pypi:`pytest_time`
     *last release*: Dec 01, 2025,
     *status*: 3 - Alpha,
     *requires*: pytest



  :pypi:`pytest-timeassert-ethan`
     *last release*: Dec 25, 2023,
     *status*: N/A,
     *requires*: pytest

     execution duration

  :pypi:`pytest-timeit`
     *last release*: Oct 13, 2016,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin to time test function runs

  :pypi:`pytest-timeout`
     *last release*: May 05, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest plugin to abort hanging tests

  :pypi:`pytest-timeouts`
     *last release*: Sep 21, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Linux-only Pytest plugin to control durations of various test case execution phases

  :pypi:`pytest-timer`
     *last release*: Dec 26, 2023,
     *status*: N/A,
     *requires*: pytest

     A timer plugin for pytest

  :pypi:`pytest-timestamper`
     *last release*: Mar 27, 2024,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to add a timestamp prefix to the pytest output

  :pypi:`pytest-timestamps`
     *last release*: Sep 11, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.3,<8.0)

     A simple plugin to view timestamps for each test

  :pypi:`pytest-timing-plugin`
     *last release*: Jul 21, 2025,
     *status*: N/A,
     *requires*: N/A

     pytest插件开发demo

  :pypi:`pytest-tiny-api-client`
     *last release*: Jan 04, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     The companion pytest plugin for tiny-api-client

  :pypi:`pytest-tinybird`
     *last release*: May 07, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=3.8.0

     A pytest plugin to report test results to tinybird

  :pypi:`pytest-tipsi-django`
     *last release*: Feb 05, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=6.0.0

     Better fixtures for django

  :pypi:`pytest-tipsi-testing`
     *last release*: Feb 04, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=3.3.0

     Better fixtures management. Various helpers

  :pypi:`pytest-tldr`
     *last release*: Nov 10, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin that limits the output to just the things you need.

  :pypi:`pytest-tm4j-reporter`
     *last release*: Sep 01, 2020,
     *status*: N/A,
     *requires*: pytest

     Cloud Jira Test Management (TM4J) PyTest reporter plugin

  :pypi:`pytest-tmnet`
     *last release*: Mar 01, 2022,
     *status*: N/A,
     *requires*: N/A

     A small example package

  :pypi:`pytest-tmp-files`
     *last release*: Dec 08, 2023,
     *status*: N/A,
     *requires*: pytest

     Utilities to create temporary file hierarchies in pytest.

  :pypi:`pytest-tmpfs`
     *last release*: Aug 29, 2022,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin that helps you on using a temporary filesystem for testing.

  :pypi:`pytest-tmreport`
     *last release*: Aug 12, 2022,
     *status*: N/A,
     *requires*: N/A

     this is a vue-element ui report for pytest

  :pypi:`pytest-tmux`
     *last release*: Sep 01, 2025,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin that enables tmux driven tests

  :pypi:`pytest-todo`
     *last release*: May 23, 2019,
     *status*: 4 - Beta,
     *requires*: pytest

     A small plugin for the pytest testing framework, marking TODO comments as failure

  :pypi:`pytest-tomato`
     *last release*: Mar 01, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A



  :pypi:`pytest-toolbelt`
     *last release*: Aug 12, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A

     This is just a collection of utilities for pytest, but don't really belong in pytest proper.

  :pypi:`pytest-toolbox`
     *last release*: Apr 07, 2018,
     *status*: N/A,
     *requires*: pytest (>=3.5.0)

     Numerous useful plugins for pytest.

  :pypi:`pytest-toolkit`
     *last release*: Jun 07, 2024,
     *status*: N/A,
     *requires*: N/A

     Useful utils for testing

  :pypi:`pytest-tools`
     *last release*: Oct 21, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Pytest tools

  :pypi:`pytest-topo`
     *last release*: Jun 05, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     Topological sorting for pytest

  :pypi:`pytest-tornado`
     *last release*: Jun 17, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.6)

     A py.test plugin providing fixtures and markers to simplify testing of asynchronous tornado applications.

  :pypi:`pytest-tornado5`
     *last release*: Nov 16, 2018,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.6)

     A py.test plugin providing fixtures and markers to simplify testing of asynchronous tornado applications.

  :pypi:`pytest-tornado-yen3`
     *last release*: Oct 15, 2018,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A py.test plugin providing fixtures and markers to simplify testing of asynchronous tornado applications.

  :pypi:`pytest-tornasync`
     *last release*: Jul 15, 2019,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0)

     py.test plugin for testing Python 3.5+ Tornado code

  :pypi:`pytest-trace`
     *last release*: Jun 19, 2022,
     *status*: N/A,
     *requires*: pytest (>=4.6)

     Save OpenTelemetry spans generated during testing

  :pypi:`pytest-track`
     *last release*: Feb 26, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.0)



  :pypi:`pytest-translate`
     *last release*: Apr 08, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest terminal output in your language — 134 languages supported, zero configuration

  :pypi:`pytest-translations`
     *last release*: Sep 11, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7)

     Test your translation files.

  :pypi:`pytest-travis-fold`
     *last release*: Nov 29, 2017,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.6.0)

     Folds captured output sections in Travis CI build log

  :pypi:`pytest-trello`
     *last release*: Nov 20, 2015,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Plugin for py.test that integrates trello using markers

  :pypi:`pytest-trepan`
     *last release*: Sep 11, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=4.0.0

     Pytest plugin for trepan debugger.

  :pypi:`pytest-trialtemp`
     *last release*: Jun 08, 2015,
     *status*: N/A,
     *requires*: N/A

     py.test plugin for using the same _trial_temp working directory as trial

  :pypi:`pytest-trio`
     *last release*: Nov 01, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.2.0)

     Pytest plugin for trio

  :pypi:`pytest-tripwire`
     *last release*: May 01, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.4.0; extra == "dev"

     Full-certainty test mocking: every call recorded and verified

  :pypi:`pytest-trytond`
     *last release*: Nov 04, 2022,
     *status*: 4 - Beta,
     *requires*: pytest (>=5)

     Pytest plugin for the Tryton server framework

  :pypi:`pytest-tspwplib`
     *last release*: Jan 08, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     A simple plugin to use with tspwplib

  :pypi:`pytest-tst`
     *last release*: Apr 27, 2022,
     *status*: N/A,
     *requires*: pytest (>=5.0.0)

     Customize pytest options, output and exit code to make it compatible with tst

  :pypi:`pytest-tstcls`
     *last release*: Mar 23, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Test Class Base

  :pypi:`pytest-tui`
     *last release*: Dec 08, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     Text User Interface (TUI) and HTML report for Pytest test runs

  :pypi:`pytest-tui-run`
     *last release*: Jun 05, 2026,
     *status*: N/A,
     *requires*: pytest

     TUI runner for \`pytest\` tests

  :pypi:`pytest-tui-runner`
     *last release*: Dec 12, 2025,
     *status*: N/A,
     *requires*: pytest<=9.0.1,>=7.4

     Textual-based terminal UI for running pytest tests

  :pypi:`pytest-tuitest`
     *last release*: Apr 11, 2025,
     *status*: N/A,
     *requires*: pytest>=7.4.0

     pytest plugin for testing TUI and regular command-line applications.

  :pypi:`pytest-tutorials`
     *last release*: Mar 11, 2023,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-twilio-conversations-client-mock`
     *last release*: Aug 02, 2022,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-twisted`
     *last release*: Sep 10, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=2.3

     A twisted plugin for pytest.

  :pypi:`pytest-ty`
     *last release*: Apr 24, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin to run the ty type checker

  :pypi:`pytest-typechecker`
     *last release*: Feb 04, 2022,
     *status*: N/A,
     *requires*: pytest (>=6.2.5,<7.0.0)

     Run type checkers on specified test files

  :pypi:`pytest-typed-schema-shot`
     *last release*: Jun 14, 2025,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for automatic JSON Schema generation and validation from examples

  :pypi:`pytest-typhoon-config`
     *last release*: Apr 07, 2022,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A Typhoon HIL plugin that facilitates test parameter configuration at runtime

  :pypi:`pytest-typhoon-polarion`
     *last release*: Feb 01, 2024,
     *status*: 4 - Beta,
     *requires*: N/A

     Typhoontest plugin for Siemens Polarion

  :pypi:`pytest-typhoon-xray`
     *last release*: Aug 15, 2023,
     *status*: 4 - Beta,
     *requires*: N/A

     Typhoon HIL plugin for pytest

  :pypi:`pytest-typing`
     *last release*: Mar 24, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest

     Test your types by running typecheckers on them.

  :pypi:`pytest-typing-runner`
     *last release*: May 31, 2025,
     *status*: N/A,
     *requires*: N/A

     Pytest plugin to make it easier to run and check python code against static type checkers

  :pypi:`pytest-tytest`
     *last release*: May 25, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=5.4.2)

     Typhoon HIL plugin for pytest

  :pypi:`pytest-tzshift`
     *last release*: Jun 25, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0

     A Pytest plugin that transparently re-runs tests under a matrix of timezones and locales.

  :pypi:`pytest-ubersmith`
     *last release*: Apr 13, 2015,
     *status*: N/A,
     *requires*: N/A

     Easily mock calls to ubersmith at the \`requests\` level.

  :pypi:`pytest-ui`
     *last release*: Jul 05, 2021,
     *status*: 4 - Beta,
     *requires*: pytest

     Text User Interface for running python tests

  :pypi:`pytest-ui-failed-screenshot`
     *last release*: Dec 06, 2022,
     *status*: N/A,
     *requires*: N/A

     UI自动测试失败时自动截图，并将截图加入到测试报告中

  :pypi:`pytest-ui-failed-screenshot-allure`
     *last release*: Dec 06, 2022,
     *status*: N/A,
     *requires*: N/A

     UI自动测试失败时自动截图，并将截图加入到Allure测试报告中

  :pypi:`pytest-uncollect-if`
     *last release*: Dec 26, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     A plugin to uncollect pytests tests rather than using skipif

  :pypi:`pytest-unflakable`
     *last release*: Apr 30, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=6.2.0

     Unflakable plugin for PyTest

  :pypi:`pytest-unhandled-exception-exit-code`
     *last release*: Jun 22, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=2.3)

     Plugin for py.test set a different exit code on uncaught exceptions

  :pypi:`pytest-unique`
     *last release*: Mar 27, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.0

     Pytest fixture to generate unique values.

  :pypi:`pytest-unittest-filter`
     *last release*: Jan 12, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.0)

     A pytest plugin for filtering unittest-based test classes

  :pypi:`pytest-unittest-id-runner`
     *last release*: Feb 09, 2025,
     *status*: N/A,
     *requires*: pytest>=6.0.0

     A pytest plugin to run tests using unittest-style test IDs

  :pypi:`pytest-unmagic`
     *last release*: Jun 04, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest fixtures with conventional import semantics

  :pypi:`pytest-unmarked`
     *last release*: Aug 27, 2019,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Run only unmarked tests

  :pypi:`pytest-unordered`
     *last release*: Jun 03, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Test equality of unordered collections in pytest

  :pypi:`pytest-unstable`
     *last release*: Sep 27, 2022,
     *status*: 4 - Beta,
     *requires*: N/A

     Set a test as unstable to return 0 even if it failed

  :pypi:`pytest-unused-fixtures`
     *last release*: Dec 23, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>7.3.2

     A pytest plugin to list unused fixtures after a test run.

  :pypi:`pytest-unused-port`
     *last release*: Oct 22, 2025,
     *status*: N/A,
     *requires*: pytest

     pytest fixture finding an unused local port

  :pypi:`pytest-upload-report`
     *last release*: Jun 18, 2021,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     pytest-upload-report is a plugin for pytest that upload your test report for test results.

  :pypi:`pytest-urllib3`
     *last release*: Mar 09, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7

     A pytest plugin to mock urllib3 requests

  :pypi:`pytest-utils`
     *last release*: Feb 02, 2023,
     *status*: 4 - Beta,
     *requires*: pytest (>=7.0.0,<8.0.0)

     Some helpers for pytest.

  :pypi:`pytest-uuid`
     *last release*: Feb 27, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin for mocking uuid.uuid4() calls

  :pypi:`pytest-vagrant`
     *last release*: Sep 07, 2021,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     A py.test plugin providing access to vagrant.

  :pypi:`pytest-valgrind`
     *last release*: May 19, 2021,
     *status*: N/A,
     *requires*: N/A



  :pypi:`pytest-variables`
     *last release*: Feb 01, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest plugin for providing variables to tests/fixtures

  :pypi:`pytest-variant`
     *last release*: Jun 06, 2022,
     *status*: N/A,
     *requires*: N/A

     Variant support for Pytest

  :pypi:`pytest-vcr`
     *last release*: Apr 26, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=3.6.0)

     Plugin for managing VCR.py cassettes

  :pypi:`pytest-vcr-delete-on-fail`
     *last release*: Feb 16, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=8.0.0,<9.0.0)

     A pytest plugin that automates vcrpy cassettes deletion on test failure.

  :pypi:`pytest-vcrpandas`
     *last release*: Jan 12, 2019,
     *status*: 4 - Beta,
     *requires*: pytest

     Test from HTTP interactions to dataframe processed.

  :pypi:`pytest-vcs`
     *last release*: Sep 22, 2022,
     *status*: 4 - Beta,
     *requires*: N/A



  :pypi:`pytest-venv`
     *last release*: Nov 23, 2023,
     *status*: 4 - Beta,
     *requires*: pytest

     py.test fixture for creating a virtual environment

  :pypi:`pytest-verbose-parametrize`
     *last release*: Nov 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     More descriptive output for parametrized py.test tests

  :pypi:`pytest-verify`
     *last release*: Oct 25, 2025,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     A pytest plugin for snapshot verification with optional visual diff viewer.

  :pypi:`pytest-ves`
     *last release*: Apr 18, 2026,
     *status*: 3 - Alpha,
     *requires*: N/A

     pytest fixtures and builders for ONAP VES 7.x events (fault, heartbeat, measurement, and more).

  :pypi:`pytest-vigil`
     *last release*: Apr 07, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=9.0.0

     A pytest plugin for enhanced test reliability and monitoring

  :pypi:`pytest-vimqf`
     *last release*: Feb 08, 2021,
     *status*: 4 - Beta,
     *requires*: pytest (>=6.2.2,<7.0.0)

     A simple pytest plugin that will shrink pytest output when specified, to fit vim quickfix window.

  :pypi:`pytest-virtualenv`
     *last release*: Nov 29, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Virtualenv fixture for py.test

  :pypi:`pytest-visionspec`
     *last release*: Jun 02, 2026,
     *status*: N/A,
     *requires*: pytest>=7.0

     Pytest plugin that auto-reports test results with screenshots to VisionSpec

  :pypi:`pytest-visual`
     *last release*: Nov 28, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0



  :pypi:`pytest-vitro`
     *last release*: May 25, 2026,
     *status*: N/A,
     *requires*: pytest>=8

     A pytest plugin to leverage the Vitro framework for test automation.

  :pypi:`pytest-vnc`
     *last release*: Nov 06, 2023,
     *status*: N/A,
     *requires*: pytest

     VNC client for Pytest

  :pypi:`pytest-voluptuous`
     *last release*: Jun 09, 2020,
     *status*: N/A,
     *requires*: pytest

     Pytest plugin for asserting data against voluptuous schema.

  :pypi:`pytest-vscodedebug`
     *last release*: Dec 04, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     A pytest plugin to easily enable debugging tests within Visual Studio Code

  :pypi:`pytest-vscode-pycharm-cls`
     *last release*: Feb 01, 2023,
     *status*: N/A,
     *requires*: pytest

     A PyTest helper to enable start remote debugger on test start or failure or when pytest.set_trace is used.

  :pypi:`pytest-vtestify`
     *last release*: Feb 04, 2025,
     *status*: N/A,
     *requires*: pytest

     A pytest plugin for visual assertion using SSIM and image comparison.

  :pypi:`pytest-vts`
     *last release*: Jun 05, 2019,
     *status*: N/A,
     *requires*: pytest (>=2.3)

     pytest plugin for automatic recording of http stubbed tests

  :pypi:`pytest-vulture`
     *last release*: Nov 25, 2024,
     *status*: N/A,
     *requires*: pytest>=7.0.0

     A pytest plugin to checks dead code with vulture

  :pypi:`pytest-vw`
     *last release*: Oct 07, 2015,
     *status*: 4 - Beta,
     *requires*: N/A

     pytest-vw makes your failing test cases succeed under CI tools scrutiny

  :pypi:`pytest-vyper`
     *last release*: May 28, 2020,
     *status*: 2 - Pre-Alpha,
     *requires*: N/A

     Plugin for the vyper smart contract language.

  :pypi:`pytest-wa-e2e-plugin`
     *last release*: Feb 18, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.5.0)

     Pytest plugin for testing whatsapp bots with end to end tests

  :pypi:`pytest-wake`
     *last release*: Nov 19, 2024,
     *status*: N/A,
     *requires*: pytest



  :pypi:`pytest-wardenbot`
     *last release*: May 26, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=8.0

     Pytest plugin for testing chatbots and LLM apps — prompt injection, jailbreaks, system-prompt leaks, hallucinations, brand drift.

  :pypi:`pytest-warmup`
     *last release*: Jun 02, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest<10,>=8.4

     Batch preparation and distribution of expensive test resources for pytest.

  :pypi:`pytest-watch`
     *last release*: May 20, 2018,
     *status*: N/A,
     *requires*: N/A

     Local continuous test runner with pytest and watchdog.

  :pypi:`pytest-watcher`
     *last release*: Jan 10, 2026,
     *status*: 4 - Beta,
     *requires*: N/A

     Automatically rerun your tests on file modifications

  :pypi:`pytest-watch-ng`
     *last release*: May 20, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=2.6.4

     Local continuous test runner with pytest and watchdog (maintained fork of pytest-watch with pyproject.toml support).

  :pypi:`pytest-watch-plugin`
     *last release*: Sep 12, 2024,
     *status*: N/A,
     *requires*: N/A

     Placeholder for internal package

  :pypi:`pytest_wdb`
     *last release*: Jul 04, 2016,
     *status*: N/A,
     *requires*: N/A

     Trace pytest tests with wdb to halt on error with --wdb.

  :pypi:`pytest-wdl`
     *last release*: Nov 17, 2020,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     Pytest plugin for testing WDL workflows.

  :pypi:`pytest-web`
     *last release*: May 10, 2026,
     *status*: 3 - Alpha,
     *requires*: pytest>=7.0

     Local web UI for running and monitoring pytest suites

  :pypi:`pytest-web3-data`
     *last release*: Oct 04, 2023,
     *status*: 4 - Beta,
     *requires*: pytest

     A pytest plugin to fetch test data from IPFS HTTP gateways during pytest execution.

  :pypi:`pytest-webdriver`
     *last release*: Oct 17, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Selenium webdriver fixture for py.test

  :pypi:`pytest-webstage`
     *last release*: Sep 20, 2024,
     *status*: N/A,
     *requires*: pytest<9.0,>=7.0

     Test web apps with pytest

  :pypi:`pytest-webtestpilot`
     *last release*: Dec 28, 2025,
     *status*: N/A,
     *requires*: pytest>=9.0.2

     Pytest plugin for running WebTestPilot JSON tests

  :pypi:`pytest-wetest`
     *last release*: Nov 10, 2018,
     *status*: 4 - Beta,
     *requires*: N/A

     Welian API Automation test framework pytest plugin

  :pypi:`pytest-when`
     *last release*: Sep 25, 2025,
     *status*: N/A,
     *requires*: pytest>=7.3.1

     Utility which makes mocking more readable and controllable

  :pypi:`pytest-whirlwind`
     *last release*: Jun 12, 2020,
     *status*: N/A,
     *requires*: N/A

     Testing Tornado.

  :pypi:`pytest-wholenodeid`
     *last release*: Aug 26, 2015,
     *status*: 4 - Beta,
     *requires*: pytest (>=2.0)

     pytest addon for displaying the whole node id for failures

  :pypi:`pytest-win32consoletitle`
     *last release*: Aug 08, 2021,
     *status*: N/A,
     *requires*: N/A

     Pytest progress in console title (Win32 only)

  :pypi:`pytest-winnotify`
     *last release*: Apr 22, 2016,
     *status*: N/A,
     *requires*: N/A

     Windows tray notifications for py.test results.

  :pypi:`pytest-wirefracture`
     *last release*: Dec 31, 2025,
     *status*: N/A,
     *requires*: N/A

     Pytest fixtures for wirefracture

  :pypi:`pytest-wiremock`
     *last release*: Mar 27, 2022,
     *status*: N/A,
     *requires*: pytest (>=7.1.1,<8.0.0)

     A pytest plugin for programmatically using wiremock in integration tests

  :pypi:`pytest-wiretap`
     *last release*: Mar 18, 2025,
     *status*: N/A,
     *requires*: pytest

     \`pytest\` plugin for recording call stacks

  :pypi:`pytest-with-docker`
     *last release*: Nov 09, 2021,
     *status*: N/A,
     *requires*: pytest

     pytest with docker helpers.

  :pypi:`pytest-workaround-12888`
     *last release*: Jan 15, 2025,
     *status*: N/A,
     *requires*: N/A

     forces an import of readline early in the process to work around pytest bug #12888

  :pypi:`pytest-workflow`
     *last release*: Mar 18, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest >=7.0.0

     A pytest plugin for configuring workflow/pipeline tests using YAML files

  :pypi:`pytest-xdist`
     *last release*: Jul 01, 2025,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7.0.0

     pytest xdist plugin for distributed testing, most importantly across multiple CPUs

  :pypi:`pytest-xdist-debug-for-graingert`
     *last release*: Jul 24, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.4.0)

     pytest xdist plugin for distributed testing and loop-on-failing modes

  :pypi:`pytest-xdist-forked`
     *last release*: Feb 10, 2020,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=4.4.0)

     forked from pytest-xdist

  :pypi:`pytest-xdist-gnumake`
     *last release*: Jun 22, 2025,
     *status*: N/A,
     *requires*: pytest

     A small example package

  :pypi:`pytest-xdist-load-testing`
     *last release*: Nov 22, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.4.2

     xdist scheduler to repeately run tests

  :pypi:`pytest-xdist-rate-limit`
     *last release*: Dec 31, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=8.4.2

     Shared state management and rate limiting for pytest-xdist workers

  :pypi:`pytest-xdist-tracker`
     *last release*: Nov 18, 2021,
     *status*: 3 - Alpha,
     *requires*: pytest (>=3.5.1)

     pytest plugin helps to reproduce failures for particular xdist node

  :pypi:`pytest-xdist-worker-stats`
     *last release*: Feb 16, 2026,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     A pytest plugin to list worker statistics after a xdist run.

  :pypi:`pytest-xdocker`
     *last release*: May 21, 2026,
     *status*: N/A,
     *requires*: pytest>=9.0.0

     Pytest fixture to run docker across test runs.

  :pypi:`pytest-xfaillist`
     *last release*: Sep 17, 2021,
     *status*: N/A,
     *requires*: pytest (>=6.2.2,<7.0.0)

     Maintain a xfaillist in an additional file to avoid merge-conflicts.

  :pypi:`pytest-xfiles`
     *last release*: Feb 27, 2018,
     *status*: N/A,
     *requires*: N/A

     Pytest fixtures providing data read from function, module or package related (x)files.

  :pypi:`pytest-xflaky`
     *last release*: Oct 14, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=8.2.1

     A simple plugin to use with pytest

  :pypi:`pytest-xhtml`
     *last release*: May 23, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=7

     pytest plugin for generating HTML reports

  :pypi:`pytest-xiuyu`
     *last release*: Jul 25, 2023,
     *status*: 5 - Production/Stable,
     *requires*: N/A

     This is a pytest plugin

  :pypi:`pytest-xlog`
     *last release*: May 31, 2020,
     *status*: 4 - Beta,
     *requires*: N/A

     Extended logging for test and decorators

  :pypi:`pytest-xlsx`
     *last release*: Aug 07, 2024,
     *status*: N/A,
     *requires*: pytest~=8.2.2

     pytest plugin for generating test cases by xlsx(excel)

  :pypi:`pytest-xml`
     *last release*: Nov 14, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=8.0.0

     Create simple XML results for parsing

  :pypi:`pytest-xpara`
     *last release*: Aug 07, 2024,
     *status*: 3 - Alpha,
     *requires*: pytest

     An extended parametrizing plugin of pytest.

  :pypi:`pytest-xprocess`
     *last release*: May 19, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=2.8

     A pytest plugin for managing processes across test runs.

  :pypi:`pytest-xray`
     *last release*: May 30, 2019,
     *status*: 3 - Alpha,
     *requires*: N/A



  :pypi:`pytest-xrayjira`
     *last release*: Mar 17, 2020,
     *status*: 3 - Alpha,
     *requires*: pytest (==4.3.1)



  :pypi:`pytest-xray-reporter`
     *last release*: May 21, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=7.0.0

     Pytest plugin for generating Xray JSON reports

  :pypi:`pytest-xray-server`
     *last release*: May 03, 2022,
     *status*: 3 - Alpha,
     *requires*: pytest (>=5.3.1)



  :pypi:`pytest-xstress`
     *last release*: Jun 01, 2024,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.0.0



  :pypi:`pytest-xtime`
     *last release*: Jun 05, 2025,
     *status*: 4 - Beta,
     *requires*: pytest

     pytest plugin for recording execution time

  :pypi:`pytest-xvfb`
     *last release*: Mar 12, 2025,
     *status*: 4 - Beta,
     *requires*: pytest>=2.8.1

     A pytest plugin to run Xvfb (or Xephyr/Xvnc) for tests.

  :pypi:`pytest-xvirt`
     *last release*: Dec 15, 2024,
     *status*: 4 - Beta,
     *requires*: pytest>=7.2.2

     A pytest plugin to virtualize test. For example to transparently running them on a remote box.

  :pypi:`pytest-yaml`
     *last release*: Oct 05, 2018,
     *status*: N/A,
     *requires*: pytest

     This plugin is used to load yaml output to your test using pytest framework.

  :pypi:`pytest-yaml-fei`
     *last release*: Jul 27, 2025,
     *status*: N/A,
     *requires*: pytest

     a pytest yaml allure package

  :pypi:`pytest-yaml-sanmu`
     *last release*: Sep 16, 2025,
     *status*: N/A,
     *requires*: pytest>=8.2.2

     Pytest plugin for generating test cases with YAML. In test cases, you can use markers, fixtures, variables, and even call Python functions.

  :pypi:`pytest-yamltree`
     *last release*: Mar 02, 2020,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     Create or check file/directory trees described by YAML

  :pypi:`pytest-yamlwsgi`
     *last release*: May 11, 2010,
     *status*: N/A,
     *requires*: N/A

     Run tests against wsgi apps defined in yaml

  :pypi:`pytest-yaml-yoyo`
     *last release*: Jun 19, 2023,
     *status*: N/A,
     *requires*: pytest (>=7.2.0)

     http/https API run by yaml

  :pypi:`pytest-yapf`
     *last release*: Jul 06, 2017,
     *status*: 4 - Beta,
     *requires*: pytest (>=3.1.1)

     Run yapf

  :pypi:`pytest-yapf3`
     *last release*: Mar 29, 2023,
     *status*: 5 - Production/Stable,
     *requires*: pytest (>=7)

     Validate your Python file format with yapf

  :pypi:`pytest-yield`
     *last release*: Jan 23, 2019,
     *status*: N/A,
     *requires*: N/A

     PyTest plugin to run tests concurrently, each \`yield\` switch context to other one

  :pypi:`pytest-yls`
     *last release*: Apr 09, 2025,
     *status*: N/A,
     *requires*: pytest<9.0.0,>=8.3.3

     Pytest plugin to test the YLS as a whole.

  :pypi:`pytest-youqu-playwright`
     *last release*: Jun 12, 2024,
     *status*: N/A,
     *requires*: pytest

     pytest-youqu-playwright

  :pypi:`pytest-yuk`
     *last release*: Mar 26, 2021,
     *status*: N/A,
     *requires*: pytest>=5.0.0

     Display tests you are uneasy with, using 🤢/🤮 for pass/fail of tests marked with yuk.

  :pypi:`pytest-zafira`
     *last release*: Sep 18, 2019,
     *status*: 5 - Production/Stable,
     *requires*: pytest (==4.1.1)

     A Zafira plugin for pytest

  :pypi:`pytest-zap`
     *last release*: May 12, 2014,
     *status*: 4 - Beta,
     *requires*: N/A

     OWASP ZAP plugin for py.test.

  :pypi:`pytest-zcc`
     *last release*: Jun 02, 2024,
     *status*: N/A,
     *requires*: N/A

     eee

  :pypi:`pytest-zebrunner`
     *last release*: Jul 04, 2024,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=4.5.0

     Pytest connector for Zebrunner reporting

  :pypi:`pytest-zeebe`
     *last release*: Feb 01, 2024,
     *status*: N/A,
     *requires*: pytest (>=7.4.2,<8.0.0)

     Pytest fixtures for testing Camunda 8 processes using a Zeebe test engine.

  :pypi:`pytest-zephyr-scale-integration`
     *last release*: Jun 26, 2025,
     *status*: N/A,
     *requires*: pytest

     A library for integrating Jira Zephyr Scale (Adaptavist\TM4J) with pytest

  :pypi:`pytest-zephyr-telegram`
     *last release*: Sep 30, 2024,
     *status*: N/A,
     *requires*: pytest==8.3.2

     Плагин для отправки данных автотестов в Телеграм и Зефир

  :pypi:`pytest-zest`
     *last release*: Nov 17, 2022,
     *status*: N/A,
     *requires*: N/A

     Zesty additions to pytest.

  :pypi:`pytest-zigzag`
     *last release*: Feb 27, 2019,
     *status*: 4 - Beta,
     *requires*: pytest (~=3.6)

     Extend py.test for RPC OpenStack testing.

  :pypi:`pytest-zulip`
     *last release*: May 07, 2022,
     *status*: 5 - Production/Stable,
     *requires*: pytest

     Pytest report plugin for Zulip

  :pypi:`pytest-zy`
     *last release*: Mar 24, 2024,
     *status*: N/A,
     *requires*: pytest~=7.2.0

     接口自动化测试框架

  :pypi:`tursu`
     *last release*: Mar 02, 2026,
     *status*: 5 - Production/Stable,
     *requires*: pytest>=8.3.5

     🎬 A pytest plugin that transpiles Gherkin feature files to Python using AST, enforcing typing for ease of use and debugging.
